@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: about.c 15598 2013-11-11 12:33:32Z yeti-dn $
+ *  @(#) $Id: about.c 20090 2017-07-26 09:11:23Z yeti-dn $
  *  Copyright (C) 2003 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -20,24 +20,24 @@
  */
 
 #include "config.h"
+#include <string.h>
 #include <gtk/gtk.h>
 #ifdef HAVE_GTKGLEXT
 #include <gtk/gtkgl.h>
 #endif
-#ifdef HAVE_FFTW3
-#include <fftw3.h>
-#endif
 #include <libgwyddion/gwymacros.h>
 #include <libgwyddion/gwyversion.h>
 #include <libgwydgets/gwystock.h>
 #include <libgwymodule/gwymoduleloader.h>
 #include "app.h"
-#include "authors.h"
 #include "gwyddion.h"
+#include "authors.h"
+#include "release.h"
 
 static void about_close  (void);
 static void fill_credits (GtkTextBuffer *buffer);
 static void fill_features(GtkTextBuffer *buffer);
+static void construct_datetime_info(GString *str);
 
 static GtkWidget *about = NULL;
 
@@ -48,6 +48,7 @@ gwy_app_about(void)
     GtkTextBuffer *buff;
     GtkTextIter iter;
     GString *str = g_string_new(NULL);
+    const gchar *verextra = "";
     gint size;
 
     if (about) {
@@ -86,10 +87,13 @@ gwy_app_about(void)
     widget = gtk_label_new(NULL);
     gtk_misc_set_alignment(GTK_MISC(widget), 0.0, 0.5);
     gtk_box_pack_start(GTK_BOX(vbox), widget, FALSE, FALSE, 0);
-    g_string_printf(str, "<big><b>%s %s</b></big>\n",
-                    g_get_application_name(), GWY_VERSION_STRING);
-    /* TRANSLATORS: %s is replaced with date in ISO format YYYY-MM-DD. */
-    g_string_append_printf(str, _("Released %s\n"), releasedate);
+    /* If we have unset release date but simple (non-date-extended) version
+     * string then we are not compiling from a public tarball. */
+    if (RELEASEDATE == 0 && strlen(GWY_VERSION_STRING) < 9)
+        verextra = "+SVN";
+    g_string_printf(str, "<span size='x-large' weight='bold'>%s %s%s</span>\n",
+                    g_get_application_name(), GWY_VERSION_STRING, verextra);
+    construct_datetime_info(str);
     g_string_append(str, _("An SPM data visualization and analysis tool."));
     gtk_label_set_markup(GTK_LABEL(widget), str->str);
 
@@ -257,15 +261,6 @@ fill_features(GtkTextBuffer *buffer)
                       _("not available\n"), TRUE);
 #endif
 
-#ifdef HAVE_FFTW3
-    s = g_strdup_printf("FFTW %s\n", fftw_version);
-    add_credits_block(buffer, _("Fast Fourier Transform"), s, FALSE);
-    g_free(s);
-#else
-    add_credits_block(buffer, _("Fast Fourier Transform"),
-                      _("built-in SimpleFFT\n"), TRUE);
-#endif
-
     b = FALSE;
 #if (REMOTE_BACKEND == REMOTE_NONE)
     cs = _("not available\n");
@@ -291,4 +286,48 @@ fill_features(GtkTextBuffer *buffer)
                           _("not available\n"), TRUE);
 }
 
+#if (RELEASEDATE == 0)
+static void
+construct_datetime_info(GString *str)
+{
+    GDate *gdate = g_date_new();
+    gchar buf[12];
+
+    g_date_set_parse(gdate, __DATE__);
+    if (!g_date_valid(gdate)) {
+        g_warning("Build date is invalid.");
+        /* Avoid trigraphs. */
+        g_snprintf(buf, sizeof(buf), "%.10s", "????" "-" "??" "-" "??");
+    }
+    else {
+        g_snprintf(buf, sizeof(buf), "%04u-%02u-%02u",
+                   (guint)g_date_get_year(gdate),
+                   (guint)g_date_get_month(gdate),
+                   (guint)g_date_get_day(gdate));
+    }
+
+    g_string_append(str, "<b>");
+    /* TRANSLATORS: %s is replaced with date in ISO format YYYY-MM-DD. */
+    g_string_append_printf(str, _("Development version, built %s"), buf);
+    g_string_append(str, "</b>\n");
+    g_date_free(gdate);
+}
+#else
+static void
+construct_datetime_info(GString *str)
+{
+    guint year = RELEASEDATE/0x10000u;
+    guint month = (RELEASEDATE/0x100u % 0x100);
+    guint day = RELEASEDATE % 0x100;
+    gchar buf[12];
+
+    g_snprintf(buf, sizeof(buf), "%04x-%02x-%02x", year, month, day);
+
+    g_string_append(str, "<b>");
+    /* TRANSLATORS: %s is replaced with date in ISO format YYYY-MM-DD. */
+    g_string_append_printf(str, _("Released %s"), buf);
+    g_string_append(str, "</b>\n");
+}
+#endif
+
 /* vim: set cin et ts=4 sw=4 cino=>1s,e0,n0,f0,{0,}0,^0,\:1s,=0,g1s,h0,t0,+1s,c3,(0,u0 : */
