@@ -1,6 +1,6 @@
 /*
- *  @(#) $Id: app.c 19043 2016-10-08 18:58:43Z yeti-dn $
- *  Copyright (C) 2003-2006,2013-2016 David Necas (Yeti), Petr Klapetek.
+ *  @(#) $Id: app.c 20119 2017-07-31 10:36:59Z yeti-dn $
+ *  Copyright (C) 2003-2006,2013-2017 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -388,6 +388,8 @@ _gwy_app_data_window_setup(GwyDataWindow *data_window)
                              corner_menu);
     g_signal_connect(data_window, "configure-event",
                      G_CALLBACK(gwy_app_data_window_configured), NULL);
+    g_signal_connect(data_window, "size-allocate",
+                     G_CALLBACK(gwy_app_data_window_configured), NULL);
 
     settings = gwy_app_settings_get();
     if (gwy_container_gis_enum_by_name(settings, "/app/default-range-type",
@@ -754,6 +756,8 @@ _gwy_app_graph_window_setup(GwyGraphWindow *graph_window,
                       GUINT_TO_POINTER(prefix));
     g_signal_connect(graph_window, "configure-event",
                      G_CALLBACK(gwy_app_graph_window_configured), NULL);
+    g_signal_connect(graph_window, "size-allocate",
+                     G_CALLBACK(gwy_app_graph_window_configured), NULL);
 }
 
 static gboolean
@@ -828,11 +832,25 @@ _gwy_app_3d_window_setup(Gwy3DWindow *window3d)
 {
     GtkTooltips *tooltips;
     Gwy3DView *view3d;
-    GtkWidget *button;
+    GwyContainer *settings;
+    gboolean autocrop = FALSE;
+    GtkWidget *button, *check, *label;
 
     gwy_app_add_main_accel_group(GTK_WINDOW(window3d));
     tooltips = gwy_3d_window_class_get_tooltips();
 
+    button = gtk_button_new_with_mnemonic(_("Set as Default"));
+    gtk_tooltips_set_tip(tooltips, button,
+                         _("Set the current view setup as the default"), NULL);
+    gwy_3d_window_add_action_widget(window3d, button);
+    g_signal_connect_swapped(button, "clicked",
+                             G_CALLBACK(gwy_app_3d_window_set_defaults),
+                             window3d);
+
+    label = gtk_label_new(NULL);
+    gtk_widget_set_size_request(label, 12, 0);
+    gwy_3d_window_add_action_widget(window3d, label);
+
     button = gwy_stock_like_button_new(gwy_sgettext("verb|Save"),
                                        GTK_STOCK_SAVE);
     gtk_tooltips_set_tip(tooltips, button,
@@ -846,13 +864,14 @@ _gwy_app_3d_window_setup(Gwy3DWindow *window3d)
     g_signal_connect_swapped(button, "clicked",
                              G_CALLBACK(gwy_app_3d_window_export), window3d);
 
-    button = gtk_button_new_with_mnemonic(_("Set as Default"));
-    gtk_tooltips_set_tip(tooltips, button,
-                         _("Set the current view setup as the default"), NULL);
-    gwy_3d_window_add_action_widget(window3d, button);
-    g_signal_connect_swapped(button, "clicked",
-                             G_CALLBACK(gwy_app_3d_window_set_defaults),
-                             window3d);
+    settings = gwy_app_settings_get();
+    gwy_container_gis_boolean_by_name(settings, "/app/3d/autocrop", &autocrop);
+    check = gtk_check_button_new_with_mnemonic(_("_Autocrop"));
+    gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check), autocrop);
+    gwy_3d_window_add_action_widget(window3d, check);
+    gtk_tooltips_set_tip(tooltips, check,
+                         _("Remove white borders from exported image"), NULL);
+    g_object_set_data(G_OBJECT(window3d), "gwy-app-autocrop-check", check);
 
     gwy_app_3d_window_add_overlay_menu(window3d);
     gwy_help_add_to_window(GTK_WINDOW(window3d), "opengl-3d-view", NULL,
@@ -865,6 +884,8 @@ _gwy_app_3d_window_setup(Gwy3DWindow *window3d)
 
     g_signal_connect(window3d, "configure-event",
                      G_CALLBACK(gwy_app_3d_window_configured), NULL);
+    g_signal_connect(window3d, "size-allocate",
+                     G_CALLBACK(gwy_app_3d_window_configured), NULL);
 }
 
 static gboolean
@@ -911,20 +932,19 @@ gwy_app_3d_window_add_overlay_menu(Gwy3DWindow *gwy3dwindow)
               g_quark_to_string(view->data_key),
               4);
     g_strlcat(refkey, "3d/data2ref", sizeof(refkey));
-    if (gwy_container_gis_string_by_name(view->data, refkey, &key)) {
+    if (gwy_container_gis_string_by_name(view->data, refkey, &key))
         data2_ref = g_quark_from_string(key);
-    };
 
     for (nids = ids; *nids != -1; nids++) {
         if (gwy_app_get_data_key_for_id(*nids) == data2_ref) {
             activeid = *nids;
             break;
-        };
+        }
         if (gwy_app_get_data_key_for_id(*nids) == view->data_key
             && activeid == -1) {
             activeid = *nids;
-        };
-    };
+        }
+    }
     g_free(ids);
 
     gwy_data_chooser_set_active(GWY_DATA_CHOOSER(menu), view->data, activeid);
@@ -1003,8 +1023,8 @@ gwy_app_3d_window_set_data2(Gwy3DWindow *gwy3dwindow,
     }
     else {
         gwy_3d_view_set_ovlay(view, ovplay, 1);
-    };
-};
+    }
+}
 
 /* callback for the chooser created by gwy_app_3d_window_add_overlay_menu */
 static void
@@ -1063,7 +1083,43 @@ gwy_app_3d_window_data2_filter(GwyContainer *data2,
 
     return !gwy_data_field_check_compatibility(data_field2, data_field1,
                                                GWY_DATA_COMPATIBILITY_RES);
-};
+}
+
+static GdkPixbuf*
+autocrop_3d_export_pixbuf(GdkPixbuf *pixbuf)
+{
+    gint width, height, stride, bpp, i, j, top, left, right, bot;
+    guchar *data, *row;
+
+    width = gdk_pixbuf_get_width(pixbuf);
+    height = gdk_pixbuf_get_height(pixbuf);
+    stride = gdk_pixbuf_get_rowstride(pixbuf);
+    bpp = gdk_pixbuf_get_n_channels(pixbuf);
+    data = gdk_pixbuf_get_pixels(pixbuf);
+
+    top = height-1;
+    bot = 0;
+    left = width-1;
+    right = 0;
+
+    for (i = 0; i < height; i++) {
+        row = data + i*stride;
+        for (j = 0; j < bpp*width; j++) {
+            if (row[j] != 0xff) {
+                top = MIN(top, i);
+                bot = MAX(bot, i);
+                left = MIN(left, j/bpp);
+                right = MAX(right, j/bpp);
+            }
+        }
+    }
+
+    if (top > bot || left > right)
+        top = bot = left = right = 0;
+
+    return gdk_pixbuf_new_subpixbuf(pixbuf,
+                                    left, top, right+1 - left, bot+1 - top);
+}
 
 static void
 gwy_app_save_3d_export(GtkWidget *dialog,
@@ -1071,9 +1127,11 @@ gwy_app_save_3d_export(GtkWidget *dialog,
                        Gwy3DWindow *gwy3dwindow)
 {
     gchar *filename_sys, *filename_utf8, *s, *filetype = NULL;
-    GdkPixbuf *pixbuf;
+    GdkPixbuf *pixbuf, *cropped_pixbuf;
     GtkWidget *gwy3dview;
     GError *err = NULL;
+    GwyContainer *settings;
+    gboolean autocrop = FALSE;
 
     if (response != GTK_RESPONSE_OK) {
         gtk_widget_destroy(dialog);
@@ -1084,21 +1142,29 @@ gwy_app_save_3d_export(GtkWidget *dialog,
     filename_sys = gtk_file_chooser_get_filename(GTK_FILE_CHOOSER(dialog));
     gtk_widget_destroy(dialog);
 
+    settings = gwy_app_settings_get();
+    gwy_container_gis_boolean_by_name(settings, "/app/3d/autocrop", &autocrop);
+
     pixbuf = gwy_3d_view_get_pixbuf(GWY_3D_VIEW(gwy3dview));
+    if (autocrop)
+        cropped_pixbuf = autocrop_3d_export_pixbuf(pixbuf);
+    else
+        cropped_pixbuf = g_object_ref(pixbuf);
+
     filename_utf8 = g_filename_to_utf8(filename_sys, -1, NULL, NULL, NULL);
     if ((s = strrchr(filename_utf8, '.'))) {
         filetype = g_ascii_strdown(s+1, -1);
-        if (gwy_strequal(filetype, "jpg")) {
+        if (gwy_stramong(filetype, "jpg", "jpeg", NULL)) {
             g_free(filetype);
             filetype = g_strdup("jpeg");
         }
-        else if (gwy_strequal(filetype, "tif")) {
+        else if (gwy_stramong(filetype, "tif", "tiff", NULL)) {
             g_free(filetype);
             filetype = g_strdup("tiff");
         }
     }
-    if (!gdk_pixbuf_save(pixbuf, filename_sys, filetype ? filetype : "png",
-                         &err, NULL)) {
+    if (!gdk_pixbuf_save(cropped_pixbuf, filename_sys,
+                         filetype ? filetype : "png", &err, NULL)) {
         dialog = gtk_message_dialog_new(NULL,
                                         GTK_DIALOG_DESTROY_WITH_PARENT,
                                         GTK_MESSAGE_ERROR,
@@ -1113,6 +1179,7 @@ gwy_app_save_3d_export(GtkWidget *dialog,
     }
     g_free(filetype);
     g_free(filename_sys);
+    g_object_unref(cropped_pixbuf);
     g_object_unref(pixbuf);
     g_free(g_object_get_data(G_OBJECT(gwy3dwindow), "gwy-app-export-filename"));
     g_object_set_data(G_OBJECT(gwy3dwindow), "gwy-app-export-filename",
@@ -1122,15 +1189,20 @@ gwy_app_save_3d_export(GtkWidget *dialog,
 static void
 gwy_app_3d_window_export(Gwy3DWindow *gwy3dwindow)
 {
-    GwyContainer *data;
-    GtkWidget *dialog, *gwy3dview;
+    GwyContainer *data, *settings;
+    GtkWidget *dialog, *gwy3dview, *check;
     const guchar *filename_utf8;
     gchar *filename_sys;
-    gboolean need_free_utf = FALSE;
+    gboolean need_free_utf = FALSE, autocrop;
 
     gwy3dview = gwy_3d_window_get_3d_view(gwy3dwindow);
     data = gwy_3d_view_get_data(GWY_3D_VIEW(gwy3dview));
 
+    check = g_object_get_data(G_OBJECT(gwy3dwindow), "gwy-app-autocrop-check");
+    autocrop = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(check));
+    settings = gwy_app_settings_get();
+    gwy_container_set_boolean_by_name(settings, "/app/3d/autocrop", autocrop);
+
     filename_utf8 = g_object_get_data(G_OBJECT(gwy3dwindow),
                                       "gwy-app-export-filename");
     if (!filename_utf8) {
@@ -1167,6 +1239,89 @@ gwy_app_3d_window_export(Gwy3DWindow *gwy3dwindow)
     gtk_widget_show_all(dialog);
 }
 
+static void
+save_or_restore_object_properties(GObject *object,
+                                  GwyContainer *settings,
+                                  gboolean restore, GString *key)
+{
+    GParamSpec **pspecs;
+    gdouble dblvalue;
+    gboolean boolvalue;
+    gint enumvalue;
+    const guchar *strvalue;
+    const gchar *name;
+    guint len, i, nspecs;
+    GType valtype;
+
+    pspecs = g_object_class_list_properties(G_OBJECT_GET_CLASS(object),
+                                            &nspecs);
+    if (!g_str_has_suffix(key->str, "/"))
+        g_string_append_c(key, '/');
+    len = key->len;
+
+    for (i = 0; i < nspecs; i++) {
+        if (!(pspecs[i]->flags & G_PARAM_WRITABLE)
+            || (pspecs[i]->flags & (G_PARAM_CONSTRUCT_ONLY | G_PARAM_PRIVATE)))
+            continue;
+
+        valtype = pspecs[i]->value_type;
+        name = pspecs[i]->name;
+        g_string_truncate(key, len);
+        g_string_append(key, name);
+
+        if (valtype == G_TYPE_BOOLEAN) {
+            if (restore) {
+                if (gwy_container_gis_boolean_by_name(settings, key->str,
+                                                      &boolvalue))
+                    g_object_set(object, name, boolvalue, NULL);
+            }
+            else {
+                g_object_get(object, name, &boolvalue, NULL);
+                gwy_container_set_boolean_by_name(settings, key->str,
+                                                  boolvalue);
+            }
+        }
+        else if (valtype == G_TYPE_DOUBLE) {
+            if (restore) {
+                if (gwy_container_gis_double_by_name(settings, key->str,
+                                                     &dblvalue))
+                    g_object_set(object, name, dblvalue, NULL);
+            }
+            else {
+                g_object_get(object, name, &dblvalue, NULL);
+                gwy_container_set_double_by_name(settings, key->str, dblvalue);
+            }
+        }
+        else if (valtype == G_TYPE_STRING) {
+            if (restore) {
+                if (gwy_container_gis_string_by_name(settings, key->str,
+                                                     &strvalue))
+                    g_object_set(object, name, strvalue, NULL);
+            }
+            else {
+                g_object_get(object, name, &strvalue, NULL);
+                gwy_container_set_string_by_name(settings, key->str, strvalue);
+            }
+        }
+        else if (g_type_is_a(valtype, G_TYPE_ENUM)) {
+            if (restore) {
+                if (gwy_container_gis_enum_by_name(settings, key->str,
+                                                   &enumvalue))
+                    g_object_set(object, name, enumvalue, NULL);
+            }
+            else {
+                g_object_get(object, name, &enumvalue, NULL);
+                gwy_container_set_enum_by_name(settings, key->str, enumvalue);
+            }
+        }
+        else {
+            g_warning("Unhandled property %s", name);
+        }
+    }
+
+    g_free(pspecs);
+}
+
 static void
 gwy_app_3d_window_set_defaults(Gwy3DWindow *window)
 {
@@ -1185,30 +1340,10 @@ gwy_app_3d_window_set_defaults(Gwy3DWindow *window)
     data = gwy_3d_view_get_data(view);
 
     settings = gwy_app_settings_get();
-    gwy_container_set_boolean_by_name(settings, "/app/3d/axes-visible",
-                                      setup->axes_visible);
-    gwy_container_set_boolean_by_name(settings, "/app/3d/labels-visible",
-                                      setup->labels_visible);
-    gwy_container_set_boolean_by_name(settings, "/app/3d/fmscale-visible",
-                                      setup->fmscale_visible);
-    gwy_container_set_double_by_name(settings, "/app/3d/rotation-x",
-                                     setup->rotation_x);
-    gwy_container_set_double_by_name(settings, "/app/3d/rotation-y",
-                                     setup->rotation_y);
-    gwy_container_set_double_by_name(settings, "/app/3d/scale",
-                                     setup->scale);
-    gwy_container_set_double_by_name(settings, "/app/3d/z-scale",
-                                     setup->z_scale);
-    gwy_container_set_double_by_name(settings, "/app/3d/light-phi",
-                                     setup->light_phi);
-    gwy_container_set_double_by_name(settings, "/app/3d/light-theta",
-                                     setup->light_theta);
-    gwy_container_set_double_by_name(settings, "/app/3d/line-width",
-                                     setup->line_width);
-    gwy_container_set_enum_by_name(settings, "/app/3d/visualization",
-                                   setup->visualization);
-    gwy_container_set_enum_by_name(settings, "/app/3d/projection",
-                                   setup->projection);
+    str = g_string_new(NULL);
+
+    g_string_assign(str, "/app/3d/");
+    save_or_restore_object_properties(G_OBJECT(setup), settings, FALSE, str);
 
     lay = G_OBJECT(window->dataov_menu);
     toggle = GTK_TOGGLE_BUTTON(g_object_get_data(lay, "m"));
@@ -1216,55 +1351,16 @@ gwy_app_3d_window_set_defaults(Gwy3DWindow *window)
                                       gtk_toggle_button_get_active(toggle));
 
     prefix = gwy_3d_view_get_setup_prefix(view);
-    str = g_string_new(NULL);
     for (i = 0; i < G_N_ELEMENTS(labels_3d); i++) {
         Gwy3DLabel *label = NULL;
-        gdouble deltax, deltay, rotation, size;
-        gboolean fixed_size;
-        guint len;
-        gchar *text;
 
         g_string_printf(str, "%s/%s", prefix, labels_3d[i].key);
         gwy_container_gis_object_by_name(data, str->str, &label);
         if (!label)
             continue;
 
-        g_object_get(label,
-                     "delta-x", &deltax,
-                     "delta-y", &deltay,
-                     "rotation", &rotation,
-                     "size", &size,
-                     "fixed-size", &fixed_size,
-                     "text", &text,
-                     NULL);
         g_string_printf(str, "/app/3d/labels/%s/", labels_3d[i].key);
-        len = str->len;
-
-        g_string_append(str, "delta-x");
-        gwy_container_set_double_by_name(settings, str->str, deltax);
-        g_string_truncate(str, len);
-
-        g_string_append(str, "delta-y");
-        gwy_container_set_double_by_name(settings, str->str, deltay);
-        g_string_truncate(str, len);
-
-        g_string_append(str, "rotation");
-        gwy_container_set_double_by_name(settings, str->str, rotation);
-        g_string_truncate(str, len);
-
-        g_string_append(str, "size");
-        gwy_container_set_double_by_name(settings, str->str, size);
-        g_string_truncate(str, len);
-
-        g_string_append(str, "fixed-size");
-        gwy_container_set_boolean_by_name(settings, str->str, fixed_size);
-        g_string_truncate(str, len);
-
-        /* g_object_get() allocates it, gwy_container_set_string_by_name()
-         * consumes it. */
-        g_string_append(str, "text");
-        gwy_container_set_string_by_name(settings, str->str, text);
-        g_string_truncate(str, len);
+        save_or_restore_object_properties(G_OBJECT(label), settings, FALSE, str);
     }
 
     g_string_free(str, TRUE);
@@ -1276,75 +1372,30 @@ _gwy_app_3d_view_init_setup(GwyContainer *container,
 {
     GwyContainer *settings;
     Gwy3DSetup *setup;
-    Gwy3DProjection projection;
-    Gwy3DVisualization visualization;
-    gdouble dblvalue;
-    gboolean boolvalue;
     GString *str;
-    gchar *key;
     guint i;
 
     g_return_val_if_fail(GWY_IS_CONTAINER(container), FALSE);
     g_return_val_if_fail(setup_prefix, FALSE);
 
-    key = g_strconcat(setup_prefix, "/setup", NULL);
-    if (gwy_container_gis_object_by_name(container, key, &setup)
+    str = g_string_new(setup_prefix);
+    g_string_append(str, "/setup");
+    if (gwy_container_gis_object_by_name(container, str->str, &setup)
         && GWY_IS_3D_SETUP(setup)) {
-        g_free(key);
+        g_string_free(str, TRUE);
         return FALSE;
     }
 
     setup = gwy_3d_setup_new();
+    gwy_container_set_object_by_name(container, str->str, setup);
+
     settings = gwy_app_settings_get();
-    if (gwy_container_gis_boolean_by_name(settings, "/app/3d/axes-visible",
-                                          &boolvalue))
-        g_object_set(setup, "axes-visible", boolvalue, NULL);
-    if (gwy_container_gis_boolean_by_name(settings, "/app/3d/labels-visible",
-                                          &boolvalue))
-        g_object_set(setup, "labels-visible", boolvalue, NULL);
-    if (gwy_container_gis_boolean_by_name(settings, "/app/3d/fmscale-visible",
-                                          &boolvalue))
-        g_object_set(setup, "fmscale-visible", boolvalue, NULL);
-    if (gwy_container_gis_double_by_name(settings, "/app/3d/rotation-x",
-                                         &dblvalue))
-        g_object_set(setup, "rotation-x", dblvalue, NULL);
-    if (gwy_container_gis_double_by_name(settings, "/app/3d/rotation-y",
-                                         &dblvalue))
-        g_object_set(setup, "rotation-y", dblvalue, NULL);
-    if (gwy_container_gis_double_by_name(settings, "/app/3d/scale",
-                                         &dblvalue))
-        g_object_set(setup, "scale", dblvalue, NULL);
-    if (gwy_container_gis_double_by_name(settings, "/app/3d/z-scale",
-                                         &dblvalue))
-        g_object_set(setup, "z-scale", dblvalue, NULL);
-    if (gwy_container_gis_double_by_name(settings, "/app/3d/light-phi",
-                                         &dblvalue))
-        g_object_set(setup, "light-phi", dblvalue, NULL);
-    if (gwy_container_gis_double_by_name(settings, "/app/3d/light-theta",
-                                         &dblvalue))
-        g_object_set(setup, "light-theta", dblvalue, NULL);
-    if (gwy_container_gis_double_by_name(settings, "/app/3d/line-width",
-                                         &dblvalue))
-        g_object_set(setup, "line-width", dblvalue, NULL);
-    if (gwy_container_gis_enum_by_name(settings, "/app/3d/visualization",
-                                       &visualization))
-        g_object_set(setup, "visualization", visualization, NULL);
-    if (gwy_container_gis_enum_by_name(settings, "/app/3d/projection",
-                                       &projection))
-        g_object_set(setup, "projection", projection, NULL);
-
-    gwy_container_set_object_by_name(container, key, setup);
+    g_string_assign(str, "/app/3d/");
+    save_or_restore_object_properties(G_OBJECT(setup), settings, TRUE, str);
     g_object_unref(setup);
-    g_free(key);
 
-    str = g_string_new(NULL);
     for (i = 0; i < G_N_ELEMENTS(labels_3d); i++) {
         Gwy3DLabel *label = NULL;
-        gdouble dbl;
-        gboolean flag;
-        guint len;
-        const guchar *text;
-
         g_string_printf(str, "%s/%s", setup_prefix, labels_3d[i].key);
         gwy_container_gis_object_by_name(container, str->str, &label);
         if (label)
@@ -1352,40 +1403,10 @@ _gwy_app_3d_view_init_setup(GwyContainer *container,
 
         label = gwy_3d_label_new(labels_3d[i].default_text);
         gwy_container_set_object_by_name(container, str->str, label);
-        g_object_unref(label);
 
         g_string_printf(str, "/app/3d/labels/%s/", labels_3d[i].key);
-        len = str->len;
-
-        g_string_append(str, "delta-x");
-        if (gwy_container_gis_double_by_name(settings, str->str, &dbl))
-            g_object_set(label, "delta-x", dbl, NULL);
-        g_string_truncate(str, len);
-
-        g_string_append(str, "delta-y");
-        if (gwy_container_gis_double_by_name(settings, str->str, &dbl))
-            g_object_set(label, "delta-y", dbl, NULL);
-        g_string_truncate(str, len);
-
-        g_string_append(str, "rotation");
-        if (gwy_container_gis_double_by_name(settings, str->str, &dbl))
-            g_object_set(label, "rotation", dbl, NULL);
-        g_string_truncate(str, len);
-
-        g_string_append(str, "size");
-        if (gwy_container_gis_double_by_name(settings, str->str, &dbl))
-            g_object_set(label, "size", dbl, NULL);
-        g_string_truncate(str, len);
-
-        g_string_append(str, "fixed-size");
-        if (gwy_container_gis_boolean_by_name(settings, str->str, &flag))
-            g_object_set(label, "fixed-size", flag, NULL);
-        g_string_truncate(str, len);
-
-        g_string_append(str, "text");
-        if (gwy_container_gis_string_by_name(settings, str->str, &text))
-            g_object_set(label, "text", text, NULL);
-        g_string_truncate(str, len);
+        save_or_restore_object_properties(G_OBJECT(label), settings, TRUE, str);
+        g_object_unref(label);
     }
 
     g_string_free(str, TRUE);
@@ -1469,6 +1490,8 @@ _gwy_app_brick_window_setup(GwyDataWindow *data_window)
 
     g_signal_connect(data_window, "configure-event",
                      G_CALLBACK(gwy_app_brick_window_configured), NULL);
+    g_signal_connect(data_window, "size-allocate",
+                     G_CALLBACK(gwy_app_brick_window_configured), NULL);
 }
 
 static gboolean
@@ -1659,36 +1682,42 @@ change_brick_preview(GwyDataWindow *data_window)
         return;
     }
 
-    if (type == BRICK_PREVIEW_MEAN)
+    if (type == BRICK_PREVIEW_MEAN) {
         gwy_brick_mean_plane(brick, preview,
                              0, 0, 0,
                              brick->xres, brick->yres, -1,
                              TRUE);
-    else if (type == BRICK_PREVIEW_MINIMUM)
+    }
+    else if (type == BRICK_PREVIEW_MINIMUM) {
         gwy_brick_min_plane(brick, preview,
                             0, 0, 0,
                             brick->xres, brick->yres, -1,
                             TRUE);
-    else if (type == BRICK_PREVIEW_MAXIMUM)
+    }
+    else if (type == BRICK_PREVIEW_MAXIMUM) {
         gwy_brick_max_plane(brick, preview,
                             0, 0, 0,
                             brick->xres, brick->yres, -1,
                             TRUE);
-    else if (type == BRICK_PREVIEW_MINPOS)
+    }
+    else if (type == BRICK_PREVIEW_MINPOS) {
         gwy_brick_minpos_plane(brick, preview,
-                            0, 0, 0,
-                            brick->xres, brick->yres, -1,
-                            TRUE);
-    else if (type == BRICK_PREVIEW_MAXPOS)
+                               0, 0, 0,
+                               brick->xres, brick->yres, -1,
+                               TRUE);
+    }
+    else if (type == BRICK_PREVIEW_MAXPOS) {
         gwy_brick_maxpos_plane(brick, preview,
-                            0, 0, 0,
-                            brick->xres, brick->yres, -1,
-                            TRUE);
-    else if (type == BRICK_PREVIEW_RMS)
+                               0, 0, 0,
+                               brick->xres, brick->yres, -1,
+                               TRUE);
+    }
+    else if (type == BRICK_PREVIEW_RMS) {
         gwy_brick_rms_plane(brick, preview,
                             0, 0, 0,
                             brick->xres, brick->yres, -1,
                             TRUE);
+    }
     else if (type == BRICK_PREVIEW_CHANNEL) {
         GQuark quark = gwy_app_get_data_key_for_id(cid);
         GObject *field = gwy_container_get_object(cdata, quark);
@@ -1880,6 +1909,8 @@ _gwy_app_surface_window_setup(GwyDataWindow *data_window)
 
     g_signal_connect(data_window, "configure-event",
                      G_CALLBACK(gwy_app_surface_window_configured), NULL);
+    g_signal_connect(data_window, "size-allocate",
+                     G_CALLBACK(gwy_app_surface_window_configured), NULL);
 }
 
 static gboolean
@@ -2462,7 +2493,7 @@ restore_data_window_zoom(GwyDataWindow *data_window)
     gtk_widget_size_request(GTK_WIDGET(data_view), &req);
     scw = gdk_screen_get_width(screen);
     sch = gdk_screen_get_height(screen);
-    newrelsize = MAX(req.width/scw, req.height/sch);
+    newrelsize = MAX(scale*req.width/scw, scale*req.height/sch);
     gwy_debug("restoring data window: "
               "relsize %g, zoom %g, request %dx%d, newrelsize %g",
               relsize, scale, req.width, req.height, newrelsize);
@@ -2542,26 +2573,37 @@ _gwy_app_get_n_recent_files(void)
 void
 gwy_app_init_widget_styles(void)
 {
-    gtk_rc_parse_string(/* data window corner buttons */
-                        "style \"cornerbutton\" {\n"
-                        "GtkButton::focus_line_width = 0\n"
-                        "GtkButton::focus_padding = 0\n"
-                        "}\n"
-                        "widget \"*.cornerbutton\" style \"cornerbutton\"\n"
-                        "\n"
-                        /* toolbox group header buttons */
-                        "style \"toolboxheader\" {\n"
-                        "GtkButton::focus_line_width = 0\n"
-                        "GtkButton::focus_padding = 0\n"
-                        "}\n"
-                        "widget \"*.toolboxheader\" style \"toolboxheader\"\n"
-                        "\n"
-                        /* toolbox single-item menubars */
-                        "style \"toolboxmenubar\" {\n"
-                        "GtkMenuBar::shadow_type = 0\n"
-                        "}\n"
-                        "widget \"*.toolboxmenubar\" style \"toolboxmenubar\"\n"
-                        "\n");
+    static const gchar gwyrcstyle[] =
+        /* data window corner buttons */
+        "style \"cornerbutton\" {\n"
+        "GtkButton::focus_line_width = 0\n"
+        "GtkButton::focus_padding = 0\n"
+        "}\n"
+        "widget \"*.cornerbutton\" style \"cornerbutton\"\n"
+        "\n"
+        /* toolbox group header buttons */
+        "style \"toolboxheader\" {\n"
+        "GtkButton::focus_line_width = 0\n"
+        "GtkButton::focus_padding = 0\n"
+        "}\n"
+        "widget \"*.toolboxheader\" style \"toolboxheader\"\n"
+        "\n"
+        /* toolbox single-item menubars */
+        "style \"toolboxmenubar\" {\n"
+        "GtkMenuBar::shadow_type = 0\n"
+        "}\n"
+        "widget \"*.toolboxmenubar\" style \"toolboxmenubar\"\n"
+        "\n"
+        /* toolbox buttons (XXX: perhaps we would like to inherit the style for
+         * toolbar buttons, but I am unable to extract the right style using
+         * gtk_rc_get_style_by_paths() and gtk_style_get()...) */
+        "style \"toolboxbutton\" {\n"
+        "GtkButton::inner_border = {1, 1, 2, 2}\n"
+        "}\n"
+        "widget \"*.toolboxbutton\" style \"toolboxbutton\"\n"
+        "\n";
+
+    gtk_rc_parse_string(gwyrcstyle);
 }
 
 /**
