@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: data-browser-aux.c 19043 2016-10-08 18:58:43Z yeti-dn $
+ *  @(#) $Id: data-browser-aux.c 19329 2016-11-29 15:32:12Z yeti-dn $
  *  Copyright (C) 2006-2016 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -1576,6 +1576,143 @@ _gwy_app_find_ids_unmanaged(GwyContainer *data,
     return (gint*)g_array_free(fidata.ids, FALSE);
 }
 
+static void
+sync_one_data_item(GwyContainer *source, GwyContainer *dest,
+                   gint from_id, gint to_id,
+                   GwyDataItem what, gboolean delete_too)
+{
+    /* FIXME: copy ALL selections */
+    static const gchar *sel_keys[] = {
+        "point", "pointer", "line", "rectangle", "ellipse", "lattice", "path",
+    };
+    static const gchar *cal_keys[] = {
+        "cal_xerr", "cal_yerr", "cal_zerr", "cal_xunc", "cal_yunc", "cal_zunc",
+    };
+
+    gchar key_from[40];
+    gchar key_to[40];
+    const guchar *name;
+    GwyRGBA rgba;
+    guint enumval;
+    gboolean boolval;
+    GObject *obj;
+    gdouble dbl;
+    guint i;
+
+    switch (what) {
+        case GWY_DATA_ITEM_GRADIENT:
+        g_snprintf(key_from, sizeof(key_from), "/%d/base/palette", from_id);
+        g_snprintf(key_to, sizeof(key_to), "/%d/base/palette", to_id);
+        if (gwy_container_gis_string_by_name(source, key_from, &name))
+            gwy_container_set_string_by_name(dest, key_to, g_strdup(name));
+        else if (delete_too)
+            gwy_container_remove_by_name(dest, key_to);
+        break;
+
+        case GWY_DATA_ITEM_MASK_COLOR:
+        g_snprintf(key_from, sizeof(key_from), "/%d/mask", from_id);
+        g_snprintf(key_to, sizeof(key_to), "/%d/mask", to_id);
+        if (gwy_rgba_get_from_container(&rgba, source, key_from))
+            gwy_rgba_store_to_container(&rgba, dest, key_to);
+        else if (delete_too)
+            gwy_rgba_remove_from_container(dest, key_to);
+        break;
+
+        case GWY_DATA_ITEM_TITLE:
+        g_snprintf(key_from, sizeof(key_from), "/%d/data/title", from_id);
+        g_snprintf(key_to, sizeof(key_to), "/%d/data/title", to_id);
+        if (gwy_container_gis_string_by_name(source, key_from, &name))
+            gwy_container_set_string_by_name(dest, key_to, g_strdup(name));
+        else if (delete_too)
+            gwy_container_remove_by_name(dest, key_to);
+        break;
+
+        case GWY_DATA_ITEM_RANGE:
+        g_snprintf(key_from, sizeof(key_from), "/%d/base/min", from_id);
+        g_snprintf(key_to, sizeof(key_to), "/%d/base/min", to_id);
+        if (gwy_container_gis_double_by_name(source, key_from, &dbl))
+            gwy_container_set_double_by_name(dest, key_to, dbl);
+        else if (delete_too)
+            gwy_container_remove_by_name(dest, key_to);
+        g_snprintf(key_from, sizeof(key_from), "/%d/base/max", from_id);
+        g_snprintf(key_to, sizeof(key_to), "/%d/base/max", to_id);
+        if (gwy_container_gis_double_by_name(source, key_from, &dbl)) {
+            gwy_container_set_double_by_name(dest, key_to, dbl);
+        }
+        else if (delete_too)
+            gwy_container_remove_by_name(dest, key_to);
+        case GWY_DATA_ITEM_RANGE_TYPE:
+        g_snprintf(key_from, sizeof(key_from), "/%d/base/range-type",
+                   from_id);
+        g_snprintf(key_to, sizeof(key_to), "/%d/base/range-type", to_id);
+        if (gwy_container_gis_enum_by_name(source, key_from, &enumval))
+            gwy_container_set_enum_by_name(dest, key_to, enumval);
+        else if (delete_too)
+            gwy_container_remove_by_name(dest, key_to);
+        break;
+
+        case GWY_DATA_ITEM_REAL_SQUARE:
+        g_snprintf(key_from, sizeof(key_from), "/%d/data/realsquare",
+                   from_id);
+        g_snprintf(key_to, sizeof(key_to), "/%d/data/realsquare", to_id);
+        if (gwy_container_gis_boolean_by_name(source, key_from, &boolval)
+            && boolval)
+            gwy_container_set_boolean_by_name(dest, key_to, boolval);
+        else if (delete_too)
+            gwy_container_remove_by_name(dest, key_to);
+        break;
+
+        case GWY_DATA_ITEM_META:
+        g_snprintf(key_from, sizeof(key_from), "/%d/meta", from_id);
+        g_snprintf(key_to, sizeof(key_to), "/%d/meta", to_id);
+        if (gwy_container_gis_object_by_name(source, key_from, &obj)) {
+            obj = gwy_serializable_duplicate(obj);
+            gwy_container_set_object_by_name(dest, key_to, obj);
+            g_object_unref(obj);
+        }
+        else if (delete_too)
+            gwy_container_remove_by_name(dest, key_to);
+        break;
+
+        case GWY_DATA_ITEM_CALDATA:
+        for (i = 0; i < G_N_ELEMENTS(cal_keys); i++) {
+            g_snprintf(key_from, sizeof(key_from), "/%d/data/%s", 
+                       from_id, cal_keys[i]);
+            g_snprintf(key_to, sizeof(key_to), "/%d/data/%s", 
+                       to_id, cal_keys[i]);
+            if (gwy_container_gis_object_by_name(source, key_from, &obj)) {
+                obj = gwy_serializable_duplicate(obj);
+                gwy_container_set_object_by_name(dest, key_to, obj);
+                g_object_unref(obj);
+            }
+            else if (delete_too)
+                gwy_container_remove_by_name(dest, key_to);
+        }
+        break;
+
+        case GWY_DATA_ITEM_SELECTIONS:
+        for (i = 0; i < G_N_ELEMENTS(sel_keys); i++) {
+            g_snprintf(key_from, sizeof(key_from), "/%d/select/%s",
+                       from_id, sel_keys[i]);
+            g_snprintf(key_to, sizeof(key_to), "/%d/select/%s",
+                       to_id, sel_keys[i]);
+            if (gwy_container_gis_object_by_name(source, key_from, &obj)
+                && gwy_selection_get_data(GWY_SELECTION(obj), NULL)) {
+                obj = gwy_serializable_duplicate(obj);
+                gwy_container_set_object_by_name(dest, key_to, obj);
+                g_object_unref(obj);
+            }
+            else if (delete_too)
+                gwy_container_remove_by_name(dest, key_to);
+        }
+        break;
+
+        default:
+        g_assert_not_reached();
+        break;
+    }
+}
+
 /**
  * gwy_app_sync_data_items:
  * @source: Source container.
@@ -1586,7 +1723,7 @@ _gwy_app_find_ids_unmanaged(GwyContainer *data,
  *              them, %FALSE to copy only.
  * @...: 0-terminated list of #GwyDataItem values defining the items to copy.
  *
- * Synchronizes auxiliary data items between data containers.
+ * Synchronizes auxiliary channel items between data containers.
  **/
 void
 gwy_app_sync_data_items(GwyContainer *source,
@@ -1596,25 +1733,8 @@ gwy_app_sync_data_items(GwyContainer *source,
                         gboolean delete_too,
                         ...)
 {
-    /* FIXME: copy ALL selections */
-    static const gchar *sel_keys[] = {
-        "point", "pointer", "line", "rectangle", "ellipse", "lattice", "path",
-    };
-    static const gchar *cal_keys[] = {
-        "cal_xerr", "cal_yerr", "cal_zerr", "cal_xunc", "cal_yunc", "cal_zunc",
-    };
-
     GwyDataItem what;
-    gchar key_from[40];
-    gchar key_to[40];
-    const guchar *name;
-    GwyRGBA rgba;
-    guint enumval;
-    gboolean boolval;
-    GObject *obj;
-    gdouble dbl;
     va_list ap;
-    guint i;
 
     g_return_if_fail(GWY_IS_CONTAINER(source));
     g_return_if_fail(GWY_IS_CONTAINER(dest));
@@ -1623,123 +1743,47 @@ gwy_app_sync_data_items(GwyContainer *source,
         return;
 
     va_start(ap, delete_too);
-    while ((what = va_arg(ap, GwyDataItem))) {
-        switch (what) {
-            case GWY_DATA_ITEM_GRADIENT:
-            g_snprintf(key_from, sizeof(key_from), "/%d/base/palette", from_id);
-            g_snprintf(key_to, sizeof(key_to), "/%d/base/palette", to_id);
-            if (gwy_container_gis_string_by_name(source, key_from, &name))
-                gwy_container_set_string_by_name(dest, key_to, g_strdup(name));
-            else if (delete_too)
-                gwy_container_remove_by_name(dest, key_to);
-            break;
-
-            case GWY_DATA_ITEM_MASK_COLOR:
-            g_snprintf(key_from, sizeof(key_from), "/%d/mask", from_id);
-            g_snprintf(key_to, sizeof(key_to), "/%d/mask", to_id);
-            if (gwy_rgba_get_from_container(&rgba, source, key_from))
-                gwy_rgba_store_to_container(&rgba, dest, key_to);
-            else if (delete_too)
-                gwy_rgba_remove_from_container(dest, key_to);
-            break;
-
-            case GWY_DATA_ITEM_TITLE:
-            g_snprintf(key_from, sizeof(key_from), "/%d/data/title", from_id);
-            g_snprintf(key_to, sizeof(key_to), "/%d/data/title", to_id);
-            if (gwy_container_gis_string_by_name(source, key_from, &name))
-                gwy_container_set_string_by_name(dest, key_to, g_strdup(name));
-            else if (delete_too)
-                gwy_container_remove_by_name(dest, key_to);
-            break;
-
-            case GWY_DATA_ITEM_RANGE:
-            g_snprintf(key_from, sizeof(key_from), "/%d/base/min", from_id);
-            g_snprintf(key_to, sizeof(key_to), "/%d/base/min", to_id);
-            if (gwy_container_gis_double_by_name(source, key_from, &dbl))
-                gwy_container_set_double_by_name(dest, key_to, dbl);
-            else if (delete_too)
-                gwy_container_remove_by_name(dest, key_to);
-            g_snprintf(key_from, sizeof(key_from), "/%d/base/max", from_id);
-            g_snprintf(key_to, sizeof(key_to), "/%d/base/max", to_id);
-            if (gwy_container_gis_double_by_name(source, key_from, &dbl)) {
-                gwy_container_set_double_by_name(dest, key_to, dbl);
-            }
-            else if (delete_too)
-                gwy_container_remove_by_name(dest, key_to);
-            case GWY_DATA_ITEM_RANGE_TYPE:
-            g_snprintf(key_from, sizeof(key_from), "/%d/base/range-type",
-                       from_id);
-            g_snprintf(key_to, sizeof(key_to), "/%d/base/range-type", to_id);
-            if (gwy_container_gis_enum_by_name(source, key_from, &enumval))
-                gwy_container_set_enum_by_name(dest, key_to, enumval);
-            else if (delete_too)
-                gwy_container_remove_by_name(dest, key_to);
-            break;
-
-            case GWY_DATA_ITEM_REAL_SQUARE:
-            g_snprintf(key_from, sizeof(key_from), "/%d/data/realsquare",
-                       from_id);
-            g_snprintf(key_to, sizeof(key_to), "/%d/data/realsquare", to_id);
-            if (gwy_container_gis_boolean_by_name(source, key_from, &boolval)
-                && boolval)
-                gwy_container_set_boolean_by_name(dest, key_to, boolval);
-            else if (delete_too)
-                gwy_container_remove_by_name(dest, key_to);
-            break;
-
-            case GWY_DATA_ITEM_META:
-            g_snprintf(key_from, sizeof(key_from), "/%d/meta", from_id);
-            g_snprintf(key_to, sizeof(key_to), "/%d/meta", to_id);
-            if (gwy_container_gis_object_by_name(source, key_from, &obj)) {
-                obj = gwy_serializable_duplicate(obj);
-                gwy_container_set_object_by_name(dest, key_to, obj);
-                g_object_unref(obj);
-            }
-            else if (delete_too)
-                gwy_container_remove_by_name(dest, key_to);
-            break;
-
-            case GWY_DATA_ITEM_CALDATA:
-            for (i = 0; i < G_N_ELEMENTS(cal_keys); i++) {
-                g_snprintf(key_from, sizeof(key_from), "/%d/data/%s", 
-                           from_id, cal_keys[i]);
-                g_snprintf(key_to, sizeof(key_to), "/%d/data/%s", 
-                           to_id, cal_keys[i]);
-                if (gwy_container_gis_object_by_name(source, key_from, &obj)) {
-                    obj = gwy_serializable_duplicate(obj);
-                    gwy_container_set_object_by_name(dest, key_to, obj);
-                    g_object_unref(obj);
-                }
-                else if (delete_too)
-                    gwy_container_remove_by_name(dest, key_to);
-            }
-            break;
-
-            case GWY_DATA_ITEM_SELECTIONS:
-            for (i = 0; i < G_N_ELEMENTS(sel_keys); i++) {
-                g_snprintf(key_from, sizeof(key_from), "/%d/select/%s",
-                           from_id, sel_keys[i]);
-                g_snprintf(key_to, sizeof(key_to), "/%d/select/%s",
-                           to_id, sel_keys[i]);
-                if (gwy_container_gis_object_by_name(source, key_from, &obj)
-                    && gwy_selection_get_data(GWY_SELECTION(obj), NULL)) {
-                    obj = gwy_serializable_duplicate(obj);
-                    gwy_container_set_object_by_name(dest, key_to, obj);
-                    g_object_unref(obj);
-                }
-                else if (delete_too)
-                    gwy_container_remove_by_name(dest, key_to);
-            }
-            break;
-
-            default:
-            g_assert_not_reached();
-            break;
-        }
-    }
+    while ((what = va_arg(ap, GwyDataItem)))
+        sync_one_data_item(source, dest, from_id, to_id, what, delete_too);
     va_end(ap);
 }
 
+/**
+ * gwy_app_sync_data_itemsv:
+ * @source: Source container.
+ * @dest: Target container (may be identical to source).
+ * @from_id: Data number to copy items from.
+ * @to_id: Data number to copy items to.
+ * @delete_too: %TRUE to delete items in target if source does not contain
+ *              them, %FALSE to copy only.
+ * @items: List of #GwyDataItem values defining the items to copy.
+ * @nitems: Number of items in @items.
+ *
+ * Synchronizes auxiliary channel items between data containers.
+ *
+ * Since: 2.48
+ **/
+void
+gwy_app_sync_data_itemsv(GwyContainer *source,
+                         GwyContainer *dest,
+                         gint from_id,
+                         gint to_id,
+                         gboolean delete_too,
+                         const GwyDataItem *items,
+                         guint nitems)
+{
+    guint i;
+
+    g_return_if_fail(GWY_IS_CONTAINER(source));
+    g_return_if_fail(GWY_IS_CONTAINER(dest));
+    g_return_if_fail(from_id >= 0 && to_id >= 0);
+    if (source == dest && from_id == to_id)
+        return;
+
+    for (i = 0; i < nitems; i++)
+        sync_one_data_item(source, dest, from_id, to_id, items[i], delete_too);
+}
+
 /**
  * gwy_app_data_browser_copy_channel:
  * @source: Source container.
