@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: data-browser.h 18862 2016-08-21 11:15:58Z yeti-dn $
+ *  @(#) $Id: data-browser.h 19329 2016-11-29 15:32:12Z yeti-dn $
  *  Copyright (C) 2006-2015 David Necas (Yeti), Petr Klapetek, Chris Anderson
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net, sidewinderasu@gmail.com.
  *
@@ -172,6 +172,13 @@ void   gwy_app_sync_data_items               (GwyContainer *source,
                                               gint to_id,
                                               gboolean delete_too,
                                               ...);
+void   gwy_app_sync_data_itemsv              (GwyContainer *source,
+                                              GwyContainer *dest,
+                                              gint from_id,
+                                              gint to_id,
+                                              gboolean delete_too,
+                                              const GwyDataItem *items,
+                                              guint nitems);
 gint   gwy_app_data_browser_copy_channel     (GwyContainer *source,
                                               gint id,
                                               GwyContainer *dest);
