@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: file.c 19229 2016-11-10 16:28:18Z yeti-dn $
+ *  @(#) $Id: file.c 19456 2017-02-07 12:39:07Z yeti-dn $
  *  Copyright (C) 2003-2006 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -177,7 +177,7 @@ warn_broken_load_func(const gchar *name,
                       GwyContainer *data)
 {
     static const gchar *broken_file_funcs[] = {
-        "ambfile", "dimensionfile",
+        "dimensionfile",
         /*"at present no modules are broken and this is not a file type name",*/
     };
 
@@ -266,6 +266,13 @@ gwy_app_file_load_real(const gchar *filename_utf8,
         gwy_data_validate(data,
                           GWY_DATA_VALIDATE_CORRECT
                           | GWY_DATA_VALIDATE_NO_REPORT);
+        if (_gwy_app_enforce_graph_abscissae_order(data)) {
+            if (!gwy_stramong(name, "gwyfile", NULL)) {
+                g_warning("Module %s did not import file %s with graph curve "
+                          "points in ascending order.  Please fix the module.",
+                          name, filename_utf8);
+            }
+        }
         if (do_add_loaded)
             gwy_app_file_add_loaded(data, filename_utf8, filename_sys);
     }
