@@ -1,6 +1,6 @@
 /*
- *  @(#) $Id: gwyappfilechooser.c 19043 2016-10-08 18:58:43Z yeti-dn $
- *  Copyright (C) 2003-2016 David Necas (Yeti), Petr Klapetek.
+ *  @(#) $Id: gwyappfilechooser.c 20124 2017-07-31 15:31:21Z yeti-dn $
+ *  Copyright (C) 2003-2017 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -22,6 +22,7 @@
 #include "config.h"
 #include <string.h>
 #include <stdlib.h>
+#include <glib/gstdio.h>
 #include <gtk/gtk.h>
 #include <libgwyddion/gwymacros.h>
 #include <libgwyddion/gwymath.h>
@@ -31,6 +32,10 @@
 #include <app/gwyapp.h>
 #include "gwyappinternal.h"
 
+/* Do not try to full-preview files larger than this.  100 MB is an arbitrary
+ * limit but most < 100 MB files seem to be readable fairly quickly. */
+#define MAX_FILE_SIZE_FOR_PREVIEW (96UL*1024UL*1024UL)
+
 enum {
     BLOODY_ICON_VIEW_PADDING = 2*6,
     PADDED_THUMBNAIL_SIZE = TMS_NORMAL_THUMB_SIZE + BLOODY_ICON_VIEW_PADDING
@@ -274,6 +279,10 @@ _gwy_app_file_chooser_get(GtkFileChooserAction action)
                      G_CALLBACK(gwy_app_file_chooser_save_position), NULL);
     gwy_app_restore_window_position(GTK_WINDOW(chooser), chooser->prefix, TRUE);
 
+    /* Does not filter when initially shown without this. */
+    if (action == GTK_FILE_CHOOSER_ACTION_OPEN)
+        enforce_refilter(chooser);
+
     return *instance;
 }
 
@@ -695,9 +704,11 @@ gwy_app_file_chooser_open_filter(const GtkFileFilterInfo *filter_info,
     gboolean ok = TRUE;
 
     if (ok && chooser->glob->len) {
-        gchar *filename_utf8 = g_filename_to_utf8(filename, -1,
+        gchar *basename = g_path_get_basename(filename);
+        gchar *filename_utf8 = g_filename_to_utf8(basename, -1,
                                                   NULL, NULL, NULL);
 
+        g_free(basename);
         if (filename_utf8) {
             if (chooser->glob_casesens)
                 ok = g_pattern_match_string(chooser->pattern, filename_utf8);
@@ -912,6 +923,8 @@ gwy_app_file_chooser_update_preview(GwyAppFileChooser *chooser)
     GdkPixbuf *pixbuf;
     GtkTreeIter iter;
     gchar *filename_sys, *basename_sys, *filename_utf8;
+    gboolean file_too_large = TRUE;
+    GStatBuf st;
 
     gwy_app_file_chooser_free_preview(chooser);
 
@@ -949,6 +962,9 @@ gwy_app_file_chooser_update_preview(GwyAppFileChooser *chooser)
     }
     gtk_label_set_text(GTK_LABEL(chooser->preview_type), "");
 
+    if (g_stat(filename_sys, &st) == 0)
+        file_too_large = (st.st_size > MAX_FILE_SIZE_FOR_PREVIEW);
+
     pixbuf = _gwy_app_recent_file_try_thumbnail(filename_sys);
     g_free(filename_sys);
 
@@ -966,14 +982,19 @@ gwy_app_file_chooser_update_preview(GwyAppFileChooser *chooser)
                  NULL);
     gtk_list_store_insert_with_values(GTK_LIST_STORE(model), &iter, -1,
                                       COLUMN_PIXBUF, pixbuf,
-                                      COLUMN_FILEINFO, _("…"),
+                                      COLUMN_FILEINFO,
+                                      (file_too_large
+                                       ? _("File too large for preview")
+                                       : _("…")),
                                       -1);
     g_object_unref(pixbuf);
 
-    chooser->full_preview_id
-        = g_timeout_add_full(G_PRIORITY_LOW, 250,
-                             gwy_app_file_chooser_do_full_preview, chooser,
-                             NULL);
+    if (!file_too_large) {
+        chooser->full_preview_id
+            = g_timeout_add_full(G_PRIORITY_LOW, 250,
+                                 gwy_app_file_chooser_do_full_preview, chooser,
+                                 NULL);
+    }
 }
 
 static guint
@@ -1353,7 +1374,7 @@ gwy_app_file_chooser_do_full_preview(gpointer user_data)
         if ((n = count_ids(xyz_ids)))
             g_string_append_printf(str, ", %d xyz", n);
         if ((n = count_ids(channel_ids)))
-            g_string_append_printf(str, ", %d ch", n);
+            g_string_append_printf(str, ", %d img", n);
         if ((n = count_ids(graph_ids)))
             g_string_append_printf(str, ", %d gr", n);
         if ((n = count_ids(sps_ids)))
