@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: gwyddion.c 18975 2016-09-20 13:28:39Z yeti-dn $
+ *  @(#) $Id: gwyddion.c 20076 2017-07-15 18:26:38Z dn2010 $
  *  Copyright (C) 2003-2006 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -62,19 +62,22 @@ typedef struct {
 static gboolean open_command_line_files         (gint n,
                                                  gchar **args);
 static gboolean open_directory_at_startup       (gpointer user_data);
+static void     block_modules                   (const gchar *modules_to_block);
 static gboolean show_tip_at_startup             (gpointer user_data);
 static gint     check_command_line_files        (gint n,
                                                  gchar **args);
 static void     print_help                      (void);
 static void     process_preinit_options         (int *argc,
                                                  char ***argv,
-                                                 GwyAppOptions *options);
+                                                 GwyAppOptions *options,
+                                                 gchar **modules_to_block);
 static void     debug_time                      (GTimer *timer,
                                                  const gchar *task);
 static void     setup_locale_from_win32_registry(void);
 static void     warn_broken_settings_file       (GtkWidget *parent,
                                                  const gchar *settings_file,
                                                  const gchar *reason);
+static void     check_broken_modules            (GtkWidget *parent);
 static void     gwy_app_init                    (int *argc,
                                                  char ***argv);
 static void     gwy_app_set_window_icon         (void);
@@ -97,6 +100,7 @@ main(int argc, char *argv[])
     GtkWidget *toolbox;
     gchar **module_dirs;
     gchar *settings_file, *recent_file_file, *accel_file;
+    gchar *modules_to_block = NULL;
     gboolean has_settings, settings_ok = FALSE;
     gboolean opening_files = FALSE, show_tips = FALSE;
     GwyContainer *settings;
@@ -107,7 +111,7 @@ main(int argc, char *argv[])
     g_unsetenv("UBUNTU_MENUPROXY");
     timer = g_timer_new();
 
-    process_preinit_options(&argc, &argv, &app_options);
+    process_preinit_options(&argc, &argv, &app_options, &modules_to_block);
     gwy_app_setup_logging((app_options.log_to_file
                            ? GWY_APP_LOGGING_TO_FILE : 0)
                           | (app_options.log_to_console
@@ -169,6 +173,8 @@ main(int argc, char *argv[])
     debug_time(timer, "load settings");
 
     gwy_app_splash_set_message(_("Registering modules"));
+    block_modules(modules_to_block);
+    GWY_FREE(modules_to_block);
     module_dirs = gwy_app_settings_get_module_dirs();
     gwy_module_register_modules((const gchar**)module_dirs);
     /* The Python initialisation somehow overrides SIGINT and Gwyddion can no
@@ -190,7 +196,11 @@ main(int argc, char *argv[])
         return !nfailures;
     }
 
-    gwy_app_splash_set_message(_("Initializing GUI"));
+    /* Destroy splash before creating UI.  Opposite order of actions can
+     * apparently lead to strange errors. */
+    gwy_app_splash_finish();
+    debug_time(timer, "destroy splash");
+
     toolbox = gwy_app_toolbox_window_create();
     debug_time(timer, "create toolbox");
     gwy_app_data_browser_restore();
@@ -198,8 +208,6 @@ main(int argc, char *argv[])
     /* A dirty trick, it constructs the recent files menu as a side effect. */
     gwy_app_recent_file_list_update(NULL, NULL, NULL, 0);
     debug_time(timer, "create recent files menu");
-    gwy_app_splash_finish();
-    debug_time(timer, "destroy splash");
 
     /* Win32 does not give programs a reasonable physical cwd.  So try to set
      * something reasonable here.  Do it before opening files from arguments
@@ -228,6 +236,8 @@ main(int argc, char *argv[])
         g_clear_error(&settings_err);
     }
 
+    check_broken_modules(toolbox);
+
     /* Move focus to toolbox */
     gtk_window_present(GTK_WINDOW(toolbox));
     debug_time(timer, "show toolbox");
@@ -281,7 +291,8 @@ main(int argc, char *argv[])
 static void
 process_preinit_options(int *argc,
                         char ***argv,
-                        GwyAppOptions *options)
+                        GwyAppOptions *options,
+                        gchar **modules_to_block)
 {
     int i, j;
     gboolean ignore = FALSE;
@@ -356,6 +367,19 @@ process_preinit_options(int *argc,
                 options->check = TRUE;
                 continue;
             }
+            if (g_str_has_prefix((*argv)[i], "--disable-modules=")) {
+                const gchar *v = (*argv)[i] + strlen("--disable-modules=");
+                if (strlen(v)) {
+                    if (*modules_to_block) {
+                        gchar *s = g_strconcat(*modules_to_block, ",", v, NULL);
+                        g_free(*modules_to_block);
+                        *modules_to_block = s;
+                    }
+                    else
+                        *modules_to_block = g_strdup(v);
+                }
+                continue;
+            }
         }
 
         j++;
@@ -385,6 +409,8 @@ print_help(void)
 "     --no-log-to-file       Do not write messages to any file.\n"
 "     --log-to-console       Print messages to console\n"
 "     --no-log-to-console    Do not print messages to console.\n"
+"     --disable-modules=MODNAME1,MODNAME2,...\n"
+"                            Prevent registration of given modules.\n"
 "     --debug-objects        Catch leaking objects (devel only).\n"
 "     --startup-time         Measure time of startup tasks.\n"
         );
@@ -431,12 +457,11 @@ warn_broken_settings_file(GtkWidget *parent,
 {
     GtkWidget *dialog;
 
-    dialog = gtk_message_dialog_new
-                 (GTK_WINDOW(parent),
-                  GTK_DIALOG_DESTROY_WITH_PARENT,
-                  GTK_MESSAGE_WARNING,
-                  GTK_BUTTONS_OK,
-                  _("Could not read settings."));
+    dialog = gtk_message_dialog_new(GTK_WINDOW(parent),
+                                    GTK_DIALOG_DESTROY_WITH_PARENT,
+                                    GTK_MESSAGE_WARNING,
+                                    GTK_BUTTONS_OK,
+                                    _("Could not read settings."));
     gtk_message_dialog_format_secondary_text
         (GTK_MESSAGE_DIALOG(dialog),
          _("Settings file `%s' cannot be read: %s\n\n"
@@ -450,6 +475,54 @@ warn_broken_settings_file(GtkWidget *parent,
     gtk_widget_destroy(dialog);
 }
 
+static void
+count_failures(gpointer mod_fail_info, gpointer user_data)
+{
+    GwyModuleFailureInfo *finfo = (GwyModuleFailureInfo*)mod_fail_info;
+    guint *n = (guint*)user_data;
+
+    /* Ignore user's modules. */
+    if (!g_str_has_prefix(finfo->filename, gwy_get_user_dir()))
+        (*n)++;
+}
+
+static void
+check_broken_modules(GtkWidget *parent)
+{
+    GtkWidget *dialog;
+    gchar *moduledir;
+    guint n = 0;
+
+    gwy_module_failure_foreach(count_failures, &n);
+    /* Usually, the number should either be less than 3 or huge. */
+    if (n < 8)
+        return;
+
+    dialog = gtk_message_dialog_new(GTK_WINDOW(parent),
+                                    GTK_DIALOG_DESTROY_WITH_PARENT,
+                                    GTK_MESSAGE_WARNING,
+                                    GTK_BUTTONS_OK,
+                                    _("Many modules (%u) failed to register."),
+                                    n);
+    moduledir = gwy_find_self_dir("modules");
+    gtk_message_dialog_format_secondary_text
+        (GTK_MESSAGE_DIALOG(dialog),
+         _("Most likely Gwyddion was not upgraded correctly.  "
+           "Instead, one installation was just overwritten with another, "
+           "and now it is a mess.\n\n"
+           "Please remove completely the module directory\n\n"
+           "%s\n\n"
+           "and reinstall Gwyddion.\n\n"
+           "See Info → Module Browser for specific errors."),
+         moduledir);
+    g_free(moduledir);
+    /* parent is usually in a screen corner, centering on it looks ugly */
+    gtk_window_set_position(GTK_WINDOW(dialog), GTK_WIN_POS_CENTER);
+    gtk_window_present(GTK_WINDOW(dialog));
+    gtk_dialog_run(GTK_DIALOG(dialog));
+    gtk_widget_destroy(dialog);
+}
+
 static void
 setup_locale_from_win32_registry(void)
 {
@@ -615,6 +688,21 @@ check_command_line_files(gint n,
     return nfailures;
 }
 
+static void
+block_modules(const gchar *modules_to_block)
+{
+    gchar **modlist;
+    guint i;
+
+    if (!modules_to_block)
+        return;
+
+    modlist = g_strsplit(modules_to_block, ",", 0);
+    for (i = 0; modlist[i]; i++)
+        gwy_module_disable_registration(modlist[i]);
+    g_strfreev(modlist);
+}
+
 static gboolean
 show_tip_at_startup(G_GNUC_UNUSED gpointer user_data)
 {
