@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: gwymoduleutils-file.c 18368 2016-02-29 21:23:00Z yeti-dn $
+ *  @(#) $Id: gwymoduleutils-file.c 19624 2017-04-18 13:45:32Z yeti-dn $
  *  Copyright (C) 2007-2016 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -227,8 +227,7 @@ gwy_app_xyz_title_fall_back(GwyContainer *data,
  * Since Gwyddion has no concept of bad data points, they are usually marked
  * with a mask and replaced with some neutral values upon import, leaving the
  * user to decide how to proceed further.  This helper function performs such
- * replacement, using the average of all good points as the neutral replacement
- * value (at this moment).
+ * replacement.
  *
  * Returns: The number of bad data points replaced.  If zero is returned, all
  *          points are good and there is no need for masking.
@@ -239,28 +238,23 @@ guint
 gwy_app_channel_remove_bad_data(GwyDataField *dfield, GwyDataField *mfield)
 {
     GwySIUnit *funit, *munit;
-    gdouble *data = gwy_data_field_get_data(dfield);
-    gdouble *mdata = gwy_data_field_get_data(mfield);
-    gdouble *drow, *mrow;
-    gdouble avg;
-    guint i, j, mcount, xres, yres;
+    gdouble *m = gwy_data_field_get_data(mfield);
+    guint i, mcount, n;
 
-    xres = gwy_data_field_get_xres(dfield);
-    yres = gwy_data_field_get_yres(dfield);
-    avg = gwy_data_field_area_get_avg(dfield, mfield, 0, 0, xres, yres);
+    n = gwy_data_field_get_xres(dfield) * gwy_data_field_get_yres(dfield);
     mcount = 0;
-    for (i = 0; i < yres; i++) {
-        mrow = mdata + i*xres;
-        drow = data + i*xres;
-        for (j = 0; j < xres; j++) {
-            if (!mrow[j]) {
-                drow[j] = avg;
-                mcount++;
-            }
-            mrow[j] = 1.0 - mrow[j];
+    for (i = 0; i < n; i++) {
+        if (m[i] <= 0.0) {
+            m[i] = 1.0;
+            mcount++;
         }
+        else
+            m[i] = 0.0;
     }
 
+    if (mcount)
+        gwy_data_field_laplace_solve(dfield, mfield, -1, 0.25);
+
     gwy_data_field_set_xreal(mfield, gwy_data_field_get_xreal(dfield));
     gwy_data_field_set_yreal(mfield, gwy_data_field_get_yreal(dfield));
     funit = gwy_data_field_get_si_unit_xy(dfield);
@@ -316,7 +310,7 @@ gwy_app_channel_mask_of_nans(GwyDataField *dfield,
     if (!mask || !removebad)
         return mask;
 
-    gwy_data_field_correct_average_unmasked(dfield, mask);
+    gwy_data_field_laplace_solve(dfield, mask, -1, 0.25);
 
     return mask;
 }
