@@ -1,6 +1,6 @@
 /*
- *  @(#) $Id: help.c 18353 2016-02-24 14:10:42Z yeti-dn $
- *  Copyright (C) 2014 David Necas (Yeti).
+ *  @(#) $Id: help.c 19898 2017-06-11 06:53:55Z yeti-dn $
+ *  Copyright (C) 2014-2017 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -64,7 +64,7 @@ show_uri_win32(G_GNUC_UNUSED const gchar *uri, gboolean complain)
 {
 #ifdef G_OS_WIN32
     static gboolean initialised_com = FALSE;
-    gint status;
+    INT_PTR status;
     gboolean ok;
 
     if (!uri)
@@ -79,11 +79,11 @@ show_uri_win32(G_GNUC_UNUSED const gchar *uri, gboolean complain)
     /* XXX: The first arg is handle to the window.  May want to pass it.
      * Apparenly gdk_win32_window_get_impl_hwnd() can provide it but this is
      * a late addition to Gdk, must check availability properly. */
-    status = (int)ShellExecute(NULL, NULL, uri, NULL, NULL, SW_SHOWNORMAL);
+    status = (INT_PTR)ShellExecute(NULL, NULL, uri, NULL, NULL, SW_SHOWNORMAL);
     ok = status > 32;  /* Otherwise it's the error code. */
     if (!ok && complain) {
         g_warning("Help ShellExecute() for URI `%s' failed with code %d.",
-                  uri, status);
+                  uri, (gint)status);
     }
     return ok;
 #else
@@ -371,58 +371,88 @@ get_user_guide_online_base(void)
     return g_strconcat(UG_ONLINE_BASE, lang, NULL);
 }
 
+#ifdef G_OS_WIN32
+static inline gboolean
+starts_with_drive_letter(const gchar *path)
+{
+    return g_ascii_isalpha(path[0]) && path[1] == ':';
+}
+#endif
+
 /* If an URI points to a local file, check if it exists.  Otherwise just assume
  * it exists. */
 static gboolean
 check_local_file_uri(const gchar *uri)
 {
-    GFile *gfile;
-    gchar *path, *scheme;
-    GFileInfo *fileinfo;
-    GFileType filetype;
+    guint i, j, len, nslashes = 0;
+    gchar *s = NULL, *decoded = NULL;
+    const gchar *p;
+    gboolean retval;
 
-    /* If we use g_file_new_for_uri() on a bare path the tests below will not
-     * behave as expected. */
-    gfile = g_file_new_for_uri(uri);
-    if (!(scheme = g_file_get_uri_scheme(gfile))) {
-        const gchar *p;
-
-        g_object_unref(gfile);
-        if ((p = strchr(uri, '#'))) {
-            path = g_strndup(uri, p - uri);
-            gfile = g_file_new_for_path(path);
-            g_free(path);
-        }
-        else
-            gfile = g_file_new_for_path(uri);
+    /* Trim fragment. */
+    if ((p = strrchr(uri, '#'))) {
+        s = g_strndup(uri, p-uri);
+        uri = s;
     }
-    else
-        g_free(scheme);
 
-    /* We used g_file_hash() here but it segfaults under wine.  No idea why. */
-    if (!(path = g_file_get_basename(gfile))) {
-        g_object_unref(gfile);
-        return FALSE;
+    if (strncmp(uri, "file:/", 6) == 0) {
+        for (nslashes = 1; uri[5 + nslashes] == '/'; nslashes++)
+            ;
     }
-    g_free(path);
 
-    if (!(path = g_file_get_path(gfile))) {
-        g_object_unref(gfile);
+    if (!nslashes) {
+        /* Plain local path. */
+        if (uri[0] == '/')
+            goto finish;
+#ifdef G_OS_WIN32
+        if (uri[0] == '\\' || starts_with_drive_letter(uri))
+            goto finish;
+#endif
+
+        /* Is not file: and is not a local path.  Assume non-local, and so we
+         * cannot check it. */
+        gwy_debug("non-local %s, assuming OK", uri);
+        g_free(s);
         return TRUE;
     }
-    g_free(path);
 
-    fileinfo = g_file_query_info(gfile, G_FILE_ATTRIBUTE_STANDARD_TYPE,
-                                 0, NULL, NULL);
-    if (!fileinfo) {
-        g_object_unref(gfile);
-        return FALSE;
+    uri += 5;
+#ifdef G_OS_WIN32
+    if ((nslashes == 1 || nslashes == 3)
+        && starts_with_drive_letter(uri + nslashes))
+        uri += nslashes;
+    else
+        uri += nslashes-2;
+#else
+    uri += nslashes-1;
+#endif
+
+    if (!strchr(uri, '%'))
+        goto finish;
+
+    len = strlen(uri);
+    decoded = g_new(gchar, len+1);
+    for (i = j = 0; i < len; i++) {
+        if (uri[i] == '%'
+            && g_ascii_isdigit(uri[i+1])
+            && g_ascii_isdigit(uri[i+2])) {
+            decoded[j++] = (16*g_ascii_xdigit_value(uri[i+1])
+                            + g_ascii_xdigit_value(uri[i+2]));
+            i += 2;
+        }
+        else
+            decoded[j++] = uri[i];
     }
-    filetype = g_file_info_get_file_type(fileinfo);
-    g_object_unref(gfile);
-    g_object_unref(fileinfo);
+    decoded[j] = '\0';
+    uri = decoded;
 
-    return filetype == G_FILE_TYPE_REGULAR;
+finish:
+    retval = g_file_test(uri, G_FILE_TEST_IS_REGULAR);
+    gwy_debug("checking %s: %d", uri, retval);
+    g_free(s);
+    g_free(decoded);
+
+    return retval;
 }
 
 static gchar*
