@@ -1,6 +1,6 @@
 /*
- *  @(#) $Id: menu.c 18346 2016-02-24 10:26:37Z yeti-dn $
- *  Copyright (C) 2003-2006,2011 David Necas (Yeti), Petr Klapetek.
+ *  @(#) $Id: menu.c 20114 2017-07-30 22:33:28Z yeti-dn $
+ *  Copyright (C) 2003-2017 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -36,9 +36,6 @@
 #include <app/gwyapp.h>
 #include "gwyappinternal.h"
 
-/* Don't use stock icons, many don't look good and/or need disambiguation */
-#define USE_STOCK_ICONS 0
-
 typedef struct {
     const gchar *name;
     const gchar *stock_id;
@@ -334,7 +331,9 @@ gwy_app_menu_create_widgets(GNode *node,
     GtkWidget *menu, *item, *image;
 
     if (!G_NODE_IS_ROOT(node)) {
-        if (USE_STOCK_ICONS && data->stock_id) {
+        /* If images in menus are disabled by the "gtk-menu-images" setting,
+         * Gtk+ will not show them anyway. */
+        if (data->stock_id) {
             item = gtk_image_menu_item_new_with_mnemonic(data->item_translated);
             image = gtk_image_new_from_stock(data->stock_id,
                                              GTK_ICON_SIZE_MENU);
