@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: remote-win32.c 19272 2016-11-16 16:46:46Z yeti-dn $
+ *  @(#) $Id: remote-win32.c 19429 2017-01-18 12:30:07Z yeti-dn $
  *  Copyright (C) 2007 David Necas (Yeti), Jan Horak.
  *  E-mail: yeti@gwyddion.net, xhorak@gmail.com.
  *
@@ -27,6 +27,7 @@
 #include <string.h>
 #include <gtk/gtk.h>
 #include <gdk/gdkwin32.h>
+#include <windows.h>
 #include <shlobj.h>
 
 struct _GwyRemote {
@@ -164,7 +165,7 @@ void
 gwy_remote_print(GwyRemote *remote)
 {
     if (remote)
-        g_print("%08x\n", (guint32)remote->winid);
+        g_print("%08x\n", (guint32)(UINT_PTR)remote->winid);
 }
 #endif
 
