@@ -1,6 +1,6 @@
 /*
- *  @(#) $Id: toolbox-editor.c 19043 2016-10-08 18:58:43Z yeti-dn $
- *  Copyright (C) 2016 David Necas (Yeti).
+ *  @(#) $Id: toolbox-editor.c 20258 2017-08-12 08:17:43Z yeti-dn $
+ *  Copyright (C) 2016-2017 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -181,7 +181,8 @@ static void          move_down_in_toolbox            (GwyToolboxEditor *editor);
 static void          width_changed                   (GwyToolboxEditor *editor);
 static void          apply_toolbox_spec              (GwyToolboxEditor *editor);
 static void          reset_toolbox_to_default        (GwyToolboxEditor *editor);
-static GtkListStore* create_function_list            (ForeachFunc foreach_do);
+static GtkListStore* create_function_list            (ForeachFunc foreach_do,
+                                                      GwyAppActionType type);
 static GtkListStore* create_function_list_builtin    (void);
 static GtkListStore* create_gtk_icon_list            (GtkWidget *widget);
 static GtkListStore* create_gwy_icon_list            (GtkWidget *widget);
@@ -405,15 +406,26 @@ add_function_name(const gchar *name, GArray *func_names)
 }
 
 static gint
-compare_func_names(gconstpointer pa, gconstpointer pb)
+compare_func_names(gconstpointer pa, gconstpointer pb, gpointer user_data)
 {
     GQuark qa = *(const GQuark*)pa;
     GQuark qb = *(const GQuark*)pb;
-    return strcmp(g_quark_to_string(qa), g_quark_to_string(qb));
+    GwyAppActionType type = GPOINTER_TO_UINT(user_data);
+    const gchar *namea = g_quark_to_string(qa);
+    const gchar *nameb = g_quark_to_string(qb);
+    /* XXX: Inefficient. */
+    gchar *nnamea = g_strdup(gwy_toolbox_action_nice_name(type, namea));
+    gchar *nnameb = g_strdup(gwy_toolbox_action_nice_name(type, nameb));
+    gint retval = g_utf8_collate(nnamea, nnameb);
+
+    g_free(nnameb);
+    g_free(nnamea);
+
+    return retval;
 }
 
 static GtkListStore*
-create_function_list(ForeachFunc foreach_do)
+create_function_list(ForeachFunc foreach_do, GwyAppActionType type)
 {
     GtkListStore *store;
     GtkTreeIter iter;
@@ -423,7 +435,8 @@ create_function_list(ForeachFunc foreach_do)
     store = gtk_list_store_new(1, G_TYPE_UINT);
     func_names = g_array_new(FALSE, FALSE, sizeof(GQuark));
     foreach_do((GFunc)add_function_name, func_names);
-    g_array_sort(func_names, compare_func_names);
+    g_array_sort_with_data(func_names, compare_func_names,
+                           GUINT_TO_POINTER(type));
     for (i = 0; i < func_names->len; i++) {
         GQuark qname = g_array_index(func_names, GQuark, i);
         gtk_list_store_insert_with_values(store, &iter, G_MAXINT, 0, qname, -1);
@@ -598,7 +611,7 @@ toolbox_cell_renderer_icon(GtkTreeViewColumn *column,
 
     iconset = gtk_icon_factory_lookup_default(id);
     widget = GTK_WIDGET(gtk_tree_view_column_get_tree_view(column));
-    pixbuf = gtk_icon_set_render_icon(iconset, widget->style, GTK_TEXT_DIR_NONE,
+    pixbuf = gtk_icon_set_render_icon(iconset, widget->style, GTK_TEXT_DIR_LTR,
                                       GTK_STATE_NORMAL,
                                       GTK_ICON_SIZE_LARGE_TOOLBAR,
                                       widget, NULL);
@@ -727,7 +740,7 @@ function_cell_renderer_icon(GtkTreeViewColumn *column,
 
     iconset = gtk_icon_factory_lookup_default(id);
     widget = GTK_WIDGET(gtk_tree_view_column_get_tree_view(column));
-    pixbuf = gtk_icon_set_render_icon(iconset, widget->style, GTK_TEXT_DIR_NONE,
+    pixbuf = gtk_icon_set_render_icon(iconset, widget->style, GTK_TEXT_DIR_LTR,
                                       GTK_STATE_NORMAL,
                                       GTK_ICON_SIZE_LARGE_TOOLBAR,
                                       widget, NULL);
@@ -936,7 +949,7 @@ suggest_group_id(GwyToolboxGroupEditor *geditor)
     }
 #else
     for (i = 0; i < name_len; i++)
-        add_unichar_if_ident(suggestion, name_chars[j]);
+        add_unichar_if_ident(suggestion, name_chars[i]);
 #endif
 
     gtk_entry_set_text(GTK_ENTRY(geditor->id), suggestion->str);
@@ -1105,15 +1118,20 @@ create_item_editor_models(GwyToolboxEditor *editor)
 
     stores[GWY_APP_ACTION_TYPE_BUILTIN] = create_function_list_builtin();
     stores[GWY_APP_ACTION_TYPE_PROC]
-        = create_function_list(gwy_process_func_foreach);
+        = create_function_list(gwy_process_func_foreach,
+                               GWY_APP_ACTION_TYPE_PROC);
     stores[GWY_APP_ACTION_TYPE_GRAPH]
-        = create_function_list(gwy_graph_func_foreach);
+        = create_function_list(gwy_graph_func_foreach,
+                               GWY_APP_ACTION_TYPE_GRAPH);
     stores[GWY_APP_ACTION_TYPE_VOLUME]
-        = create_function_list(gwy_volume_func_foreach);
+        = create_function_list(gwy_volume_func_foreach,
+                               GWY_APP_ACTION_TYPE_VOLUME);
     stores[GWY_APP_ACTION_TYPE_XYZ]
-        = create_function_list(gwy_xyz_func_foreach);
+        = create_function_list(gwy_xyz_func_foreach,
+                               GWY_APP_ACTION_TYPE_XYZ);
     stores[GWY_APP_ACTION_TYPE_TOOL]
-        = create_function_list(gwy_tool_func_foreach);
+        = create_function_list(gwy_tool_func_foreach,
+                               GWY_APP_ACTION_TYPE_TOOL);
     sync_remaining_tools_item(editor);
 
     editor->icon_model_gwy = create_gwy_icon_list(editor->dialogue);
@@ -1416,8 +1434,7 @@ add_default_function_icon(GtkListStore *store, GwyToolboxItemSpec *ispec,
     if (!iconset)
         return;
 
-    pixbuf = gtk_icon_set_render_icon(iconset, widget->style,
-                                      GTK_TEXT_DIR_NONE,
+    pixbuf = gtk_icon_set_render_icon(iconset, widget->style, GTK_TEXT_DIR_LTR,
                                       GTK_STATE_NORMAL,
                                       GTK_ICON_SIZE_LARGE_TOOLBAR,
                                       widget, NULL);
@@ -1451,6 +1468,7 @@ toolbox_model_iter_indices(GtkTreeModel *model, GtkTreeIter *iter,
         *j = indices[1];
     }
     else {
+        *i = *j = 0;
         g_return_val_if_reached(0);
     }
 
@@ -1759,7 +1777,7 @@ create_icon_list(GtkWidget *widget, const gchar **stock_ids, guint nicons)
             continue;
 
         pixbuf = gtk_icon_set_render_icon(iconset, widget->style,
-                                          GTK_TEXT_DIR_NONE,
+                                          GTK_TEXT_DIR_LTR,
                                           GTK_STATE_NORMAL,
                                           GTK_ICON_SIZE_LARGE_TOOLBAR,
                                           widget, NULL);
@@ -1818,35 +1836,35 @@ create_gtk_icon_list(GtkWidget *widget)
         "gtk-floppy",
         "gtk-fullscreen",
         "gtk-goto-bottom",
-        //"gtk-goto-first",
-        //"gtk-goto-last",
+        "gtk-goto-first",
+        "gtk-goto-last",
         "gtk-goto-top",
-        //"gtk-go-back",
+        "gtk-go-back",
         "gtk-go-down",
-        //"gtk-go-forward",
+        "gtk-go-forward",
         "gtk-go-up",
         "gtk-harddisk",
         "gtk-help",
         "gtk-home",
         "gtk-index",
-        //"gtk-indent",
+        "gtk-indent",
         "gtk-info",
         "gtk-italic",
-        //"gtk-jump-to",
+        "gtk-jump-to",
         "gtk-justify-center",
         "gtk-justify-fill",
         "gtk-justify-left",
         "gtk-justify-right",
         "gtk-leave-fullscreen",
         "gtk-missing-image",
-        //"gtk-media-forward",
-        //"gtk-media-next",
-        //"gtk-media-pause",
-        //"gtk-media-play",
-        //"gtk-media-previous",
-        //"gtk-media-record",
-        //"gtk-media-rewind",
-        //"gtk-media-stop",
+        "gtk-media-forward",
+        "gtk-media-next",
+        "gtk-media-pause",
+        "gtk-media-play",
+        "gtk-media-previous",
+        "gtk-media-record",
+        "gtk-media-rewind",
+        "gtk-media-stop",
         "gtk-network",
         "gtk-new",
         "gtk-no",
@@ -1867,10 +1885,10 @@ create_gtk_icon_list(GtkWidget *widget)
         "gtk-print-warning",
         "gtk-properties",
         "gtk-quit",
-        //"gtk-redo",
+        "gtk-redo",
         "gtk-refresh",
         "gtk-remove",
-        //"gtk-revert-to-saved",
+        "gtk-revert-to-saved",
         "gtk-save",
         "gtk-save-as",
         "gtk-select-all",
@@ -1881,10 +1899,10 @@ create_gtk_icon_list(GtkWidget *widget)
         "gtk-spell-check",
         "gtk-stop",
         "gtk-strikethrough",
-        //"gtk-undelete",
+        "gtk-undelete",
         "gtk-underline",
-        //"gtk-undo",
-        //"gtk-unindent",
+        "gtk-undo",
+        "gtk-unindent",
         "gtk-yes",
         "gtk-zoom-100",
         "gtk-zoom-fit",
@@ -1913,9 +1931,11 @@ create_gwy_icon_list(GtkWidget *widget)
     GWY_STOCK_COLOR_RANGE_FULL,
     GWY_STOCK_CONVOLUTION,
     GWY_STOCK_CORRECT_AFFINE,
+    GWY_STOCK_CORRELATION_MASK,
     GWY_STOCK_CROP,
     GWY_STOCK_CWT,
     GWY_STOCK_DATA_MEASURE,
+    GWY_STOCK_DISCONNECTED,
     GWY_STOCK_DISTANCE,
     GWY_STOCK_DISTANCE_TRANSFORM,
     GWY_STOCK_DISTRIBUTION_ANGLE,
@@ -1931,16 +1951,23 @@ create_gwy_icon_list(GtkWidget *widget)
     GWY_STOCK_FAVOURITE,
     GWY_STOCK_FFT,
     GWY_STOCK_FFT_2D,
+    GWY_STOCK_FFT_FILTER_1D,
     GWY_STOCK_FFT_FILTER_2D,
     GWY_STOCK_FILTER,
     GWY_STOCK_FIND_PEAKS,
+    GWY_STOCK_FIT_SHAPE,
     GWY_STOCK_FIX_ZERO,
     GWY_STOCK_FLIP_HORIZONTALLY,
     GWY_STOCK_FLIP_VERTICALLY,
     GWY_STOCK_FRACTAL,
+    GWY_STOCK_FRACTAL_CORRECTION,
+    GWY_STOCK_FRACTAL_MEASURE,
     GWY_STOCK_GL_MATERIAL,
     GWY_STOCK_GRADIENT_HORIZONTAL,
     GWY_STOCK_GRADIENT_VERTICAL,
+    GWY_STOCK_GRAIN_CORRELATION,
+    GWY_STOCK_GRAIN_EXSCRIBED_CIRCLE,
+    GWY_STOCK_GRAIN_INSCRIBED_CIRCLE,
     GWY_STOCK_GRAINS,
     GWY_STOCK_GRAINS_EDGE,
     GWY_STOCK_GRAINS_EDGE_REMOVE,
@@ -1948,9 +1975,6 @@ create_gwy_icon_list(GtkWidget *widget)
     GWY_STOCK_GRAINS_MEASURE,
     GWY_STOCK_GRAINS_REMOVE,
     GWY_STOCK_GRAINS_WATER,
-    GWY_STOCK_GRAIN_CORRELATION,
-    GWY_STOCK_GRAIN_EXSCRIBED_CIRCLE,
-    GWY_STOCK_GRAIN_INSCRIBED_CIRCLE,
     GWY_STOCK_GRAPH,
     GWY_STOCK_GRAPH_ALIGN,
     GWY_STOCK_GRAPH_CUT,
@@ -1989,6 +2013,8 @@ create_gwy_icon_list(GtkWidget *widget)
     GWY_STOCK_LOCAL_SLOPE,
     GWY_STOCK_LOGSCALE_HORIZONTAL,
     GWY_STOCK_LOGSCALE_VERTICAL,
+    GWY_STOCK_MARK_OUTLIERS,
+    GWY_STOCK_MARK_SCARS,
     GWY_STOCK_MARK_WITH,
     GWY_STOCK_MASK,
     GWY_STOCK_MASK_ADD,
@@ -2012,6 +2038,7 @@ create_gwy_icon_list(GtkWidget *widget)
     GWY_STOCK_MASK_RECT_EXCLUSIVE,
     GWY_STOCK_MASK_RECT_INCLUSIVE,
     GWY_STOCK_MASK_REMOVE,
+    GWY_STOCK_MASK_SET,
     GWY_STOCK_MASK_SHRINK,
     GWY_STOCK_MASK_SUBTRACT,
     GWY_STOCK_MASK_THIN,
@@ -2021,12 +2048,15 @@ create_gwy_icon_list(GtkWidget *widget)
     GWY_STOCK_MUTUAL_CROP,
     GWY_STOCK_NEURAL_APPLY,
     GWY_STOCK_NEURAL_TRAIN,
+    GWY_STOCK_NEXT,
+    GWY_STOCK_NULL_OFFSETS,
     GWY_STOCK_PALETTES,
     GWY_STOCK_PATH_LEVEL,
     GWY_STOCK_POINTER_MEASURE,
+    GWY_STOCK_POLY_DISTORT,
     GWY_STOCK_POLYNOM,
     GWY_STOCK_POLYNOM_LEVEL,
-    GWY_STOCK_POLY_DISTORT,
+    GWY_STOCK_PREVIOUS,
     GWY_STOCK_PROFILE,
     GWY_STOCK_PSDF_LOG_PHI,
     GWY_STOCK_PSDF_SECTION,
@@ -2034,6 +2064,7 @@ create_gwy_icon_list(GtkWidget *widget)
     GWY_STOCK_REMOVE_UNDER_MASK,
     GWY_STOCK_ROTATE,
     GWY_STOCK_ROTATE_180,
+    GWY_STOCK_ROTATE_3D,
     GWY_STOCK_ROTATE_90_CCW,
     GWY_STOCK_ROTATE_90_CW,
     GWY_STOCK_SCALE,
@@ -2053,12 +2084,14 @@ create_gwy_icon_list(GtkWidget *widget)
     GWY_STOCK_SYNTHETIC_COLUMNAR,
     GWY_STOCK_SYNTHETIC_DIFFUSION,
     GWY_STOCK_SYNTHETIC_DOMAINS,
+    GWY_STOCK_SYNTHETIC_FIBRES,
     GWY_STOCK_SYNTHETIC_LATTICE,
     GWY_STOCK_SYNTHETIC_LINE_NOISE,
     GWY_STOCK_SYNTHETIC_NOISE,
     GWY_STOCK_SYNTHETIC_OBJECTS,
     GWY_STOCK_SYNTHETIC_PARTICLES,
     GWY_STOCK_SYNTHETIC_PATTERN,
+    GWY_STOCK_SYNTHETIC_PHASES,
     GWY_STOCK_SYNTHETIC_SPECTRAL,
     GWY_STOCK_SYNTHETIC_WAVES,
     GWY_STOCK_TILT,
@@ -2082,6 +2115,7 @@ create_gwy_icon_list(GtkWidget *widget)
     GWY_STOCK_VOLUME_SLICE,
     GWY_STOCK_VOLUMIZE,
     GWY_STOCK_VOLUMIZE_LAYERS,
+    GWY_STOCK_XY_DENOISE,
     GWY_STOCK_ZERO_MEAN,
     GWY_STOCK_ZOOM_1_1,
     GWY_STOCK_ZOOM_FIT,
