@@ -1,6 +1,6 @@
 /*
- *  @(#) $Id: toolbox.c 19071 2016-10-14 09:02:41Z yeti-dn $
- *  Copyright (C) 2003-2016 David Necas (Yeti), Petr Klapetek.
+ *  @(#) $Id: toolbox.c 20134 2017-08-02 06:07:07Z yeti-dn $
+ *  Copyright (C) 2003-2017 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -66,40 +66,45 @@ typedef struct {
     const gchar *tooltip;
 } Action;
 
-static GtkWidget* gwy_app_menu_create_info_menu    (GtkAccelGroup *accel_group);
-static GtkWidget* gwy_app_menu_create_file_menu    (GtkAccelGroup *accel_group);
-static GtkWidget* gwy_app_menu_create_edit_menu    (GtkAccelGroup *accel_group);
-static gboolean   gwy_toolbox_fill_builtin_action  (Action *action);
-static void       gwy_app_toolbox_showhide         (GtkWidget *expander);
-static void       show_user_guide                  (void);
-static void       show_message_log                 (void);
-static GtkWindow* create_message_log_window        (void);
-static void       toolbox_dnd_data_received        (GtkWidget *widget,
-                                                    GdkDragContext *context,
-                                                    gint x,
-                                                    gint y,
-                                                    GtkSelectionData *data,
-                                                    guint info,
-                                                    guint time_,
-                                                    gpointer user_data);
-static void       delete_app_window                (void);
-static void       action_zoom_in                   (void);
-static void       action_zoom_out                  (void);
-static void       action_zoom_1_1                  (void);
-static void       action_undo                      (void);
-static void       action_redo                      (void);
-static void       remove_all_logs                  (void);
-static void       toggle_edit_accelerators         (gpointer callback_data,
-                                                    gint callback_action,
-                                                    GtkCheckMenuItem *item);
-static void       toggle_logging_enabled           (gpointer callback_data,
-                                                    gint callback_action,
-                                                    GtkCheckMenuItem *item);
-static void       enable_edit_accelerators         (gboolean enable);
-static void       gwy_app_tool_use                 (const gchar *toolname,
-                                                    GtkToggleButton *button);
-static void       gwy_app_change_default_mask_color(void);
-static void       action_display_3d                (void);
+static GtkWidget*   gwy_app_menu_create_info_menu    (GtkAccelGroup *accel_group);
+static GtkWidget*   gwy_app_menu_create_file_menu    (GtkAccelGroup *accel_group);
+static GtkWidget*   gwy_app_menu_create_edit_menu    (GtkAccelGroup *accel_group);
+static gboolean     toolbox_mapped                   (GtkWidget *toolbox);
+static void         finalise_toolbox                 (GtkWidget *toolbox);
+static gboolean     gwy_toolbox_fill_builtin_action  (Action *action);
+static const gchar* gwy_toolbox_builtin_accel_path   (const gchar *name);
+static void         gwy_app_toolbox_showhide         (GtkWidget *expander);
+static void         show_user_guide                  (void);
+static void         show_message_log                 (void);
+static GtkWindow*   create_message_log_window        (void);
+static void         toolbox_dnd_data_received        (GtkWidget *widget,
+                                                      GdkDragContext *context,
+                                                      gint x,
+                                                      gint y,
+                                                      GtkSelectionData *data,
+                                                      guint info,
+                                                      guint time_,
+                                                      gpointer user_data);
+static void         delete_app_window                (void);
+static void         action_zoom_in                   (void);
+static void         action_zoom_out                  (void);
+static void         action_zoom_1_1                  (void);
+static void         action_undo                      (void);
+static void         action_redo                      (void);
+static void         remove_all_logs                  (void);
+static void         toggle_edit_accelerators         (gpointer callback_data,
+                                                      gint callback_action,
+                                                      GtkCheckMenuItem *item);
+static void         toggle_logging_enabled           (gpointer callback_data,
+                                                      gint callback_action,
+                                                      GtkCheckMenuItem *item);
+static void         enable_edit_accelerators         (gboolean enable);
+static void         gwy_app_tool_use                 (const gchar *toolname,
+                                                      GtkToggleButton *button);
+static void         gwy_app_change_default_mask_color(void);
+static void         action_display_3d                (void);
+
+static gulong toolbox_map_event_id = 0;
 
 /* Translatability hack, intltool seems overkill at this point. */
 #define GWY_TOOLBOX_IGNORE(x) /* */
@@ -279,7 +284,7 @@ static gboolean
 toolbox_start_item(GwyAppToolboxBuilder *builder,
                    const GwyToolboxItemSpec *ispec)
 {
-    const gchar *func = NULL, *stock_id = NULL;
+    const gchar *func = NULL, *stock_id = NULL, *accel_path;
     GtkWidget *button = NULL;
     GwyToolClass *tool_class;
     GType gtype;
@@ -402,6 +407,12 @@ toolbox_start_item(GwyAppToolboxBuilder *builder,
     if (!action.stock_id && stock_id)
         action.stock_id = g_quark_from_string(stock_id);
 
+    if (action.type == GWY_APP_ACTION_TYPE_BUILTIN) {
+        accel_path = gwy_toolbox_builtin_accel_path(func);
+        if (accel_path)
+            gtk_widget_set_accel_path(button, accel_path, builder->accel_group);
+    }
+
     if (!action.stock_id) {
         g_warning("Function %s::%s has no icon set",
                   gwy_toolbox_action_type_name(action.type), func);
@@ -420,6 +431,9 @@ toolbox_start_item(GwyAppToolboxBuilder *builder,
     }
 
     gtk_button_set_relief(GTK_BUTTON(button), GTK_RELIEF_NONE);
+    GTK_WIDGET_UNSET_FLAGS(button, GTK_CAN_DEFAULT);
+    gtk_container_set_border_width(GTK_CONTAINER(button), 0);
+    gtk_widget_set_name(button, "toolboxbutton");
     gtk_table_attach_defaults(GTK_TABLE(builder->group), button,
                               builder->pos % builder->width,
                               builder->pos % builder->width + 1,
@@ -498,7 +512,7 @@ gwy_app_toolbox_build(GwyToolboxSpec *spec,
     guint i, j;
 
     gwy_clear(&builder, 1);
-    builder.width = spec->width ? spec->width : 4;
+    builder.width = spec->width ? spec->width : 5;
     builder.box = vbox;
     builder.tips = tips;
     builder.unseen_tools = g_ptr_array_new();
@@ -596,7 +610,6 @@ gwy_app_toolbox_window_create(void)
 
     spec = gwy_parse_toolbox_ui(FALSE);
     if (spec) {
-        /* TODO: free the spec upon exit so that it does not show as a leak. */
         gwy_app_toolbox_build(spec, vbox, gwy_app_get_tooltips(), accel_group);
         g_object_set_data(G_OBJECT(toolbox), "gwy-app-toolbox-spec", spec);
     }
@@ -611,19 +624,39 @@ gwy_app_toolbox_window_create(void)
     /***************************************************************/
     /* XXX */
     g_signal_connect(toolbox, "delete-event", G_CALLBACK(gwy_app_quit), NULL);
-
+    g_signal_connect(toolbox, "destroy", G_CALLBACK(finalise_toolbox), NULL);
+    toolbox_map_event_id = g_signal_connect_after(toolbox, "map-event",
+                                                  G_CALLBACK(toolbox_mapped),
+                                                  NULL);
     gtk_widget_show_all(toolbox);
 
     gwy_osx_get_menu_from_widget(container);
-    while (gtk_events_pending())
-        gtk_main_iteration_do(FALSE);
-
-    gwy_remote_setup(toolbox);
-    g_signal_connect(toolbox, "destroy", G_CALLBACK(gwy_remote_finalize), NULL);
 
     return toolbox;
 }
 
+static gboolean
+toolbox_mapped(GtkWidget *toolbox)
+{
+    g_return_val_if_fail(toolbox_map_event_id, FALSE);
+    gwy_remote_setup(toolbox);
+    g_signal_handler_disconnect(toolbox, toolbox_map_event_id);
+    toolbox_map_event_id = 0;
+    return FALSE;
+}
+
+static void
+finalise_toolbox(GtkWidget *toolbox)
+{
+    GwyToolboxSpec *spec;
+
+    if ((spec = g_object_get_data(G_OBJECT(toolbox), "gwy-app-toolbox-spec"))) {
+        gwy_toolbox_spec_free(spec);
+        g_object_set_data(G_OBJECT(toolbox), "gwy-app-toolbox-spec", NULL);
+    }
+    gwy_remote_finalize(toolbox);
+}
+
 void
 gwy_toolbox_rebuild_to_spec(GwyToolboxSpec *spec)
 {
@@ -662,6 +695,14 @@ gwy_toolbox_get_builtins(guint *nspec)
             "display_3d", GWY_STOCK_3D_BASE, &action_display_3d,
             N_("Display a 3D view of data"), N_("Display a 3D view of data"),
         },
+        {
+            "undo", GTK_STOCK_UNDO, &action_undo,
+            N_("Undo"), N_("Undo last action"),
+        },
+        {
+            "redo", GTK_STOCK_REDO, &action_redo,
+            N_("Redo"), N_("Redo again last undone action"),
+        },
         {
             "zoom_in", GWY_STOCK_ZOOM_IN, &action_zoom_in,
             N_("Zoom in"), N_("Zoom in"),
@@ -713,6 +754,24 @@ gwy_toolbox_fill_builtin_action(Action *action)
     return TRUE;
 }
 
+static const gchar*
+gwy_toolbox_builtin_accel_path(const gchar *name)
+{
+    static const gchar *paths[] = {
+        "display_3d", "<builtin>/Display 3D",
+        "zoom_in", "<builtin>/Zoom In",
+        "zoom_out", "<builtin>/Zoom Out",
+        "zoom_1_1", "<builtin>/Zoom 1:1",
+    };
+    guint i;
+
+    for (i = 0; i < G_N_ELEMENTS(paths); i += 2) {
+        if (gwy_strequal(paths[i], name))
+            return paths[i+1];
+    }
+    return NULL;
+}
+
 /*************************************************************************/
 static GtkWidget*
 gwy_app_menu_create_info_menu(GtkAccelGroup *accel_group)
