@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: validate.c 19043 2016-10-08 18:58:43Z yeti-dn $
+ *  @(#) $Id: validate.c 19303 2016-11-21 09:52:59Z yeti-dn $
  *  Copyright (C) 2007-2016 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
@@ -694,6 +694,48 @@ gwy_data_error_desrcibe(GwyDataError error)
     return errors[error];
 }
 
+static void
+enforce_one_graph_order(G_GNUC_UNUSED gpointer hash_key,
+                        gpointer hash_value,
+                        gpointer user_data)
+{
+    GValue *gvalue = (GValue*)hash_value;
+    guint *nfailures = (guint*)user_data;
+    GObject *object;
+    GwyGraphModel *gmodel;
+    GwyGraphCurveModel *gcmodel;
+    gboolean failed = FALSE;
+    guint n, i;
+
+    if (!G_VALUE_HOLDS(gvalue, G_TYPE_OBJECT))
+        return;
+
+    object = g_value_get_object(gvalue);
+    if (!GWY_IS_GRAPH_MODEL(object))
+        return;
+
+    gmodel = (GwyGraphModel*)object;
+    n = gwy_graph_model_get_n_curves(gmodel);
+    for (i = 0; i < n; i++) {
+        gcmodel = gwy_graph_model_get_curve(gmodel, i);
+        if (!gwy_graph_curve_model_is_ordered(gcmodel)) {
+            gwy_graph_curve_model_enforce_order(gcmodel);
+            failed = TRUE;
+        }
+    }
+    if (failed)
+        (*nfailures)++;
+}
+
+/* XXX: Can we get this to public validate API?  And should we? */
+guint
+_gwy_app_enforce_graph_abscissae_order(GwyContainer *data)
+{
+    guint nfailures = 0;
+    gwy_container_foreach(data, NULL, enforce_one_graph_order, &nfailures);
+    return nfailures;
+}
+
 /************************** Documentation ****************************/
 
 /**
