@@ -1,6 +1,6 @@
 /*
- *  @(#) $Id: wait.c 18678 2016-05-04 11:30:23Z yeti-dn $
- *  Copyright (C) 2004 David Necas (Yeti), Petr Klapetek.
+ *  @(#) $Id: wait.c 19935 2017-06-19 08:39:44Z yeti-dn $
+ *  Copyright (C) 2004-2017 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -28,6 +28,8 @@ static void gwy_app_wait_create_dialog (GtkWindow *window,
                                         const gchar *message);
 static void gwy_app_wait_cancelled      (void);
 
+static gboolean wait_enabled = TRUE;
+
 static GtkWidget *dialog = NULL;
 static GtkWidget *progress = NULL;
 static GtkWidget *label = NULL;
@@ -53,6 +55,9 @@ void
 gwy_app_wait_start(GtkWindow *window,
                    const gchar *message)
 {
+    if (!wait_enabled)
+        return;
+
     if (window && !GTK_IS_WINDOW(window))
         g_warning("Widget is not a window");
 
@@ -84,6 +89,9 @@ gwy_app_wait_start(GtkWindow *window,
 void
 gwy_app_wait_finish(void)
 {
+    if (!wait_enabled)
+        return;
+
     if (cancelled) {
         cancelled = FALSE;
         return;
@@ -153,6 +161,9 @@ gwy_app_wait_create_dialog(GtkWindow *window,
 gboolean
 gwy_app_wait_set_message(const gchar *message)
 {
+    if (!wait_enabled)
+        return TRUE;
+
     g_return_val_if_fail(dialog, FALSE);
 
     while (gtk_events_pending())
@@ -193,6 +204,9 @@ gwy_app_wait_set_message(const gchar *message)
 gboolean
 gwy_app_wait_set_message_prefix(const gchar *prefix)
 {
+    if (!wait_enabled)
+        return TRUE;
+
     g_return_val_if_fail(dialog, FALSE);
 
     if (cancelled)
@@ -230,6 +244,9 @@ gwy_app_wait_set_fraction(gdouble fraction)
     gchar buf[8];
     gdouble t;
 
+    if (!wait_enabled)
+        return TRUE;
+
     g_return_val_if_fail(dialog, FALSE);
 
     t = g_timer_elapsed(timer, NULL);
@@ -282,6 +299,9 @@ gwy_app_wait_cursor_start(GtkWindow *window)
     GdkWindow *wait_window;
     GtkWidget *widget;
 
+    if (!window && !wait_enabled)
+        return;
+
     g_return_if_fail(GTK_IS_WINDOW(window));
     widget = GTK_WIDGET(window);
 
@@ -321,6 +341,9 @@ gwy_app_wait_cursor_finish(GtkWindow *window)
     GdkWindow *wait_window;
     GtkWidget *widget;
 
+    if (!window && !wait_enabled)
+        return;
+
     g_return_if_fail(GTK_IS_WINDOW(window));
     widget = GTK_WIDGET(window);
 
@@ -337,6 +360,74 @@ gwy_app_wait_cursor_finish(GtkWindow *window)
         gtk_main_iteration_do(FALSE);
 }
 
+/**
+ * gwy_app_wait_get_enabled:
+ *
+ * Reports whether progress reporting is globally enabled.
+ *
+ * Returns: %TRUE if progress reporting is enabled, %FALSE if it is disabled.
+ *
+ * Since: 2.48
+ **/
+gboolean
+gwy_app_wait_get_enabled(void)
+{
+    return wait_enabled;
+}
+
+/**
+ * gwy_app_wait_set_enabled:
+ * @setting: %TRUE to enable progress reporting, %FALSE to disable it.
+ *
+ * Globally enables or disables progress reporting.
+ *
+ * This function may not be used when a waiting dialog is currently being
+ * shown.
+ *
+ * By default, progress reporting is enabled.  Non-GUI applications that run
+ * module functions may wish to disable it to avoid GTK+ calls or just showing
+ * the progress dialogs.
+ *
+ * If progress reporting is disabled then functions such as
+ * gwy_app_wait_set_message() and gwy_app_wait_set_fraction() become no-op and
+ * always return %TRUE as nothing can be cancelled by the user.  Functions
+ * gwy_app_wait_cursor_start() and gwy_app_wait_cursor_finish() still work but
+ * may be called with %NULL arguments.
+ *
+ * Since: 2.48
+ **/
+void
+gwy_app_wait_set_enabled(gboolean setting)
+{
+    if (!wait_enabled == !setting)
+        return;
+
+    g_return_if_fail(dialog);
+    g_return_if_fail(cancelled);
+    wait_enabled = !!setting;
+}
+
+/**
+ * gwy_app_wait_was_canceled:
+ *
+ * Checks if a progress dialog was cancelled.
+ *
+ * Calling this function is only meaningful between gwy_app_wait_cursor_start()
+ * and gwy_app_wait_finish().  It returns %TRUE if the computation was
+ * cancelled by the user.  This may be occasionaly useful in complex
+ * multi-level calculations.  Usually, the return values of
+ * gwy_app_wait_set_fraction() and gwy_app_wait_set_message() are sufficient.
+ *
+ * Returns: %TRUE if the currently running calculation was cancelled.
+ *
+ * Since: 2.49
+ **/
+gboolean
+gwy_app_wait_was_canceled(void)
+{
+    return cancelled;
+}
+
 /************************** Documentation ****************************/
 
 /**
