@@ -1,6 +1,6 @@
 /*
- *  @(#) $Id: wait.h 15598 2013-11-11 12:33:32Z yeti-dn $
- *  Copyright (C) 2004 David Necas (Yeti), Petr Klapetek.
+ *  @(#) $Id: wait.h 19935 2017-06-19 08:39:44Z yeti-dn $
+ *  Copyright (C) 2004-2017 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -26,15 +26,17 @@
 
 G_BEGIN_DECLS
 
-void     gwy_app_wait_start              (GtkWindow *window,
-                                          const gchar *message);
-void     gwy_app_wait_finish             (void);
-gboolean gwy_app_wait_set_fraction       (gdouble fraction);
-gboolean gwy_app_wait_set_message        (const gchar *message);
-gboolean gwy_app_wait_set_message_prefix (const gchar *prefix);
-
-void     gwy_app_wait_cursor_start       (GtkWindow *window);
-void     gwy_app_wait_cursor_finish      (GtkWindow *window);
+void     gwy_app_wait_start             (GtkWindow *window,
+                                         const gchar *message);
+void     gwy_app_wait_finish            (void);
+gboolean gwy_app_wait_set_fraction      (gdouble fraction);
+gboolean gwy_app_wait_set_message       (const gchar *message);
+gboolean gwy_app_wait_set_message_prefix(const gchar *prefix);
+void     gwy_app_wait_cursor_start      (GtkWindow *window);
+void     gwy_app_wait_cursor_finish     (GtkWindow *window);
+gboolean gwy_app_wait_get_enabled       (void);
+void     gwy_app_wait_set_enabled       (gboolean setting);
+gboolean gwy_app_wait_was_canceled      (void);
 
 G_END_DECLS
 
