@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: gwypixfield.c 16667 2014-10-11 16:39:06Z yeti-dn $
+ *  @(#) $Id: gwypixfield.c 20070 2017-07-12 07:48:27Z yeti-dn $
  *  Copyright (C) 2003,2014 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -262,8 +262,7 @@ gwy_draw_data_field_map_adaptive(GwyDataField *data_field,
 static gint*
 calc_cdh(GwyDataField *dfield, gint *cdh_size)
 {
-    const gdouble *data;
-    gdouble q, min, max;
+    gdouble min, max;
     gint i, n, xres, yres;
     gint *cdh;
 
@@ -271,24 +270,14 @@ calc_cdh(GwyDataField *dfield, gint *cdh_size)
     yres = gwy_data_field_get_yres(dfield);
     gwy_data_field_get_min_max(dfield, &min, &max);
 
-    n = GWY_ROUND(pow(xres*yres, 2.0/3.0));
-    data = gwy_data_field_get_data_const(dfield);
-    q = (n - 1.0)/(max - min);
-    cdh = g_new(gint, n);
-
-    cdh[0] = 0;
+    n = *cdh_size = GWY_ROUND(pow(xres*yres, 2.0/3.0));
+    cdh = g_new(guint, n);
+    gwy_math_histogram(gwy_data_field_get_data_const(dfield), xres*yres,
+                       min, max, n, cdh);
     for (i = 1; i < n; i++)
-        cdh[i] = xres*yres/(2*n);
-    for (i = 0; i < xres*yres; i++) {
-        gint h = (gint)((data[i] - min)*q + 1);
-        cdh[GWY_CLAMP(h, 0, n-1)]++;
-    }
-    for (i = 1; i < n; i++)
-        cdh[i] += cdh[i-1];
+        cdh[i] += xres*yres/(2*n) + cdh[i-1];
     cdh[0] = 0;
 
-    *cdh_size = n;
-
     return cdh;
 }
 
@@ -310,19 +299,18 @@ gwy_pixbuf_draw_data_field_as_mask(GdkPixbuf *pixbuf,
                                    const GwyRGBA *color)
 {
     int xres, yres, i, j, rowstride;
-    guchar *pixels, *line;
+    guchar *pixels, *pixline;
     guint32 pixel;
-    const gdouble *row, *data;
-    gdouble cor;
+    const gdouble *drow, *data;
+    guchar a;
 
     g_return_if_fail(GDK_IS_PIXBUF(pixbuf));
     g_return_if_fail(GWY_IS_DATA_FIELD(data_field));
     g_return_if_fail(color);
 
-    pixel = 0xff
-            | ((guint32)(guchar)floor(255.99999*color->b) << 8)
-            | ((guint32)(guchar)floor(255.99999*color->g) << 16)
-            | ((guint32)(guchar)floor(255.99999*color->r) << 24);
+    pixel = gwy_rgba_to_pixbuf_pixel(color);
+    a = (pixel & 0xff);
+    pixel |= 0xff;
     gdk_pixbuf_fill(pixbuf, pixel);
     if (!gdk_pixbuf_get_has_alpha(pixbuf))
         return;
@@ -336,18 +324,12 @@ gwy_pixbuf_draw_data_field_as_mask(GdkPixbuf *pixbuf,
 
     pixels = gdk_pixbuf_get_pixels(pixbuf);
     rowstride = gdk_pixbuf_get_rowstride(pixbuf);
-    cor = 255*color->a + 0.99999;
-    gwy_debug("cor = %g", cor);
 
     for (i = 0; i < yres; i++) {
-        line = pixels + i*rowstride + 3;
-        row = data + i*xres;
-        for (j = 0; j < xres; j++, row++) {
-            gdouble val = GWY_CLAMP(*row, 0.0, 1.0);
-
-            *line = (guchar)(cor*val);
-            line += 4;
-        }
+        pixline = pixels + i*rowstride + 3;
+        drow = data + i*xres;
+        for (j = xres; j; j--, drow++, pixline += 4)
+            *pixline = (*drow >= 0.5) ? a : 0;
     }
 }
 
