@@ -1,6 +1,6 @@
 /*
- *  @(#) $Id: gwyrgba.h 19135 2016-10-30 14:53:30Z yeti-dn $
- *  Copyright (C) 2004-2016 David Necas (Yeti), Petr Klapetek.
+ *  @(#) $Id: gwyrgba.h 20069 2017-07-12 07:47:40Z yeti-dn $
+ *  Copyright (C) 2004-2017 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -71,6 +71,9 @@ void     gwy_rgba_to_hex6                 (const GwyRGBA *rgba,
                                            gchar *hexout);
 void     gwy_rgba_to_hex8                 (const GwyRGBA *rgba,
                                            gchar *hexout);
+guint32  gwy_rgba_to_pixbuf_pixel         (const GwyRGBA *rgba);
+void     gwy_rgba_from_pixbuf_pixel       (GwyRGBA *rgba,
+                                           guint32 pixel);
 
 G_END_DECLS
 
