@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: gwycontainer.c 18117 2016-01-19 10:15:26Z yeti-dn $
+ *  @(#) $Id: gwycontainer.c 19324 2016-11-28 22:24:36Z yeti-dn $
  *  Copyright (C) 2003,2004,2014 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -66,62 +66,63 @@ typedef struct {
     gint i;
 } SerializeData;
 
-static void     gwy_container_serializable_init  (GwySerializableIface *iface);
-static void     value_destroy_func               (gpointer data);
-static void     gwy_container_finalize           (GObject *object);
-static GValue*  gwy_container_get_value_of_type  (GwyContainer *container,
-                                                  GQuark key,
-                                                  GType type);
-static GValue*  gwy_container_gis_value_of_type  (GwyContainer *container,
-                                                  GQuark key,
-                                                  GType type);
-static gboolean gwy_container_try_set_one        (GwyContainer *container,
-                                                  GQuark key,
-                                                  GValue *value);
-static void     gwy_container_try_setv           (GwyContainer *container,
-                                                  gsize nvalues,
-                                                  GwyKeyVal *values);
-static void     gwy_container_try_set_valist     (GwyContainer *container,
-                                                  va_list ap);
-static void     gwy_container_set_by_name_valist (GwyContainer *container,
-                                                  va_list ap);
-static GByteArray* gwy_container_serialize       (GObject *object,
-                                                  GByteArray *buffer);
-static gsize    gwy_container_get_size           (GObject *object);
-static void     hash_serialize_func              (gpointer hkey,
-                                                  gpointer hvalue,
-                                                  gpointer hdata);
-static GObject* gwy_container_deserialize        (const guchar *buffer,
-                                                  gsize size,
-                                                  gsize *position);
-static gboolean hash_remove_prefix_func          (gpointer hkey,
-                                                  gpointer hvalue,
-                                                  gpointer hdata);
-static void     hash_foreach_func                (gpointer hkey,
-                                                  gpointer hvalue,
-                                                  gpointer hdata);
-static void     keys_foreach_func                (gpointer hkey,
-                                                  gpointer hvalue,
-                                                  gpointer hdata);
-static void     keys_by_name_foreach_func        (gpointer hkey,
-                                                  gpointer hvalue,
-                                                  gpointer hdata);
-static GObject* gwy_container_duplicate_real     (GObject *object);
-static void     gwy_container_clone_real         (GObject *source,
-                                                  GObject *copy);
-static gboolean hash_remove_all_func             (void);
-static void     hash_duplicate_func              (gpointer hkey,
-                                                  gpointer hvalue,
-                                                  gpointer hdata);
-static GwyContainer*
-              gwy_container_duplicate_by_prefix_valist(GwyContainer *container,
-                                                       va_list ap);
-static void     hash_prefix_duplicate_func       (gpointer hkey,
-                                                  gpointer hvalue,
-                                                  gpointer hdata);
-static void     hash_find_keys_func              (gpointer hkey,
-                                                  gpointer hvalue,
-                                                  gpointer hdata);
+static void          gwy_container_serializable_init (GwySerializableIface *iface);
+static void          value_destroy_func              (gpointer data);
+static void          gwy_container_finalize          (GObject *object);
+static GValue*       gwy_container_get_value_of_type (GwyContainer *container,
+                                                      GQuark key,
+                                                      GType type);
+static GValue*       gwy_container_gis_value_of_type (GwyContainer *container,
+                                                      GQuark key,
+                                                      GType type);
+static gboolean      gwy_container_try_set_one       (GwyContainer *container,
+                                                      GQuark key,
+                                                      GValue *value);
+static void          gwy_container_try_setv          (GwyContainer *container,
+                                                      gsize nvalues,
+                                                      GwyKeyVal *values);
+static void          gwy_container_try_set_valist    (GwyContainer *container,
+                                                      va_list ap);
+static void          gwy_container_set_by_name_valist(GwyContainer *container,
+                                                      va_list ap);
+static GByteArray*   gwy_container_serialize         (GObject *object,
+                                                      GByteArray *buffer);
+static gsize         gwy_container_get_size          (GObject *object);
+static void          hash_serialize_func             (gpointer hkey,
+                                                      gpointer hvalue,
+                                                      gpointer hdata);
+static GObject*      gwy_container_deserialize       (const guchar *buffer,
+                                                      gsize size,
+                                                      gsize *position);
+static gboolean      hash_remove_prefix_func         (gpointer hkey,
+                                                      gpointer hvalue,
+                                                      gpointer hdata);
+static void          hash_foreach_func               (gpointer hkey,
+                                                      gpointer hvalue,
+                                                      gpointer hdata);
+static void          keys_foreach_func               (gpointer hkey,
+                                                      gpointer hvalue,
+                                                      gpointer hdata);
+static void          keys_by_name_foreach_func       (gpointer hkey,
+                                                      gpointer hvalue,
+                                                      gpointer hdata);
+static GObject*      gwy_container_duplicate_real    (GObject *object);
+static void          gwy_container_clone_real        (GObject *source,
+                                                      GObject *copy);
+static gboolean      hash_remove_all_func            (void);
+static void          hash_duplicate_func             (gpointer hkey,
+                                                      gpointer hvalue,
+                                                      gpointer hdata);
+static GwyContainer* duplicate_by_prefix_valist      (GwyContainer *container,
+                                                      va_list ap);
+static GwyContainer* duplicate_by_prefix_do          (GwyContainer *container,
+                                                      PrefixListData *pfxlist);
+static void          hash_prefix_duplicate_func      (gpointer hkey,
+                                                      gpointer hvalue,
+                                                      gpointer hdata);
+static void          hash_find_keys_func             (gpointer hkey,
+                                                      gpointer hvalue,
+                                                      gpointer hdata);
 
 static int      pstring_compare_callback         (const void *p,
                                                   const void *q);
@@ -2107,8 +2108,7 @@ hash_duplicate_func(gpointer hkey, gpointer hvalue, gpointer hdata)
  * Returns: A newly created container.
  **/
 GwyContainer*
-gwy_container_duplicate_by_prefix(GwyContainer *container,
-                                  ...)
+gwy_container_duplicate_by_prefix(GwyContainer *container, ...)
 {
     GwyContainer *duplicate;
     va_list ap;
@@ -2116,15 +2116,42 @@ gwy_container_duplicate_by_prefix(GwyContainer *container,
     g_return_val_if_fail(GWY_IS_CONTAINER(container), NULL);
 
     va_start(ap, container);
-    duplicate = gwy_container_duplicate_by_prefix_valist(container, ap);
+    duplicate = duplicate_by_prefix_valist(container, ap);
     va_end(ap);
 
     return duplicate;
 }
 
+/**
+ * gwy_container_duplicate_by_prefixv:
+ * @container: A container.
+ * @n: Number of prefixes.
+ * @prefixes: List of prefixes.
+ *
+ * Duplicates a container keeping only values under given prefixes.
+ *
+ * Like gwy_container_duplicate(), this method creates a deep copy, that is
+ * contained object are physically duplicated too, not just referenced again.
+ *
+ * Returns: A newly created container.
+ *
+ * Since: 2.48
+ **/
+GwyContainer*
+gwy_container_duplicate_by_prefixv(GwyContainer *container,
+                                   guint n,
+                                   const gchar **prefixes)
+{
+    PrefixListData pfxlist;
+
+    g_return_val_if_fail(GWY_IS_CONTAINER(container), NULL);
+    pfxlist.nprefixes = n;
+    pfxlist.prefixes = prefixes;
+    return duplicate_by_prefix_do(container, &pfxlist);
+}
+
 static GwyContainer*
-gwy_container_duplicate_by_prefix_valist(GwyContainer *container,
-                                         va_list ap)
+duplicate_by_prefix_valist(GwyContainer *container, va_list ap)
 {
     GwyContainer *duplicate;
     PrefixListData pfxlist;
@@ -2144,26 +2171,38 @@ gwy_container_duplicate_by_prefix_valist(GwyContainer *container,
         pfxlist.nprefixes++;
         prefix = va_arg(ap, const gchar*);
     }
-    pfxlist.pfxlengths = g_new(gsize, n);
-    pfxlist.pfxclosed = g_new(gboolean, n);
-    for (n = 0; n < pfxlist.nprefixes; n++) {
-        pfxlist.pfxlengths[n] = strlen(pfxlist.prefixes[n]);
-        pfxlist.pfxclosed[n] = !pfxlist.pfxlengths[n]
-                               || pfxlist.prefixes[n][pfxlist.pfxlengths[n] - 1]
-                                  == GWY_CONTAINER_PATHSEP;
+
+    duplicate = duplicate_by_prefix_do(container, &pfxlist);
+    g_free(pfxlist.prefixes);
+    return duplicate;
+}
+
+static GwyContainer*
+duplicate_by_prefix_do(GwyContainer *container, PrefixListData *pfxlist)
+{
+    GwyContainer *duplicate;
+    gsize n;
+
+    pfxlist->pfxlengths = g_new(gsize, pfxlist->nprefixes);
+    pfxlist->pfxclosed = g_new(gboolean, pfxlist->nprefixes);
+    for (n = 0; n < pfxlist->nprefixes; n++) {
+        const gchar *prefix = pfxlist->prefixes[n];
+        gsize len;
+        len = pfxlist->pfxlengths[n] = strlen(prefix);
+        pfxlist->pfxclosed[n] = !len || (prefix[len - 1]
+                                         == GWY_CONTAINER_PATHSEP);
     }
 
     /* don't emit signals when no one can be connected */
     duplicate = (GwyContainer*)gwy_container_new();
     duplicate->in_construction = TRUE;
-    pfxlist.container = duplicate;
+    pfxlist->container = duplicate;
     g_hash_table_foreach(container->values,
-                         hash_prefix_duplicate_func, &pfxlist);
+                         hash_prefix_duplicate_func, pfxlist);
     duplicate->in_construction = FALSE;
 
-    g_free(pfxlist.prefixes);
-    g_free(pfxlist.pfxclosed);
-    g_free(pfxlist.pfxlengths);
+    g_free(pfxlist->pfxclosed);
+    g_free(pfxlist->pfxlengths);
 
     return duplicate;
 }
