@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: gwycontainer.h 18117 2016-01-19 10:15:26Z yeti-dn $
+ *  @(#) $Id: gwycontainer.h 19818 2017-05-31 11:41:43Z yeti-dn $
  *  Copyright (C) 2003,2004,2014 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -78,13 +78,16 @@ gboolean      gwy_container_gis_value             (GwyContainer *container,
 void          gwy_container_set_value             (GwyContainer *container,
                                                    ...);
 void          gwy_container_set_value_by_name     (GwyContainer *container,
-                                                   ...);
+                                                   ...) G_GNUC_NULL_TERMINATED;
 gboolean      gwy_container_remove                (GwyContainer *container,
                                                    GQuark key);
 guint         gwy_container_remove_by_prefix      (GwyContainer *container,
                                                    const gchar *prefix);
 GwyContainer* gwy_container_duplicate_by_prefix   (GwyContainer *container,
                                                    ...);
+GwyContainer* gwy_container_duplicate_by_prefixv  (GwyContainer *container,
+                                                   guint n,
+                                                   const gchar **prefixes);
 gint          gwy_container_transfer              (GwyContainer *source,
                                                    GwyContainer *dest,
                                                    const gchar *source_prefix,
