@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: gwyenum.h 15790 2013-12-26 12:10:09Z yeti-dn $
+ *  @(#) $Id: gwyenum.h 19818 2017-05-31 11:41:43Z yeti-dn $
  *  Copyright (C) 2005 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -43,7 +43,7 @@ const gchar*  gwy_enum_to_string     (gint enumval,
                                       const GwyEnum *enum_table,
                                       gint n);
 gchar*        gwy_enuml_to_string    (gint enumval,
-                                      ...);
+                                      ...) G_GNUC_NULL_TERMINATED;
 gint          gwy_string_to_flags    (const gchar *str,
                                       const GwyEnum *enum_table,
                                       gint n,
