@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: gwymath.c 19134 2016-10-30 14:53:05Z yeti-dn $
+ *  @(#) $Id: gwymath.c 20264 2017-08-13 11:01:18Z yeti-dn $
  *  Copyright (C) 2003-2016 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -977,7 +977,41 @@ gwy_math_curvature(const gdouble *coeffs,
 }
 
 /**
- * gwy_math_refine_maximum:
+ * gwy_math_refine_maximum_1d:
+ * @y: Array of length 3, containing the neighbourhood values with the maximum
+ *     in the centre.
+ * @x: Location to store the refined @x-coordinate.
+ *
+ * Performs subpixel refinement of parabolic a one-dimensional maximum.
+ *
+ * The central value corresponds to x-coordinate 0, distances between values
+ * are unity.  The refinement is based by fitting a parabola through the
+ * maximum.  If it fails or the calculated maximum lies farther than the
+ * surrounding values the function sets the refined maximum to the origin and
+ * returns %FALSE.
+ *
+ * Returns: %TRUE if the refinement succeeded, %FALSE if it failed.  The value
+ *          of @x is usable regardless of the return value.
+ *
+ * Since: 2.49
+ **/
+gboolean
+gwy_math_refine_maximum_1d(const gdouble *y, gdouble *x)
+{
+    gdouble b, D;
+
+    *x = 0.0;
+    D = y[2] + y[0] - 2.0*y[1];
+    b = 0.5*(y[0] - y[2]);
+    if (fabs(D) < fabs(b))
+        return FALSE;
+
+    *x = b/D;
+    return TRUE;
+}
+
+/**
+ * gwy_math_refine_maximum_2d:
  * @z: Array of length 9, containing the square 3x3 neighbourhood values in
  *     matrix order and with the maximum in the centre.
  * @x: Location to store the refined @x-coordinate.
@@ -994,11 +1028,11 @@ gwy_math_curvature(const gdouble *coeffs,
  * Returns: %TRUE if the refinement succeeded, %FALSE if it failed.  The values
  *          of @x and @y are usable regardless of the return value.
  *
- * Since: 2.42
+ * Since: 2.49
  **/
 gboolean
-gwy_math_refine_maximum(const gdouble *z,
-                        gdouble *x, gdouble *y)
+gwy_math_refine_maximum_2d(const gdouble *z,
+                           gdouble *x, gdouble *y)
 {
     gdouble sz, szx, szy, szxx, szxy, szyy;
     gdouble bx, by, cxx, cxy, cyy, D, sx, sy;
@@ -1041,7 +1075,7 @@ gwy_math_refine_maximum(const gdouble *z,
 
     /* Don't trust the sub-pixel refinement if it moves the maximum too far
      * from the centre. */
-    if (fabs(sx) > 1.0 || fabs(sy) > 1.0)
+    if (sx*sx + sy*sy > 2.0)
         return FALSE;
 
     *x = sx;
@@ -1049,6 +1083,250 @@ gwy_math_refine_maximum(const gdouble *z,
     return TRUE;
 }
 
+/**
+ * gwy_math_refine_maximum:
+ * @z: Array of length 9, containing the square 3x3 neighbourhood values in
+ *     matrix order and with the maximum in the centre.
+ * @x: Location to store the refined @x-coordinate.
+ * @y: Location to store the refined @y-coordinate.
+ *
+ * Performs subpixel refinement of parabolic a two-dimensional maximum.
+ *
+ * An alias for gwy_math_refine_maximum_2d().
+ *
+ * Returns: %TRUE if the refinement succeeded, %FALSE if it failed.  The values
+ *          of @x and @y are usable regardless of the return value.
+ *
+ * Since: 2.42
+ **/
+gboolean
+gwy_math_refine_maximum(const gdouble *z, gdouble *x, gdouble *y)
+{
+    return gwy_math_refine_maximum_2d(z, x, y);
+}
+
+static guint
+estimate_regular_res(gdouble *pos, gint n, gdouble *minpos, gdouble *maxpos)
+{
+    gdouble maxstep = 0.0;
+    guint k, res;
+
+    gwy_math_sort(n, pos);
+    *minpos = pos[0];
+    *maxpos = pos[n-1];
+    gwy_debug("range [%g,%g]", *minpos, *maxpos);
+    if (maxpos <= minpos)
+        return 0;
+
+    for (k = 1; k < n; k++) {
+        if (pos[k] - pos[k-1] > maxstep)
+            maxstep = pos[k] - pos[k-1];
+    }
+    gwy_debug("maxstep %g", maxstep);
+    res = (gint)ceil((*maxpos - *minpos)/maxstep) + 1;
+    gwy_debug("estimated res %d", res);
+
+    if (n % res != 0)
+        return 0;
+
+    return res;
+}
+
+/**
+ * gwy_check_regular_2d_grid:
+ * @coords: Array of @n coordinate pairs in plane.  You can also typecast
+ *          #GwyXY or #GwyXYZ to doubles.
+ * @stride: Actual number of double values in one block.  It must be at least
+ *          2 if @coords contains just alternating @x and @y.  If you pass an
+ *          typecast #GwyXYZ array give stride as 3, etc.
+ * @n: Number of items in @coords.
+ * @tolerance: Relative distance from pixel center which is still considered
+ *             OK.  Pass a negative value for some reasonable default.
+ *             The maximum meaningful value is 0.5, beyond that the point would
+ *             end up in a different pixel.
+ * @xres: Location where to store the number of columns.
+ * @yres: Location where to store the number of rows.
+ * @xymin: Location where to store the minimum coordinates (top left corner).
+ * @xystep: Location where to store the pixel size.
+ *
+ * Detects if points in plane form a regular rectangular grid oriented along
+ * the Cartesian axes.
+ *
+ * Points lying in one straight line are not considered to form a rectangle.
+ *
+ * When the function fails, i.e. the points do not form a regular grid, the
+ * values of output arguments are undefined.
+ *
+ * Returns: On success, a newly allocated array mapping grid indices
+ *          (@i*@xres+@j) to indices in @coords.  %NULL is returned on failure.
+ *
+ * Since: 2.48
+ **/
+guint*
+gwy_check_regular_2d_grid(const gdouble *coords, guint stride, guint n,
+                          gdouble tolerance,
+                          guint *pxres, guint *pyres,
+                          GwyXY *xymin, GwyXY *xystep)
+{
+    gdouble xmin, xmax, ymin, ymax, dx, dy;
+    gint xres, yres;
+    guint k;
+    gdouble *pos;
+    guint *map;
+    gboolean *encountered;
+
+    g_return_val_if_fail(stride >= 2, NULL);
+    g_return_val_if_fail(coords || !n, NULL);
+    g_return_val_if_fail(pxres && pyres && xymin && xystep, NULL);
+
+    if (n < 4)
+        return NULL;
+
+    if (tolerance < 0.0)
+        tolerance = 0.05;
+
+    pos = g_new(gdouble, n);
+    gwy_debug("estimating yres from rows");
+    for (k = 0; k < n; k++)
+        pos[k] = coords[k*stride + 1];
+    yres = estimate_regular_res(pos, n, &ymin, &ymax);
+
+    gwy_debug("estimating xres from columns");
+    for (k = 0; k < n; k++)
+        pos[k] = coords[k*stride];
+    xres = estimate_regular_res(pos, n, &xmin, &xmax);
+
+    g_free(pos);
+
+    if (yres) {
+        xres = n/yres;
+        gwy_debug("from rows xres %u, yres %u", xres, yres);
+    }
+    else if (xres) {
+        yres = n/xres;
+        gwy_debug("from columns xres %u, yres %u", xres, yres);
+    }
+    else
+        return NULL;
+
+    dx = (xmax - xmin)/(xres - 1);
+    dy = (ymax - ymin)/(yres - 1);
+    xmin -= 0.5*dx;
+    xmax += 0.5*dx;
+    ymin -= 0.5*dy;
+    ymax += 0.5*dy;
+
+    map = g_new(guint, n);
+    encountered = g_new0(gboolean, n);
+    for (k = 0; k < n; k++) {
+        gdouble y = (coords[k*stride + 1] - ymin)/dy;
+        gdouble x = (coords[k*stride + 0] - xmin)/dx;
+        gint i = (gint)floor(y);
+        gint j = (gint)floor(x);
+
+        if (i < 0 || i >= yres || j < 0 || j >= xres) {
+            g_critical("Points not inside estimated region?!");
+            goto fail;
+        }
+        if (fabs(x - j - 0.5) > tolerance || fabs(y - i - 0.5) > tolerance) {
+            gwy_debug("(%g,%g) too far from (%g,%g)", x, y, j+0.5, i+0.5);
+            goto fail;
+        }
+        if (encountered[i*xres + j])
+            goto fail;
+
+        encountered[i*xres + j] = TRUE;
+        map[i*xres + j] = k;
+    }
+
+    g_free(encountered);
+    xymin->x = xmin;
+    xymin->y = ymin;
+    xystep->x = dx;
+    xystep->y = dy;
+    *pxres = xres;
+    *pyres = yres;
+    return map;
+
+fail:
+    g_free(map);
+    g_free(encountered);
+    return NULL;
+}
+
+/**
+ * gwy_math_histogram:
+ * @values: Values to make histogram from.
+ * @n: Number of values in @values.
+ * @min: Minimum value to consider (left edge of histogram).
+ * @max: Maximum value to consider (right edge of histogram).
+ * @nbins: Number of histogram bins (number of @counts items), a positive
+ *         number.
+ * @counts: Array where to store the counts.
+ *
+ * Counts the numbers of values falling into equal-sized bins.
+ *
+ * The value of @min must not be larger than @max.  The values may lie outside
+ * [@min,@max].  They are not counted in the histogram, nor the returned total.
+ *
+ * Rounding rules for values exactly at the edge of two bins are arbitrary
+ * and must not be relied upon.
+ *
+ * Returns: The number of values inside the entire histogram, i.e. at most @n
+ *          but possibly a reduced count.
+ *
+ * Since: 2.49
+ **/
+guint
+gwy_math_histogram(const gdouble *values,
+                   guint n,
+                   gdouble min,
+                   gdouble max,
+                   guint nbins,
+                   guint *counts)
+{
+    guint i, total = 0;
+    gint nb;
+    gdouble d;
+
+    g_return_val_if_fail(nbins > 0, 0);
+    g_return_val_if_fail(counts, 0);
+    g_return_val_if_fail(values || !n, 0);
+    g_return_val_if_fail(min <= max, 0);
+
+    gwy_clear(counts, nbins);
+    d = max - min;
+    if (G_UNLIKELY(!(d > 0.0))) {
+        for (i = 0; i < n; i++) {
+            if (values[i] == min)
+                counts[0]++;
+        }
+        return counts[0];
+    }
+
+    d = nbins/d;
+    nb = nbins;
+    for (i = 0; i < n; i++) {
+        gdouble v = values[i];
+        gint bi;
+
+        if (v < min || v > max)
+            continue;
+
+        bi = (gint)floor((v - min)*d);
+        if (G_LIKELY(bi >= 0 && bi < nb)) {
+            counts[bi]++;
+            total++;
+        }
+        else if (v == max) {
+            counts[nbins-1]++;
+            total++;
+        }
+    }
+
+    return total;
+}
+
 /**
  * gwy_xlnx_int:
  * @x: Value to calculate @x*log(@x) of.
@@ -1402,8 +1680,6 @@ gwy_math_median_uncertainty(gsize n, gdouble *array, gdouble *uarray)
     }
 }
 
-
-
 /************************** Documentation ****************************/
 
 /**
