@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: gwymath.h 19134 2016-10-30 14:53:05Z yeti-dn $
+ *  @(#) $Id: gwymath.h 19750 2017-05-16 09:35:02Z yeti-dn $
  *  Copyright (C) 2003-2016 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -123,9 +123,22 @@ guint    gwy_math_curvature            (const gdouble *coeffs,
                                         gdouble *xc,
                                         gdouble *yc,
                                         gdouble *zc);
+gboolean gwy_math_refine_maximum_1d    (const gdouble *y,
+                                        gdouble *x);
+gboolean gwy_math_refine_maximum_2d    (const gdouble *z,
+                                        gdouble *x,
+                                        gdouble *y);
 gboolean gwy_math_refine_maximum       (const gdouble *z,
                                         gdouble *x,
                                         gdouble *y);
+guint*   gwy_check_regular_2d_grid     (const gdouble *coords,
+                                        guint stride,
+                                        guint n,
+                                        gdouble tolerance,
+                                        guint *xres,
+                                        guint *yres,
+                                        GwyXY *xymin,
+                                        GwyXY *xystep)          G_GNUC_MALLOC;
 gdouble  gwy_math_median               (gsize n,
                                         gdouble *array);
 void     gwy_math_sort                 (gsize n,
@@ -134,6 +147,12 @@ gdouble  gwy_math_median_uncertainty   (gsize n,
                                         gdouble *array,
                                         gdouble *uarray);
 gdouble  gwy_xlnx_int                  (guint x)                G_GNUC_CONST;
+guint    gwy_math_histogram            (const gdouble *values,
+                                        guint n,
+                                        gdouble min,
+                                        gdouble max,
+                                        guint nbins,
+                                        guint *counts);
 
 G_END_DECLS
 
