@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: gwymathfallback.h 18915 2016-09-04 20:37:09Z yeti-dn $
+ *  @(#) $Id: gwymathfallback.h 20151 2017-08-03 08:47:10Z yeti-dn $
  *  Copyright (C) 2007-2016 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
@@ -130,13 +130,19 @@ gwy_math_fallback_isnan(double x)
 
 #endif /* GWY_MATH_NAMESPACE_CLEAN */
 
-#ifdef GWY_HAVE_ISINF
+/* GCC's fast math makes isinf no-op.  Must use the fallback function.
+ * Gwyddion works with finite arithmetic, but we need to detect INFs upon
+ * file import and remove it. */
+#if (defined(GWY_HAVE_ISINF) && !defined(__FAST_MATH__))
 #define gwy_isinf isinf
 #else
 #define gwy_isinf gwy_math_fallback_isinf
 #endif  /* GWY_HAVE_ISINF */
 
-#ifdef GWY_HAVE_ISNAN
+/* GCC's fast math makes isnan no-op.  Must use the fallback function.
+ * Gwyddion works with finite arithmetic, but we need to detect NaNs upon
+ * file import and remove it. */
+#if (defined(GWY_HAVE_ISNAN) && !defined(__FAST_MATH__))
 #define gwy_isnan isnan
 #else
 #define gwy_isnan gwy_math_fallback_isnan
