@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: gwynlfit.c 19150 2016-10-31 21:34:48Z yeti-dn $
+ *  @(#) $Id: gwynlfit.c 19529 2017-03-16 22:17:27Z yeti-dn $
  *  Copyright (C) 2000-2003 Martin Siler.
  *  Copyright (C) 2004-2016 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
@@ -703,7 +703,7 @@ gwy_math_nlfit_fit_real(GwyNLFitter *nlfit,
                 for (j = 0; j < i; j++) {
                     gint jid = var_param_id[j];
 
-                    if (iid == G_MAXDOUBLE || jid == G_MAXDOUBLE)
+                    if (iid < 0 || jid < 0)
                         SLi(nlfit->covar, i, j) = 0.0;
                     else
                         SLi(nlfit->covar, i, j) = SLi(save_a, iid, jid);
@@ -1063,7 +1063,8 @@ gwy_math_nlfit_succeeded(GwyNLFitter *nlfit)
  *
  * Returns the standard deviation of parameter number @par.
  *
- * This function makes sense only after a successful fit.
+ * This function makes sense only after a successful fit and for a free
+ * parameter.
  *
  * Returns: The SD of @par-th parameter.
  **/
@@ -1331,7 +1332,9 @@ free_private_data(GwyNLFitter *fitter)
  * @i: Data index from the set {0, 1, 2, ..., ndata-1}.
  * @param: Parameters.
  * @fixed_param: Which parameters should be treated as fixed (corresponding
- *               entries are set to %TRUE).
+ *               entries are set to %TRUE).  It may be %NULL is no parameters
+ *               are fixed.  The function must set derivatives by fixed
+ *               parameters to zero.
  * @func: The fitted function.
  * @user_data: User data as passed to gwy_math_nlfit_fit().
  * @der: Array where the @nparam partial derivatives by each parameter are
