@@ -1,7 +1,7 @@
 /*
- *  @(#) $Id: gwynlfitpreset.c 19146 2016-10-31 16:29:54Z yeti-dn $
+ *  @(#) $Id: gwynlfitpreset.c 20262 2017-08-12 10:49:32Z yeti-dn $
  *  Copyright (C) 2000-2003 Martin Siler.
- *  Copyright (C) 2004 David Necas (Yeti), Petr Klapetek.
+ *  Copyright (C) 2004-2017 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -33,6 +33,34 @@ gwy_nlfit_preset_new_static(const GwyNLFitPresetBuiltin *data);
 
 G_DEFINE_TYPE(GwyNLFitPreset, gwy_nlfit_preset, GWY_TYPE_RESOURCE)
 
+G_GNUC_UNUSED
+static gdouble
+_gwy_gamma(gdouble x)
+{
+    static const gdouble p[] = {
+        676.5203681218851,
+        -1259.1392167224028,
+        771.32342877765313,
+        -176.61502916214059,
+        12.507343278686905,
+        -0.13857109526572012,
+        9.9843695780195716e-6,
+        1.5056327351493116e-7
+    };
+    gdouble xi = 0.99999999999980993, t;
+    guint i;
+
+    if (x < 0.5)
+        return G_PI/(sin(G_PI*x)*_gwy_gamma(1.0 - x));
+
+    x -= 1.0;
+    for (i = 0; i < G_N_ELEMENTS(p); i++)
+        xi += p[i]/(x + i + 1);
+
+    t = x + G_N_ELEMENTS(p) - 0.5;
+    return sqrt(2.0*G_PI) * pow(t, x + 0.5) * exp(-t) * xi;
+}
+
 /*********************** gaussian *****************************/
 static gdouble
 gauss_func(gdouble x,
@@ -759,6 +787,52 @@ exp_rpsdf_guess(gint n_dat,
     *fres = TRUE;
 }
 
+/******************** K-correlated PSDF ***************************/
+
+/* XXX: σ² = s² β(1/2, (C-1)/2)
+ * But we cannot normalise to σ² because C and σ are terribly correlated. */
+static gdouble
+kcorr_psdf_func(gdouble x,
+                G_GNUC_UNUSED gint n_param,
+                const gdouble *b,
+                G_GNUC_UNUSED gpointer user_data,
+                gboolean *fres)
+{
+    gdouble s = b[0], T = b[1], C = b[2], t;
+
+    if (T == 0.0 || C <= 0.0) {
+        *fres = FALSE;
+        return 0.0;
+    }
+    *fres = TRUE;
+    t = T*x;
+    return T*s*s/pow(1.0 + t*t, 0.5*(C + 1.0));
+}
+
+static void
+kcorr_psdf_guess(gint n_dat,
+                 const gdouble *x,
+                 const gdouble *y,
+                 gdouble *param,
+                 gboolean *fres)
+{
+    exp_psdf_guess(n_dat, x, y, param, fres);
+    /* Usually C is around 1.  We probably cannot guess it better... */
+    param[2] = 0.2;
+}
+
+static GwySIUnit*
+kcorr_psdf_get_units(GwyNLFitPreset *preset,
+                     guint param,
+                     GwySIUnit *siunit_x,
+                     GwySIUnit *siunit_y)
+{
+    if (param == 2)
+        return gwy_si_unit_new(NULL);
+
+    return psdf_get_units(preset, param, siunit_x, siunit_y);
+}
+
 /**************   polynomial 0th order ********************************/
 static gdouble
 poly_0_func(G_GNUC_UNUSED gdouble x,
@@ -1078,13 +1152,14 @@ smstep_guess(gint n_dat,
         param[3] = (yleft/nleft < yright/nright) ? ymax - ymin : ymin - ymax;
     else
         param[3] = (xymax > xymin) ? ymax - ymin : ymin - ymax;
-    param[4] = 0.0;
-    param[5] = 0.0;
+    /* Using zero here prevents L-M from making progress. */
+    param[4] = 0.05*param[3]/(xmax - xmin);
+    param[5] = param[4]/(xmax - xmin);
 
     *fres = TRUE;
 }
 
-/******************* bent step ********************************/
+/******************* erf bent step ********************************/
 static gdouble
 bentstep_func(gdouble x,
               G_GNUC_UNUSED gint n_param,
@@ -1109,6 +1184,31 @@ bentstep_func(gdouble x,
     return f;
 }
 
+/******************* tanh bent step ********************************/
+static gdouble
+boltzmannstep_func(gdouble x,
+                   G_GNUC_UNUSED gint n_param,
+                   const gdouble *b,
+                   G_GNUC_UNUSED gpointer user_data,
+                   gboolean *fres)
+{
+    gdouble xc = b[0], yc = b[1], w = b[2], h = b[3], alpha = b[4], beta = b[5];
+    gdouble f;
+
+    *fres = TRUE;
+
+    *fres = TRUE;
+    x -= xc;
+    w = fabs(w);
+    f = yc + alpha*x + beta*x*x;
+    if (w == 0.0)
+        f += (x > 0.0) ? 0.5*h : -0.5*h;
+    else
+        f += h*tanh(x/w)/2.0;
+
+    return f;
+}
+
 /******************* power function ********************************/
 static gdouble
 power_func(gdouble x,
@@ -1377,6 +1477,13 @@ static const GwyNLFitParam gauss2_four_params[] = {
    { "T<sub>2</sub>", 1, 0, },
 };
 
+/* XXX: s power is fractional, attempted to fix case-by-case */
+static const GwyNLFitParam kcorr_psdf_params[] = {
+   { "s", 0, 0, },
+   { "T", 1, 0, },
+   { "C", 0, 0, },
+};
+
 static const GwyNLFitParam poly3_params[] = {
    { "a",  0, 1, },
    { "b", -1, 1, },
@@ -1501,7 +1608,7 @@ static const GwyNLFitPresetBuiltin fitting_presets[] = {
         NULL,
         &gauss_rpsdf_guess,
         &psdf_get_units,
-        &weights_linear_decrease,
+        NULL,
         G_N_ELEMENTS(gauss_two_params),
         gauss_two_params,
     },
@@ -1580,10 +1687,24 @@ static const GwyNLFitPresetBuiltin fitting_presets[] = {
         NULL,
         &exp_rpsdf_guess,
         &psdf_get_units,
-        &weights_linear_decrease,
+        NULL,
         G_N_ELEMENTS(gauss_two_params),
         gauss_two_params,
     },
+    {
+        N_("K-correlated (PSDF)"),
+        "<i>f</i>(<i>x</i>) "
+            "= s<sup>2</sup><i>T</i>"
+            "/[1 + <i>x</i><sup>2</sup><i>T</i><sup>2</sup>]"
+            "<sup><i>C</i>/2</sup>",
+        &kcorr_psdf_func,
+        NULL,
+        &kcorr_psdf_guess,
+        &kcorr_psdf_get_units,
+        NULL,
+        G_N_ELEMENTS(kcorr_psdf_params),
+        kcorr_psdf_params,
+    },
     {
         N_("Polynomial (order 0)"),
         "<i>f</i>(<i>x</i>) = <i>a</i>",
@@ -1696,6 +1817,22 @@ static const GwyNLFitPresetBuiltin fitting_presets[] = {
         G_N_ELEMENTS(bentstep_params),
         bentstep_params,
     },
+    {
+        N_("Boltzmann bent step"),
+        "<i>f</i>(<i>x</i>) "
+            "= y<sub>0</sub> "
+            "+ <i>h</i>/2 tanh(<i>ξ</i>/<i>w</i>) "
+            "+ <i>α</i><i>ξ</i> "
+            "+ <i>β</i><i>ξ</i><sup>2</sup>, "
+            "<i>ξ</i> = <i>x</i> − <i>x</i><sub>0</sub>",
+        &boltzmannstep_func,
+        NULL,
+        &smstep_guess,
+        NULL,
+        NULL,
+        G_N_ELEMENTS(bentstep_params),
+        bentstep_params,
+    },
     {
         N_("Power"),
         "<i>f</i>(<i>x</i>) "
@@ -2096,6 +2233,16 @@ gwy_nlfit_presets(void)
  * <member><literal>"Smooth slanted step"</literal></member>
  * </simplelist>
  *
+ * The following presets are available since version 2.48:
+ * <simplelist type='vert'>
+ * <member><literal>"K-correlated (PSDF)"</literal></member>
+ * </simplelist>
+ *
+ * The following presets are available since version 2.49:
+ * <simplelist type='vert'>
+ * <member><literal>"Boltzmann bent step"</literal></member>
+ * </simplelist>
+ *
  * The result of the fitting is stored in a normal #GwyNLFitter, therefore the
  * typical use is:
  *
