@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: gwysiunit.c 19216 2016-11-09 10:39:06Z yeti-dn $
+ *  @(#) $Id: gwysiunit.c 20108 2017-07-29 13:00:31Z yeti-dn $
  *  Copyright (C) 2004-2016 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -563,7 +563,7 @@ gwy_si_unit_get_format(GwySIUnit *siunit,
 
 /**
  * gwy_si_unit_get_format_with_resolution:
- * @siunit: A SI unit.
+ * @siunit: An SI unit.
  * @style: Unit format style.
  * @maximum: The maximum value to be represented.
  * @resolution: The smallest step (approximately) that should make a visible
@@ -614,7 +614,7 @@ gwy_si_unit_get_format_with_resolution(GwySIUnit *siunit,
 
 /**
  * gwy_si_unit_get_format_with_digits:
- * @siunit: A SI unit.
+ * @siunit: An SI unit.
  * @style: Unit format style.
  * @maximum: The maximum value to be represented.
  * @sdigits: The number of significant digits the value should have.
@@ -665,12 +665,12 @@ gwy_si_unit_get_format_with_digits(GwySIUnit *siunit,
 
 /**
  * gwy_si_unit_equal:
- * @siunit1: First unit.
+ * @siunit: First unit.
  * @siunit2: Second unit.
  *
  * Checks whether two SI units are equal.
  *
- * Returns: %TRUE if units are equal.
+ * Returns: %TRUE if the units are equal.
  **/
 gboolean
 gwy_si_unit_equal(GwySIUnit *siunit1, GwySIUnit *siunit2)
@@ -705,6 +705,47 @@ gwy_si_unit_equal(GwySIUnit *siunit1, GwySIUnit *siunit2)
     return TRUE;
 }
 
+/**
+ * gwy_si_unit_equal_string:
+ * @siunit: An SI unit.
+ * @unit_string: Unit string (it can be %NULL for an empty unit).
+ *
+ * Checks whether an SI unit corresponds to given string.
+ *
+ * Any power-of-ten prefixes are ignored.  This function is mostly useful for
+ * quick comparison with simple units such as "m" and for checking whether a
+ * unit is non-empty (by comparing with %NULL or an empty string).
+ *
+ * Returns: %TRUE if the units is equivalent to the given string.
+ *
+ * Since: 2.49
+ **/
+gboolean
+gwy_si_unit_equal_string(GwySIUnit *siunit,
+                         const gchar *unit_string)
+{
+    GwySIUnit *tmpunit;
+    gboolean retval;
+
+    g_return_val_if_fail(GWY_IS_SI_UNIT(siunit), FALSE);
+
+    if (!unit_string || !*unit_string)
+        return !siunit->units->len;
+
+    if (siunit->units->len == 1) {
+        GwySimpleUnit *unit = &g_array_index(siunit->units, GwySimpleUnit, 0);
+        if (gwy_strequal(g_quark_to_string(unit->unit), unit_string))
+            return TRUE;
+        /* If they differ we cannot make any conclusion. */
+    }
+
+    tmpunit = gwy_si_unit_new_parse(unit_string, NULL);
+    retval = gwy_si_unit_equal(siunit, tmpunit);
+    g_object_unref(tmpunit);
+
+    return retval;
+}
+
 /* fix all kinds of sloppy and strange notations */
 static void
 fix_unit_name(GString *str)
