@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: gwyutils.c 19216 2016-11-09 10:39:06Z yeti-dn $
+ *  @(#) $Id: gwyutils.c 19821 2017-05-31 15:21:55Z yeti-dn $
  *  Copyright (C) 2003-2016 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -1840,6 +1840,128 @@ gwy_object_set_or_reset(gpointer object,
     g_object_thaw_notify(object);
 }
 
+/**
+ * gwy_set_member_object:
+ * @instance: An object instance.
+ * @member_object: Another object to be owned by @instanced, or %NULL.
+ * @expected_type: The type of @member_object.  It is checked and a critical
+ *                 message is emitted if it does not conform.
+ * @member_field: Pointer to location storing the current member object to
+ *                be replaced by @member_object.
+ * @...: List of quadruplets of the form signal name, #GCallback callback,
+ *       #gulong pointer to location to hold the signal handler id, and
+ *       #GConnectFlags connection flags.
+ *
+ * Replaces a member object of another object, handling signal connection and
+ * disconnection.
+ *
+ * If @member_object is not %NULL a reference is taken, sinking any floating
+ * objects (and conversely, the reference to the previous member object is
+ * released).
+ *
+ * The purpose is to simplify bookkeeping in classes that have settable
+ * member objects and (usually but not necessarily) need to connect to some
+ * signals of these member objects.  Since this function both connects and
+ * disconnects signals it must be always called with the same set of signals,
+ * including callbacks and flags, for a specific member object.
+ *
+ * Example for a <type>GwyFoo</type> class owning a #GwyGradient member object,
+ * assuming the usual conventions:
+ * |[
+ * typedef struct _GwyFooPrivate GwyFooPrivate;
+ *
+ * struct _GwyFooPrivate {
+ *     GwyGradient *gradient;
+ *     gulong gradient_data_changed_id;
+ * };
+ *
+ * static gboolean
+ * set_gradient(GwyFoo *foo)
+ * {
+ *     GwyFooPrivate *priv = G_TYPE_INSTANCE_GET_PRIVATE(foo, GWY_TYPE_FOO,
+ *                                                       GwyFooPrivate);
+ *     if (!gwy_set_member_object(foo, gradient, GWY_TYPE_GRADIENT,
+ *                                &priv->gradient,
+ *                                "data-changed", &foo_gradient_data_changed,
+ *                                &priv->gradient_data_changed_id,
+ *                                G_CONNECT_SWAPPED,
+ *                                NULL))
+ *         return FALSE;
+ *
+ *     // Do whatever else needs to be done if the gradient changes.
+ *     return TRUE;
+ * }
+ * ]|
+ * The gradient setter then usually only calls
+ * <function>set_gradient()</function> and disposing of the member object again
+ * only calls <function>set_gradient()</function> but with %NULL gradient.
+ *
+ * Returns: %TRUE if @member_field was changed.  %FALSE means the new
+ *          member is identical to the current one and the function reduced to
+ *          no-op (or that an assertion faled).
+ *
+ * Since: 2.49
+ **/
+gboolean
+gwy_set_member_object(gpointer instance,
+                      gpointer member_object,
+                      GType expected_type,
+                      gpointer member_field,
+                      ...)
+{
+    gpointer *pmember = (gpointer*)member_field;
+    gpointer old_member = *pmember;
+    const gchar *signal_name;
+
+    if (old_member == member_object)
+        return FALSE;
+
+    g_return_val_if_fail(!member_object
+                         || G_TYPE_CHECK_INSTANCE_TYPE(member_object,
+                                                       expected_type),
+                         FALSE);
+
+    if (member_object)
+        g_object_ref_sink(member_object);
+
+    if (old_member) {
+        va_list ap;
+        va_start(ap, member_field);
+        for (signal_name = va_arg(ap, const gchar*);
+             signal_name;
+             signal_name = va_arg(ap, const gchar*)) {
+            G_GNUC_UNUSED GCallback handler = va_arg(ap, GCallback);
+            gulong *handler_id = va_arg(ap, gulong*);
+            G_GNUC_UNUSED GConnectFlags flags = va_arg(ap, GConnectFlags);
+            g_signal_handler_disconnect(old_member, *handler_id);
+            *handler_id = 0;
+        }
+        va_end(ap);
+    }
+
+    *pmember = member_object;
+
+    if (member_object) {
+        va_list ap;
+        va_start(ap, member_field);
+        for (signal_name = va_arg(ap, const gchar*);
+             signal_name;
+             signal_name = va_arg(ap, const gchar*)) {
+            GCallback handler = va_arg(ap, GCallback);
+            gulong *handler_id = va_arg(ap, gulong*);
+            GConnectFlags flags = va_arg(ap, GConnectFlags);
+            *handler_id = g_signal_connect_data(member_object, signal_name,
+                                                handler, instance, NULL,
+                                                flags);
+        }
+        va_end(ap);
+    }
+
+    if (old_member)
+        g_object_unref(old_member);
+
+    return TRUE;
+}
 
 /**
  * gwy_fopen:
