@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: gwyutils.h 18799 2016-08-01 07:15:50Z yeti-dn $
+ *  @(#) $Id: gwyutils.h 19821 2017-05-31 15:21:55Z yeti-dn $
  *  Copyright (C) 2003-2011 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -72,7 +72,7 @@ gboolean     gwy_ascii_strcase_equal   (gconstpointer v1,
                                         gconstpointer v2);
 guint        gwy_ascii_strcase_hash    (gconstpointer v);
 guint        gwy_stramong              (const gchar *str,
-                                        ...);
+                                        ...)                        G_GNUC_NULL_TERMINATED;
 gpointer     gwy_memmem                (gconstpointer haystack,
                                         gsize haystack_len,
                                         gconstpointer needle,
@@ -112,7 +112,12 @@ void         gwy_convert_raw_data      (gconstpointer data,
 guint        gwy_raw_data_size         (GwyRawDataType datatype);
 void         gwy_object_set_or_reset   (gpointer object,
                                         GType type,
-                                        ...);
+                                        ...)                        G_GNUC_NULL_TERMINATED;
+gboolean     gwy_set_member_object     (gpointer instance,
+                                        gpointer member_object,
+                                        GType expected_type,
+                                        gpointer member_field,
+                                        ...)                        G_GNUC_NULL_TERMINATED;
 #ifdef G_OS_WIN32
 FILE*        gwy_fopen                 (const gchar *filename, 
                                         const gchar *mode);
