@@ -1,6 +1,6 @@
 /*
- *  @(#) $Id: gwy3dsetup.c 18070 2016-01-11 20:55:02Z yeti-dn $
- *  Copyright (C) 2006 David Necas (Yeti), Petr Klapetek.
+ *  @(#) $Id: gwy3dsetup.c 20263 2017-08-12 11:13:26Z yeti-dn $
+ *  Copyright (C) 2006-2017 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -42,6 +42,9 @@ enum {
     PROP_LIGHT_THETA,
     PROP_HIDE_MASKED,
     PROP_LINE_WIDTH,
+    PROP_FMSCALE_SIZE,
+    PROP_FMSCALE_Y_ALIGN,
+    PROP_FMSCALE_RESERVE_SPACE,
     PROP_LAST
 };
 
@@ -129,9 +132,8 @@ gwy_3d_setup_class_init(Gwy3DSetupClass *klass)
         (gobject_class,
          PROP_FMSCALE_VISIBLE,
          g_param_spec_boolean("fmscale-visible",
-                              "fmscale visible",
-                              "Whether false color bar is visible "
-                              "",
+                              "Fmscale visible",
+                              "Whether false color bar is visible",
                               FALSE,
                               G_PARAM_READWRITE));
 
@@ -217,6 +219,56 @@ gwy_3d_setup_class_init(Gwy3DSetupClass *klass)
                              "Width of axis lines and ticks, in pixels.",
                              1.0, 10.0, 1.0,
                              G_PARAM_READWRITE));
+
+    /**
+     * Gwy3DSetup:fmscale-size:
+     *
+     * Size of false colour scale relative to view height.
+     *
+     * Since: 2.49
+     **/
+    g_object_class_install_property
+        (gobject_class,
+         PROP_FMSCALE_SIZE,
+         g_param_spec_double("fmscale-size",
+                             "Fmscale size",
+                             "Size of false colour scale relative to "
+                             "view height.",
+                             0.0, 1.0, 1.0,
+                             G_PARAM_READWRITE));
+
+    /**
+     * Gwy3DSetup:fmscale-y-align:
+     *
+     * Vertical alignment of false colour scale.
+     *
+     * Since: 2.49
+     **/
+    g_object_class_install_property
+        (gobject_class,
+         PROP_FMSCALE_Y_ALIGN,
+         g_param_spec_double("fmscale-y-align",
+                             "Fmscale y align",
+                             "Vertical alignment of false colour scale.",
+                             0.0, 1.0, 0.5,
+                             G_PARAM_READWRITE));
+    /**
+     * Gwy3DSetup:fmscale-reserve-space:
+     *
+     * Whethere to reserve entire vertical stripe of the false colour scale.
+     *
+     * Since: 2.49
+     **/
+    g_object_class_install_property
+        (gobject_class,
+         PROP_FMSCALE_RESERVE_SPACE,
+         g_param_spec_boolean("fmscale-reserve-space",
+                              "Fmscale resrrve space",
+                              "Whether to reserve horizontal space for "
+                              "the false colour scale.",
+                              TRUE,
+                              G_PARAM_READWRITE));
+
 }
 
 static void
@@ -236,6 +288,9 @@ gwy_3d_setup_init(Gwy3DSetup *setup)
     setup->light_phi = 0.0;
     setup->light_theta = 0.0;
     setup->line_width = 1.0;
+    setup->fmscale_size = 1.0;
+    setup->fmscale_yalign = 0.5;
+    setup->fmscale_reserve_space = TRUE;
 }
 
 static void
@@ -299,6 +354,18 @@ gwy_3d_setup_set_property(GObject *object,
         setup->line_width = g_value_get_double(value);
         break;
 
+        case PROP_FMSCALE_SIZE:
+        setup->fmscale_size = g_value_get_double(value);
+        break;
+
+        case PROP_FMSCALE_Y_ALIGN:
+        setup->fmscale_yalign = g_value_get_double(value);
+        break;
+
+        case PROP_FMSCALE_RESERVE_SPACE:
+        setup->fmscale_reserve_space = g_value_get_boolean(value);
+        break;
+
         default:
         G_OBJECT_WARN_INVALID_PROPERTY_ID(object, prop_id, pspec);
         break;
@@ -366,6 +433,18 @@ gwy_3d_setup_get_property(GObject *object,
         g_value_set_double(value, setup->line_width);
         break;
 
+        case PROP_FMSCALE_SIZE:
+        g_value_set_double(value, setup->fmscale_size);
+        break;
+
+        case PROP_FMSCALE_Y_ALIGN:
+        g_value_set_double(value, setup->fmscale_yalign);
+        break;
+
+        case PROP_FMSCALE_RESERVE_SPACE:
+        g_value_set_boolean(value, setup->fmscale_reserve_space);
+        break;
+
         default:
         G_OBJECT_WARN_INVALID_PROPERTY_ID(object, prop_id, pspec);
         break;
@@ -397,6 +476,9 @@ gwy_3d_setup_serialize(GObject *serializable,
             { 'd', "light-theta", &setup->light_theta, NULL, },
             { 'b', "hide-masked", &setup->hide_masked, NULL, },
             { 'd', "line-width", &setup->line_width, NULL, },
+            { 'd', "fmscale-size", &setup->fmscale_size, NULL, },
+            { 'd', "fmscale-y-align", &setup->fmscale_yalign, NULL, },
+            { 'b', "fmscale-resrrve-space", &setup->fmscale_reserve_space, NULL, },
         };
 
         return gwy_serialize_pack_object_struct(buffer,
@@ -429,6 +511,9 @@ gwy_3d_setup_get_size(GObject *object)
             { 'd', "light-theta", &setup->light_theta, NULL, },
             { 'b', "hide-masked", &setup->hide_masked, NULL, },
             { 'd', "line-width", &setup->line_width, NULL, },
+            { 'd', "fmscale-size", &setup->fmscale_size, NULL, },
+            { 'd', "fmscale-y-align", &setup->fmscale_yalign, NULL, },
+            { 'b', "fmscale-resrrve-space", &setup->fmscale_reserve_space, NULL, },
         };
 
         return gwy_serialize_get_struct_size(GWY_3D_SETUP_TYPE_NAME,
@@ -462,6 +547,9 @@ gwy_3d_setup_deserialize(const guchar *buffer,
             { 'd', "light-theta", &setup->light_theta, NULL, },
             { 'b', "hide-masked", &setup->hide_masked, NULL, },
             { 'd', "line-width", &setup->line_width, NULL, },
+            { 'd', "fmscale-size", &setup->fmscale_size, NULL, },
+            { 'd', "fmscale-y-align", &setup->fmscale_yalign, NULL, },
+            { 'b', "fmscale-resrrve-space", &setup->fmscale_reserve_space, NULL, },
         };
 
         if (!gwy_serialize_unpack_object_struct(buffer, size, position,
@@ -548,6 +636,21 @@ gwy_3d_setup_clone(GObject *source,
         g_object_notify(copy, "line-width");
     }
 
+    if (clone->fmscale_size != setup->fmscale_size) {
+        clone->fmscale_size = setup->fmscale_size;
+        g_object_notify(copy, "fmscale-size");
+    }
+
+    if (clone->fmscale_yalign != setup->fmscale_yalign) {
+        clone->fmscale_yalign = setup->fmscale_yalign;
+        g_object_notify(copy, "fmscale-y-align");
+    }
+
+    if (clone->fmscale_reserve_space != setup->fmscale_reserve_space) {
+        clone->fmscale_reserve_space = setup->fmscale_reserve_space;
+        g_object_notify(copy, "fmscale-reserve-space");
+    }
+
     g_object_thaw_notify(copy);
 }
 
@@ -576,6 +679,9 @@ gwy_3d_setup_duplicate_real(GObject *object)
     duplicate->hide_masked = setup->hide_masked;
 
     duplicate->line_width = setup->line_width;
+    duplicate->fmscale_size = setup->fmscale_size;
+    duplicate->fmscale_yalign = setup->fmscale_yalign;
+    duplicate->fmscale_reserve_space = setup->fmscale_reserve_space;
 
     return (GObject*)duplicate;
 }
