@@ -1,6 +1,6 @@
 /*
- *  @(#) $Id: gwy3dsetup.h 17340 2015-09-10 08:49:47Z yeti-dn $
- *  Copyright (C) 2006 David Necas (Yeti), Petr Klapetek.
+ *  @(#) $Id: gwy3dsetup.h 20263 2017-08-12 11:13:26Z yeti-dn $
+ *  Copyright (C) 2006-2017 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -49,7 +49,7 @@ struct _Gwy3DSetup {
     gboolean labels_visible;
     gboolean fmscale_visible;
     gboolean hide_masked;
-    gboolean b_reserved3;
+    gboolean fmscale_reserve_space;
     gboolean b_reserved4;
 
     guint i_reserved1;
@@ -62,8 +62,8 @@ struct _Gwy3DSetup {
     gdouble light_phi;
     gdouble light_theta;
     gdouble line_width;
-    gdouble d_reserved_2;
-    gdouble d_reserved_3;
+    gdouble fmscale_size;
+    gdouble fmscale_yalign;
     gdouble d_reserved_4;
 };
 
