@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: gwy3dwindow.h 16431 2014-07-23 12:56:36Z yeti-dn $
+ *  @(#) $Id: gwy3dwindow.h 19769 2017-05-18 08:07:41Z yeti-dn $
  *  Copyright (C) 2004 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -71,7 +71,7 @@ struct _Gwy3DWindow {
 
     GtkWidget *dataov_menu;
     GtkWidget *physcale_entry;
-    GtkWidget *widget4;
+    GtkWidget *label_size_equal;
     GtkWidget *widget5;
 
     gboolean in_update;
