@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: gwycombobox.c 18289 2016-02-18 20:46:34Z yeti-dn $
+ *  @(#) $Id: gwycombobox.c 20070 2017-07-12 07:48:27Z yeti-dn $
  *  Copyright (C) 2003-2016 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -449,10 +449,7 @@ render_curve_colour(G_GNUC_UNUSED GtkCellLayout *layout,
     g_return_if_fail(gcmodel);
 
     g_object_get(gcmodel, "color", &color, NULL);
-    pixel = 0xff
-        | ((guint32)(guchar)floor(255.99999*color->b) << 8)
-        | ((guint32)(guchar)floor(255.99999*color->g) << 16)
-        | ((guint32)(guchar)floor(255.99999*color->r) << 24);
+    pixel = 0xff | gwy_rgba_to_pixbuf_pixel(color);
     gwy_rgba_free(color);
     gdk_pixbuf_fill(pixbuf, pixel);
 }
