@@ -1,6 +1,6 @@
 /*
- *  @(#) $Id: gwydataview.c 19037 2016-10-08 10:40:49Z yeti-dn $
- *  Copyright (C) 2003 David Necas (Yeti), Petr Klapetek.
+ *  @(#) $Id: gwydataview.c 19491 2017-02-24 09:35:27Z yeti-dn $
+ *  Copyright (C) 2003-2017 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -1213,6 +1213,8 @@ gwy_data_view_coords_xy_clamp(GwyDataView *data_view,
     }
 }
 
+/* XXX: This functions should have a return value saying whether the line
+ * intersect the area at all.  But cannot do this without changing the API. */
 /**
  * gwy_data_view_coords_xy_cut_line:
  * @data_view: A data view.
@@ -1249,15 +1251,19 @@ gwy_data_view_coords_xy_cut_line(GwyDataView *data_view,
 
     /* Horizontal/vertical lines */
     if (*x1scr == *x0scr) {
+        if (*x0scr != x0s)
+            goto fail;
         *y0scr = y0s;
         *y1scr = y1s;
+        return;
     }
     if (*y1scr == *y0scr) {
+        if (*y0scr != y0s)
+            goto fail;
         *x0scr = x0s;
         *x1scr = x1s;
-    }
-    if (*y1scr == *y0scr || *x1scr == *x0scr)
         return;
+    }
 
     /* The hard case */
     x0s = *x0scr;
@@ -1298,18 +1304,20 @@ gwy_data_view_coords_xy_cut_line(GwyDataView *data_view,
         i1 = i;
     }
 
-    /* The line does not intersect the boundary at all.  Just return something
-     * and pray... */
-    if (i0 == -1) {
-        *x0scr = *x1scr = xsize/2;
-        *y0scr = *y1scr = ysize/2;
-        return;
-    }
+    if (i0 == -1)
+        goto fail;
 
     *x0scr = GWY_ROUND(x0s + t[i0]*(x1s - x0s));
     *x1scr = GWY_ROUND(x0s + t[i1]*(x1s - x0s));
     *y0scr = GWY_ROUND(y0s + t[i0]*(y1s - y0s));
     *y1scr = GWY_ROUND(y0s + t[i1]*(y1s - y0s));
+    return;
+
+fail:
+    /* The line does not intersect the boundary at all.  Just return something
+     * and pray... */
+    *x0scr = *x1scr = xsize/2;
+    *y0scr = *y1scr = ysize/2;
 }
 
 /**
