@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: gwydgetenums.h 18878 2016-08-24 17:22:53Z yeti-dn $
+ *  @(#) $Id: gwydgetenums.h 19924 2017-06-17 12:57:41Z yeti-dn $
  *  Copyright (C) 2005 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -66,15 +66,16 @@ typedef enum {
     GWY_UNITS_PLACEMENT_AT_ZERO
 } GwyUnitsPlacement;
 
-/* XXX */
 typedef enum {
     GWY_HSCALE_DEFAULT          = 0,
     GWY_HSCALE_LOG              = 1,
     GWY_HSCALE_SQRT             = 2,
+    GWY_HSCALE_LINEAR           = 3,
     GWY_HSCALE_NO_SCALE         = 6,
     GWY_HSCALE_WIDGET           = 7,
     GWY_HSCALE_WIDGET_NO_EXPAND = 8,
-    GWY_HSCALE_CHECK            = 1024
+    GWY_HSCALE_CHECK            = 1024,
+    GWY_HSCALE_SNAP             = 2048,
 } GwyHScaleStyle;
 
 typedef enum {
