@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: gwydgets.c 15598 2013-11-11 12:33:32Z yeti-dn $
+ *  @(#) $Id: gwydgets.c 19833 2017-06-04 13:03:23Z yeti-dn $
  *  Copyright (C) 2003 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -65,6 +65,13 @@ gwy_widgets_type_init(void)
          "  GtkStatusbar::shadow_type = 0\n"
          "}\n"
          "widget \"*.gwyflatstatusbar\" style \"gwyflatstatusbar\"\n"
+         "\n"
+         /* adjust bar internal check button */
+         "style \"gwyadjbarcheck\" {\n"
+         "  GtkCheckButton::focus_padding = 0\n"
+         "  GtkCheckButton::focus_line_width = 0\n"
+         "}\n"
+         "widget \"*.gwyadjbarcheck\" style \"gwyadjbarcheck\"\n"
          "\n");
 }
 
