@@ -120,10 +120,12 @@ gwy_hscale_style_get_type(void)
             { GWY_HSCALE_DEFAULT, "GWY_HSCALE_DEFAULT", "default" },
             { GWY_HSCALE_LOG, "GWY_HSCALE_LOG", "log" },
             { GWY_HSCALE_SQRT, "GWY_HSCALE_SQRT", "sqrt" },
+            { GWY_HSCALE_LINEAR, "GWY_HSCALE_LINEAR", "linear" },
             { GWY_HSCALE_NO_SCALE, "GWY_HSCALE_NO_SCALE", "no-scale" },
             { GWY_HSCALE_WIDGET, "GWY_HSCALE_WIDGET", "widget" },
             { GWY_HSCALE_WIDGET_NO_EXPAND, "GWY_HSCALE_WIDGET_NO_EXPAND", "widget-no-expand" },
             { GWY_HSCALE_CHECK, "GWY_HSCALE_CHECK", "check" },
+            { GWY_HSCALE_SNAP, "GWY_HSCALE_SNAP", "snap" },
             { 0, NULL, NULL }
         };
         etype = g_enum_register_static("GwyHScaleStyle", values);
@@ -365,6 +367,25 @@ gwy_ticks_style_get_type(void)
     return etype;
 }
 
+#include "./gwyadjustbar.h"
+
+GType
+gwy_scale_mapping_type_get_type(void)
+{
+    static GType etype = 0;
+
+    if (etype == 0) {
+        static const GEnumValue values[] = {
+            { GWY_SCALE_MAPPING_LINEAR, "GWY_SCALE_MAPPING_LINEAR", "linear" },
+            { GWY_SCALE_MAPPING_SQRT, "GWY_SCALE_MAPPING_SQRT", "sqrt" },
+            { GWY_SCALE_MAPPING_LOG, "GWY_SCALE_MAPPING_LOG", "log" },
+            { 0, NULL, NULL }
+        };
+        etype = g_enum_register_static("GwyScaleMappingType", values);
+    }
+    return etype;
+}
+
 #include "./gwygrainvaluemenu.h"
 
 GType
