@@ -1,6 +1,6 @@
 /*
- *  @(#) $Id: gwydgetutils.c 19127 2016-10-26 21:09:48Z yeti-dn $
- *  Copyright (C) 2003 David Necas (Yeti), Petr Klapetek.
+ *  @(#) $Id: gwydgetutils.c 19924 2017-06-17 12:57:41Z yeti-dn $
+ *  Copyright (C) 2003-2017 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -28,8 +28,10 @@
 #include <libgwyddion/gwydebugobjects.h>
 #include <libdraw/gwydraw.h>
 #ifndef GDK_WINDOWING_QUARTZ
+/* Produces a warning with -Wundef in Fedora.  Reported as Bug 1414319. */
 #include <pango/pangoft2.h>
 #endif
+#include <libgwydgets/gwyadjustbar.h>
 #include <libgwydgets/gwydgetutils.h>
 
 enum {
@@ -44,6 +46,8 @@ static void gwy_hscale_update_sqrt(GtkAdjustment *adj,
                                    GtkAdjustment *slave);
 static void gwy_hscale_update_sq  (GtkAdjustment *adj,
                                    GtkAdjustment *slave);
+static void hscale_set_sensitive  (GtkObject *pivot,
+                                   gboolean sensitive);
 static void disconnect_slave      (GtkWidget *slave,
                                    GtkWidget *master);
 static void disconnect_master     (GtkWidget *master,
@@ -78,7 +82,7 @@ gwy_table_attach_spinbutton(GtkWidget *table,
     else
         adj = gtk_adjustment_new(0, 0, 0, 0, 0, 0);
 
-    spin = gtk_spin_button_new(GTK_ADJUSTMENT(adj), 1, 0);
+    spin = gtk_spin_button_new(GTK_ADJUSTMENT(adj), 0.1, 0);
     gtk_spin_button_set_numeric(GTK_SPIN_BUTTON(spin), TRUE);
     gwy_table_attach_row(table, row, name, units, spin);
 
@@ -166,6 +170,18 @@ gwy_table_get_child_widget(GtkWidget *table,
 
 /************************** Scale attaching ****************************/
 
+static gdouble
+ssqrt(gdouble x)
+{
+    return (x < 0.0) ? -sqrt(fabs(x)) : sqrt(x);
+}
+
+static gdouble
+ssqr(gdouble x)
+{
+    return x*fabs(x);
+}
+
 static void
 gwy_hscale_update_log(GtkAdjustment *adj, GtkAdjustment *slave)
 {
@@ -201,7 +217,7 @@ gwy_hscale_update_sqrt(GtkAdjustment *adj, GtkAdjustment *slave)
                                G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA,
                                0, 0, 0, gwy_hscale_update_sq, adj);
     g_signal_handler_block(slave, id);
-    gtk_adjustment_set_value(slave, sqrt(adj->value));
+    gtk_adjustment_set_value(slave, ssqrt(adj->value));
     g_signal_handler_unblock(slave, id);
 }
 
@@ -214,7 +230,7 @@ gwy_hscale_update_sq(GtkAdjustment *adj, GtkAdjustment *slave)
                                G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA,
                                0, 0, 0, gwy_hscale_update_sqrt, adj);
     g_signal_handler_block(slave, id);
-    gtk_adjustment_set_value(slave, adj->value*adj->value);
+    gtk_adjustment_set_value(slave, ssqr(adj->value));
     g_signal_handler_unblock(slave, id);
 }
 
@@ -224,38 +240,80 @@ gwy_hscale_update_sq(GtkAdjustment *adj, GtkAdjustment *slave)
  *         @pivot.
  * @sensitive: %TRUE to make the row sensitive, %FALSE to insensitive.
  *
- * Sets sensitivity of a group of controls create by gwy_table_attach_hscale().
+ * Sets sensitivity of a group of controls create by gwy_table_attach_hscale()
+ * or gwy_table_attach_adjbar().
  *
- * Do not use with %GWY_HSCALE_CHECK, simply set state of the check button
- * in such a case.
+ * For controls without an enable/disable check button controls the sensitivity
+ * as expected.  If the hscale was created with %GWY_HSCALE_CHECK you usually
+ * manage its sensitivity by setting state of the check button instead.
+ * Only use this function when you want to enable/disable the entire group
+ * of controls, including the check button.
  *
- * This function can be used with rows created by gwy_table_attach_spinbutton()
- * too if the spinbutton is passed as @pivot.
+ * This function can also be used with rows created by
+ * gwy_table_attach_spinbutton() too if the spinbutton is passed as @pivot.
  **/
 void
-gwy_table_hscale_set_sensitive(GtkObject *pivot,
-                               gboolean sensitive)
+gwy_table_hscale_set_sensitive(GtkObject *pivot, gboolean sensitive)
 {
-    GtkWidget *widget;
-    GObject *object;
+    GtkWidget *scale, *check;
+    gboolean sens = sensitive;
 
-    object = G_OBJECT(pivot);
+    g_object_set_data(G_OBJECT(pivot), "gwy-explicit-disable",
+                      GINT_TO_POINTER(!sensitive));
 
-    if ((widget = g_object_get_data(object, "scale")))
-        gtk_widget_set_sensitive(widget, sensitive);
-    if ((widget = g_object_get_data(object, "middle_widget")))
-        gtk_widget_set_sensitive(widget, sensitive);
-    if ((widget = g_object_get_data(object, "label")))
-        gtk_widget_set_sensitive(widget, sensitive);
-    if ((widget = g_object_get_data(object, "units")))
-        gtk_widget_set_sensitive(widget, sensitive);
+    if ((check = gwy_table_hscale_get_check(pivot))
+        && GTK_IS_CHECK_BUTTON(check)) {
+        sens = (sensitive
+                && gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(check)));
+    }
+    else
+        check = NULL;
+
+    hscale_set_sensitive(pivot, sens);
+
+    if (check) {
+        scale = gwy_table_hscale_get_scale(pivot);
+        if (scale && GWY_IS_ADJUST_BAR(scale))
+            gtk_widget_set_sensitive(scale, sensitive);
+        else
+            gtk_widget_set_sensitive(check, sensitive);
+    }
 }
 
 static void
-gwy_hscale_checkbutton_cb(GtkToggleButton *check,
-                          GtkObject *pivot)
+hscale_checkbutton_toggled(GtkToggleButton *check, GtkObject *pivot)
 {
-    gwy_table_hscale_set_sensitive(pivot, gtk_toggle_button_get_active(check));
+    gboolean sens, active;
+
+    active = gtk_toggle_button_get_active(check);
+    sens = !GPOINTER_TO_INT(g_object_get_data(G_OBJECT(pivot),
+                                              "gwy-explicit-disable"));
+    hscale_set_sensitive(pivot, active && sens);
+}
+
+static void
+hscale_set_sensitive(GtkObject *pivot, gboolean sensitive)
+{
+    GtkWidget *widget;
+    gboolean is_adjbar = FALSE;
+
+    widget = gwy_table_hscale_get_scale(pivot);
+    if (widget && GWY_IS_ADJUST_BAR(widget))
+        is_adjbar = TRUE;
+
+    if (is_adjbar)
+        gwy_adjust_bar_set_bar_sensitive(GWY_ADJUST_BAR(widget), sensitive);
+    else {
+        if (widget)
+            gtk_widget_set_sensitive(widget, sensitive);
+        if ((widget = gwy_table_hscale_get_label(pivot)))
+            gtk_widget_set_sensitive(widget, sensitive);
+    }
+
+    if ((widget = gwy_table_hscale_get_middle_widget(pivot)))
+        gtk_widget_set_sensitive(widget, sensitive);
+    if ((widget = gwy_table_hscale_get_units(pivot)))
+        gtk_widget_set_sensitive(widget, sensitive);
 }
 
 /**
@@ -269,28 +327,30 @@ gwy_hscale_checkbutton_cb(GtkToggleButton *check,
  * @style: A mix of options an flags determining what and how will be attached
  *         to the table.
  *
- * Attaches a spinbutton with a scale and labels, or something else to a table
+ * Attaches a spinbutton with a scale and labels, or something else, to a table
  * row.
  *
+ * The group of controls takes four table columns: label, scale, spinbutton
+ * and units.
+ *
  * You can use functions gwy_table_hscale_get_scale(),
  * gwy_table_hscale_get_check(), etc. to get the various widgets from pivot
  * later.
  *
- * FIXME: What exactly happens with various @style values is quite convoluted.
+ * The function usually does the right thing but what exactly happens with
+ * various @style values is a bit convoluted.
  *
  * Returns: The middle widget.  If a spinbutton is attached, then this
  *          spinbutton is returned.  Otherwise (in %GWY_HSCALE_WIDGET case)
  *          @pivot itself.
  **/
 GtkWidget*
-gwy_table_attach_hscale(GtkWidget *table,
-                        gint row,
-                        const gchar *name,
-                        const gchar *units,
+gwy_table_attach_hscale(GtkWidget *table, gint row,
+                        const gchar *name, const gchar *units,
                         GtkObject *pivot,
                         GwyHScaleStyle style)
 {
-    GtkWidget *spin, *scale, *label, *check, *middle_widget, *align;
+    GtkWidget *spin, *scale, *label, *check = NULL, *middle_widget, *align;
     GtkAdjustment *scale_adj = NULL, *adj = NULL;
     GwyHScaleStyle base_style;
     GtkTable *tab;
@@ -300,12 +360,13 @@ gwy_table_attach_hscale(GtkWidget *table,
     g_return_val_if_fail(GTK_IS_TABLE(table), NULL);
     tab = GTK_TABLE(table);
 
-    base_style = style & ~GWY_HSCALE_CHECK;
+    base_style = style & ~(GWY_HSCALE_CHECK | GWY_HSCALE_SNAP);
     switch (base_style) {
         case GWY_HSCALE_DEFAULT:
         case GWY_HSCALE_NO_SCALE:
         case GWY_HSCALE_LOG:
         case GWY_HSCALE_SQRT:
+        case GWY_HSCALE_LINEAR:
         if (pivot) {
             g_return_val_if_fail(GTK_IS_ADJUSTMENT(pivot), NULL);
             adj = GTK_ADJUSTMENT(pivot);
@@ -313,7 +374,8 @@ gwy_table_attach_hscale(GtkWidget *table,
         else {
             if (base_style == GWY_HSCALE_LOG || base_style == GWY_HSCALE_SQRT)
                 g_warning("Nonlinear scale doesn't work with implicit adj.");
-            adj = GTK_ADJUSTMENT(gtk_adjustment_new(0, 0, 0, 0, 0, 0));
+            adj = GTK_ADJUSTMENT(gtk_adjustment_new(0.01, 0.01, 1.00, 0.01, 0.1,
+                                                    0));
         }
         break;
 
@@ -327,11 +389,16 @@ gwy_table_attach_hscale(GtkWidget *table,
         break;
     }
 
+    if (style & GWY_HSCALE_SNAP) {
+        g_warning("gwy_table_attach_hscale() does not implement "
+                  "snapping to ticks.");
+    }
+
     if (base_style != GWY_HSCALE_WIDGET
         && base_style != GWY_HSCALE_WIDGET_NO_EXPAND) {
         u = adj->step_increment;
         digits = (u > 0.0) ? (gint)floor(-log10(u)) : 0;
-        spin = gtk_spin_button_new(adj, adj->step_increment, MAX(digits, 0));
+        spin = gtk_spin_button_new(adj, 0.1, MAX(digits, 0));
         u = adj->value;
         gtk_spin_button_set_numeric(GTK_SPIN_BUTTON(spin), TRUE);
         gtk_spin_button_set_snap_to_ticks(GTK_SPIN_BUTTON(spin), TRUE);
@@ -357,7 +424,7 @@ gwy_table_attach_hscale(GtkWidget *table,
             u = sqrt(adj->upper);
             l = sqrt(adj->lower);
             scale_adj
-                = GTK_ADJUSTMENT(gtk_adjustment_new(sqrt(adj->value),
+                = GTK_ADJUSTMENT(gtk_adjustment_new(ssqrt(adj->value),
                                                     l, u,
                                                     (u - l)/GWY_HSCALE_WIDTH,
                                                     10*(u - l)/GWY_HSCALE_WIDTH,
@@ -387,7 +454,8 @@ gwy_table_attach_hscale(GtkWidget *table,
 
     if (base_style == GWY_HSCALE_DEFAULT
         || base_style == GWY_HSCALE_LOG
-        || base_style == GWY_HSCALE_SQRT) {
+        || base_style == GWY_HSCALE_SQRT
+        || base_style == GWY_HSCALE_LINEAR) {
         scale = gtk_hscale_new(scale_adj);
         gtk_scale_set_draw_value(GTK_SCALE(scale), FALSE);
         gtk_widget_set_size_request(scale, GWY_HSCALE_WIDTH, -1);
@@ -396,12 +464,11 @@ gwy_table_attach_hscale(GtkWidget *table,
         g_object_set_data(G_OBJECT(pivot), "scale", scale);
     }
 
-
     if (style & GWY_HSCALE_CHECK) {
         check = gtk_check_button_new_with_mnemonic(name);
         gtk_table_attach(tab, check, 0, 1, row, row+1, GTK_FILL, 0, 0, 0);
         g_signal_connect(check, "toggled",
-                         G_CALLBACK(gwy_hscale_checkbutton_cb), pivot);
+                         G_CALLBACK(hscale_checkbutton_toggled), pivot);
         g_object_set_data(G_OBJECT(pivot), "check", check);
     }
     else {
@@ -420,6 +487,193 @@ gwy_table_attach_hscale(GtkWidget *table,
         g_object_set_data(G_OBJECT(pivot), "units", label);
     }
 
+    if (check)
+        hscale_checkbutton_toggled(GTK_TOGGLE_BUTTON(check), pivot);
+
+    return middle_widget;
+}
+
+/**
+ * gwy_table_attach_adjbar:
+ * @table: A #GtkTable.
+ * @row: Row in @table to attach stuff to.
+ * @name: The label before @pivot widget.
+ * @units: The label after @pivot widget.
+ * @pivot: Either a #GtkAdjustment, or a widget to use instead of the spin
+ *         button and scale widgets (if @style is %GWY_HSCALE_WIDGET).
+ * @style: A mix of options an flags determining what and how will be attached
+ *         to the table.
+ *
+ * Attaches an adjustment bar with spinbutton and labels, or something else, to
+ * a table row.
+ *
+ * The group of controls takes three table columns: adjustment bar, spinbutton
+ * and units.
+ *
+ * You can use functions gwy_table_hscale_get_scale(),
+ * gwy_table_hscale_get_check(), etc. to get the various widgets from pivot
+ * later.
+ *
+ * The function usually does the right thing but what exactly happens with
+ * various @style values is a bit convoluted.
+ *
+ * Returns: The middle widget.  If a spinbutton is attached, then this
+ *          spinbutton is returned.  Otherwise (in %GWY_HSCALE_WIDGET case)
+ *          @pivot itself.
+ *
+ * Since: 2.49
+ **/
+GtkWidget*
+gwy_table_attach_adjbar(GtkWidget *table, gint row,
+                        const gchar *name, const gchar *units,
+                        GtkObject *pivot,
+                        GwyHScaleStyle style)
+{
+    GtkWidget *spin, *label, *check = NULL, *middle_widget, *hbox;
+    GtkAdjustment *adj = NULL;
+    GwyHScaleStyle base_style;
+    GwyAdjustBar *adjbar;
+    GtkTable *tab;
+    gdouble u;
+    gint digits, spacing;
+
+    g_return_val_if_fail(GTK_IS_TABLE(table), NULL);
+    tab = GTK_TABLE(table);
+
+    base_style = style & ~(GWY_HSCALE_CHECK | GWY_HSCALE_SNAP);
+    switch (base_style) {
+        case GWY_HSCALE_DEFAULT:
+        case GWY_HSCALE_NO_SCALE:
+        case GWY_HSCALE_LOG:
+        case GWY_HSCALE_SQRT:
+        case GWY_HSCALE_LINEAR:
+        if (pivot) {
+            g_return_val_if_fail(GTK_IS_ADJUSTMENT(pivot), NULL);
+            adj = GTK_ADJUSTMENT(pivot);
+        }
+        else {
+            if (base_style == GWY_HSCALE_LOG || base_style == GWY_HSCALE_SQRT)
+                g_warning("Nonlinear scale doesn't work with implicit adj.");
+            adj = GTK_ADJUSTMENT(gtk_adjustment_new(0.01, 0.01, 1.00, 0.01, 0.1,
+                                                    0));
+        }
+        break;
+
+        case GWY_HSCALE_WIDGET:
+        case GWY_HSCALE_WIDGET_NO_EXPAND:
+        g_return_val_if_fail(GTK_IS_WIDGET(pivot), NULL);
+        break;
+
+        default:
+        g_return_val_if_reached(NULL);
+        break;
+    }
+
+    if ((style & GWY_HSCALE_SNAP)
+        && (base_style == GWY_HSCALE_NO_SCALE
+            || base_style == GWY_HSCALE_WIDGET
+            || base_style == GWY_HSCALE_WIDGET_NO_EXPAND)) {
+        g_warning("There is no adjust bar that could snap to ticks.");
+    }
+
+    if (base_style == GWY_HSCALE_WIDGET
+        || base_style == GWY_HSCALE_WIDGET_NO_EXPAND) {
+        middle_widget = GTK_WIDGET(pivot);
+
+        g_object_get(table, "column-spacing", &spacing, NULL);
+        hbox = gtk_hbox_new(FALSE, spacing);
+        gtk_table_attach(GTK_TABLE(table), hbox, 0, 2, row, row+1,
+                         GTK_FILL, 0, 0, 0);
+
+        if (base_style == GWY_HSCALE_WIDGET_NO_EXPAND)
+            gtk_box_pack_end(GTK_BOX(hbox), middle_widget, FALSE, FALSE, 0);
+        else
+            gtk_box_pack_end(GTK_BOX(hbox), middle_widget, TRUE, TRUE, 0);
+
+        if (style & GWY_HSCALE_CHECK) {
+            check = gtk_check_button_new_with_mnemonic(name);
+            gtk_box_pack_start(GTK_BOX(hbox), check, FALSE, FALSE, 0);
+            g_signal_connect(check, "toggled",
+                             G_CALLBACK(hscale_checkbutton_toggled), pivot);
+            g_object_set_data(G_OBJECT(pivot), "check", check);
+        }
+        else {
+            label = gtk_label_new_with_mnemonic(name);
+            gtk_misc_set_alignment(GTK_MISC(label), 0, 0.5);
+            gtk_box_pack_start(GTK_BOX(hbox), label, FALSE, FALSE, 0);
+            gtk_label_set_mnemonic_widget(GTK_LABEL(label), middle_widget);
+            g_object_set_data(G_OBJECT(pivot), "label", label);
+        }
+    }
+    else {
+        u = adj->step_increment;
+        digits = (u > 0.0) ? (gint)floor(-log10(u)) : 0;
+        spin = gtk_spin_button_new(adj, 0.1, MAX(digits, 0));
+        gtk_spin_button_set_numeric(GTK_SPIN_BUTTON(spin), TRUE);
+        gtk_spin_button_set_snap_to_ticks(GTK_SPIN_BUTTON(spin), TRUE);
+        gtk_table_attach(tab, spin, 1, 2, row, row+1, GTK_FILL, 0, 0, 0);
+        middle_widget = spin;
+
+        if (base_style == GWY_HSCALE_NO_SCALE) {
+            if (style & GWY_HSCALE_CHECK) {
+                check = gtk_check_button_new_with_mnemonic(name);
+                gtk_table_attach(tab, check, 0, 1, row, row+1,
+                                 GTK_EXPAND | GTK_FILL, 0, 0, 0);
+                g_signal_connect(check, "toggled",
+                                 G_CALLBACK(hscale_checkbutton_toggled), pivot);
+                g_object_set_data(G_OBJECT(pivot), "check", check);
+            }
+            else {
+                label = gtk_label_new_with_mnemonic(name);
+                gtk_misc_set_alignment(GTK_MISC(label), 0, 0.5);
+                gtk_table_attach(tab, label, 0, 1, row, row+1,
+                                 GTK_EXPAND | GTK_FILL, 0, 0, 0);
+                gtk_label_set_mnemonic_widget(GTK_LABEL(label), middle_widget);
+                g_object_set_data(G_OBJECT(pivot), "label", label);
+            }
+        }
+        else {
+            adjbar = GWY_ADJUST_BAR(gwy_adjust_bar_new(adj, name));
+            if (base_style == GWY_HSCALE_LINEAR)
+                gwy_adjust_bar_set_mapping(adjbar, GWY_SCALE_MAPPING_LINEAR);
+            else if (base_style == GWY_HSCALE_SQRT)
+                gwy_adjust_bar_set_mapping(adjbar, GWY_SCALE_MAPPING_SQRT);
+            else if (base_style == GWY_HSCALE_LOG)
+                gwy_adjust_bar_set_mapping(adjbar, GWY_SCALE_MAPPING_LOG);
+
+            gtk_table_attach(tab, GTK_WIDGET(adjbar), 0, 1, row, row+1,
+                             GTK_EXPAND | GTK_FILL, 0, 0, 0);
+            g_object_set_data(G_OBJECT(pivot), "scale", adjbar);
+
+            label = gwy_adjust_bar_get_label(adjbar);
+            g_object_set_data(G_OBJECT(pivot), "label", label);
+            gtk_label_set_mnemonic_widget(GTK_LABEL(label), middle_widget);
+
+            if (style & GWY_HSCALE_CHECK) {
+                gwy_adjust_bar_set_has_check_button(adjbar, TRUE);
+                check = gwy_adjust_bar_get_check_button(adjbar);
+                g_signal_connect(check, "toggled",
+                                 G_CALLBACK(hscale_checkbutton_toggled), pivot);
+                g_object_set_data(G_OBJECT(pivot), "check", check);
+            }
+            if (style & GWY_HSCALE_SNAP)
+                gwy_adjust_bar_set_snap_to_ticks(adjbar, TRUE);
+        }
+    }
+
+    g_object_set_data(G_OBJECT(pivot), "middle_widget", middle_widget);
+
+    if (units) {
+        label = gtk_label_new(units);
+        gtk_label_set_use_markup(GTK_LABEL(label), TRUE);
+        gtk_misc_set_alignment(GTK_MISC(label), 0, 0.5);
+        gtk_table_attach(tab, label, 2, 3, row, row+1, GTK_FILL, 0, 0, 0);
+        g_object_set_data(G_OBJECT(pivot), "units", label);
+    }
+
+    if (check)
+        hscale_checkbutton_toggled(GTK_TOGGLE_BUTTON(check), pivot);
+
     return middle_widget;
 }
 
@@ -432,6 +686,12 @@ gwy_table_attach_hscale(GtkWidget *table,
  * May return %NULL if constructed with %GWY_HSCALE_NO_SCALE,
  * %GWY_HSCALE_WIDGET, or %GWY_HSCALE_WIDGET_NO_EXPAND.
  **/
+GtkWidget*
+gwy_table_hscale_get_scale(GtkObject *pivot)
+{
+    g_return_val_if_fail(pivot, NULL);
+    return (GtkWidget*)g_object_get_data(G_OBJECT(pivot), "scale");
+}
 
 /**
  * gwy_table_hscale_get_check:
@@ -441,6 +701,12 @@ gwy_table_attach_hscale(GtkWidget *table,
  *
  * May return %NULL if not constructed with %GWY_HSCALE_CHECK.
  **/
+GtkWidget*
+gwy_table_hscale_get_check(GtkObject *pivot)
+{
+    g_return_val_if_fail(pivot, NULL);
+    return (GtkWidget*)g_object_get_data(G_OBJECT(pivot), "check");
+}
 
 /**
  * gwy_table_hscale_get_label:
@@ -450,6 +716,12 @@ gwy_table_attach_hscale(GtkWidget *table,
  *
  * May return %NULL if constructed with %GWY_HSCALE_CHECK.
  **/
+GtkWidget*
+gwy_table_hscale_get_label(GtkObject *pivot)
+{
+    g_return_val_if_fail(pivot, NULL);
+    return (GtkWidget*)g_object_get_data(G_OBJECT(pivot), "label");
+}
 
 /**
  * gwy_table_hscale_get_units:
@@ -459,6 +731,12 @@ gwy_table_attach_hscale(GtkWidget *table,
  *
  * May return %NULL if constructed without units.
  **/
+GtkWidget*
+gwy_table_hscale_get_units(GtkObject *pivot)
+{
+    g_return_val_if_fail(pivot, NULL);
+    return (GtkWidget*)g_object_get_data(G_OBJECT(pivot), "units");
+}
 
 /**
  * gwy_table_hscale_get_middle_widget:
@@ -466,6 +744,12 @@ gwy_table_attach_hscale(GtkWidget *table,
  *
  * Gets the middle widget associated with a pivot object.
  **/
+GtkWidget*
+gwy_table_hscale_get_middle_widget(GtkObject *pivot)
+{
+    g_return_val_if_fail(pivot, NULL);
+    return (GtkWidget*)g_object_get_data(G_OBJECT(pivot), "middle_widget");
+}
 
 /************************** Mask colors ****************************/
 
