@@ -1,6 +1,6 @@
 /*
- *  @(#) $Id: gwydgetutils.h 15598 2013-11-11 12:33:32Z yeti-dn $
- *  Copyright (C) 2003-2005 David Necas (Yeti), Petr Klapetek.
+ *  @(#) $Id: gwydgetutils.h 19847 2017-06-06 08:22:50Z yeti-dn $
+ *  Copyright (C) 2003-2017 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -32,35 +32,35 @@ G_BEGIN_DECLS
 #define gwy_adjustment_get_int(adj) \
     ((gint)(gtk_adjustment_get_value(GTK_ADJUSTMENT(adj)) + 0.5))
 
-GtkWidget*   gwy_table_attach_spinbutton    (GtkWidget *table,
-                                             gint row,
-                                             const gchar *name,
-                                             const gchar *units,
-                                             GtkObject *adj);
-void         gwy_table_attach_row           (GtkWidget *table,
-                                             gint row,
-                                             const gchar *name,
-                                             const gchar *units,
-                                             GtkWidget *middle_widget);
-GtkWidget*   gwy_table_attach_hscale        (GtkWidget *table,
-                                             gint row,
-                                             const gchar *name,
-                                             const gchar *units,
-                                             GtkObject *pivot,
-                                             GwyHScaleStyle style);
-void         gwy_table_hscale_set_sensitive (GtkObject *pivot,
-                                             gboolean sensitive);
-
-#define      gwy_table_hscale_get_scale(pivot) \
-    ((GtkWidget*)(g_object_get_data(G_OBJECT(pivot), "scale")))
-#define      gwy_table_hscale_get_check(pivot) \
-    ((GtkWidget*)(g_object_get_data(G_OBJECT(pivot), "check")))
-#define      gwy_table_hscale_get_label(pivot) \
-    ((GtkWidget*)(g_object_get_data(G_OBJECT(pivot), "label")))
-#define      gwy_table_hscale_get_units(pivot) \
-    ((GtkWidget*)(g_object_get_data(G_OBJECT(pivot), "units")))
-#define      gwy_table_hscale_get_middle_widget(pivot) \
-    ((GtkWidget*)(g_object_get_data(G_OBJECT(pivot), "middle_widget")))
+GtkWidget* gwy_table_attach_spinbutton       (GtkWidget *table,
+                                              gint row,
+                                              const gchar *name,
+                                              const gchar *units,
+                                              GtkObject *adj);
+void       gwy_table_attach_row              (GtkWidget *table,
+                                              gint row,
+                                              const gchar *name,
+                                              const gchar *units,
+                                              GtkWidget *middle_widget);
+GtkWidget* gwy_table_attach_hscale           (GtkWidget *table,
+                                              gint row,
+                                              const gchar *name,
+                                              const gchar *units,
+                                              GtkObject *pivot,
+                                              GwyHScaleStyle style);
+GtkWidget* gwy_table_attach_adjbar           (GtkWidget *table,
+                                              gint row,
+                                              const gchar *name,
+                                              const gchar *units,
+                                              GtkObject *pivot,
+                                              GwyHScaleStyle style);
+void       gwy_table_hscale_set_sensitive    (GtkObject *pivot,
+                                              gboolean sensitive);
+GtkWidget* gwy_table_hscale_get_scale        (GtkObject *pivot);
+GtkWidget* gwy_table_hscale_get_check        (GtkObject *pivot);
+GtkWidget* gwy_table_hscale_get_label        (GtkObject *pivot);
+GtkWidget* gwy_table_hscale_get_units        (GtkObject *pivot);
+GtkWidget* gwy_table_hscale_get_middle_widget(GtkObject *pivot);
 
 GtkWidget*   gwy_table_get_child_widget     (GtkWidget *table,
                                              gint row,
