@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: gwygraphareadialog.c 17484 2015-09-28 11:35:31Z yeti-dn $
+ *  @(#) $Id: gwygraphareadialog.c 20070 2017-07-12 07:48:27Z yeti-dn $
  *  Copyright (C) 2003-2007 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -98,10 +98,10 @@ _gwy_graph_area_dialog_init(GwyGraphAreaDialog *dialog)
     gint row;
 
     gtk_window_set_title(GTK_WINDOW(dialog), _("Curve Properties"));
-    dialog->prev = gwy_stock_like_button_new(_("Pre_v"), GWY_STOCK_LESS);
+    dialog->prev = gwy_stock_like_button_new(_("Pre_v"), GWY_STOCK_PREVIOUS);
     gtk_dialog_add_action_widget(GTK_DIALOG(dialog), dialog->prev,
                                  GWY_GRAPH_AREA_DIALOG_RESPONSE_PREV);
-    dialog->next = gwy_stock_like_button_new(_("_Next"), GWY_STOCK_MORE);
+    dialog->next = gwy_stock_like_button_new(_("_Next"), GWY_STOCK_NEXT);
     gtk_dialog_add_action_widget(GTK_DIALOG(dialog), dialog->next,
                                  GWY_GRAPH_AREA_DIALOG_RESPONSE_NEXT);
     gtk_dialog_add_button(GTK_DIALOG(dialog),
@@ -109,61 +109,53 @@ _gwy_graph_area_dialog_init(GwyGraphAreaDialog *dialog)
     gtk_dialog_set_default_response(GTK_DIALOG(dialog), GTK_RESPONSE_CLOSE);
     update_switcher_sensitivity(dialog);
 
-    table = gtk_table_new(7, 4, FALSE);
+    table = gtk_table_new(7, 3, FALSE);
     gtk_table_set_col_spacings(GTK_TABLE(table), 6);
     gtk_table_set_row_spacings(GTK_TABLE(table), 2);
     gtk_container_set_border_width(GTK_CONTAINER(table), 4);
     gtk_container_add(GTK_CONTAINER(GTK_DIALOG(dialog)->vbox), table);
     row = 0;
 
-    hbox = gtk_hbox_new(FALSE, 6);
-    gtk_table_attach(GTK_TABLE(table), hbox,
-                     0, 4, row, row+1, GTK_FILL, 0, 0, 0);
-
     dialog->curvetype_menu
         = gwy_enum_combo_box_new(gwy_graph_curve_type_get_enum(), -1,
                                  G_CALLBACK(curvetype_changed), dialog,
                                  0, TRUE);
-    gwy_table_attach_hscale(table, row, _("Plot _style:"), NULL,
+    gwy_table_attach_adjbar(table, row, _("Plot _style:"), NULL,
                             GTK_OBJECT(dialog->curvetype_menu),
-                            GWY_HSCALE_WIDGET);
+                            GWY_HSCALE_WIDGET_NO_EXPAND);
     row++;
 
-    hbox = gtk_hbox_new(FALSE, 4);
-    gtk_table_attach(GTK_TABLE(table), hbox,
-                     1, 3, row, row+1, GTK_FILL, 0, 0, 0);
-
     dialog->color_button = gwy_color_button_new();
     gwy_color_button_set_use_alpha(GWY_COLOR_BUTTON(dialog->color_button),
                                    FALSE);
-    gtk_box_pack_start(GTK_BOX(hbox), dialog->color_button, FALSE, FALSE, 0);
+    gwy_table_attach_adjbar(table, row, _("Pl_ot color:"), NULL,
+                            GTK_OBJECT(dialog->color_button),
+                            GWY_HSCALE_WIDGET_NO_EXPAND);
     g_signal_connect(dialog->color_button, "clicked",
                      G_CALLBACK(color_change), dialog);
 
+    hbox = gtk_widget_get_parent(dialog->color_button);
     dialog->color_selector = gwy_graph_color_combo_new();
-    gtk_box_pack_start(GTK_BOX(hbox), dialog->color_selector, FALSE, FALSE, 0);
+    gtk_box_pack_end(GTK_BOX(hbox), dialog->color_selector, FALSE, FALSE, 0);
+    gtk_container_child_set(GTK_CONTAINER(hbox), dialog->color_selector,
+                            "position", 1,
+                            NULL);
     g_signal_connect(dialog->color_selector, "changed",
                      G_CALLBACK(color_selected), dialog);
-
-    label = gtk_label_new_with_mnemonic(_("Pl_ot color:"));
-    gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
-    gtk_table_attach(GTK_TABLE(table), label,
-                     0, 1, row, row+1, GTK_FILL, 0, 0, 0);
-    gtk_label_set_mnemonic_widget(GTK_LABEL(label), dialog->color_button);
     row++;
 
     dialog->pointtype_menu
         = gwy_graph_combo_box_new(dialog, "point-type", TRUE,
                                   G_CALLBACK(_gwy_graph_get_point_type_store),
                                   GWY_GRAPH_POINT_SQUARE);
-    gwy_table_attach_hscale(table, row, _("Point _type:"), NULL,
+    gwy_table_attach_adjbar(table, row, _("Point _type:"), NULL,
                             GTK_OBJECT(dialog->pointtype_menu),
-                            GWY_HSCALE_WIDGET);
+                            GWY_HSCALE_WIDGET_NO_EXPAND);
     row++;
 
     dialog->pointsize = gtk_adjustment_new(6, 1, 50, 1, 5, 0);
-    gwy_table_attach_hscale(table, row, _("_Point size:"), "px",
-                            dialog->pointsize, 0);
+    gwy_table_attach_adjbar(table, row, _("_Point size:"), _("px"),
+                            dialog->pointsize, GWY_HSCALE_SQRT);
     g_signal_connect(dialog->pointsize, "value-changed",
                      G_CALLBACK(pointsize_changed), dialog);
     row++;
@@ -172,23 +164,24 @@ _gwy_graph_area_dialog_init(GwyGraphAreaDialog *dialog)
         = gwy_graph_combo_box_new(dialog, "line-style", FALSE,
                                   G_CALLBACK(_gwy_graph_get_line_style_store),
                                   GDK_LINE_SOLID);
-    gwy_table_attach_hscale(table, row, _("_Line type:"), NULL,
+    gwy_table_attach_adjbar(table, row, _("_Line type:"), NULL,
                             GTK_OBJECT(dialog->linestyle_menu),
-                            GWY_HSCALE_WIDGET);
+                            GWY_HSCALE_WIDGET_NO_EXPAND);
     row++;
 
     dialog->thickness = gtk_adjustment_new(6, 1, 50, 1, 5, 0);
-    gwy_table_attach_hscale(table, row, _("Line t_hickness:"), "px",
-                            dialog->thickness, 0);
+    gwy_table_attach_adjbar(table, row, _("Line t_hickness:"), _("px"),
+                            dialog->thickness, GWY_HSCALE_SQRT);
     g_signal_connect(dialog->thickness, "value-changed",
                      G_CALLBACK(thickness_changed), dialog);
     row++;
 
+    gtk_table_set_row_spacing(GTK_TABLE(table), row-1, 8);
     label = gtk_label_new_with_mnemonic(_("<b>Label Te_xt</b>"));
     gtk_label_set_use_markup(GTK_LABEL(label), TRUE);
     gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
     gtk_table_attach(GTK_TABLE(table), label,
-                     0, 3, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
+                     0, 2, row, row+1, GTK_FILL, 0, 0, 0);
     row++;
 
     dialog->sci_text = gwy_sci_text_new();
@@ -714,10 +707,7 @@ render_graph_color(G_GNUC_UNUSED GtkCellLayout *cell_layout,
             pixel = 0;
     }
     if (pixel)
-        pixel = 0xff
-                | ((guint32)(guchar)floor(255.99999*rgba.b) << 8)
-                | ((guint32)(guchar)floor(255.99999*rgba.g) << 16)
-                | ((guint32)(guchar)floor(255.99999*rgba.r) << 24);
+        pixel = 0xff | gwy_rgba_to_pixbuf_pixel(&rgba);
     gdk_pixbuf_fill(pixbuf, pixel);
     g_object_set(renderer, "pixbuf", pixbuf, NULL);
 }
