@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: gwygraphcurves.c 19071 2016-10-14 09:02:41Z yeti-dn $
+ *  @(#) $Id: gwygraphcurves.c 20070 2017-07-12 07:48:27Z yeti-dn $
  *  Copyright (C) 2007 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -371,10 +371,7 @@ render_column(GtkCellLayout *column,
             guint32 pixel;
 
             g_object_get(gcmodel, "color", &color, NULL);
-            pixel = 0xff
-                   | ((guint32)(guchar)floor(255.99999*color->b) << 8)
-                    | ((guint32)(guchar)floor(255.99999*color->g) << 16)
-                    | ((guint32)(guchar)floor(255.99999*color->r) << 24);
+            pixel = 0xff | gwy_rgba_to_pixbuf_pixel(color);
             gwy_rgba_free(color);
             gdk_pixbuf_fill(graph_curves->pixbuf, pixel);
         }
