@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: gwyradiobuttons.c 15598 2013-11-11 12:33:32Z yeti-dn $
+ *  @(#) $Id: gwyradiobuttons.c 19837 2017-06-05 11:40:09Z yeti-dn $
  *  Copyright (C) 2003 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -195,7 +195,7 @@ gwy_radio_buttons_attach_to_table(GSList *group,
     while (group) {
         gtk_table_attach(table, GTK_WIDGET(group->data),
                          0, colspan, row, row + 1,
-                         GTK_EXPAND | GTK_FILL, 0, 0, 0);
+                         GTK_FILL, 0, 0, 0);
         row++;
         group = g_slist_next(group);
     }
@@ -238,11 +238,13 @@ gwy_radio_buttons_set_current(GSList *group,
 gint
 gwy_radio_buttons_get_current(GSList *group)
 {
+    setup_quark();
     while (group) {
         g_return_val_if_fail(GTK_IS_RADIO_BUTTON(group->data), -1);
-        if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(group->data)))
+        if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(group->data))) {
             return GPOINTER_TO_INT(g_object_get_qdata(G_OBJECT(group->data),
                                                       gwyrb_quark));
+        }
         group = g_slist_next(group);
     }
 
@@ -263,6 +265,7 @@ gwy_radio_buttons_find(GSList *group,
                        gint value)
 {
     g_return_val_if_fail(group, NULL);
+    setup_quark();
     while (group) {
         g_return_val_if_fail(GTK_IS_RADIO_BUTTON(group->data), FALSE);
         if (GPOINTER_TO_INT(g_object_get_qdata(G_OBJECT(group->data),
