@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: gwystock.h 18961 2016-09-17 07:38:23Z yeti-dn $
+ *  @(#) $Id: gwystock.h 20258 2017-08-12 08:17:43Z yeti-dn $
  *  Copyright (C) 2003 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -40,9 +40,11 @@ G_BEGIN_DECLS
 #define GWY_STOCK_COLOR_RANGE_FULL               "gwy_color_range_full"
 #define GWY_STOCK_CONVOLUTION                    "gwy_convolution"
 #define GWY_STOCK_CORRECT_AFFINE                 "gwy_correct_affine"
+#define GWY_STOCK_CORRELATION_MASK               "gwy_correlation_mask"
 #define GWY_STOCK_CROP                           "gwy_crop"
 #define GWY_STOCK_CWT                            "gwy_cwt"
 #define GWY_STOCK_DATA_MEASURE                   "gwy_data_measure"
+#define GWY_STOCK_DISCONNECTED                   "gwy_disconnected"
 #define GWY_STOCK_DISTANCE                       "gwy_distance"
 #define GWY_STOCK_DISTANCE_TRANSFORM             "gwy_distance_transform"
 #define GWY_STOCK_DISTRIBUTION_ANGLE             "gwy_distribution_angle"
@@ -58,16 +60,23 @@ G_BEGIN_DECLS
 #define GWY_STOCK_FAVOURITE                      "gwy_favourite"
 #define GWY_STOCK_FFT                            "gwy_fft"
 #define GWY_STOCK_FFT_2D                         "gwy_fft_2d"
+#define GWY_STOCK_FFT_FILTER_1D                  "gwy_fft_filter_1d"
 #define GWY_STOCK_FFT_FILTER_2D                  "gwy_fft_filter_2d"
 #define GWY_STOCK_FILTER                         "gwy_filter"
 #define GWY_STOCK_FIND_PEAKS                     "gwy_find_peaks"
+#define GWY_STOCK_FIT_SHAPE                      "gwy_fit_shape"
 #define GWY_STOCK_FIX_ZERO                       "gwy_fix_zero"
 #define GWY_STOCK_FLIP_HORIZONTALLY              "gwy_flip_horizontally"
 #define GWY_STOCK_FLIP_VERTICALLY                "gwy_flip_vertically"
 #define GWY_STOCK_FRACTAL                        "gwy_fractal"
+#define GWY_STOCK_FRACTAL_CORRECTION             "gwy_fractal_correction"
+#define GWY_STOCK_FRACTAL_MEASURE                "gwy_fractal_measure"
 #define GWY_STOCK_GL_MATERIAL                    "gwy_gl_material"
 #define GWY_STOCK_GRADIENT_HORIZONTAL            "gwy_gradient_horizontal"
 #define GWY_STOCK_GRADIENT_VERTICAL              "gwy_gradient_vertical"
+#define GWY_STOCK_GRAIN_CORRELATION              "gwy_grain_correlation"
+#define GWY_STOCK_GRAIN_EXSCRIBED_CIRCLE         "gwy_grain_exscribed_circle"
+#define GWY_STOCK_GRAIN_INSCRIBED_CIRCLE         "gwy_grain_inscribed_circle"
 #define GWY_STOCK_GRAINS                         "gwy_grains"
 #define GWY_STOCK_GRAINS_EDGE                    "gwy_grains_edge"
 #define GWY_STOCK_GRAINS_EDGE_REMOVE             "gwy_grains_edge_remove"
@@ -75,9 +84,6 @@ G_BEGIN_DECLS
 #define GWY_STOCK_GRAINS_MEASURE                 "gwy_grains_measure"
 #define GWY_STOCK_GRAINS_REMOVE                  "gwy_grains_remove"
 #define GWY_STOCK_GRAINS_WATER                   "gwy_grains_water"
-#define GWY_STOCK_GRAIN_CORRELATION              "gwy_grain_correlation"
-#define GWY_STOCK_GRAIN_EXSCRIBED_CIRCLE         "gwy_grain_exscribed_circle"
-#define GWY_STOCK_GRAIN_INSCRIBED_CIRCLE         "gwy_grain_inscribed_circle"
 #define GWY_STOCK_GRAPH                          "gwy_graph"
 #define GWY_STOCK_GRAPH_ALIGN                    "gwy_graph_align"
 #define GWY_STOCK_GRAPH_CUT                      "gwy_graph_cut"
@@ -116,6 +122,8 @@ G_BEGIN_DECLS
 #define GWY_STOCK_LOCAL_SLOPE                    "gwy_local_slope"
 #define GWY_STOCK_LOGSCALE_HORIZONTAL            "gwy_logscale_horizontal"
 #define GWY_STOCK_LOGSCALE_VERTICAL              "gwy_logscale_vertical"
+#define GWY_STOCK_MARK_OUTLIERS                  "gwy_mark_outliers"
+#define GWY_STOCK_MARK_SCARS                     "gwy_mark_scars"
 #define GWY_STOCK_MARK_WITH                      "gwy_mark_with"
 #define GWY_STOCK_MASK                           "gwy_mask"
 #define GWY_STOCK_MASK_ADD                       "gwy_mask_add"
@@ -139,6 +147,7 @@ G_BEGIN_DECLS
 #define GWY_STOCK_MASK_RECT_EXCLUSIVE            "gwy_mask_rect_exclusive"
 #define GWY_STOCK_MASK_RECT_INCLUSIVE            "gwy_mask_rect_inclusive"
 #define GWY_STOCK_MASK_REMOVE                    "gwy_mask_remove"
+#define GWY_STOCK_MASK_SET                       "gwy_mask_set"
 #define GWY_STOCK_MASK_SHRINK                    "gwy_mask_shrink"
 #define GWY_STOCK_MASK_SUBTRACT                  "gwy_mask_subtract"
 #define GWY_STOCK_MASK_THIN                      "gwy_mask_thin"
@@ -148,12 +157,15 @@ G_BEGIN_DECLS
 #define GWY_STOCK_MUTUAL_CROP                    "gwy_mutual_crop"
 #define GWY_STOCK_NEURAL_APPLY                   "gwy_neural_apply"
 #define GWY_STOCK_NEURAL_TRAIN                   "gwy_neural_train"
+#define GWY_STOCK_NEXT                           "gwy_next"
+#define GWY_STOCK_NULL_OFFSETS                   "gwy_null_offsets"
 #define GWY_STOCK_PALETTES                       "gwy_palettes"
 #define GWY_STOCK_PATH_LEVEL                     "gwy_path_level"
 #define GWY_STOCK_POINTER_MEASURE                "gwy_pointer_measure"
+#define GWY_STOCK_POLY_DISTORT                   "gwy_poly_distort"
 #define GWY_STOCK_POLYNOM                        "gwy_polynom"
 #define GWY_STOCK_POLYNOM_LEVEL                  "gwy_polynom_level"
-#define GWY_STOCK_POLY_DISTORT                   "gwy_poly_distort"
+#define GWY_STOCK_PREVIOUS                       "gwy_previous"
 #define GWY_STOCK_PROFILE                        "gwy_profile"
 #define GWY_STOCK_PSDF_LOG_PHI                   "gwy_psdf_log_phi"
 #define GWY_STOCK_PSDF_SECTION                   "gwy_psdf_section"
@@ -161,6 +173,7 @@ G_BEGIN_DECLS
 #define GWY_STOCK_REMOVE_UNDER_MASK              "gwy_remove_under_mask"
 #define GWY_STOCK_ROTATE                         "gwy_rotate"
 #define GWY_STOCK_ROTATE_180                     "gwy_rotate_180"
+#define GWY_STOCK_ROTATE_3D                      "gwy_rotate_3d"
 #define GWY_STOCK_ROTATE_90_CCW                  "gwy_rotate_90_ccw"
 #define GWY_STOCK_ROTATE_90_CW                   "gwy_rotate_90_cw"
 #define GWY_STOCK_SCALE                          "gwy_scale"
@@ -180,12 +193,14 @@ G_BEGIN_DECLS
 #define GWY_STOCK_SYNTHETIC_COLUMNAR             "gwy_synthetic_columnar"
 #define GWY_STOCK_SYNTHETIC_DIFFUSION            "gwy_synthetic_diffusion"
 #define GWY_STOCK_SYNTHETIC_DOMAINS              "gwy_synthetic_domains"
+#define GWY_STOCK_SYNTHETIC_FIBRES               "gwy_synthetic_fibres"
 #define GWY_STOCK_SYNTHETIC_LATTICE              "gwy_synthetic_lattice"
 #define GWY_STOCK_SYNTHETIC_LINE_NOISE           "gwy_synthetic_line_noise"
 #define GWY_STOCK_SYNTHETIC_NOISE                "gwy_synthetic_noise"
 #define GWY_STOCK_SYNTHETIC_OBJECTS              "gwy_synthetic_objects"
 #define GWY_STOCK_SYNTHETIC_PARTICLES            "gwy_synthetic_particles"
 #define GWY_STOCK_SYNTHETIC_PATTERN              "gwy_synthetic_pattern"
+#define GWY_STOCK_SYNTHETIC_PHASES               "gwy_synthetic_phases"
 #define GWY_STOCK_SYNTHETIC_SPECTRAL             "gwy_synthetic_spectral"
 #define GWY_STOCK_SYNTHETIC_WAVES                "gwy_synthetic_waves"
 #define GWY_STOCK_TILT                           "gwy_tilt"
@@ -209,6 +224,7 @@ G_BEGIN_DECLS
 #define GWY_STOCK_VOLUME_SLICE                   "gwy_volume_slice"
 #define GWY_STOCK_VOLUMIZE                       "gwy_volumize"
 #define GWY_STOCK_VOLUMIZE_LAYERS                "gwy_volumize_layers"
+#define GWY_STOCK_XY_DENOISE                     "gwy_xy_denoise"
 #define GWY_STOCK_ZERO_MEAN                      "gwy_zero_mean"
 #define GWY_STOCK_ZOOM_1_1                       "gwy_zoom_1_1"
 #define GWY_STOCK_ZOOM_FIT                       "gwy_zoom_fit"
