@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: gwymodule-file.c 18070 2016-01-11 20:55:02Z yeti-dn $
+ *  @(#) $Id: gwymodule-file.c 19428 2017-01-18 12:22:20Z yeti-dn $
  *  Copyright (C) 2003,2004 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -436,7 +436,7 @@ static gboolean
 gwy_file_detect_fill_info(GwyFileDetectInfo *fileinfo,
                           gboolean only_name)
 {
-    struct stat st;
+    GStatBuf st;
     FILE *fh;
 
     g_return_val_if_fail(fileinfo && fileinfo->name, FALSE);
