@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: gwymodulebrowser.c 15598 2013-11-11 12:33:32Z yeti-dn $
+ *  @(#) $Id: gwymodulebrowser.c 20051 2017-07-10 09:11:41Z yeti-dn $
  *  Copyright (C) 2003 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -25,7 +25,6 @@
 #include <libgwyddion/gwymacros.h>
 #include <libgwyddion/gwyutils.h>
 #include <libgwymodule/gwymodulebrowser.h>
-#include "gwymoduleinternal.h"
 
 static GtkWidget* gwy_module_browser_construct    (GtkWidget *parent);
 static GtkWidget* gwy_module_browser_info_table   (GtkWidget *parent);
@@ -105,14 +104,14 @@ gwy_module_browser_store_module(const gchar *name,
 }
 
 static void
-gwy_module_browser_store_failure(G_GNUC_UNUSED const gchar *filename,
-                                 _GwyModuleFailureInfo *fail_info,
+gwy_module_browser_store_failure(GwyModuleFailureInfo *fail_info,
                                  GtkListStore *store)
 {
     GtkTreeIter iter;
+    const gchar *name = fail_info->modname ? fail_info->modname : "???";
 
     gtk_list_store_insert_with_values(store, &iter, G_MAXINT,
-                                      MODEL_NAME, fail_info->modname,
+                                      MODEL_NAME, name,
                                       MODEL_INFO, fail_info,
                                       MODEL_FAILED, TRUE,
                                       -1);
@@ -127,7 +126,7 @@ gwy_module_browser_render(G_GNUC_UNUSED GtkTreeViewColumn *column,
 {
     const gchar *name;
     const GwyModuleInfo *mod_info;
-    const _GwyModuleFailureInfo *fail_info;
+    const GwyModuleFailureInfo *fail_info;
     gboolean failed;
     const gchar *text;
 
@@ -202,8 +201,7 @@ gwy_module_browser_construct(GtkWidget *parent)
                                G_TYPE_POINTER,
                                G_TYPE_BOOLEAN);
     gwy_module_foreach((GHFunc)gwy_module_browser_store_module, store);
-    _gwy_module_failure_foreach((GHFunc)gwy_module_browser_store_failure,
-                                store);
+    gwy_module_failure_foreach((GFunc)gwy_module_browser_store_failure, store);
     gtk_tree_sortable_set_sort_func(GTK_TREE_SORTABLE(store),
                                     MODEL_NAME, compare_modules, NULL, NULL);
     gtk_tree_sortable_set_sort_column_id(GTK_TREE_SORTABLE(store), MODEL_NAME,
@@ -283,7 +281,7 @@ update_module_info_cb(GtkWidget *tree,
     GtkTreeModel *store;
     GtkTreeSelection *selection;
     const GwyModuleInfo *mod_info;
-    const _GwyModuleFailureInfo *fail_info;
+    const GwyModuleFailureInfo *fail_info;
     const gchar *name;
     gboolean failed;
     GtkTreeIter iter;
@@ -317,7 +315,7 @@ update_module_info_cb(GtkWidget *tree,
         gtk_label_set_text(label, fail_info->filename);
 
         label = GTK_LABEL(g_object_get_data(G_OBJECT(parent), "failure"));
-        gtk_label_set_text(label, fail_info->message);
+        gtk_label_set_text(label, fail_info->err_message);
 
         return;
     }
