@@ -1,6 +1,6 @@
 /*
- *  @(#) $Id: gwymoduleloader.c 19278 2016-11-16 16:51:38Z yeti-dn $
- *  Copyright (C) 2003,2004 David Necas (Yeti), Petr Klapetek.
+ *  @(#) $Id: gwymoduleloader.c 20052 2017-07-10 09:12:58Z yeti-dn $
+ *  Copyright (C) 2003-2017 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -40,20 +40,38 @@ typedef struct {
     gpointer data;
 } GwyModuleForeachData;
 
-static gboolean             check_python_availability    (void);
-static void                 gwy_load_modules_in_dir      (GDir *gdir,
-                                                          const gchar *dirname,
-                                                          GHashTable *mods);
-static gboolean             gwy_module_pedantic_check    (_GwyModuleInfoInternal *iinfo);
-static void                 gwy_module_get_rid_of        (const gchar *modname);
-static void                 gwy_module_init              (void);
-static const GwyModuleInfo* gwy_module_do_register_module(const gchar *modulename,
-                                                          GHashTable *mods,
-                                                          GError **error);
-static void                 gwy_module_register_fail     (GError *myerr,
-                                                          GError **error,
-                                                          const gchar *modname,
-                                                          const gchar *filename);
+typedef struct {
+    GFunc func;
+    gpointer data;
+} GwyModuleFailForeachData;
+
+static gboolean             check_python_availability     (void);
+static void                 gwy_load_modules_in_dir       (GDir *gdir,
+                                                           const gchar *dirname,
+                                                           GHashTable *mods);
+static gboolean             gwy_module_pedantic_check     (_GwyModuleInfoInternal *iinfo);
+static void                 gwy_module_get_rid_of         (const gchar *modname);
+static void                 gwy_module_init               (void);
+static const GwyModuleInfo* gwy_module_do_register_module (const gchar *modulename,
+                                                           GHashTable *mods,
+                                                           GError **error);
+static gboolean             gwy_module_check_module_name  (const gchar *modname,
+                                                           GHashTable *mods,
+                                                           GError **error);
+static gboolean             register_module_with_info     (GHashTable *mods,
+                                                           const GwyModuleInfo *mod_info,
+                                                           const gchar *filename,
+                                                           gchar *modname,
+                                                           gboolean in_bundle,
+                                                           GError **error);
+static gchar*               gwy_module_figure_out_name    (const gchar *filename);
+static void                 gwy_module_register_fail      (GError *myerr,
+                                                           GError **error,
+                                                           const gchar *modname,
+                                                           const gchar *filename);
+static GHashTable*          gwy_module_get_blocking_table (gboolean do_create);
+static gboolean             gwy_module_filename_is_blocked(const gchar *filename);
+static gboolean             gwy_module_name_is_blocked    (const gchar *modname);
 
 static GHashTable *modules = NULL;
 static GHashTable *failures = NULL;
@@ -89,6 +107,9 @@ gwy_module_error_quark(void)
  * It can be called several times (on different directories).  No errors are
  * reported, register modules individually with gwy_module_register_module()
  * to get registration errors.
+ *
+ * If you need to prevent specific modules from loading use
+ * gwy_module_disable_registration() beforehand.
  **/
 void
 gwy_module_register_modules(const gchar **paths)
@@ -132,13 +153,39 @@ _gwy_module_add_registered_function(const gchar *prefix,
     return TRUE;
 }
 
-
-void
-_gwy_module_failure_foreach(GHFunc function,
-                            gpointer data)
+static void
+gwy_module_failure_foreach_one(G_GNUC_UNUSED const gchar *key,
+                               _GwyModuleFailureInfoInternal *finfo,
+                               GwyModuleFailForeachData *data)
 {
-    if (failures)
-        g_hash_table_foreach(failures, function, data);
+    data->func((GwyModuleFailureInfo*)finfo, data->data);
+}
+
+/**
+ * gwy_module_failure_foreach:
+ * @function: A #GFunc run for each module registration failure.
+ * @data: User data.
+ *
+ * Runs @function for each module that failed to register.
+ *
+ * It passes the failure info (#GwyModuleFailureInfo) as the data argument.
+ * It should be modified.
+ *
+ * Since: 2.49
+ **/
+void
+gwy_module_failure_foreach(GFunc function, gpointer data)
+{
+    GwyModuleFailForeachData fdata;
+
+    if (!failures)
+        return;
+
+    g_return_if_fail(function);
+    fdata.func = function;
+    fdata.data = data;
+    g_hash_table_foreach(failures,
+                         (GHFunc)&gwy_module_failure_foreach_one, &fdata);
 }
 
 static void
@@ -146,7 +193,7 @@ gwy_module_foreach_one(const gchar *name,
                        _GwyModuleInfoInternal *iinfo,
                        GwyModuleForeachData *fdata)
 {
-    fdata->func((gpointer)name, iinfo->mod_info, fdata->data);
+    fdata->func((gpointer)name, (gpointer)iinfo->mod_info, fdata->data);
 }
 
 /**
@@ -229,6 +276,9 @@ gwy_module_get_functions(const gchar *name)
  *
  * Loads a single module.
  *
+ * This function also works with bundles.  The returned module info is for the
+ * bundle and thus not of much use.
+ *
  * Returns: Module info on success, %NULL on failure.
  **/
 const GwyModuleInfo*
@@ -247,20 +297,25 @@ gwy_module_register_fail(GError *myerr,
                          const gchar *modname,
                          const gchar *filename)
 {
-    _GwyModuleFailureInfo *finfo;
+    _GwyModuleFailureInfoInternal *finfo;
 
     if (!failures)
         failures = g_hash_table_new(g_str_hash, g_str_equal);
 
-    if (g_hash_table_lookup(failures, filename))
+    if (g_hash_table_lookup(failures, filename)) {
+        g_clear_error(&myerr);
         return;
+    }
 
     g_return_if_fail(myerr);
-    finfo = g_new(_GwyModuleFailureInfo, 1);
+    finfo = g_new(_GwyModuleFailureInfoInternal, 1);
+    finfo->key = g_strconcat(filename, "/", modname, NULL);
     finfo->modname = g_strdup(modname);
     finfo->filename = g_strdup(filename);
-    finfo->message = g_strdup(myerr->message);
-    g_hash_table_insert(failures, finfo->filename, finfo);
+    finfo->err_message = g_strdup(myerr->message);
+    finfo->err_domain = myerr->domain;
+    finfo->err_code = myerr->code;
+    g_hash_table_insert(failures, finfo->key, finfo);
 
     g_propagate_error(error, myerr);
 }
@@ -272,44 +327,13 @@ gwy_module_do_register_module(const gchar *filename,
 {
     GModule *mod;
     gboolean ok;
-    _GwyModuleInfoInternal *iinfo;
     GwyModuleInfo *mod_info = NULL;
     GwyModuleQueryFunc query;
-    gchar *modname, *s;
+    gchar *modname;
     GError *err = NULL;
 
-    s = g_path_get_basename(filename);
-    modname = g_ascii_strdown(s, -1);
-    g_free(s);
-    /* FIXME: On normal platforms module names have an extension, but if
-     * it doesn't, just get over it.  This can happen only with explicit
-     * gwy_module_register_module() as gwy_load_modules_in_dir() accepts
-     * only sane names. */
-    if ((s = strchr(modname, '.')))
-        *s = '\0';
-    if (!*modname) {
-        g_set_error(&err, GWY_MODULE_ERROR, GWY_MODULE_ERROR_NAME,
-                    "Module name is empty");
-        gwy_module_register_fail(err, error, modname, filename);
-        g_free(modname);
-        return NULL;
-    }
-
-    if (!gwy_strisident(modname, "_-", NULL))
-        g_warning("Module name `%s' is not a valid identifier. "
-                  "It may be rejected in future.", modname);
-
-    if (g_hash_table_lookup(mods, modname)) {
-        g_set_error(&err, GWY_MODULE_ERROR, GWY_MODULE_ERROR_DUPLICATE,
-                    "Module was already registered");
-        gwy_module_register_fail(err, error, modname, filename);
-        g_free(modname);
-        return NULL;
-    }
-
-    if (gwy_strequal(modname, "pygwy") && !check_python_availability()) {
-        g_set_error(&err, GWY_MODULE_ERROR, GWY_MODULE_ERROR_OPEN,
-                    "Avoiding to register pygwy if Python is unavailable.");
+    modname = gwy_module_figure_out_name(filename);
+    if (!gwy_module_check_module_name(modname, mods, &err)) {
         gwy_module_register_fail(err, error, modname, filename);
         g_free(modname);
         return NULL;
@@ -340,16 +364,138 @@ gwy_module_do_register_module(const gchar *filename,
 
     if (ok) {
         mod_info = query();
-        if (!mod_info) {
-            g_set_error(&err, GWY_MODULE_ERROR, GWY_MODULE_ERROR_INFO,
-                        "Module info is NULL");
-            gwy_module_register_fail(err, error, modname, filename);
-            ok = FALSE;
+        /* register_module_with_info() always consumes (or frees) modname */
+        ok = register_module_with_info(mods, mod_info, filename, modname, FALSE,
+                                       error);
+        if (ok) {
+            gwy_debug("Making module `%s' resident.", filename);
+            g_module_make_resident(mod);
         }
+        else {
+            if (!g_module_close(mod)) {
+                g_critical("Cannot unload module `%s': %s",
+                           filename, g_module_error());
+            }
+        }
+    }
+    else
+        g_free(modname);
+
+    currenly_registered_module = NULL;
+
+    return ok ? mod_info : NULL;
+}
+
+static gboolean
+register_module_bundle(GHashTable *mods, const GwyModuleInfo *bundle_info,
+                       const gchar *filename, const gchar *bundlename,
+                       GError **error)
+{
+    const GwyModuleInfo *mod_info;
+    GwyModuleQueryFunc query;
+    const GwyModuleRecord *records;
+    GwyModuleBundleRegisterFunc register_bundle;
+    GError *err = NULL;
+    gchar *modname;
+    guint i, nok = 0;
+
+    if (!bundle_info->register_func) {
+        g_set_error(&err, GWY_MODULE_ERROR, GWY_MODULE_ERROR_ABI,
+                    "Module bundle %s info has no registration function",
+                    bundlename);
+        gwy_module_register_fail(err, error, bundlename, filename);
+        return FALSE;
+    }
+
+    register_bundle = (GwyModuleBundleRegisterFunc)(bundle_info->register_func);
+    records = register_bundle();
+    if (!records) {
+        g_set_error(&err, GWY_MODULE_ERROR, GWY_MODULE_ERROR_ABI,
+                    "Module bundle %s returned NULL module records",
+                    bundlename);
+        gwy_module_register_fail(err, error, bundlename, filename);
+        return FALSE;
+    }
+
+    for (i = 0; records[i].query && records[i].name; i++) {
+        gwy_debug("bundle module record for %s", records[i].name);
+        if (gwy_module_name_is_blocked(records[i].name))
+            continue;
+
+        err = NULL;
+        if (!gwy_module_check_module_name(records[i].name, mods, &err)) {
+            gwy_module_register_fail(err, error, records[i].name, filename);
+            continue;
+        }
+
+        query = records[i].query;
+        modname = g_strdup(records[i].name);
+        currenly_registered_module = modname;
+        mod_info = query();
+        if (mod_info) {
+            /* TODO: Must again check duplicit names, etc. */
+            if (register_module_with_info(mods, mod_info, filename,
+                                          modname, TRUE, NULL))
+                nok++;
+        }
+        else
+            g_free(modname);
+
+        currenly_registered_module = NULL;
+    }
+
+    if (nok > 0)
+        return TRUE;
+
+    /* FIXME: Could be report errors in more detail? */
+    g_set_error(error, GWY_MODULE_ERROR, GWY_MODULE_ERROR_ABI,
+                "Module bundle %s did not successfully register any module",
+                bundlename);
+    return FALSE;
+}
+
+static gboolean
+register_module_with_info(GHashTable *mods, const GwyModuleInfo *mod_info,
+                          const gchar *filename, gchar *modname,
+                          gboolean in_bundle, GError **error)
+{
+    _GwyModuleInfoInternal *iinfo;
+    GError *err = NULL;
+    gboolean ok = TRUE;
+    guint abi_version;
+
+    if (!mod_info) {
+        g_set_error(&err, GWY_MODULE_ERROR, GWY_MODULE_ERROR_INFO,
+                    "Module info is NULL");
+        gwy_module_register_fail(err, error, modname, filename);
+        ok = FALSE;
     }
 
     if (ok) {
-        ok = mod_info->abi_version == GWY_MODULE_ABI_VERSION;
+        abi_version = mod_info->abi_version;
+        if (abi_version & GWY_MODULE_BUNDLE_FLAG) {
+            gwy_debug("bundle flag found on %s", filename);
+            if (in_bundle) {
+                g_set_error(&err, GWY_MODULE_ERROR, GWY_MODULE_ERROR_NESTING,
+                            "Nested module bundles are insane "
+                            "and not supported.");
+                gwy_module_register_fail(err, error, modname, filename);
+                g_free(modname);
+                return FALSE;
+            }
+            abi_version &= ~(GWY_MODULE_BUNDLE_FLAG);
+            if (abi_version == GWY_MODULE_ABI_VERSION) {
+                ok = register_module_bundle(mods, mod_info,
+                                            filename, modname, error);
+                g_free(modname);
+                return ok;
+            }
+            ok = FALSE;
+        }
+        else {
+            ok = (abi_version == GWY_MODULE_ABI_VERSION);
+        }
+
         if (!ok) {
             g_set_error(&err, GWY_MODULE_ERROR, GWY_MODULE_ERROR_ABI,
                         "Module ABI version %d differs from %d",
@@ -359,12 +505,12 @@ gwy_module_do_register_module(const gchar *filename,
     }
 
     if (ok) {
-        ok = mod_info->register_func
-                && mod_info->blurb && *mod_info->blurb
-                && mod_info->author && *mod_info->author
-                && mod_info->version && *mod_info->version
-                && mod_info->copyright && *mod_info->copyright
-                && mod_info->date && *mod_info->date;
+        ok = (mod_info->register_func
+              && mod_info->blurb && *mod_info->blurb
+              && mod_info->author && *mod_info->author
+              && mod_info->version && *mod_info->version
+              && mod_info->copyright && *mod_info->copyright
+              && mod_info->date && *mod_info->date);
         if (!ok) {
             g_set_error(&err, GWY_MODULE_ERROR, GWY_MODULE_ERROR_ABI,
                         "Module info has missing/invalid fields");
@@ -394,25 +540,63 @@ gwy_module_do_register_module(const gchar *filename,
 
         if (ok)
             gwy_module_pedantic_check(iinfo);
-        else {
+        else
             gwy_module_get_rid_of(iinfo->name);
-            modname = NULL;
-        }
     }
-
-    if (ok) {
-        gwy_debug("Making module `%s' resident.", filename);
-        g_module_make_resident(mod);
-    }
-    else {
-        if (!g_module_close(mod))
-            g_critical("Cannot unload module `%s': %s",
-                       filename, g_module_error());
+    else
         g_free(modname);
-    }
-    currenly_registered_module = NULL;
 
-    return ok ? mod_info : NULL;
+    return ok;
+}
+
+static gchar*
+gwy_module_figure_out_name(const gchar *filename)
+{
+    gchar *modname, *s;
+    guint i;
+
+    modname = g_path_get_basename(filename);
+    for (i = 0; modname[i]; i++)
+        modname[i] = g_ascii_tolower(modname[i]);
+
+    /* FIXME: On normal platforms module names have an extension, but if
+     * it doesn't, just get over it.  This can happen only with explicit
+     * gwy_module_register_module() as gwy_load_modules_in_dir() accepts
+     * only sane names. */
+    if ((s = strchr(modname, '.')))
+        *s = '\0';
+
+    return modname;
+}
+
+static gboolean
+gwy_module_check_module_name(const gchar *modname,
+                             GHashTable *mods,
+                             GError **error)
+{
+    if (!modname || !*modname) {
+        g_set_error(error, GWY_MODULE_ERROR, GWY_MODULE_ERROR_NAME,
+                    "Module name is empty");
+        return FALSE;
+    }
+
+    if (!gwy_strisident(modname, "_-", NULL))
+        g_warning("Module name `%s' is not a valid identifier. "
+                  "It may be rejected in future.", modname);
+
+    if (g_hash_table_lookup(mods, modname)) {
+        g_set_error(error, GWY_MODULE_ERROR, GWY_MODULE_ERROR_DUPLICATE,
+                    "Module was already registered");
+        return FALSE;
+    }
+
+    if (gwy_strequal(modname, "pygwy") && !check_python_availability()) {
+        g_set_error(error, GWY_MODULE_ERROR, GWY_MODULE_ERROR_OPEN,
+                    "Avoiding to register pygwy if Python is unavailable.");
+        return FALSE;
+    }
+
+    return TRUE;
 }
 
 /* XXX: If python is not available loading pygwy can pop up weird boxes.  Fix
@@ -492,9 +676,15 @@ gwy_load_modules_in_dir(GDir *gdir,
         if (!g_str_has_suffix(filename, "." G_MODULE_SUFFIX))
 #endif
             continue;
-        modulename = g_build_filename(dirname, filename, NULL);
-        gwy_module_do_register_module(modulename, mods, NULL);
-        g_free(modulename);
+
+        /* FIXME: Should we block bundles here?  Probably, because we may want
+         * to block things *before* we try to dlopen() them.  This allows to
+         * get out of some hairy situations. */
+        if (!gwy_module_filename_is_blocked(filename)) {
+            modulename = g_build_filename(dirname, filename, NULL);
+            gwy_module_do_register_module(modulename, mods, NULL);
+            g_free(modulename);
+        }
     }
 }
 
@@ -646,10 +836,142 @@ gwy_module_lookup(const gchar *name)
 {
     _GwyModuleInfoInternal *info;
 
+    if (!modules)
+        return NULL;
+
     info = g_hash_table_lookup(modules, name);
     return info ? info->mod_info : NULL;
 }
 
+/**
+ * gwy_module_disable_registration:
+ * @name: A module name.
+ *
+ * Prevents the registration of a module of given name.
+ *
+ * This function blocks future module registration using
+ * gwy_module_register_modules().  Already loaded modules are unaffected.
+ * The low-level module loading function gwy_module_register_module() always
+ * attempts to load the module, even if blocked.
+ *
+ * Since: 2.48
+ **/
+void
+gwy_module_disable_registration(const gchar *name)
+{
+    GHashTable *blocked_modules;
+    GQuark quark;
+
+    g_return_if_fail(name);
+    blocked_modules = gwy_module_get_blocking_table(TRUE);
+    quark = g_quark_from_string(name);
+    g_hash_table_insert(blocked_modules,
+                        GSIZE_TO_POINTER(quark), GINT_TO_POINTER(TRUE));
+}
+
+/**
+ * gwy_module_enable_registration:
+ * @name: A module name.
+ *
+ * Unblocks the registration of a module of given name.
+ *
+ * This function influences future module registration.  Already loaded modules
+ * are unaffected.
+ *
+ * Since: 2.48
+ **/
+void
+gwy_module_enable_registration(const gchar *name)
+{
+    GHashTable *blocked_modules;
+    GQuark quark;
+
+    g_return_if_fail(name);
+    blocked_modules = gwy_module_get_blocking_table(FALSE);
+    if (!blocked_modules)
+        return;
+
+    quark = g_quark_from_string(name);
+    g_hash_table_remove(blocked_modules, GSIZE_TO_POINTER(quark));
+}
+
+/**
+ * gwy_module_is_enabled:
+ * @name: A module name.
+ *
+ * Reports whether the registration of a module is enabled.
+ *
+ * If the registration of module @name was prevented using
+ * gwy_module_disable_registration() and not subsequently re-enabled
+ * using gwy_module_enabled_registration() this function returns %FALSE.
+ *
+ * The reported values only represents the current state of blocking.  A module
+ * @name could have been loaded when it was not blocked.
+ *
+ * Returns: %TRUE if module @name can be registered; %FALSE when it is blocked
+ *          from registration.
+ *
+ * Since: 2.48
+ **/
+gboolean
+gwy_module_is_enabled(const gchar *name)
+{
+    GHashTable *blocked_modules;
+    GQuark quark;
+
+    g_return_val_if_fail(name, FALSE);
+    blocked_modules = gwy_module_get_blocking_table(FALSE);
+    if (!blocked_modules)
+        return TRUE;
+
+    quark = g_quark_from_string(name);
+    return !g_hash_table_lookup(blocked_modules, GSIZE_TO_POINTER(quark));
+}
+
+static gboolean
+gwy_module_filename_is_blocked(const gchar *filename)
+{
+    GHashTable *blocked_modules;
+    gchar *modname;
+    GQuark quark;
+
+    blocked_modules = gwy_module_get_blocking_table(FALSE);
+    if (!blocked_modules)
+        return FALSE;
+
+    modname = gwy_module_figure_out_name(filename);
+    quark = g_quark_from_string(modname);
+    g_free(modname);
+
+    return !!g_hash_table_lookup(blocked_modules, GSIZE_TO_POINTER(quark));
+}
+
+static gboolean
+gwy_module_name_is_blocked(const gchar *modname)
+{
+    GHashTable *blocked_modules;
+    GQuark quark;
+
+    blocked_modules = gwy_module_get_blocking_table(FALSE);
+    if (!blocked_modules)
+        return FALSE;
+
+    quark = g_quark_from_string(modname);
+
+    return !!g_hash_table_lookup(blocked_modules, GSIZE_TO_POINTER(quark));
+}
+
+static GHashTable*
+gwy_module_get_blocking_table(gboolean do_create)
+{
+    static GHashTable *blocked_modules = NULL;
+
+    if (!blocked_modules && do_create)
+        blocked_modules = g_hash_table_new(g_direct_hash, g_direct_equal);
+
+    return blocked_modules;
+}
+
 /************************** Documentation ****************************/
 
 /**
@@ -679,7 +1001,7 @@ gwy_module_lookup(const gchar *name)
  * The module query must be the ONLY exported symbol from a module.
  *
  * This macro does The Right Thing necessary to export module info in a way
- * Gwyddion understands it. Put #GWY_MODULE_QUERY with the module info
+ * Gwyddion understands it. Put %GWY_MODULE_QUERY with the module info
  * (#GwyModuleInfo) of your module as its argument on a line (with NO
  * semicolon after).
  *
@@ -695,26 +1017,40 @@ gwy_module_lookup(const gchar *name)
  * it is compiled using a C++ compiler.
  **/
 
-/*
- * GWY_MODULE_QUERY_BUILTIN:
+/**
+ * GWY_MODULE_QUERY2:
  * @mod_info: The #GwyModuleInfo structure to return as module info.
- * @name: Module name.  This is the base name of the source file with dashes
- *        and other non-identifier characters changed to underscores.  For
- *        instance module "nt-mdt.c" should pass nt_mdt.
+ * @mod_name: Module name.  It should be identical to the file name the module
+ *            would have if installed standalone, without any extension.
+ *            For instance module implemented in "nt-mdt.c" and installed as
+ *            "nt-mdt.so" or "nt-mdt.dll" (or with other extension, depending
+ *            on the platform) should pass "nt-mdt".
  *
- * The declaration of module info query for built-in modules.
+ * The module query must be the ONLY exported symbol from a module.
  *
- * See GWY_MODULE_QUERY() for discussion.  Using this macro instead of
- * GWY_MODULE_QUERY() changes the name of the exported query function and
- * enables integrating the module into the gwyddion executable.  This obviously
- * makes sense only for core modules that are distributed with Gwyddion,
- * however, it does no harm in third party modules as this macro functions
- * differently from GWY_MODULE_QUERY() only if preprocessor symbol
- * %GWY_MODULE_IS_BUILTIN is defined (which you do not do in an external
- * module).
+ * See %GWY_MODULE_QUERY for discussion.
  *
- * Since: 2.22
- */
+ * This macro is intended for modules that can be bundled together to one big
+ * shared library for time and space optimization.  This mostly makes sense
+ * only for modules included in Gwyddion itself as it contains hundreds of
+ * modules.
+ *
+ * However, it safe to use in third party modules because if modules
+ * are not bundled the macro behaves exactly as %GWY_MODULE_QUERY and the
+ * @mod_name argument is just ignored.  The macro expansion differs only when
+ * %GWY_MODULE_BUNDLING is defined when including the "gwymoduleloader.h"
+ * header.
+ *
+ * Since: 2.49
+ **/
+
+/**
+ * GWY_MODULE_BUNDLE_FLAG
+ *
+ * Value to bitwise combine with %GWY_MODULE_ABI_VERSION to indicate a bundle.
+ *
+ * Since: 2.49
+ **/
 
 /**
  * GwyModuleRegisterFunc:
@@ -724,10 +1060,14 @@ gwy_module_lookup(const gchar *name)
  * It actually runs particular featrue registration functions, like
  * gwy_file_func_register() and gwy_process_func_register().
  *
+ * If the module has a complex initialisation it may be safer to simply not
+ * register any function but return %TRUE even if it fails to set up itself
+ * correctly.  The module feature unregistration is somewhat crude and,
+ * generally, unregisteration may lead to disaster when shared library
+ * unloading has unexpected side effects.
+ *
  * Returns: Whether the registration succeeded.  When it returns %FALSE, the
- *          module and its features are unloaded (FIXME: maybe. Currenly only
- *          module is unloaded, features are NOT unregistered, this can lead
- *          to all kinds of disasters).
+ *          module and its features are unregistered.
  **/
 
 /**
@@ -742,6 +1082,17 @@ gwy_module_lookup(const gchar *name)
  * Returns: The module info struct.
  **/
 
+/**
+ * GwyModuleBundleRegisterFunc:
+ *
+ * Module bundle query function type.
+ *
+ * It returns an array of module records for all modules in the bundle,
+ * terminated by {%NULL, %NULL}.
+ *
+ * Since: 2.49
+ **/
+
 /**
  * GwyModuleInfo:
  * @abi_version: Gwyddion module ABI version, should be always
@@ -758,6 +1109,29 @@ gwy_module_lookup(const gchar *name)
  * Module information returned by GWY_MODULE_QUERY().
  **/
 
+/**
+ * GwyModuleFailureInfo:
+ * @filename: Name of the file the module was loaded from.
+ * @modname: Module name (can be %NULL and contain odd bytes).
+ * @err_message: Error message from the failed module registration.
+ * @err_domain: #GError domain from the failed module registration.
+ * @err_code: #GError code from the failed module registration.
+ *
+ * Information about a failed module registration.
+ *
+ * Since: 2.49
+ **/
+
+/**
+ * GwyModuleRecord:
+ * @query: Module query function.
+ * @name: Module name (base file name without extensions).
+ *
+ * Module record returned by bundle query function.
+ *
+ * Since: 2.49
+ **/
+
 /**
  * GwyRunType:
  * @GWY_RUN_NONE: None.
@@ -796,6 +1170,7 @@ gwy_module_lookup(const gchar *name)
  * @GWY_MODULE_ERROR_INFO: Module query function provided %NULL info.
  * @GWY_MODULE_ERROR_REGISTER: The registration function returned %FALSE; or
  *                             the module did not register any function.
+ * @GWY_MODULE_ERROR_NESTING: Nested module bundle found.  (Since 2.49)
  *
  * Type of module loading and registration error.
  **/
