@@ -1,6 +1,6 @@
 /*
- *  @(#) $Id: gwymoduleloader.h 15598 2013-11-11 12:33:32Z yeti-dn $
- *  Copyright (C) 2003,2004 David Necas (Yeti), Petr Klapetek.
+ *  @(#) $Id: gwymoduleloader.h 20051 2017-07-10 09:11:41Z yeti-dn $
+ *  Copyright (C) 2003,2004,2017 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -27,6 +27,7 @@
 G_BEGIN_DECLS
 
 #define GWY_MODULE_ABI_VERSION 2
+#define GWY_MODULE_BUNDLE_FLAG 256u
 
 #ifdef  __cplusplus
 #define __GWY_MODULE_QUERY_EXTERN_C extern "C"
@@ -36,7 +37,15 @@ G_BEGIN_DECLS
 
 #define GWY_MODULE_QUERY(mod_info) \
     __GWY_MODULE_QUERY_EXTERN_C G_MODULE_EXPORT GwyModuleInfo* \
-    _gwy_module_query(void) { return &mod_info; } \
+    _gwy_module_query(void) { return &mod_info; }
+
+#ifdef GWY_MODULE_BUNDLING
+#define GWY_MODULE_QUERY2(mod_info,mod_name) \
+    __GWY_MODULE_QUERY_EXTERN_C G_GNUC_INTERNAL GwyModuleInfo* \
+    _gwy_module_query__##mod_name(void) { return &mod_info; }
+#else
+#define GWY_MODULE_QUERY2(mod_info,mod_name) GWY_MODULE_QUERY(mod_info)
+#endif
 
 #define GWY_MODULE_ERROR gwy_module_error_quark()
 
@@ -47,14 +56,21 @@ typedef enum {
     GWY_MODULE_ERROR_QUERY,
     GWY_MODULE_ERROR_ABI,
     GWY_MODULE_ERROR_INFO,
-    GWY_MODULE_ERROR_REGISTER
+    GWY_MODULE_ERROR_REGISTER,
+    GWY_MODULE_ERROR_NESTING
 } GwyModuleError;
 
-/* FIXME: This is a public structure, remove the underscore indirection. */
 typedef struct _GwyModuleInfo GwyModuleInfo;
+typedef struct _GwyModuleRecord GwyModuleRecord;
 
-typedef gboolean       (*GwyModuleRegisterFunc) (void);
-typedef GwyModuleInfo* (*GwyModuleQueryFunc)    (void);
+typedef gboolean               (*GwyModuleRegisterFunc)       (void);
+typedef GwyModuleInfo*         (*GwyModuleQueryFunc)          (void);
+typedef const GwyModuleRecord* (*GwyModuleBundleRegisterFunc) (void);
+
+struct _GwyModuleRecord {
+    GwyModuleQueryFunc query;
+    const gchar *name;
+};
 
 struct _GwyModuleInfo {
     guint32 abi_version;
@@ -66,15 +82,28 @@ struct _GwyModuleInfo {
     const gchar *date;
 };
 
-GQuark                  gwy_module_error_quark      (void);
-void                    gwy_module_register_modules (const gchar **paths);
-const GwyModuleInfo*    gwy_module_lookup           (const gchar *name);
-const gchar*            gwy_module_get_filename     (const gchar *name);
-GSList*                 gwy_module_get_functions    (const gchar *name);
-void                    gwy_module_foreach          (GHFunc function,
+typedef struct {
+    const gchar *filename;
+    const gchar *modname;
+    const gchar *err_message;
+    gint err_domain;
+    gint err_code;
+} GwyModuleFailureInfo;
+
+GQuark               gwy_module_error_quark         (void);
+void                 gwy_module_register_modules    (const gchar **paths);
+const GwyModuleInfo* gwy_module_lookup              (const gchar *name);
+const gchar*         gwy_module_get_filename        (const gchar *name);
+GSList*              gwy_module_get_functions       (const gchar *name);
+void                 gwy_module_foreach             (GHFunc function,
                                                      gpointer data);
-const GwyModuleInfo*    gwy_module_register_module  (const gchar *name,
+void                 gwy_module_failure_foreach     (GFunc function,
+                                                     gpointer data);
+const GwyModuleInfo* gwy_module_register_module     (const gchar *name,
                                                      GError **error);
+void                 gwy_module_disable_registration(const gchar *name);
+void                 gwy_module_enable_registration (const gchar *name);
+gboolean             gwy_module_is_enabled          (const gchar *name);
 
 G_END_DECLS
 
