@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: arithmetic.c 19036 2016-10-08 10:32:41Z yeti-dn $
+ *  @(#) $Id: arithmetic.c 20128 2017-08-01 11:19:59Z yeti-dn $
  *  Copyright (C) 2003,2004 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -446,32 +446,6 @@ gwy_data_line_check_compatibility(GwyDataLine *data_line1,
     return result;
 }
 
-/* code ported from libgwy3 */
-typedef void (*RowExtendFunc)(const gdouble *in,
-                              gdouble *out,
-                              guint pos,
-                              guint width,
-                              guint res,
-                              guint extend_left,
-                              guint extend_right,
-                              gdouble value);
-
-typedef void (*RectExtendFunc)(const gdouble *in,
-                               guint inrowstride,
-                               gdouble *out,
-                               guint outrowstride,
-                               guint xpos,
-                               guint ypos,
-                               guint width,
-                               guint height,
-                               guint xres,
-                               guint yres,
-                               guint extend_left,
-                               guint extend_right,
-                               guint extend_up,
-                               guint extend_down,
-                               gdouble value);
-
 static inline void
 fill_block(gdouble *data, guint len, gdouble value)
 {
@@ -729,8 +703,22 @@ rect_extend_fill(const gdouble *in, guint inrowstride,
         fill_block(out2, extend_left + width + extend_right, value);
 }
 
-static RectExtendFunc
-get_rect_extend_func(GwyExteriorType exterior)
+RowExtendFunc
+_gwy_get_row_extend_func(GwyExteriorType exterior)
+{
+    if (exterior == GWY_EXTERIOR_FIXED_VALUE)
+        return &row_extend_fill;
+    if (exterior == GWY_EXTERIOR_BORDER_EXTEND)
+        return &row_extend_border;
+    if (exterior == GWY_EXTERIOR_MIRROR_EXTEND)
+        return &row_extend_mirror;
+    if (exterior == GWY_EXTERIOR_PERIODIC)
+        return &row_extend_periodic;
+    g_return_val_if_reached(NULL);
+}
+
+RectExtendFunc
+_gwy_get_rect_extend_func(GwyExteriorType exterior)
 {
     if (exterior == GWY_EXTERIOR_FIXED_VALUE)
         return &rect_extend_fill;
@@ -779,7 +767,7 @@ gwy_data_field_extend(GwyDataField *data_field,
 
     g_return_val_if_fail(GWY_IS_DATA_FIELD(data_field), NULL);
 
-    extend_rect = get_rect_extend_func(exterior);
+    extend_rect = _gwy_get_rect_extend_func(exterior);
     g_return_val_if_fail(extend_rect, NULL);
 
     width = data_field->xres;
@@ -802,10 +790,7 @@ gwy_data_field_extend(GwyDataField *data_field,
         gwy_data_field_set_xoffset(target, 0.0);
         gwy_data_field_set_yoffset(target, 0.0);
     }
-    gwy_serializable_clone(G_OBJECT(gwy_data_field_get_si_unit_xy(data_field)),
-                           G_OBJECT(gwy_data_field_get_si_unit_xy(target)));
-    gwy_serializable_clone(G_OBJECT(gwy_data_field_get_si_unit_z(data_field)),
-                           G_OBJECT(gwy_data_field_get_si_unit_z(target)));
+    gwy_data_field_copy_units(data_field, target);
 
     return target;
 }
