@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: brick.h 18119 2016-01-19 11:01:32Z yeti-dn $
+ *  @(#) $Id: brick.h 20128 2017-08-01 11:19:59Z yeti-dn $
  *  Copyright (C) 2003 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -106,21 +106,6 @@ GwyBrick* gwy_brick_new_part    (const GwyBrick *brick,
                                  gboolean keep_offsets);
 void      gwy_brick_data_changed(GwyBrick *brick);
 
-/*void            gwy_brick_set_size    (GwyBrick *brick,
-                                       guint xres,
-                                       guint yres,
-                                       guint zres,
-                                       gboolean clear);*/
-/*void            gwy_brick_copy        (const GwyBrick *src,
-                                       const GwyBrickPart *srcpart,
-                                       GwyBrick *dest,
-                                       guint destcol,
-                                       guint destrow,
-                                       guint destlevel);*/
-/*void            gwy_brick_copy_full   (const GwyBrick *src,
-                                       GwyBrick *dest);*/
-/*void            gwy_brick_invalidate  (GwyBrick *brick);*/
-
 void              gwy_brick_resample          (GwyBrick *brick,
                                                gint xres,
                                                gint yres,
@@ -162,6 +147,8 @@ void              gwy_brick_set_si_unit_w     (GwyBrick *brick,
                                                GwySIUnit *si_unit);
 gdouble           gwy_brick_get_min           (GwyBrick *brick);
 gdouble           gwy_brick_get_max           (GwyBrick *brick);
+void              gwy_brick_copy_units        (const GwyBrick *brick,
+                                               GwyBrick *target);
 GwySIValueFormat* gwy_brick_get_value_format_x(GwyBrick *brick,
                                                GwySIUnitFormatStyle style,
                                                GwySIValueFormat *format);
