@@ -1,6 +1,6 @@
 /*
- *  @(#) $Id: dataline.c 19036 2016-10-08 10:32:41Z yeti-dn $
- *  Copyright (C) 2003 David Necas (Yeti), Petr Klapetek.
+ *  @(#) $Id: dataline.c 20128 2017-08-01 11:19:59Z yeti-dn $
+ *  Copyright (C) 2003-2017 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -25,8 +25,10 @@
 #include <libgwyddion/gwymacros.h>
 #include <libgwyddion/gwymath.h>
 #include <libgwyddion/gwydebugobjects.h>
+#include <libprocess/datafield.h>
 #include <libprocess/linestats.h>
 #include <libprocess/interpolation.h>
+#include "gwyprocessinternal.h"
 
 #define GWY_DATA_LINE_TYPE_NAME "GwyDataLine"
 
@@ -167,10 +169,7 @@ gwy_data_line_new_alike(GwyDataLine *model,
     else
         data_line->data = g_new(gdouble, data_line->res);
 
-    if (model->si_unit_x)
-        data_line->si_unit_x = gwy_si_unit_duplicate(model->si_unit_x);
-    if (model->si_unit_y)
-        data_line->si_unit_y = gwy_si_unit_duplicate(model->si_unit_y);
+    gwy_data_line_copy_units(model, data_line);
 
     return data_line;
 }
@@ -205,11 +204,7 @@ gwy_data_line_new_resampled(GwyDataLine *data_line,
 
     result = gwy_data_line_new(res, data_line->real, FALSE);
     result->off = data_line->off;
-    if (data_line->si_unit_x)
-        result->si_unit_x = gwy_si_unit_duplicate(data_line->si_unit_x);
-    if (data_line->si_unit_y)
-        result->si_unit_y = gwy_si_unit_duplicate(data_line->si_unit_y);
-
+    gwy_data_line_copy_units(data_line, result);
     gwy_interpolation_resample_block_1d(data_line->res, data_line->data,
                                         result->res, result->data,
                                         interpolation, TRUE);
@@ -222,24 +217,19 @@ gwy_data_line_serialize(GObject *obj,
                         GByteArray *buffer)
 {
     GwyDataLine *data_line;
-    gdouble *poff;
-
-    gwy_debug("");
-    g_return_val_if_fail(GWY_IS_DATA_LINE(obj), NULL);
+    gpointer poff, pxunit, pyunit;
 
     data_line = GWY_DATA_LINE(obj);
-    if (!data_line->si_unit_x)
-        data_line->si_unit_x = gwy_si_unit_new(NULL);
-    if (!data_line->si_unit_y)
-        data_line->si_unit_y = gwy_si_unit_new(NULL);
     poff = data_line->off ? &data_line->off : NULL;
+    pxunit = unit_pointer_if_nonempty(data_line->si_unit_x);
+    pyunit = unit_pointer_if_nonempty(data_line->si_unit_y);
     {
         GwySerializeSpec spec[] = {
             { 'i', "res", &data_line->res, NULL, },
             { 'd', "real", &data_line->real, NULL, },
             { 'd', "off", poff, NULL, },
-            { 'o', "si_unit_x", &data_line->si_unit_x, NULL, },
-            { 'o', "si_unit_y", &data_line->si_unit_y, NULL, },
+            { 'o', "si_unit_x", pxunit, NULL, },
+            { 'o', "si_unit_y", pyunit, NULL, },
             { 'D', "data", &data_line->data, &data_line->res, },
         };
 
@@ -253,22 +243,19 @@ static gsize
 gwy_data_line_get_size(GObject *obj)
 {
     GwyDataLine *data_line;
-
-    gwy_debug("");
-    g_return_val_if_fail(GWY_IS_DATA_LINE(obj), 0);
+    gpointer poff, pxunit, pyunit;
 
     data_line = GWY_DATA_LINE(obj);
-    if (!data_line->si_unit_x)
-        data_line->si_unit_x = gwy_si_unit_new(NULL);
-    if (!data_line->si_unit_y)
-        data_line->si_unit_y = gwy_si_unit_new(NULL);
+    poff = data_line->off ? &data_line->off : NULL;
+    pxunit = unit_pointer_if_nonempty(data_line->si_unit_x);
+    pyunit = unit_pointer_if_nonempty(data_line->si_unit_y);
     {
         GwySerializeSpec spec[] = {
             { 'i', "res", &data_line->res, NULL, },
             { 'd', "real", &data_line->real, NULL, },
-            { 'd', "off", &data_line->off, NULL, },
-            { 'o', "si_unit_x", &data_line->si_unit_x, NULL, },
-            { 'o', "si_unit_y", &data_line->si_unit_y, NULL, },
+            { 'd', "off", poff, NULL, },
+            { 'o', "si_unit_x", pxunit, NULL, },
+            { 'o', "si_unit_y", pyunit, NULL, },
             { 'D', "data", &data_line->data, &data_line->res, },
         };
 
@@ -296,7 +283,6 @@ gwy_data_line_deserialize(const guchar *buffer,
       { 'D', "data", &data, &fsize, },
     };
 
-    gwy_debug("");
     g_return_val_if_fail(buffer, NULL);
 
     if (!gwy_serialize_unpack_object_struct(buffer, size, position,
@@ -339,7 +325,6 @@ gwy_data_line_duplicate_real(GObject *object)
 {
     GwyDataLine *data_line, *duplicate;
 
-    g_return_val_if_fail(GWY_IS_DATA_LINE(object), NULL);
     data_line = GWY_DATA_LINE(object);
     duplicate = gwy_data_line_new_alike(data_line, FALSE);
     gwy_assign(duplicate->data, data_line->data, data_line->res);
@@ -367,21 +352,8 @@ gwy_data_line_clone_real(GObject *source, GObject *copy)
     gwy_assign(clone->data, data_line->data, data_line->res);
 
     /* SI Units can be NULL */
-    if (data_line->si_unit_x && clone->si_unit_x)
-        gwy_serializable_clone(G_OBJECT(data_line->si_unit_x),
-                               G_OBJECT(clone->si_unit_x));
-    else if (data_line->si_unit_x && !clone->si_unit_x)
-        clone->si_unit_x = gwy_si_unit_duplicate(data_line->si_unit_x);
-    else if (!data_line->si_unit_x && clone->si_unit_x)
-        GWY_OBJECT_UNREF(clone->si_unit_x);
-
-    if (data_line->si_unit_y && clone->si_unit_y)
-        gwy_serializable_clone(G_OBJECT(data_line->si_unit_y),
-                               G_OBJECT(clone->si_unit_y));
-    else if (data_line->si_unit_y && !clone->si_unit_y)
-        clone->si_unit_y = gwy_si_unit_duplicate(data_line->si_unit_y);
-    else if (!data_line->si_unit_y && clone->si_unit_y)
-        GWY_OBJECT_UNREF(clone->si_unit_y);
+    _gwy_assign_si_unit(data_line->si_unit_x, &clone->si_unit_x);
+    _gwy_assign_si_unit(data_line->si_unit_y, &clone->si_unit_y);
 }
 
 /**
@@ -487,11 +459,7 @@ gwy_data_line_part_extract(GwyDataLine *data_line,
 
     result = gwy_data_line_new(len, data_line->real*len/data_line->res, FALSE);
     gwy_assign(result->data, data_line->data + from, len);
-
-    if (data_line->si_unit_x)
-        result->si_unit_x = gwy_si_unit_duplicate(data_line->si_unit_x);
-    if (data_line->si_unit_y)
-        result->si_unit_y = gwy_si_unit_duplicate(data_line->si_unit_y);
+    gwy_data_line_copy_units(data_line, result);
 
     return result;
 }
@@ -499,7 +467,7 @@ gwy_data_line_part_extract(GwyDataLine *data_line,
 /**
  * gwy_data_line_copy:
  * @data_line: Source data line.
- * @b: Destination data line.
+ * @target: Destination data line.
  *
  * Copies the contents of a data line to another already allocated data line
  * of the same size.
@@ -755,13 +723,7 @@ gwy_data_line_set_si_unit_x(GwyDataLine *data_line,
                             GwySIUnit *si_unit)
 {
     g_return_if_fail(GWY_IS_DATA_LINE(data_line));
-    g_return_if_fail(GWY_IS_SI_UNIT(si_unit));
-    if (data_line->si_unit_x == si_unit)
-        return;
-
-    GWY_OBJECT_UNREF(data_line->si_unit_x);
-    g_object_ref(si_unit);
-    data_line->si_unit_x = si_unit;
+    _gwy_set_object_si_unit(si_unit, &data_line->si_unit_x);
 }
 
 /**
@@ -769,7 +731,7 @@ gwy_data_line_set_si_unit_x(GwyDataLine *data_line,
  * @data_line: A data line.
  * @si_unit: SI unit to be set.
  *
- * Sets the SI unit corresponding to the "height" (Z) dimension of a data
+ * Sets the SI unit corresponding to the "height" (Y) dimension of a data
  * line.
  *
  * It does not assume a reference on @si_unit, instead it adds its own
@@ -780,13 +742,7 @@ gwy_data_line_set_si_unit_y(GwyDataLine *data_line,
                             GwySIUnit *si_unit)
 {
     g_return_if_fail(GWY_IS_DATA_LINE(data_line));
-    g_return_if_fail(GWY_IS_SI_UNIT(si_unit));
-    if (data_line->si_unit_y == si_unit)
-        return;
-
-    GWY_OBJECT_UNREF(data_line->si_unit_y);
-    g_object_ref(si_unit);
-    data_line->si_unit_y = si_unit;
+    _gwy_set_object_si_unit(si_unit, &data_line->si_unit_y);
 }
 
 /**
@@ -850,6 +806,44 @@ gwy_data_line_get_value_format_y(GwyDataLine *data_line,
                                   style, max - min, format);
 }
 
+/**
+ * gwy_data_line_copy_units:
+ * @data_line: A data line.
+ * @target: Destination data line.
+ *
+ * Sets lateral and value units of a data line to match another data line.
+ *
+ * Since: 2.49
+ **/
+void
+gwy_data_line_copy_units(GwyDataLine *data_line,
+                         GwyDataLine *target)
+{
+    g_return_if_fail(GWY_IS_DATA_LINE(data_line));
+    g_return_if_fail(GWY_IS_DATA_LINE(target));
+
+    _gwy_assign_si_unit(data_line->si_unit_x, &target->si_unit_x);
+    _gwy_assign_si_unit(data_line->si_unit_y, &target->si_unit_y);
+}
+
+/**
+ * gwy_data_line_copy_units_to_data_field:
+ * @data_line: A data line to get units from.
+ * @data_field: A data field to set units of.
+ *
+ * Sets lateral and value units of a data field to match a data line.
+ **/
+void
+gwy_data_line_copy_units_to_data_field(GwyDataLine *data_line,
+                                       GwyDataField *data_field)
+{
+    g_return_if_fail(GWY_IS_DATA_LINE(data_line));
+    g_return_if_fail(GWY_IS_DATA_FIELD(data_field));
+
+    _gwy_assign_si_unit(data_line->si_unit_x, &data_field->si_unit_xy);
+    _gwy_assign_si_unit(data_line->si_unit_y, &data_field->si_unit_z);
+}
+
 /**
  * gwy_data_line_itor:
  * @data_line: A data line.
@@ -1610,7 +1604,6 @@ gwy_data_line_sqrt(GwyDataLine *data_line)
     }
 }
 
-
 /************************** Documentation ****************************/
 
 /**
