@@ -1,6 +1,6 @@
 /*
- *  @(#) $Id: elliptic.c 19036 2016-10-08 10:32:41Z yeti-dn $
- *  Copyright (C) 2005-2006 David Necas (Yeti), Petr Klapetek, Chris Anderson.
+ *  @(#) $Id: elliptic.c 20283 2017-08-15 08:54:48Z yeti-dn $
+ *  Copyright (C) 2005-2017 David Necas (Yeti), Petr Klapetek, Chris Anderson.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net, sidewinder.asu@gmail.com.
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -19,7 +19,6 @@
  *  Boston, MA 02110-1301, USA.
  */
 
-#include "config.h"
 #include <string.h>
 #include <libgwyddion/gwymacros.h>
 #include <libgwyddion/gwymath.h>
@@ -254,6 +253,114 @@ gwy_data_field_get_elliptic_area_size(gint width,
     return count;
 }
 
+/**
+ * gwy_data_field_local_maximum:
+ * @dfield: A two-dimensional data field.
+ * @x: Approximate maximum @x-location to be improved (in pixels).
+ * @y: Approximate maximum @y-location to be improved (in pixels).
+ * @ax: Horizontal search radius.
+ * @ay: Vertical search radius.
+ *
+ * Searches an elliptical area in a data field for local maximum.
+ *
+ * The area may stick outside the data field.
+ *
+ * The function first finds the maximum within the ellipse, intersected with
+ * the data field and then tries subpixel refinement.  The maximum is
+ * considered successfully located if it is inside the data field, i.e. not on
+ * edge, there is no higher value in its 8-neighbourhood, and the subpixel
+ * refinement of its position succeeds (which usually happens when the
+ * first two conditions are met, but not always).
+ *
+ * Even if the function returns %FALSE the values of @x and @y are reasonable,
+ * but they may not correspond to an actual maximum.
+ *
+ * The radii can be zero.  A single pixel is then examined, but if it is indeed
+ * a local maximum, its position is refined.
+ *
+ * Returns: %TRUE if the maximum was successfully located.  %FALSE when the
+ *          location is problematic and should not be used.
+ *
+ * Since: 2.49
+ **/
+gboolean
+gwy_data_field_local_maximum(GwyDataField *dfield,
+                             gdouble *x, gdouble *y,
+                             gint ax, gint ay)
+{
+    gint xj,yi, mi, mj, i, j, k;
+    gint xres, yres, xfrom, xto, yfrom, yto;
+    gdouble xx, yy, v, max;
+    const gdouble *d;
+    gdouble z[9];
+    gboolean ok;
+
+    g_return_val_if_fail(GWY_IS_DATA_FIELD(dfield), FALSE);
+    g_return_val_if_fail(x, FALSE);
+    g_return_val_if_fail(y, FALSE);
+
+    xres = dfield->xres;
+    yres = dfield->yres;
+    xj = (gint)(*x);
+    yi = (gint)(*y);
+    ax = ABS(ax);
+    ay = ABS(ay);
+
+    gwy_debug("searching around: %g, %g (%d+-%d, %d+-%d)",
+              *x, *y, xj, ax, yi, ay);
+    mi = mj = 0;
+    max = -G_MAXDOUBLE;
+    yfrom = MAX(yi - ay, 0) - yi;
+    yto = MIN(yi + ay, yres-1) - yi;
+    for (i = yfrom; i <= yto; i++) {
+        v = i/(ay + 0.5);
+        k = (gint)floor((ax + 0.5)*sqrt(1.0 - v*v));
+        xfrom = MAX(xj - k, 0) - xj;
+        xto = MIN(xj + k, xres-1) - xj;
+        d = dfield->data + (i + yi)*xres + (xj + xfrom);
+        for (j = xfrom; j <= xto; j++, d++) {
+            if (*d > max) {
+                max = *d;
+                mi = i;
+                mj = j;
+            }
+        }
+    }
+    mj += xj;
+    mi += yi;
+    gwy_debug("pixel maximum at: %d, %d", mj, mi);
+
+    /* No pixels found at all. */
+    if (max == -G_MAXDOUBLE)
+        return FALSE;
+
+    /* Data field edge. */
+    *x = mj;
+    *y = mi;
+    if (mi == 0 || mi == yres-1 || mj == 0 || mj == xres-1)
+        return FALSE;
+
+    d = dfield->data;
+    k = mi*xres + mj;
+    for (i = -1; i <= 1; i++) {
+        for (j = -1; j <= 1; j++) {
+            v = d[k + i*xres + j];
+            /* Not an actual maximum. */
+            if ((i || j) && v > max)
+                return FALSE;
+            z[3*(i + 1) + (j + 1)] = v;
+        }
+    }
+    ok = gwy_math_refine_maximum_2d(z, &xx, &yy);
+    gwy_debug("refinement by (%g, %g)", xx, yy);
+    if (!ok)
+        return FALSE;
+
+    *x += xx;
+    *y += yy;
+    return TRUE;
+}
+
 /**
  * gwy_data_field_circular_area_fill:
  * @data_field: A data field.
