@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: filters.h 18539 2016-03-28 19:40:38Z yeti-dn $
+ *  @(#) $Id: filters.h 19808 2017-05-30 07:32:41Z yeti-dn $
  *  Copyright (C) 2003-2016 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -77,6 +77,16 @@ void gwy_data_field_area_convolve                     (GwyDataField *data_field,
                                                        gint row,
                                                        gint width,
                                                        gint height);
+void gwy_data_field_area_ext_convolve                 (GwyDataField *field,
+                                                       guint col,
+                                                       guint row,
+                                                       guint width,
+                                                       guint height,
+                                                       GwyDataField *target,
+                                                       GwyDataField *kernel,
+                                                       GwyExteriorType exterior,
+                                                       gdouble fill_value,
+                                                       gboolean as_integral);
 void gwy_data_field_convolve_1d                       (GwyDataField *data_field,
                                                        GwyDataLine *kernel_line,
                                                        GwyOrientation orientation);
@@ -87,6 +97,16 @@ void gwy_data_field_area_convolve_1d                  (GwyDataField *data_field,
                                                        gint row,
                                                        gint width,
                                                        gint height);
+void gwy_data_field_area_ext_row_convolve             (GwyDataField *field,
+                                                       guint col,
+                                                       guint row,
+                                                       guint width,
+                                                       guint height,
+                                                       GwyDataField *target,
+                                                       GwyDataLine *kernel,
+                                                       GwyExteriorType exterior,
+                                                       gdouble fill_value,
+                                                       gboolean as_integral);
 void gwy_data_field_filter_median                     (GwyDataField *data_field,
                                                        gint size);
 void gwy_data_field_area_filter_median                (GwyDataField *data_field,
