@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: fractals.c 16242 2014-05-30 20:39:32Z yeti-dn $
+ *  @(#) $Id: fractals.c 19698 2017-05-03 20:18:10Z yeti-dn $
  *  Copyright (C) 2004 Jindrich Bilek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -19,13 +19,12 @@
  *  Boston, MA 02110-1301, USA.
  */
 
-#include "config.h"
-#include <glib.h>
 #include <libgwyddion/gwymacros.h>
 #include <libgwyddion/gwymath.h>
 #include <libgwyddion/gwyrandgenset.h>
 #include <libprocess/datafield.h>
 #include <libprocess/stats.h>
+#include <libprocess/fractals.h>
 
 static void gwy_data_field_fractal_fit(GwyDataLine *xresult,
                                        GwyDataLine *yresult,
