@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: gwygrainvalue.c 17175 2015-05-23 20:53:49Z yeti-dn $
+ *  @(#) $Id: gwygrainvalue.c 19698 2017-05-03 20:18:10Z yeti-dn $
  *  Copyright (C) 2007 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
@@ -19,12 +19,10 @@
  *  Boston, MA 02110-1301, USA.
  */
 
-#include "config.h"
 #include <stdlib.h>
 #include <string.h>
 #include <libgwyddion/gwymacros.h>
 #include <libgwyddion/gwyexpr.h>
-#include <libgwyddion/gwyutils.h>
 #include <libgwyddion/gwydebugobjects.h>
 #include <libprocess/gwygrainvalue.h>
 #include "gwyprocessinternal.h"
