@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: gwyprocess.c 19101 2016-10-19 12:56:46Z yeti-dn $
+ *  @(#) $Id: gwyprocess.c 20128 2017-08-01 11:19:59Z yeti-dn $
  *  Copyright (C) 2003-2004 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -19,12 +19,7 @@
  *  Boston, MA 02110-1301, USA.
  */
 
-#include "config.h"
-
-#ifdef HAVE_FFTW3
 #include <fftw3.h>
-#endif
-
 #include <libgwyddion/gwyddion.h>
 #include <libprocess/gwyprocess.h>
 #include "gwyprocessinternal.h"
@@ -32,12 +27,10 @@
 static void
 gwy_process_import_fftw_wisdom(void)
 {
-#ifdef HAVE_FFTW3
     G_GNUC_UNUSED gboolean ok;
 
     ok = fftw_import_system_wisdom();
     gwy_debug("FFTW3 system wisdom imported: %d", ok);
-#endif
 }
 
 /**
@@ -78,6 +71,46 @@ gwy_process_type_init(void)
     gwy_process_import_fftw_wisdom();
 }
 
+/* Transfer units by value (gwy_foo_copy_units()). */
+void
+_gwy_assign_si_unit(GwySIUnit *source, GwySIUnit **dest)
+{
+    if (source == *dest)
+        return;
+
+    if (!source || gwy_si_unit_equal_string(source, NULL)) {
+        GWY_OBJECT_UNREF(*dest);
+        return;
+    }
+
+    if (*dest)
+        gwy_serializable_clone(G_OBJECT(source), G_OBJECT(*dest));
+    else
+        *dest = gwy_si_unit_duplicate(source);
+}
+
+/* Take unit object ownership -- @objmember is presumably an object member
+ * (gwy_foo_set_si_unit_x()). */
+void
+_gwy_set_object_si_unit(GwySIUnit *unit, GwySIUnit **objmember)
+{
+    GwySIUnit *tmp;
+
+    g_return_if_fail(!unit || GWY_IS_SI_UNIT(unit));
+
+    if (unit == *objmember)
+        return;
+
+    if (!unit || gwy_si_unit_equal_string(unit, NULL)) {
+        GWY_OBJECT_UNREF(*objmember);
+        return;
+    }
+
+    tmp = *objmember;
+    *objmember = g_object_ref(unit);
+    GWY_OBJECT_UNREF(tmp);
+}
+
 /************************** Documentation ****************************/
 
 /**
