@@ -1,6 +1,6 @@
 /*
- *  @(#) $Id: gwyprocessenums.c 19145 2016-10-31 16:19:12Z yeti-dn $
- *  Copyright (C) 2005 David Necas (Yeti), Petr Klapetek.
+ *  @(#) $Id: gwyprocessenums.c 20155 2017-08-03 14:52:21Z yeti-dn $
+ *  Copyright (C) 2005-2017 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -528,6 +528,8 @@ gwy_masking_type_get_enum(void)
  *                       2.42).
  * @GWY_LINE_STAT_VARIATION: Variation (integral of absolute value) (Since:
  *                           2.42).
+ * @GWY_LINE_STAT_MINPOS: Minimum position along the line (Since: 2.48).
+ * @GWY_LINE_STAT_MAXPOS: Maximum position along the line (Since: 2.48).
  *
  * Line statistical quantities to be requested with
  * gwy_data_field_area_get_line_stats().
@@ -678,6 +680,20 @@ gwy_distance_transform_type_get_enum(void)
  * Since: 2.46
  **/
 
+/**
+ * GwyAffineScalingType:
+ * @GWY_AFFINE_SCALING_AS_GIVEN: Correct lattice vectors lengths are taken
+ *                               as given.
+ * @GWY_AFFINE_SCALING_PRESERVE_AREA: Correct lattice vectors are scaled to
+ *                                    make the transformation area-preserving.
+ * @GWY_AFFINE_SCALING_PRESERVE_X: Correct lattice vectors are scaled to
+ *                                 preserve the scale along @x-axis.
+ *
+ * Type of lattice vector scaling in affine transform preparation.
+ *
+ * Since: 2.49
+ **/
+
 /**
  * GwyComputationStateType:
  * @GWY_COMPUTATION_STATE_INIT: Iterator was set up, the next step will
@@ -724,4 +740,49 @@ gwy_distance_transform_type_get_enum(void)
  * </programlisting></informalexample>
  **/
 
+GType
+gwy_computation_state_get_type(void)
+{
+    static GType compstate_type = 0;
+
+    if (G_UNLIKELY(!compstate_type))
+        compstate_type = g_pointer_type_register_static("GwyComputationState");
+
+    return compstate_type;
+}
+
+/**
+ * gwy_computation_state_get_state:
+ * @compstate: Computation state.
+ *
+ * Gets the state field of a computation state struct.
+ *
+ * Useful mostly for language bindings.
+ *
+ * Returns: The state field of @compstate.
+ *
+ * Since: 2.49
+ **/
+gint
+gwy_computation_state_get_state(GwyComputationState *compstate)
+{
+    return compstate->state;
+}
+
+/**
+ * gwy_computation_state_get_fraction:
+ * @compstate: Computation state.
+ *
+ * Gets the fraction field of a computation state struct.
+ *
+ * Returns: The fraction field of @compstate.
+ *
+ * Since: 2.49
+ **/
+gdouble
+gwy_computation_state_get_fraction(GwyComputationState *compstate)
+{
+    return compstate->fraction;
+}
+
 /* vim: set cin et ts=4 sw=4 cino=>1s,e0,n0,f0,{0,}0,^0,\:1s,=0,g1s,h0,t0,+1s,c3,(0,u0 : */
