@@ -431,6 +431,8 @@ gwy_line_stat_quantity_get_type(void)
             { GWY_LINE_STAT_KURTOSIS, "GWY_LINE_STAT_KURTOSIS", "kurtosis" },
             { GWY_LINE_STAT_RANGE, "GWY_LINE_STAT_RANGE", "range" },
             { GWY_LINE_STAT_VARIATION, "GWY_LINE_STAT_VARIATION", "variation" },
+            { GWY_LINE_STAT_MINPOS, "GWY_LINE_STAT_MINPOS", "minpos" },
+            { GWY_LINE_STAT_MAXPOS, "GWY_LINE_STAT_MAXPOS", "maxpos" },
             { 0, NULL, NULL }
         };
         etype = g_enum_register_static("GwyLineStatQuantity", values);
@@ -518,6 +520,23 @@ gwy_rotate_resize_type_get_type(void)
     return etype;
 }
 
+GType
+gwy_affine_scaling_type_get_type(void)
+{
+    static GType etype = 0;
+
+    if (etype == 0) {
+        static const GEnumValue values[] = {
+            { GWY_AFFINE_SCALING_AS_GIVEN, "GWY_AFFINE_SCALING_AS_GIVEN", "as-given" },
+            { GWY_AFFINE_SCALING_PRESERVE_AREA, "GWY_AFFINE_SCALING_PRESERVE_AREA", "preserve-area" },
+            { GWY_AFFINE_SCALING_PRESERVE_X, "GWY_AFFINE_SCALING_PRESERVE_X", "preserve-x" },
+            { 0, NULL, NULL }
+        };
+        etype = g_enum_register_static("GwyAffineScalingType", values);
+    }
+    return etype;
+}
+
 #include "./peaks.h"
 
 GType
