@@ -80,6 +80,9 @@ GType gwy_min_max_filter_type_get_type(void) G_GNUC_CONST;
 GType gwy_rotate_resize_type_get_type(void) G_GNUC_CONST;
 #define GWY_TYPE_ROTATE_RESIZE_TYPE (gwy_rotate_resize_type_get_type())
 
+GType gwy_affine_scaling_type_get_type(void) G_GNUC_CONST;
+#define GWY_TYPE_AFFINE_SCALING_TYPE (gwy_affine_scaling_type_get_type())
+
 GType gwy_peak_background_type_get_type(void) G_GNUC_CONST;
 #define GWY_TYPE_PEAK_BACKGROUND_TYPE (gwy_peak_background_type_get_type())
 
