@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: gwyshapefitpreset.c 19259 2016-11-15 08:26:23Z yeti-dn $
+ *  @(#) $Id: gwyshapefitpreset.c 19380 2016-12-23 11:12:56Z pecold $
  *  Copyright (C) 2016 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
@@ -332,9 +332,9 @@ static gdouble            enforce_secondary_flags(const FitShapeFunc *builtin,
                                                   guint i,
                                                   gdouble value);
 static GwyShapeFitPreset* create_static_preset   (const FitShapeFunc *function);
-static void               reduce_data_size       (const GwyXYZ *xyzsrc,
+static GwySurface*        reduce_data_size       (const GwyXYZ *xyzsrc,
                                                   guint nsrc,
-                                                  GwySurface *dest);
+                                                  guint nred);
 
 G_DEFINE_TYPE(GwyShapeFitPreset, gwy_shape_fit_preset, GWY_TYPE_RESOURCE)
 
@@ -399,6 +399,12 @@ _gwy_shape_fit_preset_class_setup_presets(void)
     g_type_class_unref(klass);
 }
 
+static guint
+calculate_nreduced(guint n)
+{
+    return (guint)sqrt(n*(gdouble)NREDLIM);
+}
+
 /**
  * gwy_shape_fit_preset_needs_same_units:
  * @preset: A 3D geometrical shape fitting function.
@@ -983,6 +989,78 @@ gwy_shape_fit_preset_fit(GwyShapeFitPreset *preset,
     return fitter;
 }
 
+/**
+ * gwy_shape_fit_preset_quick_fit:
+ * @preset: A 3D geometrical shape fitting function.
+ * @fitter: A Marquardt-Levenberg nonlinear fitter already initialized for
+ *          @preset's function, or %NULL.
+ * @points: Array of @n XYZ data defining the lateral coordinates and values
+ *          to fit.
+ * @n: Number of items in @points.
+ * @params: Fitting parameters filled with initial estimates (the fitting
+ *          starts from the provided values).
+ * @fixed_param: Which parameters should be treated as fixed (set
+ *               corresponding element to %TRUE for them).  May be %NULL if
+ *               all parameters are free.
+ * @rss: Location to store the residual sum of squares, as returned by
+ *       gwy_math_nlfit_fit_idx(), may be %NULL.
+ *
+ * Performs a rough non-linear least-squares fit with a 3D geometrical shape
+ * fitter.
+ *
+ * See gwy_shape_fit_preset_fit() for discussion.  This functions differs by
+ * using a reduced number of points to perform the fit (unless the input set
+ * is small) and may also set fitter parameters to make the least squares
+ * method terminate faster.  The input points are reduced the same way as in
+ * gwy_surface_reduce_points().
+ *
+ * Returns: Either @fitter itself, or a newly created fitter if it was %NULL.
+ *
+ * Since: 2.48
+ **/
+GwyNLFitter*
+gwy_shape_fit_preset_quick_fit(GwyShapeFitPreset *preset,
+                               GwyNLFitter *fitter,
+                               const GwyXYZ *points,
+                               guint n,
+                               gdouble *params,
+                               const gboolean *fixed_param,
+                               gdouble *rss)
+{
+    ShapeFitPreset *priv;
+    const FitShapeFunc *builtin;
+    guint nred = calculate_nreduced(n);
+    gdouble myrss;
+
+    g_return_val_if_fail(GWY_IS_SHAPE_FIT_PRESET(preset), NULL);
+    g_return_val_if_fail(points, NULL);
+    g_return_val_if_fail(params, NULL);
+    if (!fitter)
+        fitter = gwy_shape_fit_preset_create_fitter(preset);
+
+    gwy_math_nlfit_set_max_iterations(fitter, 30);
+    priv = preset->priv;
+    builtin = priv->builtin;
+    if (nred < n) {
+        GwySurface *surface = reduce_data_size(points, n, nred);
+        priv->xyz = surface->data;
+        myrss = gwy_math_nlfit_fit_idx_full(fitter, nred, builtin->nparams,
+                                            params, fixed_param, NULL, priv);
+        g_object_unref(surface);
+    }
+    else {
+        priv->xyz = points;
+        myrss = gwy_math_nlfit_fit_idx_full(fitter, n, builtin->nparams,
+                                            params, fixed_param, NULL, priv);
+    }
+    priv->xyz = NULL;
+    enforce_param_flags(builtin, params);
+    if (rss)
+        *rss = myrss;
+
+    return fitter;
+}
+
 static void
 enforce_param_flags(const FitShapeFunc *builtin, gdouble *param)
 {
@@ -1014,20 +1092,23 @@ enforce_secondary_flags(const FitShapeFunc *builtin, guint i, gdouble value)
     return value;
 }
 
-static void
-reduce_data_size(const GwyXYZ *xyzsrc, guint nsrc, GwySurface *dest)
+static GwySurface*
+reduce_data_size(const GwyXYZ *xyzsrc, guint nsrc, guint nred)
 {
-    GwyRandGenSet *rngset = gwy_rand_gen_set_new(1);
-    guint ndest = gwy_surface_get_npoints(dest);
-    guint *redindex = gwy_rand_gen_set_choose_shuffle(rngset, 0, nsrc, ndest);
-    GwyXYZ *xyzdest = gwy_surface_get_data(dest);
-    guint i;
+    GwySurface *reduced, *surface = gwy_surface_new();
+    guint n = surface->n;
+    GwyXYZ *data = surface->data;
 
-    for (i = 0; i < ndest; i++)
-        xyzdest[i] = xyzsrc[redindex[i]];
+    /* XXX: This is a dirty trick we can only dare to attempt since we are
+     * doing it inside the library and know gwy_surface_reduce_points() does
+     * not change the @data and @n fields.  Do not try it at home! */
+    surface->data = (GwyXYZ*)xyzsrc;
+    surface->n = nsrc;
+    reduced = gwy_surface_reduce_points(surface, nred);
+    surface->data = data;
+    surface->n = n;
 
-    g_free(redindex);
-    gwy_rand_gen_set_free(rngset);
+    return reduced;
 }
 
 static GwyShapeFitPreset*
@@ -1095,7 +1176,7 @@ gwy_coshm1(gdouble x)
             sphi = sphi_last; \
         } \
         else { \
-            sincos(phi, &sphi, &cphi); \
+            _gwy_sincos(phi, &sphi, &cphi); \
             cphi_last = cphi; \
             sphi_last = sphi; \
             phi##_last = phi; \
@@ -1440,21 +1521,18 @@ estimate_projection_direction_red(const GwyXYZ *xyz, guint n,
                                   FitShapeEstimateCache *estimcache)
 {
     FitShapeEstimateCache estimcachered;
-    guint nred = (guint)sqrt(n*(gdouble)NREDLIM);
+    guint nred = calculate_nreduced(n);
     GwySurface *surface;
     gdouble phi;
 
     if (nred >= n)
         return estimate_projection_direction(xyz, n, estimcache);
 
-    surface = gwy_surface_new_sized(nred);
-    reduce_data_size(xyz, n, surface);
-
     /* Make sure caching still works for the reduced data. */
+    surface = reduce_data_size(xyz, n, nred);
     gwy_clear(&estimcachered, 1);
     phi = estimate_projection_direction(gwy_surface_get_data_const(surface),
                                         nred, &estimcachered);
-
     g_object_unref(surface);
 
     return phi;
