@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: hough.c 19128 2016-10-26 21:25:12Z yeti-dn $
+ *  @(#) $Id: hough.c 20129 2017-08-01 20:01:48Z yeti-dn $
  *  Copyright (C) 2003 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -19,14 +19,14 @@
  *  Boston, MA 02110-1301, USA.
  */
 
-#include "config.h"
 #include <libgwyddion/gwymacros.h>
 #include <libgwyddion/gwymath.h>
 #include <libprocess/filters.h>
 #include <libprocess/stats.h>
-#include <libprocess/hough.h>
 #include <libprocess/grains.h>
 #include <libprocess/arithmetic.h>
+#include <libprocess/elliptic.h>
+#include <libprocess/hough.h>
 
 static void bresenhams_line           (GwyDataField *dfield,
                                        gint x1,
@@ -503,36 +503,9 @@ get_local_maximum(GwyDataField *dfield,
                   gint mcol, gint mrow,
                   gdouble *xval, gdouble *yval)
 {
-    gint xres, yres;
-    gdouble zm, zp, z0;
-    const gdouble *data;
-
-    xres = dfield->xres;
-    yres = dfield->yres;
-    data = dfield->data;
-    z0 = dfield->data[xres*mrow + mcol];
-    if (mcol > 0 && mcol < xres-1) {
-        zm = data[mrow*xres + mcol-1];
-        zp = data[mrow*xres + mcol+1];
-        if ((zm + zp - 2*z0) == 0)
-            *xval = (gdouble)mcol;
-        else {
-            *xval = (gdouble)mcol + (zm - zp)/(zm + zp - 2*z0)/2.0;
-        }
-    }
-    else
-        *xval = (gdouble)mcol;
-
-    if (mrow > 0 && mrow < yres-1) {
-        zm = data[(mrow - 1)*xres + mcol];
-        zp = data[(mrow + 1)*xres + mcol];
-        if ((zm + zp - 2*z0) == 0)
-            *yval = (gdouble)mrow;
-        else
-            *yval = (gdouble)mrow + (zm - zp)/(zm + zp - 2*z0)/2.0;
-    }
-    else
-        *yval = (gdouble)mrow;
+    *xval = mcol;
+    *yval = mrow;
+    gwy_data_field_local_maximum(dfield, xval, yval, 3, 3);
 }
 
 /**
@@ -587,8 +560,7 @@ gwy_data_field_get_local_maxima_list(GwyDataField *dfield,
 
                 if (zdata[i] < value)  {
                     if (subpixel) {
-                        get_local_maximum(dfield, mcol, mrow,
-                                          &xval, &yval);
+                        get_local_maximum(dfield, mcol, mrow, &xval, &yval);
                         zdata[i] = value;
                         xdata[i] = xval;
                         ydata[i] = yval;
