@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: interpolation.h 15598 2013-11-11 12:33:32Z yeti-dn $
+ *  @(#) $Id: interpolation.h 19328 2016-11-29 14:21:48Z yeti-dn $
  *  Copyright (C) 2003 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -32,30 +32,30 @@ gdouble gwy_interpolation_get_dval(gdouble x,
                                    gdouble y1_,
                                    gdouble x2_,
                                    gdouble y2_,
-                                   GwyInterpolationType interpolation);
+                                   GwyInterpolationType interpolation) G_GNUC_CONST;
 
 gdouble
 gwy_interpolation_get_dval_of_equidists(gdouble x,
                                         gdouble *data,
-                                        GwyInterpolationType interpolation);
+                                        GwyInterpolationType interpolation) G_GNUC_PURE;
 
 gdouble
 gwy_interpolation_interpolate_1d(gdouble x,
                                  const gdouble *coeff,
-                                 GwyInterpolationType interpolation);
+                                 GwyInterpolationType interpolation) G_GNUC_PURE;
 
 gdouble
 gwy_interpolation_interpolate_2d(gdouble x,
                                  gdouble y,
                                  gint rowstride,
                                  const gdouble *coeff,
-                                 GwyInterpolationType interpolation);
+                                 GwyInterpolationType interpolation) G_GNUC_PURE;
 
 gboolean
-gwy_interpolation_has_interpolating_basis(GwyInterpolationType interpolation);
+gwy_interpolation_has_interpolating_basis(GwyInterpolationType interpolation) G_GNUC_CONST;
 
 gint
-gwy_interpolation_get_support_size(GwyInterpolationType interpolation);
+gwy_interpolation_get_support_size(GwyInterpolationType interpolation) G_GNUC_CONST;
 
 void
 gwy_interpolation_resolve_coeffs_1d(gint n,
