@@ -1,6 +1,6 @@
 /*
- *  @(#) $Id: inttrans.c 19036 2016-10-08 10:32:41Z yeti-dn $
- *  Copyright (C) 2003 David Necas (Yeti), Petr Klapetek.
+ *  @(#) $Id: inttrans.c 19717 2017-05-09 08:25:16Z yeti-dn $
+ *  Copyright (C) 2003-2017 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -19,13 +19,8 @@
  *  Boston, MA 02110-1301, USA.
  */
 
-#include "config.h"
-
-#ifdef HAVE_FFTW3
-#include <fftw3.h>
-#endif
-
 #include <string.h>
+#include <fftw3.h>
 #include <libgwyddion/gwymacros.h>
 #include <libgwyddion/gwymath.h>
 #include <libprocess/arithmetic.h>
@@ -323,7 +318,6 @@ gwy_data_line_fft_do(GwyDataLine *rsrc,
                      GwyDataLine *idest,
                      GwyTransformDirection direction)
 {
-#ifdef HAVE_FFTW3
     fftw_iodim dims[1], howmany_dims[1];
     gdouble *rbuf = g_memdup(rsrc->data, rsrc->res*sizeof(gdouble));
     gdouble *ibuf = g_memdup(isrc->data, isrc->res*sizeof(gdouble));
@@ -337,16 +331,18 @@ gwy_data_line_fft_do(GwyDataLine *rsrc,
     howmany_dims[0].os = rsrc->res;
     /* Backward direction is equivalent to switching real and imaginary parts */
     /* XXX: Planner destroys input. */
-    if (direction == GWY_TRANSFORM_DIRECTION_BACKWARD)
+    if (direction == GWY_TRANSFORM_DIRECTION_BACKWARD) {
         plan = fftw_plan_guru_split_dft(1, dims, 1, howmany_dims,
                                         rsrc->data, isrc->data,
                                         rdest->data, idest->data,
                                         _GWY_FFTW_PATIENCE);
-    else
+    }
+    else {
         plan = fftw_plan_guru_split_dft(1, dims, 1, howmany_dims,
                                         isrc->data, rsrc->data,
                                         idest->data, rdest->data,
                                         _GWY_FFTW_PATIENCE);
+    }
     g_return_if_fail(plan);
     gwy_assign(rsrc->data, rbuf, rsrc->res);
     gwy_assign(isrc->data, ibuf, isrc->res);
@@ -357,11 +353,6 @@ gwy_data_line_fft_do(GwyDataLine *rsrc,
 
     gwy_data_line_multiply(rdest, 1.0/sqrt(rsrc->res));
     gwy_data_line_multiply(idest, 1.0/sqrt(rsrc->res));
-#else
-    gwy_fft_simple(direction, rsrc->res,
-                   1, rsrc->data, isrc->data,
-                   1, rdest->data, idest->data);
-#endif
 }
 
 static void
@@ -371,7 +362,6 @@ gwy_data_line_fft_real_do(GwyDataLine *rsrc,
                           GwyDataLine *idest,
                           GwyTransformDirection direction)
 {
-#ifdef HAVE_FFTW3
     fftw_iodim dims[1], howmany_dims[1];
     fftw_plan plan;
     gint j;
@@ -404,13 +394,6 @@ gwy_data_line_fft_real_do(GwyDataLine *rsrc,
         gwy_data_line_multiply(idest, 1.0/sqrt(rsrc->res));
     else
         gwy_data_line_multiply(idest, -1.0/sqrt(rsrc->res));
-#else
-    /* We cannot save anything here.  Or correct me... */
-    gwy_data_line_clear(ibuf);
-    gwy_fft_simple(direction, rsrc->res,
-                   1, rsrc->data, ibuf->data,
-                   1, rdest->data, idest->data);
-#endif
 }
 
 static void
@@ -588,7 +571,6 @@ gwy_data_field_2dfft_do(GwyDataField *rin,
                         GwyDataField *iout,
                         GwyTransformDirection direction)
 {
-#ifdef HAVE_FFTW3
     fftw_iodim dims[2], howmany_dims[1];
     fftw_plan plan;
 
@@ -618,32 +600,6 @@ gwy_data_field_2dfft_do(GwyDataField *rin,
 
     gwy_data_field_multiply(rout, 1.0/sqrt(rin->xres*rin->yres));
     gwy_data_field_multiply(iout, 1.0/sqrt(rin->xres*rin->yres));
-#else
-    gdouble *ibuf, *rbuf;
-    gint j, k, xres, yres;
-
-    xres = rin->xres;
-    yres = rin->yres;
-    for (k = 0; k < yres; k++) {
-        gwy_fft_simple(direction, xres,
-                       1, rin->data + k*xres, iin->data + k*xres,
-                       1, rout->data + k*xres, iout->data + k*xres);
-    }
-    /* Use a one-row temporary buffer */
-    rbuf = g_new(gdouble, 2*yres);
-    ibuf = rbuf + 1;
-    for (k = 0; k < xres; k++) {
-        gwy_fft_simple(direction, yres,
-                       xres, rout->data + k, iout->data + k,
-                       2, rbuf, ibuf);
-        /* Move the result from buffer to iout, rout columns */
-        for (j = 0; j < yres; j++) {
-            rout->data[j*xres + k] = rbuf[2*j];
-            iout->data[j*xres + k] = ibuf[2*j];
-        }
-    }
-    g_free(rbuf);
-#endif
     gwy_data_field_invalidate(rout);
     gwy_data_field_invalidate(iout);
 }
@@ -728,7 +684,6 @@ gwy_data_field_2dfft_real_do(GwyDataField *rin,
                              GwyTransformDirection direction)
 {
     gint xres = rin->xres, yres = rin->yres;
-#ifdef HAVE_FFTW3
     fftw_iodim dims[2], howmany_dims[1];
     fftw_plan plan;
     gint j, k;
@@ -774,48 +729,6 @@ gwy_data_field_2dfft_real_do(GwyDataField *rin,
         gwy_data_field_multiply(iout, 1.0/sqrt(xres*yres));
     else
         gwy_data_field_multiply(iout, -1.0/sqrt(xres*yres));
-#else
-    GwyDataField *rbuf = gwy_data_field_duplicate(rin);
-    gint k, j;
-
-    for (k = 0; k+1 < yres; k += 2) {
-        gdouble *re, *im, *r0, *r1, *i0, *i1;
-
-        re = rout->data + k*xres;
-        im = rout->data + (k + 1)*xres;
-        r0 = rbuf->data + k*xres;
-        r1 = rbuf->data + (k + 1)*xres;
-        i0 = ibuf->data + k*xres;
-        i1 = ibuf->data + (k + 1)*xres;
-
-        gwy_fft_simple(direction, xres, 1, r0, r1, 1, re, im);
-
-        /* Disentangle transforms of the row couples */
-        r0[0] = re[0];
-        i0[0] = 0.0;
-        r1[0] = im[0];
-        i1[0] = 0.0;
-        for (j = 1; j < xres; j++) {
-            r0[j] = (re[j] + re[xres - j])/2.0;
-            i0[j] = (im[j] - im[xres - j])/2.0;
-            r1[j] = (im[j] + im[xres - j])/2.0;
-            i1[j] = (-re[j] + re[xres - j])/2.0;
-        }
-    }
-    if (yres % 2) {
-        k = xres * (yres - 1);
-        gwy_clear(ibuf->data, xres);
-        gwy_fft_simple(direction, xres,
-                       1, rbuf->data + k, ibuf->data,
-                       1, rout->data + k, iout->data + k);
-
-    }
-    for (k = 0; k < xres; k++)
-        gwy_fft_simple(direction, yres,
-                       xres, rbuf->data + k, ibuf->data + k,
-                       xres, rout->data + k, iout->data + k);
-    g_object_unref(rbuf);
-#endif
     gwy_data_field_invalidate(rout);
     gwy_data_field_invalidate(iout);
 }
@@ -1336,7 +1249,6 @@ gwy_data_field_xfft_do(GwyDataField *rin,
                        GwyDataField *iout,
                        GwyTransformDirection direction)
 {
-#ifdef HAVE_FFTW3
     fftw_iodim dims[1], howmany_dims[1];
     fftw_plan plan;
 
@@ -1368,14 +1280,6 @@ gwy_data_field_xfft_do(GwyDataField *rin,
 
     gwy_data_field_multiply(rout, 1.0/sqrt(rin->xres));
     gwy_data_field_multiply(iout, 1.0/sqrt(rin->xres));
-#else
-    gint k;
-
-    for (k = 0; k < rin->yres; k++)
-        gwy_fft_simple(direction, rin->xres,
-                       1, rin->data + k*rin->xres, iin->data + k*rin->xres,
-                       1, rout->data + k*rin->xres, iout->data + k*rin->xres);
-#endif
     gwy_data_field_invalidate(rout);
     gwy_data_field_invalidate(iout);
 }
@@ -1456,7 +1360,6 @@ gwy_data_field_xfft_real_do(GwyDataField *rin,
                             GwyDataField *iout,
                             GwyTransformDirection direction)
 {
-#ifdef HAVE_FFTW3
     fftw_iodim dims[1], howmany_dims[1];
     fftw_plan plan;
     gint j, k;
@@ -1493,45 +1396,6 @@ gwy_data_field_xfft_real_do(GwyDataField *rin,
         gwy_data_field_multiply(iout, 1.0/sqrt(rin->xres));
     else
         gwy_data_field_multiply(iout, -1.0/sqrt(rin->xres));
-#else
-    gint j, k;
-
-    for (k = 0; k+1 < rin->yres; k += 2) {
-        gdouble *re, *im, *r0, *r1, *i0, *i1;
-
-        re = ibuf->data + k*rin->xres;
-        im = ibuf->data + (k + 1)*rin->xres;
-        r0 = rin->data + k*rin->xres;
-        r1 = rin->data + (k + 1)*rin->xres;
-
-        gwy_fft_simple(direction, rin->xres, 1, r0, r1, 1, re, im);
-
-        r0 = rout->data + k*rin->xres;
-        r1 = rout->data + (k + 1)*rin->xres;
-        i0 = iout->data + k*rin->xres;
-        i1 = iout->data + (k + 1)*rin->xres;
-
-        /* Disentangle transforms of the row couples */
-        r0[0] = re[0];
-        i0[0] = 0.0;
-        r1[0] = im[0];
-        i1[0] = 0.0;
-        for (j = 1; j < rin->xres; j++) {
-            r0[j] = (re[j] + re[rin->xres - j])/2.0;
-            i0[j] = (im[j] - im[rin->xres - j])/2.0;
-            r1[j] = (im[j] + im[rin->xres - j])/2.0;
-            i1[j] = (-re[j] + re[rin->xres - j])/2.0;
-        }
-    }
-    if (rin->yres % 2) {
-        k = rin->xres * (rin->yres - 1);
-        gwy_clear(ibuf->data, rin->xres);
-        gwy_fft_simple(direction, rin->xres,
-                       1, rin->data + k, ibuf->data,
-                       1, rout->data + k, iout->data + k);
-
-    }
-#endif
     gwy_data_field_invalidate(rout);
     gwy_data_field_invalidate(iout);
 }
@@ -1623,7 +1487,6 @@ gwy_data_field_yfft_do(GwyDataField *rin,
                        GwyDataField *iout,
                        GwyTransformDirection direction)
 {
-#ifdef HAVE_FFTW3
     fftw_iodim dims[1], howmany_dims[1];
     fftw_plan plan;
 
@@ -1655,14 +1518,6 @@ gwy_data_field_yfft_do(GwyDataField *rin,
 
     gwy_data_field_multiply(rout, 1.0/sqrt(rin->yres));
     gwy_data_field_multiply(iout, 1.0/sqrt(rin->yres));
-#else
-    gint k;
-
-    for (k = 0; k < rin->xres; k++)
-        gwy_fft_simple(direction, rin->yres,
-                       rin->xres, rin->data + k, iin->data + k,
-                       rin->xres, rout->data + k, iout->data + k);
-#endif
     gwy_data_field_invalidate(rout);
     gwy_data_field_invalidate(iout);
 }
@@ -1743,7 +1598,6 @@ gwy_data_field_yfft_real_do(GwyDataField *rin,
                             GwyDataField *iout,
                             GwyTransformDirection direction)
 {
-#ifdef HAVE_FFTW3
     fftw_iodim dims[1], howmany_dims[1];
     fftw_plan plan;
     gint j, k;
@@ -1780,51 +1634,6 @@ gwy_data_field_yfft_real_do(GwyDataField *rin,
         gwy_data_field_multiply(iout, 1.0/sqrt(rin->yres));
     else
         gwy_data_field_multiply(iout, -1.0/sqrt(rin->yres));
-#else
-    gint j, k;
-
-    for (k = 0; k+1 < rin->xres; k += 2) {
-        gdouble *re, *im, *r0, *r1, *i0, *i1;
-
-        re = ibuf->data + k;
-        im = ibuf->data + (k + 1);
-        r0 = rin->data + k;
-        r1 = rin->data + (k + 1);
-
-        /* FIXME: we could achieve better data locality by using the in
-         * arrays `rotated'. */
-        gwy_fft_simple(direction, rin->yres, rin->xres, r0, r1,
-                       rin->xres, re, im);
-
-        r0 = rout->data + k;
-        r1 = rout->data + (k + 1);
-        i0 = iout->data + k;
-        i1 = iout->data + (k + 1);
-
-        /* Disentangle transforms of the row couples */
-        r0[0] = re[0];
-        i0[0] = 0.0;
-        r1[0] = im[0];
-        i1[0] = 0.0;
-        for (j = 1; j < rin->yres; j++) {
-            gint n = rin->xres*rin->yres, kj = rin->xres*j;
-
-            r0[kj] = (re[kj] + re[n - kj])/2.0;
-            i0[kj] = (im[kj] - im[n - kj])/2.0;
-            r1[kj] = (im[kj] + im[n - kj])/2.0;
-            i1[kj] = (-re[kj] + re[n - kj])/2.0;
-        }
-    }
-    if (rin->xres % 2) {
-        k = rin->xres - 1;
-        for (j = 0; j < rin->yres; j++)
-            ibuf->data[j*rin->xres + k] = 0.0;
-        gwy_fft_simple(direction, rin->yres,
-                       rin->xres, rin->data + k, ibuf->data + k,
-                       rin->xres, rout->data + k, iout->data + k);
-
-    }
-#endif
     gwy_data_field_invalidate(rout);
     gwy_data_field_invalidate(iout);
 }
@@ -2037,32 +1846,23 @@ gwy_data_field_cwt(GwyDataField *data_field,
     gwy_data_field_invalidate(data_field);
 }
 
-static void
-flip_xy(GwyDataField *source, GwyDataField *dest, gboolean minor)
+static GwyDataLine*
+resample_dline_for_1d_fft_filter(GwyDataLine *dline, gint res,
+                                 GwyInterpolationType interpolation)
 {
-    gint xres, yres, i, j;
-    gdouble *dd;
-    const gdouble *sd;
+    GwyDataLine *half = gwy_data_line_new_resampled(dline, (res + 1)/2,
+                                                    interpolation);
+    GwyDataLine *full = gwy_data_line_new(res, res, FALSE);
+    gint i;
 
-    xres = gwy_data_field_get_xres(source);
-    yres = gwy_data_field_get_yres(source);
-    gwy_data_field_resample(dest, yres, xres, GWY_INTERPOLATION_NONE);
-    sd = gwy_data_field_get_data_const(source);
-    dd = gwy_data_field_get_data(dest);
-    if (minor) {
-        for (i = 0; i < xres; i++) {
-            for (j = 0; j < yres; j++) {
-                dd[i*yres + j] = sd[j*xres + (xres - 1 - i)];
-            }
-        }
-    }
-    else {
-        for (i = 0; i < xres; i++) {
-            for (j = 0; j < yres; j++) {
-                dd[i*yres + (yres - 1 - j)] = sd[j*xres + i];
-            }
-        }
-    }
+    /* Fill the full line symmetrically.  The central element may we written
+     * twice, but with the same value. */
+    gwy_assign(full->data, half->data, half->res);
+    for (i = 0; i < half->res; i++)
+        full->data[res-1 - i] = half->data[i];
+
+    g_object_unref(half);
+    return full;
 }
 
 /**
@@ -2085,7 +1885,7 @@ gwy_data_field_fft_filter_1d(GwyDataField *data_field,
                              GwyOrientation orientation,
                              GwyInterpolationType interpolation)
 {
-    GwyDataField *source, *target, *iresult_field, *hlp_rdfield, *hlp_idfield;
+    GwyDataField *iresult_field, *hlp_rdfield, *hlp_idfield;
     GwyDataLine *w;
     gint i, j, xres, yres;
 
@@ -2093,60 +1893,50 @@ gwy_data_field_fft_filter_1d(GwyDataField *data_field,
     g_return_if_fail(GWY_IS_DATA_FIELD(result_field));
     g_return_if_fail(GWY_IS_DATA_LINE(weights));
 
-    gwy_data_field_resample(result_field, data_field->xres, data_field->yres,
-                            GWY_INTERPOLATION_NONE);
+    yres = data_field->yres;
+    xres = data_field->xres;
+    gwy_data_field_resample(result_field, xres, yres, GWY_INTERPOLATION_NONE);
 
-    if (orientation == GWY_ORIENTATION_VERTICAL) {
-        source = target = gwy_data_field_new_alike(data_field, FALSE);
-        flip_xy(data_field, source, FALSE);
-    }
-    else {
-        source = data_field;
-        target = result_field;
-    }
+    hlp_rdfield = gwy_data_field_new_alike(data_field, TRUE);
+    hlp_idfield = gwy_data_field_new_alike(data_field, TRUE);
+    iresult_field = gwy_data_field_new_alike(data_field, TRUE);
 
-    yres = source->yres;
-    xres = source->xres;
-
-    hlp_rdfield = gwy_data_field_new_alike(source, TRUE);
-    hlp_idfield = gwy_data_field_new_alike(source, TRUE);
-    iresult_field = gwy_data_field_new_alike(source, TRUE);
-
-    gwy_data_field_1dfft_raw(source, NULL,
+    gwy_data_field_1dfft_raw(data_field, NULL,
                              hlp_rdfield, hlp_idfield,
-                             GWY_ORIENTATION_HORIZONTAL,
-                             GWY_TRANSFORM_DIRECTION_FORWARD);
+                             orientation, GWY_TRANSFORM_DIRECTION_FORWARD);
+
+    if (orientation == GWY_ORIENTATION_VERTICAL)
+        w = resample_dline_for_1d_fft_filter(weights, yres, interpolation);
+    else
+        w = resample_dline_for_1d_fft_filter(weights, xres, interpolation);
 
-    w = gwy_data_line_new_resampled(weights, (xres + 1)/2, interpolation);
     for (i = 0; i < yres; i++) {
         gdouble *rrow = hlp_rdfield->data + i*xres;
         gdouble *irow = hlp_idfield->data + i*xres;
 
-        for (j = 0; j < xres/2; j++) {
-            rrow[j] *= w->data[j];
-            rrow[xres-1 - j] *= w->data[j];
-            irow[j] *= w->data[j];
-            irow[xres-1 - j] *= w->data[j];
+        if (orientation == GWY_ORIENTATION_VERTICAL) {
+            gdouble wi = w->data[i];
+            for (j = 0; j < xres; j++) {
+                rrow[j] *= wi;
+                irow[j] *= wi;
+            }
         }
-        if (w->res != xres/2) {
-            rrow[xres/2] *= w->data[xres/2];
-            irow[xres/2] *= w->data[xres/2];
+        else {
+            gdouble *wrow = w->data;
+            for (j = 0; j < xres; j++) {
+                rrow[j] *= wrow[j];
+                irow[j] *= wrow[j];
+            }
         }
     }
     g_object_unref(w);
 
     gwy_data_field_1dfft_raw(hlp_rdfield, hlp_idfield,
-                             target, iresult_field,
-                             GWY_ORIENTATION_HORIZONTAL,
-                             GWY_TRANSFORM_DIRECTION_BACKWARD);
+                             result_field, iresult_field,
+                             orientation, GWY_TRANSFORM_DIRECTION_BACKWARD);
     g_object_unref(iresult_field);
     g_object_unref(hlp_rdfield);
     g_object_unref(hlp_idfield);
-
-    if (orientation == GWY_ORIENTATION_VERTICAL) {
-        flip_xy(target, result_field, TRUE);
-        g_object_unref(target);
-    }
 }
 
 /************************** Documentation ****************************/
@@ -2169,10 +1959,9 @@ gwy_data_field_fft_filter_1d(GwyDataField *data_field,
  * This makes them suitable for applications where both forward and inverse
  * transform is performed.
  *
- * Both types of functions wrap a Fourier transform backend which can be
- * currently either gwy_fft_simple(), available always, or
- * <ulink url="http://fftw.org/">FFTW3</ulink>, available when Gwyddion was
- * compiled with it.
+ * Both types of functions wrap
+ * <ulink url="http://fftw.org/">FFTW3</ulink>
+ * routines.
  **/
 
 /* vim: set cin et ts=4 sw=4 cino=>1s,e0,n0,f0,{0,}0,^0,\:1s,=0,g1s,h0,t0,+1s,c3,(0,u0 : */
