@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: linestats.c 19108 2016-10-21 08:50:43Z yeti-dn $
+ *  @(#) $Id: linestats.c 20171 2017-08-06 19:49:48Z yeti-dn $
  *  Copyright (C) 2003 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -19,7 +19,6 @@
  *  Boston, MA 02110-1301, USA.
  */
 
-#include "config.h"
 #include <string.h>
 #include <libgwyddion/gwymacros.h>
 #include <libgwyddion/gwymath.h>
@@ -74,6 +73,124 @@ gwy_data_line_get_min(GwyDataLine *data_line)
     return min;
 }
 
+/**
+ * gwy_data_line_min_pos_i:
+ * @data_line: A data line.
+ *
+ * Finds the minimum pixel position of a data line.
+ *
+ * Returns: The minimum pixel position.
+ *
+ * Since 2.48
+ **/
+gdouble
+gwy_data_line_min_pos_i(GwyDataLine *data_line)
+{
+    gint i, res, minpos = 0;
+    gdouble min = G_MAXDOUBLE, *val;
+
+    g_return_val_if_fail(GWY_IS_DATA_LINE(data_line), 0.0);
+
+    res = data_line->res;
+    val = data_line->data;
+    for (i = 0; i < res; i++) {
+        if (G_UNLIKELY(*(val++) < min)) {
+            min = *val;
+            minpos = i;
+        }
+    }
+    return minpos;
+}
+
+/**
+ * gwy_data_line_max_pos_i:
+ * @data_line: A data line.
+ *
+ * Finds the maximum pixel position of a data line.
+ *
+ * Returns: The maximum pixel position.
+ *
+ * Since 2.48
+ **/
+gdouble
+gwy_data_line_max_pos_i(GwyDataLine *data_line)
+{
+    gint i, res, maxpos = 0;
+    gdouble max = G_MINDOUBLE, *val;
+
+    g_return_val_if_fail(GWY_IS_DATA_LINE(data_line), 0.0);
+
+    res = data_line->res;;
+    val = data_line->data;
+    for (i = 0; i < res; i++) {
+        if (G_UNLIKELY(*(val++) > max)) {
+            max = *val;
+            maxpos = i;
+        }
+    }
+    return maxpos;
+}
+
+/**
+ * gwy_data_line_min_pos_r:
+ * @data_line: A data line.
+ *
+ * Finds the real minimum position in a data line.
+ *
+ * Returns: Real position for the minimum.
+ *
+ * Since 2.48
+ **/
+gdouble
+gwy_data_line_min_pos_r(GwyDataLine *data_line)
+{
+    gint res;
+    gdouble real, offset, pos;
+
+    g_return_val_if_fail(GWY_IS_DATA_LINE(data_line), 0.0);
+
+    res = data_line->res;
+    if (G_UNLIKELY(res == 0.0)) {
+        return 0.0;
+    }
+    real = data_line->real;
+    offset = data_line->off;
+
+    pos = gwy_data_line_min_pos_i(data_line);
+
+    return pos * real / res + offset;
+}
+
+/**
+ * gwy_data_line_max_pos_r:
+ * @data_line: A data line.
+ *
+ * Finds the real maximum position in a data line.
+ *
+ * Returns: Real position for the maximum.
+ *
+ * Since 2.48
+ **/
+gdouble
+gwy_data_line_max_pos_r(GwyDataLine *data_line)
+{
+    gint res;
+    gdouble real, offset, pos;
+
+    g_return_val_if_fail(GWY_IS_DATA_LINE(data_line), 0.0);
+
+    res = data_line->res;
+    if (G_UNLIKELY(res == 0.0)) {
+        return 0.0;
+    }
+    real = data_line->real;
+    offset = data_line->off;
+
+    pos = gwy_data_line_max_pos_i(data_line);
+
+    return pos * real / res + offset;
+}
+
 /**
  * gwy_data_line_get_avg:
  * @data_line: A data line.
@@ -781,7 +898,8 @@ gwy_data_line_distribution(GwyDataLine *data_line,
 {
     GwySIUnit *yunit, *lineunit;
     const gdouble *data;
-    gint i, j, res, ndata;
+    gint i, res, ndata;
+    guint *counts;
     gdouble s;
 
     g_return_if_fail(GWY_IS_DATA_LINE(data_line));
@@ -830,20 +948,11 @@ gwy_data_line_distribution(GwyDataLine *data_line,
     gwy_data_line_resample(distribution, nstats, GWY_INTERPOLATION_NONE);
     gwy_data_line_clear(distribution);
 
-    ndata = 0;
-    for (i = 0; i < res; i++) {
-        if (data[i] == ymax) {
-            distribution->data[nstats-1] += 1.0;
-            ndata++;
-        }
-        else {
-            j = (gint)((data[i] - ymin)/s);
-            if (j >= 0 && j < nstats) {
-                distribution->data[j] += 1.0;
-                ndata++;
-            }
-        }
-    }
+    counts = g_new0(guint, nstats);
+    ndata = gwy_math_histogram(data, res, ymin, ymax, nstats, counts);
+    for (i = 0; i < nstats; i++)
+        distribution->data[i] = counts[i];
+    g_free(counts);
 
     /* Set proper units and scales */
     distribution->real = ymax - ymin;
@@ -881,8 +990,9 @@ gwy_data_line_dh(GwyDataLine *data_line,
                  gdouble ymin, gdouble ymax,
                  gint nsteps)
 {
-    gint i, n, val;
-    gdouble step, nstep, imin;
+    gint i, n;
+    gdouble step;
+    guint *counts;
 
     g_return_if_fail(GWY_IS_DATA_LINE(data_line));
     g_return_if_fail(GWY_IS_DATA_LINE(target_line));
@@ -897,18 +1007,14 @@ gwy_data_line_dh(GwyDataLine *data_line,
         ymax = gwy_data_line_get_max(data_line);
     }
     step = (ymax - ymin)/(nsteps - 1.0);
-    imin = ymin/step;
 
-    for (i = 0; i < n; i++) {
-        val = (gint)((data_line->data[i]/step) - imin);
-        if (G_UNLIKELY(val < 0 || val >= nsteps)) {
-            /*this should never happened*/
-            val = 0;
-        }
-        target_line->data[val] += 1.0;
-    }
-    nstep = n*step;
-    gwy_data_line_multiply(target_line, 1.0/nstep);
+    counts = g_new0(guint, nsteps);
+    n = gwy_math_histogram(data_line->data, n, ymin, ymax, nsteps, counts);
+    for (i = 0; i < nsteps; i++)
+        target_line->data[i] = counts[i];
+    g_free(counts);
+
+    gwy_data_line_multiply(target_line, 1.0/(n*step));
     target_line->off = ymin;
     target_line->real = ymax - ymin;
 }
@@ -938,6 +1044,7 @@ gwy_data_line_cdh(GwyDataLine *data_line,
 
     gwy_data_line_dh(data_line, target_line, ymin, ymax, nsteps);
     gwy_data_line_cumulate(target_line);
+    target_line->data[target_line->res-1] = 1.0;   /* Fix rounding errors. */
 }
 
 /**
@@ -1021,6 +1128,7 @@ gwy_data_line_cda(GwyDataLine *data_line,
 
     gwy_data_line_da(data_line, target_line, ymin, ymax, nsteps);
     gwy_data_line_cumulate(target_line);
+    target_line->data[target_line->res-1] = 1.0;   /* Fix rounding errors. */
 }
 
 /**
