@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: linestats.h 17386 2015-09-14 09:22:40Z yeti-dn $
+ *  @(#) $Id: linestats.h 19341 2016-12-03 08:22:08Z dn2010 $
  *  Copyright (C) 2003 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -31,6 +31,10 @@ gdouble gwy_data_line_get_min           (GwyDataLine *data_line);
 void    gwy_data_line_get_min_max       (GwyDataLine *data_line,
                                          gdouble *min,
                                          gdouble *max);
+gdouble gwy_data_line_min_pos_i         (GwyDataLine *data_line);
+gdouble gwy_data_line_max_pos_i         (GwyDataLine *data_line);
+gdouble gwy_data_line_min_pos_r         (GwyDataLine *data_line);
+gdouble gwy_data_line_max_pos_r         (GwyDataLine *data_line);
 gdouble gwy_data_line_get_avg           (GwyDataLine *data_line);
 gdouble gwy_data_line_get_rms           (GwyDataLine *data_line);
 gdouble gwy_data_line_get_tan_beta0     (GwyDataLine *data_line);
