@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: spectra.c 19108 2016-10-21 08:50:43Z yeti-dn $
+ *  @(#) $Id: spectra.c 20128 2017-08-01 11:19:59Z yeti-dn $
  *  Copyright (C) 2006 Owain Davies, David Necas (Yeti), Petr Klapetek.
  *  E-mail: owain.davies@blueyonder.co.uk
  *          yeti@gwyddion.net, klapetek@gwyddion.net.
@@ -30,6 +30,7 @@
 #include <libprocess/spectra.h>
 #include <libprocess/linestats.h>
 #include <libprocess/interpolation.h>
+#include "gwyprocessinternal.h"
 
 #define GWY_SPECTRA_TYPE_NAME "GwySpectra"
 /* default number number of spectra allocated to data and coords */
@@ -178,8 +179,6 @@ gwy_spectra_finalize(GObject *object)
     GwySpectra *spectra = (GwySpectra*)object;
     guint i;
 
-    gwy_debug("");
-
     GWY_OBJECT_UNREF(spectra->si_unit_xy);
     for (i = 0; i < spectra->spectra->len; i++) {
         GwySpectrum *spec = &g_array_index(spectra->spectra, GwySpectrum, i);
@@ -291,9 +290,7 @@ gwy_spectra_new_alike(GwySpectra *model)
 
     g_return_val_if_fail(GWY_IS_SPECTRA(model), NULL);
     spectra = g_object_new(GWY_TYPE_SPECTRA, NULL);
-
-    if (model->si_unit_xy)
-        spectra->si_unit_xy = gwy_si_unit_duplicate(model->si_unit_xy);
+    _gwy_assign_si_unit(model->si_unit_xy, &spectra->si_unit_xy);
 
     return spectra;
 }
@@ -356,23 +353,20 @@ gwy_spectra_serialize(GObject *obj,
     guint32 *selected;
     guint32 ncurves, ncoords, nselected;
     GByteArray *retval;
-
-    gwy_debug("");
-    g_return_val_if_fail(GWY_IS_SPECTRA(obj), NULL);
+    gpointer pxyunit;
 
     spectra = GWY_SPECTRA(obj);
-    if (!spectra->si_unit_xy)
-        spectra->si_unit_xy = gwy_si_unit_new(NULL);
 
     separate_arrays(spectra->spectra,
                     &ncurves, &curves,
                     &ncoords, &coords,
                     &nselected, &selected);
+    pxyunit = unit_pointer_if_nonempty(spectra->si_unit_xy);
 
     {
         GwySerializeSpec spec[] = {
             { 's', "title",       &spectra->title,       NULL,       },
-            { 'o', "si_unit_xy",  &spectra->si_unit_xy,  NULL,       },
+            { 'o', "si_unit_xy",  pxyunit,               NULL,       },
             { 'D', "coords",      &coords,               &ncoords,   },
             { 'I', "selected",    &selected,             &nselected, },
             { 'O', "data",        &curves,               &ncurves,   },
@@ -401,23 +395,20 @@ gwy_spectra_get_size(GObject *obj)
     guint32 *selected;
     guint32 ncurves, ncoords, nselected;
     gsize retval;
-
-    gwy_debug("");
-    g_return_val_if_fail(GWY_IS_SPECTRA(obj), 0);
+    gpointer pxyunit;
 
     spectra = GWY_SPECTRA(obj);
-    if (!spectra->si_unit_xy)
-        spectra->si_unit_xy = gwy_si_unit_new(NULL);
 
     separate_arrays(spectra->spectra,
                     &ncurves, &curves,
                     &ncoords, &coords,
                     &nselected, &selected);
+    pxyunit = unit_pointer_if_nonempty(spectra->si_unit_xy);
 
     {
         GwySerializeSpec spec[] = {
             { 's', "title",       &spectra->title,       NULL,       },
-            { 'o', "si_unit_xy",  &spectra->si_unit_xy,  NULL,       },
+            { 'o', "si_unit_xy",  pxyunit,               NULL,       },
             { 'D', "coords",      &coords,               &ncoords,   },
             { 'I', "selected",    &selected,             &nselected, },
             { 'O', "data",        &curves,               &ncurves,   },
@@ -546,8 +537,7 @@ gwy_spectra_duplicate_real(GObject *object)
     spectra = GWY_SPECTRA(object);
     duplicate = gwy_spectra_new_alike(spectra);
     duplicate->title = g_strdup(spectra->title);
-    if (spectra->si_unit_xy)
-        duplicate->si_unit_xy = gwy_si_unit_duplicate(spectra->si_unit_xy);
+    _gwy_assign_si_unit(spectra->si_unit_xy, &duplicate->si_unit_xy);
     g_array_append_vals(duplicate->spectra, spectra->spectra->data,
                         spectra->spectra->len);
 
@@ -595,14 +585,7 @@ gwy_spectra_clone_real(GObject *source, GObject *copy)
             = gwy_data_line_duplicate(dataline);
     }
 
-    /* SI Units can be NULL */
-    if (spectra->si_unit_xy && clone->si_unit_xy)
-        gwy_serializable_clone(G_OBJECT(spectra->si_unit_xy),
-                               G_OBJECT(clone->si_unit_xy));
-    else if (spectra->si_unit_xy && !clone->si_unit_xy)
-        clone->si_unit_xy = gwy_si_unit_duplicate(spectra->si_unit_xy);
-    else if (!spectra->si_unit_xy && clone->si_unit_xy)
-        GWY_OBJECT_UNREF(clone->si_unit_xy);
+    _gwy_assign_si_unit(spectra->si_unit_xy, &clone->si_unit_xy);
 }
 
 /**
@@ -659,13 +642,7 @@ gwy_spectra_set_si_unit_xy(GwySpectra *spectra,
                            GwySIUnit *si_unit)
 {
     g_return_if_fail(GWY_IS_SPECTRA(spectra));
-    g_return_if_fail(GWY_IS_SI_UNIT(si_unit));
-    if (spectra->si_unit_xy == si_unit)
-        return;
-
-    GWY_OBJECT_UNREF(spectra->si_unit_xy);
-    g_object_ref(si_unit);
-    spectra->si_unit_xy = si_unit;
+    _gwy_set_object_si_unit(si_unit, &spectra->si_unit_xy);
 }
 
 /**
