@@ -1,6 +1,6 @@
 /*
- *  @(#) $Id: spline.c 19036 2016-10-08 10:32:41Z yeti-dn $
- *  Copyright (C) 2016 David Necas (Yeti).
+ *  @(#) $Id: spline.c 20156 2017-08-03 15:04:56Z yeti-dn $
+ *  Copyright (C) 2016-2017 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -19,10 +19,8 @@
  *  Boston, MA 02110-1301, USA.
  */
 
-#include "config.h"
 #include <string.h>
 #include <libgwyddion/gwymacros.h>
-#include <libgwyddion/gwymath.h>
 #include <libprocess/spline.h>
 
 #define MAX_RECURSION_DEPTH 20
@@ -104,6 +102,20 @@ static void sample_curve_uniformly  (GwySpline *spline,
                                      GwyXY *velocities);
 static void calculate_point_tangents(GwySpline *spline);
 
+GType
+gwy_spline_get_type(void)
+{
+    static GType spline_type = 0;
+
+    if (G_UNLIKELY(!spline_type)) {
+        spline_type = g_boxed_type_register_static("GwySpline",
+                                                   (GBoxedCopyFunc)gwy_spline_copy,
+                                                   (GBoxedFreeFunc)gwy_spline_free);
+    }
+
+    return spline_type;
+}
+
 /**
  * gwy_spline_new:
  *
@@ -156,6 +168,30 @@ gwy_spline_free(GwySpline *spline)
     g_slice_free(GwySpline, spline);
 }
 
+/**
+ * gwy_spline_copy:
+ * @spline: A spline curve.
+ *
+ * Creates a copy of a spline curve.
+ *
+ * Returns: A newly created spline curve.
+ *
+ * Since: 2.49
+ **/
+GwySpline*
+gwy_spline_copy(GwySpline *spline)
+{
+    GwySpline *retval;
+
+    g_return_val_if_fail(spline, NULL);
+    retval = gwy_spline_new_from_points((const GwyXY*)spline->points->data,
+                                        spline->points->len);
+    retval->slackness = spline->slackness;
+    retval->closed = spline->closed;
+
+    return retval;
+}
+
 /**
  * gwy_spline_new_from_points:
  * @xy: Array of points in plane the curve will pass through.
