@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: tip.c 19251 2016-11-14 08:42:00Z yeti-dn $
+ *  @(#) $Id: tip.c 20155 2017-08-03 14:52:21Z yeti-dn $
  *  Copyright (C) 2003-2016 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -19,16 +19,14 @@
  *  Boston, MA 02110-1301, USA.
  */
 
-#include "config.h"
 #include <string.h>
 #include <libgwyddion/gwymacros.h>
 #include <libgwyddion/gwymath.h>
 #include <libprocess/filters.h>
 #include <libprocess/stats.h>
 #include <libprocess/grains.h>
-#include <libprocess/morph_lib.h>
-
-/* INTERPOLATION: New (not applicable). */
+#include <libprocess/tip.h>
+#include "morph_lib.h"
 
 /* Update when new parameter type is added. */
 enum {
@@ -44,6 +42,17 @@ typedef struct {
     const GwyTipParamType *params;
 } GwyTipModelPresetReal;
 
+GType
+gwy_tip_model_preset_get_type(void)
+{
+    static GType tipmodel_type = 0;
+
+    if (G_UNLIKELY(!tipmodel_type))
+        tipmodel_type = g_pointer_type_register_static("GwyTipModelPreset");
+
+    return tipmodel_type;
+}
+
 static void
 guess_symmetrical(GwyDataField *data,
                   gdouble height,
