@@ -1,5 +1,5 @@
 /*
- *  $Id: aistfile.c 17187 2015-06-05 05:32:45Z pecold $
+ *  $Id: aistfile.c 20195 2017-08-08 06:10:25Z yeti-dn $
  *  Copyright (C) 2009 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
@@ -62,10 +62,6 @@
 
 #include "err.h"
 
-#ifdef _MSC_VER
-#define swab _swab
-#endif
-
 #define EXTENSION ".aist"
 
 typedef struct {
@@ -126,12 +122,12 @@ static GwyModuleInfo module_info = {
     &module_register,
     N_("Imports AIST-NT data files."),
     "Yeti <yeti@gwyddion.net>",
-    "0.5",
+    "0.5.1",
     "David Nečas (Yeti)",
     "2009",
 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, aistfile)
 
 static gboolean
 module_register(void)
@@ -624,7 +620,8 @@ read_qt_string(const guchar **p, gsize *size, gchar **value)
     }
     else if (G_BYTE_ORDER == G_LITTLE_ENDIAN) {
         utf16native = must_free = g_new(gunichar2, len/sizeof(gunichar2));
-        swab(*p, (gpointer)must_free, len);
+        gwy_memcpy_byte_swap(*p, (guint8*)must_free,
+                             2, len/sizeof(gunichar2), 1);
     }
     *value = g_utf16_to_utf8(utf16native, len/sizeof(gunichar2), NULL, NULL,
                              NULL);
