@@ -1,5 +1,5 @@
 /*
- *  $Id: alicona.c 17187 2015-06-05 05:32:45Z pecold $
+ *  $Id: alicona.c 19948 2017-06-22 14:05:41Z yeti-dn $
  *  Copyright (C) 2011 David Necas (Yeti).
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -151,7 +151,7 @@ static GwyModuleInfo module_info = {
     "2011",
 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, alicona)
 
 static gboolean
 module_register(void)
