@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: ambfile.c 18884 2016-08-26 06:59:41Z yeti-dn $
+ *  @(#) $Id: ambfile.c 19948 2017-06-22 14:05:41Z yeti-dn $
  *  Copyright (C) 2005 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -67,8 +67,7 @@
 
 enum {
     HEADER_SIZE = 65,
-    XRES_OFFSET = 0x31,
-    YRES_OFFSET = 0x35,
+    PARAM_OFFSET = 0x31,
 };
 
 static gboolean      module_register(void);
@@ -83,12 +82,12 @@ static GwyModuleInfo module_info = {
     &module_register,
     N_("Imports Ambios AMB data files."),
     "Yeti <yeti@gwyddion.net>",
-    "0.2",
+    "0.3",
     "David Nečas (Yeti)",
     "2011",
 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, ambfile)
 
 static gboolean
 module_register(void)
@@ -126,11 +125,11 @@ amb_load(const gchar *filename,
     GwyContainer *container = NULL;
     guchar *buffer = NULL;
     const guchar *p;
-    gdouble *data;
-    guint i, j;
     gsize size = 0;
     GError *err = NULL;
     guint xres, yres;
+    gdouble xreal;
+    G_GNUC_UNUSED gdouble q;
     GwyDataField *dfield;
 
     if (!gwy_file_get_contents(filename, &buffer, &size, &err)) {
@@ -143,9 +142,8 @@ amb_load(const gchar *filename,
     }
 
     /* The two bytes before are usually zeroes */
-    p = buffer + XRES_OFFSET;
+    p = buffer + PARAM_OFFSET;
     xres = gwy_get_guint32_le(&p);
-    p = buffer + YRES_OFFSET;
     yres = gwy_get_guint32_le(&p);
     gwy_debug("xres: %u yres: %u", xres, yres);
     /* The four bytes after might be a float, then there are four more bytes. */
@@ -154,15 +152,16 @@ amb_load(const gchar *filename,
     if (err_SIZE_MISMATCH(error, 4*xres*yres + HEADER_SIZE, size, TRUE))
         goto fail;
 
-    dfield = gwy_data_field_new(xres, yres, 1.0, 1.0*yres/xres,
-                                FALSE);
-    data = gwy_data_field_get_data(dfield);
-    p = buffer + HEADER_SIZE;
-    for (i = 0; i < yres; i++) {
-        for (j = 0; j < xres; j++)
-            data[i*xres + j] = gwy_get_gfloat_le(&p);
-    }
+    xreal = gwy_get_gfloat_le(&p) * 1e-3;
+    /* FIXME: I do not know what the second number means.  It does not seem to
+     * be z-scale because z scaling does not change when the number changes. */
+    q = gwy_get_gfloat_le(&p);
+    gwy_debug("xreal: %g, q: %g", xreal, q);
 
+    dfield = gwy_data_field_new(xres, yres, xreal, xreal, FALSE);
+    gwy_convert_raw_data(buffer + HEADER_SIZE, xres*yres, 1,
+                         GWY_RAW_DATA_FLOAT, GWY_BYTE_ORDER_LITTLE_ENDIAN,
+                         gwy_data_field_get_data(dfield), 1e-3, 0.0);
     gwy_si_unit_set_from_string(gwy_data_field_get_si_unit_xy(dfield), "m");
     gwy_si_unit_set_from_string(gwy_data_field_get_si_unit_z(dfield), "m");
 
@@ -170,6 +169,7 @@ amb_load(const gchar *filename,
     gwy_container_set_object_by_name(container, "/0/data", dfield);
     gwy_container_set_string_by_name(container, "/0/data/title",
                                      g_strdup("Topography"));
+    gwy_app_channel_check_nonsquare(container, 0);
     g_object_unref(dfield);
 
     gwy_file_channel_import_log_add(container, 0, NULL, filename);
