@@ -1,5 +1,5 @@
 /*
- *  $Id: apedaxfile.c 19044 2016-10-08 19:10:46Z yeti-dn $
+ *  $Id: apedaxfile.c 19549 2017-03-27 08:34:42Z yeti-dn $
  *  Copyright (C) 2005 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -213,31 +213,33 @@ static const APEXmlField dax_stm[] = {
 
 /*Prototypes*/
 
-static gboolean      module_register               (void);
-static gint          apedax_detect                 (const GwyFileDetectInfo *fileinfo,
-                                                    gboolean only_name);
-static GwyContainer* apedax_load                   (const gchar *filename,
-                                                    GwyRunType mode,
-                                                    GError **error);
-static GwyContainer* apedax_get_meta               (guchar *scan_xml_content,
-                                                    gsize content_size,
-                                                    gboolean apdt_file);
-static gchar*        apedax_get_xml_node_as_string (xmlDocPtr doc,
-                                                    const gchar *node_xpath);
-static GwyDataField* apedax_get_data_field         (GwyZipFile uFile,
-                                                    const gchar *chFileName,
-                                                    const APEScanSize *scan_size,
-                                                    gchar *zUnit,
-                                                    gdouble scale,
-                                                    GError **error);
-static gboolean      apedax_get_channels_data      (GwyZipFile uFile,
-                                                    guchar *scan_xml_content,
-                                                    gsize content_size,
-                                                    const gchar *filename,
-                                                    GwyContainer *container,
-                                                    GwyContainer *meta,
-                                                    const APEScanSize *scan_size,
-                                                    GError **error);
+static gboolean      module_register              (void);
+static gint          apedax_detect                (const GwyFileDetectInfo *fileinfo,
+                                                   gboolean only_name);
+static gboolean      apedax_is_plausible_file     (const guchar *filehead,
+                                                   gsize len);
+static GwyContainer* apedax_load                  (const gchar *filename,
+                                                   GwyRunType mode,
+                                                   GError **error);
+static GwyContainer* apedax_get_meta              (guchar *scan_xml_content,
+                                                   gsize content_size,
+                                                   gboolean apdt_file);
+static gchar*        apedax_get_xml_node_as_string(xmlDocPtr doc,
+                                                   const gchar *node_xpath);
+static GwyDataField* apedax_get_data_field        (GwyZipFile uFile,
+                                                   const gchar *chFileName,
+                                                   const APEScanSize *scan_size,
+                                                   gchar *zUnit,
+                                                   gdouble scale,
+                                                   GError **error);
+static gboolean      apedax_get_channels_data     (GwyZipFile uFile,
+                                                   guchar *scan_xml_content,
+                                                   gsize content_size,
+                                                   const gchar *filename,
+                                                   GwyContainer *container,
+                                                   GwyContainer *meta,
+                                                   const APEScanSize *scan_size,
+                                                   GError **error);
 
 static gboolean     apedax_is_xml_valid            (guchar *scan_xml_content,
                                                     gsize content_size);
@@ -260,7 +262,7 @@ static GwyModuleInfo module_info = {
     "Andrea Cervesato <infos@aperesearch.com>, "
         "Gianfranco Gallizia <infos@aperesearch.com>, "
         "Samo Ziberna <infos@aperesearch.com>",
-    "0.7",
+    "0.8",
     "A.P.E. Research srl",
     "2015"
 };
@@ -306,6 +308,11 @@ apedax_detect(const GwyFileDetectInfo *fileinfo,
     else
         return 0;
 
+    /* Weed out surely non-DAX files before calling possibly expensive ZIP
+     * functions. */
+    if (!apedax_is_plausible_file(fileinfo->head, fileinfo->buffer_len))
+        return 0;
+
     gwy_debug("Opening the file with MiniZIP");
     uFile = gwyzip_open(fileinfo->name);
 
@@ -334,6 +341,23 @@ apedax_detect(const GwyFileDetectInfo *fileinfo,
     return score;
 }
 
+/* Try to find the name of an expected file somewhere. */
+static gboolean
+apedax_is_plausible_file(const guchar *filehead, gsize len)
+{
+    static const gchar *filenames[] = {
+        ".bin", "scan.xml",
+    };
+    guint i;
+
+    for (i = 0; i < G_N_ELEMENTS(filenames); i++) {
+        if (gwy_memmem(filehead, len, filenames[i], strlen(filenames[i])))
+            return TRUE;
+    }
+
+    return FALSE;
+}
+
 /*Load function*/
 
 static GwyContainer*
