@@ -1,5 +1,5 @@
 /*
- *  $Id: apefile.c 17817 2015-12-09 21:35:07Z yeti-dn $
+ *  $Id: apefile.c 19948 2017-06-22 14:05:41Z yeti-dn $
  *  Copyright (C) 2005 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -200,7 +200,7 @@ static GwyModuleInfo module_info = {
     "2005",
 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, apefile)
 
 static gboolean
 module_register(void)
