@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: asciiexport.c 17719 2015-11-06 08:46:13Z pecold $
+ *  @(#) $Id: asciiexport.c 19948 2017-06-22 14:05:41Z yeti-dn $
  *  Copyright (C) 2003,2007 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
@@ -79,7 +79,7 @@ static GwyModuleInfo module_info = {
     "2004",
 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, asciiexport)
 
 static gboolean
 module_register(void)
