@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: assing-afm.c 18007 2016-01-06 23:14:44Z yeti-dn $
+ *  @(#) $Id: assing-afm.c 19948 2017-06-22 14:05:41Z yeti-dn $
  *  Copyright (C) 2005 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -76,7 +76,7 @@ static GwyModuleInfo module_info = {
     "2005",
 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, assing_afm)
 
 static gboolean
 module_register(void)
