@@ -1,5 +1,5 @@
 /*
- *  $Id: attocube.c 17718 2015-11-06 08:04:04Z pecold $
+ *  $Id: attocube.c 19948 2017-06-22 14:05:41Z yeti-dn $
  *  Copyright (C) 2009 David Necas (Yeti).
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -88,7 +88,7 @@ static GwyModuleInfo module_info = {
     "2009",
 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, attocube)
 
 static gboolean
 module_register(void)
@@ -271,6 +271,12 @@ asc_load(const gchar *filename,
     if ((value = g_hash_table_lookup(hash, "scanspeed")))
         gwy_container_set_string_by_name(meta, "Scan Speed", g_strdup(value));
 
+    if ((value = g_hash_table_lookup(hash, "x-offset")))
+        gwy_container_set_string_by_name(meta, "X Offset", g_strdup(value));
+
+    if ((value = g_hash_table_lookup(hash, "y-offset")))
+        gwy_container_set_string_by_name(meta, "Y Offset", g_strdup(value));
+
     gwy_file_channel_import_log_add(container, 0, NULL, filename);
 
 fail:
