@@ -1,5 +1,5 @@
 /*
- *  $Id: bcrfile.c 19216 2016-11-09 10:39:06Z yeti-dn $
+ *  $Id: bcrfile.c 20196 2017-08-08 06:13:38Z yeti-dn $
  *  Copyright (C) 2005 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -76,11 +76,6 @@
 
 #include "err.h"
 
-#ifdef _MSC_VER
-#define swab _swab
-#endif
-
-
 /* in characters, not bytes */
 #define HEADER_SIZE 2048
 
@@ -145,12 +140,12 @@ static GwyModuleInfo module_info = {
     &module_register,
     N_("Imports Image Metrology BCR data files."),
     "Yeti <yeti@gwyddion.net>",
-    "0.15",
+    "0.16",
     "David Nečas (Yeti) & Petr Klapetek",
     "2005",
 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, bcrfile)
 
 static gboolean
 module_register(void)
@@ -228,7 +223,7 @@ bcrfile_load(const gchar *filename,
 #endif
 #if (G_BYTE_ORDER == G_BIG_ENDIAN)
         s = g_new(gunichar2, HEADER_SIZE);
-        swab(buffer, s, header_size);
+        gwy_memcpy_byte_swap(buffer, (guint8*)s, 2, HEADER_SIZE, 1);
 #endif
         header = g_utf16_to_utf8(s, HEADER_SIZE, 0, 0, &err);
         g_free(s);
