@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: burleigh.c 19071 2016-10-14 09:02:41Z yeti-dn $
+ *  @(#) $Id: burleigh.c 19948 2017-06-22 14:05:41Z yeti-dn $
  *  Copyright (C) 2006 David Necas (Yeti), Petr Klapetek, Hans-Peter Doerr.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net,
  *          doerr@cip.physik.uni-freiburg.de.
@@ -131,7 +131,7 @@ static GwyModuleInfo module_info = {
     "2006",
 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, burleigh)
 
 static gboolean
 module_register(void)
