@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: burleigh_exp.c 19216 2016-11-09 10:39:06Z yeti-dn $
+ *  @(#) $Id: burleigh_exp.c 19948 2017-06-22 14:05:41Z yeti-dn $
  *  Copyright (C) 2007 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
@@ -92,7 +92,7 @@ static GwyModuleInfo module_info = {
     "2007",
 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, burleigh_exp)
 
 static gboolean
 module_register(void)
