@@ -1,5 +1,5 @@
 /*
- *  $Id: codevfile.c 19044 2016-10-08 19:10:46Z yeti-dn $
+ *  $Id: codevfile.c 19948 2017-06-22 14:05:41Z yeti-dn $
  *  Copyright (C) 2011 David Necas (Yeti).
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -75,7 +75,7 @@ static GwyModuleInfo module_info = {
     "2011",
 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, codevfile)
 
 static gboolean
 module_register(void)
