@@ -1,5 +1,5 @@
 /*
- *  $Id: dmefile.c 18071 2016-01-11 21:00:49Z yeti-dn $
+ *  $Id: dmefile.c 19948 2017-06-22 14:05:41Z yeti-dn $
  *  Copyright (C) 2006 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -135,7 +135,7 @@ static GwyModuleInfo module_info = {
     "2006",
 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, dmefile)
 
 static gboolean
 module_register(void)
