@@ -1,5 +1,5 @@
 /*
- *  $Id: ecsfile.c 19044 2016-10-08 19:10:46Z yeti-dn $
+ *  $Id: ecsfile.c 19948 2017-06-22 14:05:41Z yeti-dn $
  *  Copyright (C) 2006 David Necas (Yeti), Petr Klapetek, Markus Pristovsek
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net,
  *  prissi@gift.physik.tu-berlin.de.
@@ -88,7 +88,7 @@ static GwyModuleInfo module_info = {
     "2006",
 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, ecsfile)
 
 static gboolean
 module_register(void)
