@@ -1,5 +1,5 @@
 /*
- *  $Id: ezdfile.c 16387 2014-07-10 10:41:50Z yeti-dn $
+ *  $Id: ezdfile.c 19948 2017-06-22 14:05:41Z yeti-dn $
  *  Copyright (C) 2005 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -139,7 +139,7 @@ static GwyModuleInfo module_info = {
     "2005",
 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, ezdfile)
 
 static gboolean
 module_register(void)
