@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: femtoscan.c 19044 2016-10-08 19:10:46Z yeti-dn $
+ *  @(#) $Id: femtoscan.c 19948 2017-06-22 14:05:41Z yeti-dn $
  *  Copyright (C) 2014 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
@@ -85,7 +85,7 @@ static GwyModuleInfo module_info = {
     "2014",
 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, femtoscan)
 
 static gboolean
 module_register(void)
