@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: gdeffile.c 17718 2015-11-06 08:04:04Z pecold $
+ *  @(#) $Id: gdeffile.c 19948 2017-06-22 14:05:41Z yeti-dn $
  *  Copyright (C) 2010 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
@@ -133,7 +133,7 @@ static GwyModuleInfo module_info = {
     "2010",
 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, gdeffile)
 
 static gboolean
 module_register(void)
