@@ -1,5 +1,5 @@
 /*
- *  $Id: gsffile.c 17719 2015-11-06 08:46:13Z pecold $
+ *  $Id: gsffile.c 20109 2017-07-29 13:06:01Z yeti-dn $
  *  Copyright (C) 2009 David Necas (Yeti).
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -95,7 +95,7 @@ static GwyModuleInfo module_info = {
     "2010",
 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, gsffile)
 
 static gboolean
 module_register(void)
@@ -314,7 +314,7 @@ gsf_export(GwyContainer *container,
     const gdouble *d;
     gdouble v;
     gchar *s;
-    GwySIUnit *unit, *emptyunit;
+    GwySIUnit *unit;
     FILE *fh;
 
     gwy_app_data_browser_get_current(GWY_APP_DATA_FIELD, &dfield,
@@ -343,20 +343,18 @@ gsf_export(GwyContainer *container,
     if ((v = gwy_data_field_get_yoffset(dfield)))
         append_num(header, "YOffset", v);
 
-    emptyunit = gwy_si_unit_new(NULL);
     unit = gwy_data_field_get_si_unit_xy(dfield);
-    if (!gwy_si_unit_equal(unit, emptyunit)) {
+    if (!gwy_si_unit_equal_string(unit, NULL)) {
         s = gwy_si_unit_get_string(unit, GWY_SI_UNIT_FORMAT_PLAIN);
         g_string_append_printf(header, "XYUnits = %s\n", s);
         g_free(s);
     }
     unit = gwy_data_field_get_si_unit_z(dfield);
-    if (!gwy_si_unit_equal(unit, emptyunit)) {
+    if (!gwy_si_unit_equal_string(unit, NULL)) {
         s = gwy_si_unit_get_string(unit, GWY_SI_UNIT_FORMAT_PLAIN);
         g_string_append_printf(header, "ZUnits = %s\n", s);
         g_free(s);
     }
-    g_object_unref(emptyunit);
 
     s = gwy_app_get_data_field_title(container, id);
     g_string_append_printf(header, "Title = %s\n", s);
