@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: gwytiff.h 19049 2016-10-10 13:53:53Z yeti-dn $
+ *  @(#) $Id: gwytiff.h 19394 2017-01-05 15:12:04Z dn2010 $
  *  Copyright (C) 2007-2016 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
@@ -101,6 +101,8 @@ typedef enum {
     GWY_TIFFTAG_SOFTWARE          = 305,
     GWY_TIFFTAG_DATE_TIME         = 306,
     GWY_TIFFTAG_ARTIST            = 315,
+    GWY_TIFFTAG_PREDICTOR         = 317,
+    GWY_TIFFTAG_COLORMAP          = 320,
     GWY_TIFFTAG_TILE_WIDTH        = 322,
     GWY_TIFFTAG_TILE_LENGTH       = 323,
     GWY_TIFFTAG_TILE_OFFSETS      = 324,
@@ -113,6 +115,7 @@ typedef enum {
  * standard if needed.  */
 typedef enum {
     GWY_TIFF_COMPRESSION_NONE = 1,
+    GWY_TIFF_COMPRESSION_LZW  = 5,
 } GwyTIFFCompression;
 
 typedef enum {
