@@ -1,5 +1,5 @@
 /*
- *  $Id: gxyzffile.c 19044 2016-10-08 19:10:46Z yeti-dn $
+ *  $Id: gxyzffile.c 20109 2017-07-29 13:06:01Z yeti-dn $
  *  Copyright (C) 2013-2016 David Necas (Yeti).
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -122,7 +122,7 @@ static GwyModuleInfo module_info = {
     "2013",
 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, gxyzffile)
 
 static gboolean
 module_register(void)
@@ -667,7 +667,6 @@ write_header(FILE *fh, guint nchannels, guint npoints,
              GError **error)
 {
     static const gchar zeros[8] = { 0, 0, 0, 0, 0, 0, 0, 0 };
-    GwySIUnit *emptyunit;
     GString *header;
     gchar *s;
     guint i, padding;
@@ -676,22 +675,19 @@ write_header(FILE *fh, guint nchannels, guint npoints,
     g_string_append_printf(header, "NChannels = %u\n", nchannels);
     g_string_append_printf(header, "NPoints = %u\n", npoints);
 
-    emptyunit = gwy_si_unit_new(NULL);
-
-    if (!gwy_si_unit_equal(xyunit, emptyunit)) {
+    if (!gwy_si_unit_equal_string(xyunit, NULL)) {
         s = gwy_si_unit_get_string(xyunit, GWY_SI_UNIT_FORMAT_PLAIN);
         g_string_append_printf(header, "XYUnits = %s\n", s);
         g_free(s);
     }
 
     for (i = 0; i < nchannels; i++) {
-        if (!gwy_si_unit_equal(zunits[i], emptyunit)) {
+        if (!gwy_si_unit_equal_string(zunits[i], NULL)) {
             s = gwy_si_unit_get_string(zunits[i], GWY_SI_UNIT_FORMAT_PLAIN);
             g_string_append_printf(header, "ZUnits%u = %s\n", i+1, s);
             g_free(s);
         }
     }
-    g_object_unref(emptyunit);
 
     for (i = 0; i < nchannels; i++)
         g_string_append_printf(header, "Title%u = %s\n", i, titles[i]);
