@@ -1,5 +1,5 @@
 /*
- *  $Id: hdf4file.c 16387 2014-07-10 10:41:50Z yeti-dn $
+ *  $Id: hdf4file.c 19948 2017-06-22 14:05:41Z yeti-dn $
  *  Copyright (C) 2006 David Necas (Yeti), Petr Klapetek, Markus Pristovsek
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net,
  *  prissi@gift.physik.tu-berlin.de.
@@ -343,7 +343,7 @@ static GwyModuleInfo module_info = {
     "2006",
 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, hdf4file)
 
 static gboolean
 module_register(void)
