@@ -1,5 +1,5 @@
 /*
- *  $Id: hitachi-afm.c 16387 2014-07-10 10:41:50Z yeti-dn $
+ *  $Id: hitachi-afm.c 19948 2017-06-22 14:05:41Z yeti-dn $
  *  Copyright (C) 2005 David Necas (Yeti), Petr Klapetek, Markus Pristovsek
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *  prissi@gift.physik.tu-berlin.de.
@@ -111,7 +111,7 @@ static GwyModuleInfo module_info = {
     "2005",
 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, hitachi_afm)
 
 static gboolean
 module_register(void)
