@@ -1,6 +1,6 @@
 /*
- *  $Id: igorfile.c 19044 2016-10-08 19:10:46Z yeti-dn $
- *  Copyright (C) 2009 David Necas (Yeti).
+ *  $Id: igorfile.c 19948 2017-06-22 14:05:41Z yeti-dn $
+ *  Copyright (C) 2009-2017 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -32,16 +32,19 @@
  * [FILE-MAGIC-USERGUIDE]
  * WaveMetrics IGOR binary wave v5
  * .ibw
- * Read
+ * Read Export
  **/
 
 #include "config.h"
 #include <string.h>
 #include <stdlib.h>
+#include <stdio.h>
+#include <glib/gstdio.h>
 #include <libgwyddion/gwymacros.h>
 #include <libgwyddion/gwyutils.h>
 #include <libgwyddion/gwymath.h>
 #include <libprocess/stats.h>
+#include <libprocess/arithmetic.h>
 #include <libgwymodule/gwymodule-file.h>
 #include <app/gwymoduleutils-file.h>
 #include <app/data-browser.h>
@@ -166,33 +169,40 @@ typedef struct {
     GwyContainer *channelmeta;
 } IgorFile;
 
-static gboolean      module_register       (void);
-static gint          igor_detect           (const GwyFileDetectInfo *fileinfo,
-                                            gboolean only_name);
-static GwyContainer* igor_load             (const gchar *filename,
-                                            GwyRunType mode,
-                                            GError **error);
-static guint         igor_read_headers     (IgorFile *igorfile,
-                                            const guchar *buffer,
-                                            gsize size,
-                                            gboolean check_only,
-                                            GError **error);
-static guint         igor_checksum         (gconstpointer buffer,
-                                            gsize size,
-                                            gboolean lsb);
-static guint         igor_data_type_size   (IgorDataType type);
-static GwyDataField* igor_read_data_field  (const IgorFile *igorfile,
-                                            const guchar *buffer,
-                                            guint i,
-                                            const gchar *zunits,
-                                            gboolean imaginary);
-static GwyContainer* igor_get_metadata     (IgorFile *igorfile,
-                                            guint id);
-static GPtrArray*    read_channel_labels   (const gchar *p,
-                                            guint n,
-                                            guint l);
-static gchar*        canonicalize_title    (const gchar *title);
-static const gchar*  channel_title_to_units(const gchar *title);
+static gboolean      module_register         (void);
+static gint          igor_detect             (const GwyFileDetectInfo *fileinfo,
+                                              gboolean only_name);
+static GwyContainer* igor_load               (const gchar *filename,
+                                              GwyRunType mode,
+                                              GError **error);
+static gboolean      igor_export             (GwyContainer *data,
+                                              const gchar *filename,
+                                              GwyRunType mode,
+                                              GError **error);
+static guint         igor_read_headers       (IgorFile *igorfile,
+                                              const guchar *buffer,
+                                              gsize size,
+                                              gboolean check_only,
+                                              GError **error);
+static guint         igor_checksum           (gconstpointer buffer,
+                                              gsize size,
+                                              gboolean lsb);
+static guint         igor_data_type_size     (IgorDataType type);
+static GwyDataField* igor_read_data_field    (const IgorFile *igorfile,
+                                              const guchar *buffer,
+                                              guint i,
+                                              const gchar *zunits,
+                                              gboolean is_imaginary);
+static GwyContainer* igor_get_metadata       (IgorFile *igorfile,
+                                              guint id);
+static GPtrArray*    read_channel_labels     (const gchar *p,
+                                              guint n,
+                                              guint l);
+static gchar*        canonicalize_title      (const gchar *title);
+static const gchar*  channel_title_to_units  (const gchar *title);
+static gint*         find_compatible_channels(GwyContainer *container,
+                                              GwyDataField *dfield,
+                                              guint *n);
 
 static GwyModuleInfo module_info = {
     GWY_MODULE_ABI_VERSION,
@@ -204,7 +214,7 @@ static GwyModuleInfo module_info = {
     "2009",
 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, igorfile)
 
 static gboolean
 module_register(void)
@@ -214,7 +224,7 @@ module_register(void)
                            (GwyFileDetectFunc)&igor_detect,
                            (GwyFileLoadFunc)&igor_load,
                            NULL,
-                           NULL);
+                           (GwyFileSaveFunc)&igor_export);
 
     return TRUE;
 }
@@ -287,7 +297,8 @@ igor_load(const gchar *filename,
     xres = wave5->n_dim[0];
     yres = wave5->n_dim[1];
     igorfile.nchannels = wave5->n_dim[2];
-    if (igorfile.nchannels==0) igorfile.nchannels=1;
+    if (igorfile.nchannels == 0)
+        igorfile.nchannels = 1;
 
     if (!xres || !yres || !igorfile.nchannels || wave5->n_dim[3]) {
         g_set_error(error, GWY_MODULE_FILE_ERROR, GWY_MODULE_FILE_ERROR_DATA,
@@ -327,7 +338,7 @@ igor_load(const gchar *filename,
         goto fail;
 
     p = buffer + igorfile.headers_size + expected_size;
-    gwy_debug("remaning data size: %lu", (gulong)(size - (p - buffer)));
+    gwy_debug("remaining data size: %lu", (gulong)(size - (p - buffer)));
 
     p += igorfile.header.formula_size;
     if ((igorfile.variant == IGOR_ASYLUM_FORCE
@@ -352,8 +363,8 @@ igor_load(const gchar *filename,
 
     /* FIXME: The labels are mandatory only in Asylum Research files. */
     nlabels = igorfile.header.dim_labels_size[2]/(MAX_WAVE_NAME5+1);
-    expected_size = (MAX_WAVE_NAME5 + 1)*(nlabels);
-    if ((p - buffer) + expected_size > size ) {
+    expected_size = (MAX_WAVE_NAME5 + 1)*nlabels;
+    if ((p - buffer) + expected_size > size) {
         g_set_error(error, GWY_MODULE_FILE_ERROR, GWY_MODULE_FILE_ERROR_DATA,
                     _("Cannot read channel labels."));
         goto fail;
@@ -614,6 +625,7 @@ igor_read_headers(IgorFile *igorfile,
         get_CHARARRAY(wave5->whpad1, &p);
         wave5->wh_version = igorfile->get_guint16(&p);
         get_CHARARRAY0(wave5->bname, &p);
+        gwy_debug("bname %s", wave5->bname);
         wave5->whpad2 = igorfile->get_guint32(&p);
         wave5->dfolder = igorfile->get_guint32(&p);
         for (i = 0; i < MAXDIMS; i++) {
@@ -695,7 +707,7 @@ igor_read_data_field(const IgorFile *igorfile,
                      const guchar *buffer,
                      guint i,
                      const gchar *zunits,
-                     gboolean imaginary)
+                     gboolean is_imaginary)
 {
     const IgorWaveHeader5 *wave5;
     guint n, xres, yres, skip;
@@ -717,9 +729,9 @@ igor_read_data_field(const IgorFile *igorfile,
                                 FALSE);
     data = gwy_data_field_get_data(dfield);
 
-    g_return_val_if_fail(!imaginary || (wave5->type & IGOR_COMPLEX), dfield);
-    skip = imaginary ? igorfile->type_size/2 : 0;
-    if (imaginary)
+    g_return_val_if_fail(!is_imaginary || (wave5->type & IGOR_COMPLEX), dfield);
+    skip = is_imaginary ? igorfile->type_size/2 : 0;
+    if (is_imaginary)
         p += skip;
 
     /* TODO: Support extended units */
@@ -931,4 +943,299 @@ igor_get_metadata(IgorFile *igorfile,
     return igorfile->channelmeta;
 }
 
+static inline guint
+append_uint16(GByteArray *content, guint16 u16)
+{
+    guint pos = content->len;
+
+    u16 = GUINT16_TO_LE(u16);
+    g_byte_array_append(content, (guint8*)&u16, sizeof(guint16));
+    return pos;
+}
+
+static inline guint
+append_uint32(GByteArray *content, guint32 u32)
+{
+    guint pos = content->len;
+
+    u32 = GUINT32_TO_LE(u32);
+    g_byte_array_append(content, (guint8*)&u32, sizeof(guint32));
+    return pos;
+}
+
+static inline void
+append_double(GByteArray *content, gdouble dbl)
+{
+    union { guchar pp[8]; double d; } u;
+
+    u.d = dbl;
+#if (G_BYTE_ORDER == G_BIG_ENDIAN)
+    GWY_SWAP(guchar, u.pp[0], u.pp[7]);
+    GWY_SWAP(guchar, u.pp[1], u.pp[6]);
+    GWY_SWAP(guchar, u.pp[2], u.pp[5]);
+    GWY_SWAP(guchar, u.pp[3], u.pp[4]);
+#endif
+    g_byte_array_append(content, u.pp, sizeof(gdouble));
+}
+
+static inline void
+append_zeros(GByteArray *content, guint len)
+{
+    guint8 *zeros;
+    guint64 z64 = 0;
+
+    if (len <= 8) {
+        g_byte_array_append(content, (guint8*)&z64, len);
+        return;
+    }
+
+    zeros = g_new0(guint8, len);
+    g_byte_array_append(content, zeros, len);
+    g_free(zeros);
+}
+
+static inline void
+append_string(GByteArray *content, const gchar *str, guint maxlen)
+{
+    guint len;
+
+    if (!str) {
+        append_zeros(content, maxlen+1);
+        return;
+    }
+
+    len = strlen(str);
+    g_byte_array_append(content, str, MIN(len, maxlen));
+    append_zeros(content, maxlen+1 - MIN(len, maxlen));
+}
+
+static gboolean
+igor_export(GwyContainer *data,
+            const gchar *filename,
+            G_GNUC_UNUSED GwyRunType mode,
+            GError **error)
+{
+    GByteArray *header = NULL;
+    GwyDataField *dfield;
+    GwySIUnit *xyunit, *zunit;
+    const gdouble *d, *drow;
+    gfloat *dfl = NULL, *frow;
+    gint *ids = NULL;
+    FILE *fh = NULL;
+    gboolean ok = FALSE;
+    guint chksumpos;
+    guint xres, yres, n, npts, nchannels, i, j, k, wantlen;
+    gdouble xreal, yreal;
+    guint16 chksum;
+    gchar *title, *title_latin1, *unitstr;
+    gchar bname[MAX_WAVE_NAME5+1];
+    GQuark quark;
+
+    gwy_app_data_browser_get_current(GWY_APP_DATA_FIELD, &dfield, 0);
+    if (!dfield) {
+        err_NO_CHANNEL_EXPORT(error);
+        return FALSE;
+    }
+
+    ids = find_compatible_channels(data, dfield, &nchannels);
+    g_return_val_if_fail(nchannels > 0, FALSE);
+
+    if (!(fh = gwy_fopen(filename, "wb"))) {
+        err_OPEN_WRITE(error);
+        g_free(ids);
+        return FALSE;
+    }
+
+    xres = gwy_data_field_get_xres(dfield);
+    yres = gwy_data_field_get_yres(dfield);
+    xreal = gwy_data_field_get_xreal(dfield);
+    yreal = gwy_data_field_get_yreal(dfield);
+    xyunit = gwy_data_field_get_si_unit_xy(dfield);
+    zunit = gwy_data_field_get_si_unit_z(dfield);
+
+    n = xres*yres;
+    npts = nchannels*n;
+
+    wantlen = HEADER_SIZE5 + WAVE_SIZE5;
+    header = g_byte_array_sized_new(wantlen);
+
+    /* File header. */
+    append_uint16(header, 0x0005u); /* Version. */
+    chksumpos = append_uint16(header, 0); /* Checksum - TBD later. */
+    append_uint32(header, WAVE_SIZE5 + npts*sizeof(gfloat)); /* WFM size */
+    append_uint32(header, 0); /* formula size */
+    append_uint32(header, 0); /* note size */
+    append_uint32(header, 0); /* extended data units size */
+    for (i = 0; i < MAXDIMS; i++)
+        append_uint32(header, 0); /* extended dimension unit sizes */
+
+    /* extended dimension label sizes: x, y, channel, 4D */
+    append_uint32(header, 0);
+    append_uint32(header, 0);
+    append_uint32(header, nchannels*(MAX_WAVE_NAME5 + 1));
+    append_uint32(header, 0);
+
+    append_uint32(header, 0); /* string indices for text waves */
+    append_uint32(header, 0); /* options1, reserved */
+    append_uint32(header, 0); /* options2, reserved */
+
+    /* Wave header. */
+    append_uint32(header, 0); /* next */
+    append_uint32(header, 0); /* creation date */
+    append_uint32(header, 0); /* modification date */
+    append_uint32(header, npts); /* npts */
+    append_uint16(header, IGOR_SINGLE); /* type */
+    append_uint16(header, 0); /* lock */
+    append_zeros(header, 6); /* whpad1 */
+    append_uint16(header, 1); /* wh_version */
+    /* Igor complains if the field is empty.  Also it does not like it being
+     * the same as something else... */
+    g_snprintf(bname, sizeof(bname), "gwy%u", g_random_int());
+    append_string(header, bname, MAX_WAVE_NAME5); /* bname */
+    append_zeros(header, 4); /* whpad2 */
+    append_uint32(header, 0); /* dfolder */
+
+    append_uint32(header, xres); /* n_dim[0] */
+    append_uint32(header, yres); /* n_dim[1] */
+    append_uint32(header, nchannels); /* n_dim[2] */
+    append_uint32(header, 0); /* n_dim[3] */
+
+    append_double(header, xreal/xres); /* sfA[0] */
+    append_double(header, yreal/yres); /* sfA[1] */
+    append_double(header, 1.0); /* sfA[2] */
+    append_double(header, 1.0); /* sfA[3] */
+
+    /* FIXME: We could store offsets but they may differ among the fields. */
+    append_double(header, 0.0); /* sfB[0] */
+    append_double(header, 0.0); /* sfB[1] */
+    append_double(header, 0.0); /* sfB[2] */
+    append_double(header, 0.0); /* sfB[3] */
+
+    /* natural data units */
+    unitstr = gwy_si_unit_get_string(zunit, GWY_SI_UNIT_FORMAT_PLAIN);
+    if (strlen(unitstr) == 1)
+        append_string(header, unitstr, MAX_UNIT_CHARS);
+    else
+        append_string(header, NULL, MAX_UNIT_CHARS);
+
+    /* dimension units */
+    unitstr = gwy_si_unit_get_string(xyunit, GWY_SI_UNIT_FORMAT_PLAIN);
+    if (strlen(unitstr) == 1) {
+        append_string(header, unitstr, MAX_UNIT_CHARS);
+        append_string(header, unitstr, MAX_UNIT_CHARS);
+    }
+    else {
+        append_string(header, NULL, MAX_UNIT_CHARS);
+        append_string(header, NULL, MAX_UNIT_CHARS);
+    }
+    g_free(unitstr);
+    for (i = 2; i < MAXDIMS; i++)
+        append_string(header, NULL, MAX_UNIT_CHARS);
+
+    append_uint16(header, 0); /* fsValid */
+    append_uint16(header, 0); /* whpad3 */
+    append_double(header, 0.0); /* top full scale */
+    append_double(header, 0.0); /* bottom full scale */
+
+    gwy_debug("header len %u", header->len);
+
+    if (header->len < wantlen)
+        append_zeros(header, wantlen - header->len);
+    chksum = igor_checksum(header->data, header->len, TRUE);
+    gwy_debug("checksum %04x", chksum);
+    chksum = ((chksum + 0xffff) & 0xffff) ^ 0xffff;
+    header->data[chksumpos] = chksum % 0x100;
+    header->data[chksumpos+1] = chksum/0x100;
+
+    if (!(ok = (fwrite(header->data, 1, header->len, fh) == header->len))) {
+        err_WRITE(error);
+        goto fail;
+    }
+
+    dfl = g_new(gfloat, n);
+    for (k = 0; ids[k] >= 0; k++) {
+        quark = gwy_app_get_data_key_for_id(ids[k]);
+        dfield = gwy_container_get_object(data, quark);
+        d = gwy_data_field_get_data_const(dfield);
+        for (i = 0; i < yres; i++) {
+            frow = dfl + i*xres;
+            drow = d + (yres-1 - i)*xres;
+            for (j = 0; j < xres; j++) {
+#if (G_BYTE_ORDER == G_BIG_ENDIAN)
+                {
+                    union { guchar pp[4]; gfloat f; } u;
+
+                    u.f = drow[j];
+                    GWY_SWAP(guchar, u.pp[0], u.pp[3]);
+                    GWY_SWAP(guchar, u.pp[1], u.pp[2]);
+                    frow[j] = u.f;
+                }
+#else
+                frow[j] = drow[j];
+#endif
+            }
+        }
+
+        if (!(ok = (fwrite(dfl, sizeof(gfloat), n, fh) == n))) {
+            err_WRITE(error);
+            goto fail;
+        }
+    }
+
+    g_byte_array_set_size(header, 0);
+    for (k = 0; ids[k] >= 0; k++) {
+        title = gwy_app_get_data_field_title(data, ids[k]);
+        title_latin1 = g_convert(title, -1, "ISO-8859-1", "UTF-8",
+                                 NULL, NULL, NULL);
+        append_string(header, title_latin1, MAX_WAVE_NAME5);
+        g_free(title_latin1);
+        g_free(title);
+    }
+
+    if (!(ok = (fwrite(header->data, 1, header->len, fh) == header->len))) {
+        err_WRITE(error);
+        goto fail;
+    }
+
+    ok = TRUE;
+
+fail:
+    fclose(fh);
+    if (!ok)
+        g_unlink(filename);
+    g_free(ids);
+    g_free(dfl);
+    if (header)
+        g_byte_array_free(header, TRUE);
+
+    return ok;
+}
+
+static gint*
+find_compatible_channels(GwyContainer *container,
+                         GwyDataField *dfield,
+                         guint *n)
+{
+    GwyDataField *otherfield;
+    GQuark quark;
+    guint i, j;
+    gint *ids;
+
+    ids = gwy_app_data_browser_get_data_ids(container);
+    for (i = j = 0; ids[i] >= 0; i++) {
+        quark = gwy_app_get_data_key_for_id(ids[i]);
+        otherfield = gwy_container_get_object(container, quark);
+        if (gwy_data_field_check_compatibility(dfield, otherfield,
+                                               GWY_DATA_COMPATIBILITY_ALL) != 0)
+            continue;
+
+        ids[j++] = ids[i];
+    }
+    g_assert(j > 0);
+    *n = j;
+    ids[j] = -1;
+
+    return ids;
+}
+
 /* vim: set cin et ts=4 sw=4 cino=>1s,e0,n0,f0,{0,}0,^0,\:1s,=0,g1s,h0,t0,+1s,c3,(0,u0 : */
