@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: imgexportpreset.h 19082 2016-10-14 20:40:18Z dn2010 $
+ *  @(#) $Id: imgexportpreset.h 19917 2017-06-15 12:28:10Z yeti-dn $
  *  Copyright (C) 2014-2016 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
@@ -162,7 +162,7 @@ static const ImgExportArgs img_export_defaults = {
     GWYRGBA_WHITE, GWYRGBA_WHITE, INSET_POS_BOTTOM_RIGHT,
     GWYRGBA_BLACK, GWYRGBA_WHITE, TRUE,
     TRUE, TRUE, FALSE, TRUE,
-    "Helvetica", TRUE,
+    "Arial", TRUE,
     FALSE, TRUE, TRUE, FALSE,
     1.0, 1.0, 1.0, 0.0, 1.0,
     FALSE, 2,
@@ -269,7 +269,7 @@ img_export_sanitize_args(ImgExportArgs *args)
     args->fmscale_gap = CLAMP(args->fmscale_gap, 0.0, 2.0);
     args->inset_xgap = CLAMP(args->inset_xgap, 0.0, 4.0);
     args->inset_ygap = CLAMP(args->inset_ygap, 0.0, 2.0);
-    args->title_gap = CLAMP(args->title_gap, -1.0, 1.0);
+    args->title_gap = CLAMP(args->title_gap, -2.0, 1.0);
     args->fix_fmscale_precision = !!args->fix_fmscale_precision;
     args->fmscale_precision = CLAMP(args->fmscale_precision, 0, 16);
     args->fix_kilo_threshold = !!args->fix_kilo_threshold;
