@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: intematix.c 17718 2015-11-06 08:04:04Z pecold $
+ *  @(#) $Id: intematix.c 19948 2017-06-22 14:05:41Z yeti-dn $
  *  Copyright (C) 2007 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -129,7 +129,7 @@ static GwyModuleInfo module_info = {
     "2006",
 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, intematix)
 
 static gboolean
 module_register(void)
