@@ -1,6 +1,6 @@
 /*
- *  $Id: iso28600.c 19044 2016-10-08 19:10:46Z yeti-dn $
- *  Copyright (C) 2011 David Necas (Yeti).
+ *  $Id: iso28600.c 19948 2017-06-22 14:05:41Z yeti-dn $
+ *  Copyright (C) 2011-2016 David Necas (Yeti).
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -170,6 +170,15 @@ static GwyContainer*       load_channels      (ISO28600FieldValue *header,
                                                gdouble xreal,
                                                gdouble yreal,
                                                GError **error);
+static GwyContainer*       load_xyz_data      (ISO28600FieldValue *header,
+                                               const gchar *filename,
+                                               gchar **strings,
+                                               gchar **p,
+                                               ISO28600ExperimentMode experiment,
+                                               guint nchannels,
+                                               gdouble qx,
+                                               gdouble qy,
+                                               GError **error);
 static GwyContainer*       load_spectra_graphs(ISO28600FieldValue *header,
                                                gchar **p,
                                                ISO28600SpectroscopyScanMode smode,
@@ -533,12 +542,12 @@ static GwyModuleInfo module_info = {
     &module_register,
     N_("Imports and exports ISO 28600:2011 SPM data transfer format."),
     "Yeti <yeti@gwyddion.net>",
-    "0.2",
+    "0.4",
     "David Nečas (Yeti)",
     "2011",
 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, iso28600)
 
 static gboolean
 module_register(void)
@@ -600,34 +609,6 @@ iso28600_load(const gchar *filename,
         guint xres, yres, nchannels;
         gdouble xreal, yreal;
 
-        if (header[16].enumerated.value != ISO28600_SCAN_REGULAR_MAPPING) {
-            g_set_error(error, GWY_MODULE_FILE_ERROR,
-                        GWY_MODULE_FILE_ERROR_DATA,
-                        _("Only regular mappings are implemented but "
-                          "file has mapping type ‘%s’."),
-                        header[16].enumerated.str);
-            goto fail;
-        }
-        xres = header[23].i;
-        yres = header[24].i;
-        if (err_DIMENSION(error, xres) || err_DIMENSION(error, yres))
-            goto fail;
-
-        xreal = header[27].d;
-        yreal = header[28].d;
-        if (!((xreal = fabs(xreal)) > 0)) {
-            g_warning("Real x size is 0.0, fixing to 1.0");
-            xreal = 1.0;
-        }
-        if (!((yreal = fabs(yreal)) > 0)) {
-            g_warning("Real y size is 0.0, fixing to 1.0");
-            yreal = 1.0;
-        }
-        xreal *= pow10(header[25].unit.power10);
-        yreal *= pow10(header[26].unit.power10);
-        if (!gwy_si_unit_equal(header[25].unit.unit, header[26].unit.unit))
-            g_warning("X and Y units differ, using X");
-
         nchannels = 1;
         if (experiment == ISO28600_EXPERIMENT_MAP_MC) {
             nchannels = header[93].i;
@@ -636,11 +617,49 @@ iso28600_load(const gchar *filename,
                 goto fail;
             }
         }
+        if (!gwy_si_unit_equal(header[25].unit.unit, header[26].unit.unit))
+            g_warning("X and Y units differ, using X");
 
-        container = load_channels(header, filename, strings, &p,
-                                  experiment, nchannels,
-                                  xres, yres, xreal, yreal,
-                                  error);
+        if (header[16].enumerated.value == ISO28600_SCAN_IRREGULAR_MAPPING) {
+            /* Ignore all area information because we have explicit X and Y
+             * coordinates of each point.  Just precalculate the factors. */
+            xreal = pow10(header[25].unit.power10);
+            yreal = pow10(header[26].unit.power10);
+            container = load_xyz_data(header, filename, strings, &p,
+                                      experiment, nchannels, xreal, yreal,
+                                      error);
+        }
+        else if (header[16].enumerated.value == ISO28600_SCAN_REGULAR_MAPPING) {
+            xres = header[23].i;
+            yres = header[24].i;
+            if (err_DIMENSION(error, xres) || err_DIMENSION(error, yres))
+                goto fail;
+
+            xreal = header[27].d;
+            yreal = header[28].d;
+            if (!((xreal = fabs(xreal)) > 0)) {
+                g_warning("Real x size is 0.0, fixing to 1.0");
+                xreal = 1.0;
+            }
+            if (!((yreal = fabs(yreal)) > 0)) {
+                g_warning("Real y size is 0.0, fixing to 1.0");
+                yreal = 1.0;
+            }
+            xreal *= pow10(header[25].unit.power10);
+            yreal *= pow10(header[26].unit.power10);
+            container = load_channels(header, filename, strings, &p,
+                                      experiment, nchannels,
+                                      xres, yres, xreal, yreal,
+                                      error);
+        }
+        else {
+            g_set_error(error, GWY_MODULE_FILE_ERROR,
+                        GWY_MODULE_FILE_ERROR_DATA,
+                        _("Only regular and irregular mappings are implemented "
+                          "but the file has mapping type ‘%s’."),
+                        header[16].enumerated.str);
+            goto fail;
+        }
     }
     if (experiment == ISO28600_EXPERIMENT_SPEC_SC
         || experiment == ISO28600_EXPERIMENT_SPEC_MC) {
@@ -724,6 +743,7 @@ load_channels(ISO28600FieldValue *header,
     gdouble *datas[MAX_CHANNELS];
     gdouble powers10[MAX_CHANNELS];
     gchar *line, *end;
+    GQuark quark;
     guint id, k;
 
     for (id = 0; id < nchannels; id++) {
@@ -752,7 +772,7 @@ load_channels(ISO28600FieldValue *header,
         if (!line) {
             g_set_error(error, GWY_MODULE_FILE_ERROR,
                         GWY_MODULE_FILE_ERROR_DATA,
-                        _("End of file reached when reading sample #%d of %d"),
+                        _("End of file reached when reading sample #%u of %u"),
                         k, xres*yres);
             goto fail;
         }
@@ -762,11 +782,14 @@ load_channels(ISO28600FieldValue *header,
                 g_set_error(error, GWY_MODULE_FILE_ERROR,
                             GWY_MODULE_FILE_ERROR_DATA,
                             _("Malformed data encountered when reading sample "
-                              "#%d of %d"),
-                            k, xres*yres);
+                              "#%u"),
+                            k);
                 goto fail;
             }
             line = end;
+            /* The standard specifies comma separator. */
+            while (g_ascii_isspace(*line) || *line == ',')
+                line++;
         }
     }
     if (!line || !gwy_strequal(line, EOD_MAGIC)) {
@@ -779,16 +802,13 @@ load_channels(ISO28600FieldValue *header,
     for (id = 0; id < nchannels; id++) {
         GwyContainer *meta;
         const gchar *title;
-        GQuark quark = gwy_app_get_data_key_for_id(id);
 
+        quark = gwy_app_get_data_key_for_id(id);
         gwy_container_set_object(container, quark, fields[id]);
 
-        meta = get_meta(header, strings, id);
-        if (meta) {
-            gchar key[40];
-
-            g_snprintf(key, sizeof(key), "/%d/meta", id);
-            gwy_container_set_object_by_name(container, key, meta);
+        if ((meta = get_meta(header, strings, id))) {
+            quark = gwy_app_get_data_meta_key_for_id(id);
+            gwy_container_set_object(container, quark, meta);
             g_object_unref(meta);
         }
 
@@ -798,10 +818,8 @@ load_channels(ISO28600FieldValue *header,
             title = header[94 + 3*id].s;
 
         if (strlen(title)) {
-            gchar key[40];
-
-            g_snprintf(key, sizeof(key), "/%d/data/title", id);
-            gwy_container_set_string_by_name(container, key, g_strdup(title));
+            quark = gwy_app_get_data_title_key_for_id(id);
+            gwy_container_set_const_string(container, quark, title);
         }
 
         gwy_file_channel_import_log_add(container, id, NULL, filename);
@@ -814,6 +832,124 @@ fail:
     return container;
 }
 
+static GwyContainer*
+load_xyz_data(ISO28600FieldValue *header,
+              const gchar *filename,
+              gchar **strings,
+              gchar **p,
+              ISO28600ExperimentMode experiment,
+              guint nchannels,
+              gdouble qx, gdouble qy,
+              GError **error)
+{
+    GwyContainer *container = NULL;
+    gdouble powers10[MAX_CHANNELS+2];
+    GArray *alldata;
+    gchar *line, *end;
+    guint id, k;
+
+    powers10[0] = qx;
+    powers10[1] = qy;
+    for (id = 0; id < nchannels; id++) {
+        if (experiment == ISO28600_EXPERIMENT_MAP_SC)
+            powers10[id+2] = pow10(header[69].unit.power10);
+        else
+            powers10[id+2] = pow10(header[95 + 3*id].unit.power10);
+    }
+
+    /* It is not clear how many rows with data there are because the
+     * specification is obviously nonsensical, using 1..M×N range even for
+     * irregular data. */
+    alldata = g_array_new(FALSE, FALSE, sizeof(gdouble));
+    k = 0;
+    while ((line = gwy_str_next_line(p))) {
+        if (gwy_strequal(line, EOD_MAGIC))
+            break;
+        for (id = 0; id < nchannels+2; id++) {
+            gdouble v = powers10[id]*g_ascii_strtod(line, &end);
+            if (line == end) {
+                g_set_error(error, GWY_MODULE_FILE_ERROR,
+                            GWY_MODULE_FILE_ERROR_DATA,
+                            _("Malformed data encountered when reading sample "
+                              "#%u")
+                            , k);
+                goto fail;
+            }
+            g_array_append_val(alldata, v);
+            line = end;
+            /* The standard specifies comma separator. */
+            while (g_ascii_isspace(*line) || *line == ',')
+                line++;
+        }
+    }
+    if (!line || !gwy_strequal(line, EOD_MAGIC)) {
+        g_set_error(error, GWY_MODULE_FILE_ERROR, GWY_MODULE_FILE_ERROR_DATA,
+                    _("Missing end-of-data marker."));
+        goto fail;
+    }
+
+    container = gwy_container_new();
+    k = alldata->len/(nchannels + 2);
+    for (id = 0; id < nchannels; id++) {
+        GQuark quark;
+        GwyContainer *meta;
+        const gchar *title;
+        GwySurface *surface;
+        GwySIUnit *unit;
+        GwyXYZ *data;
+        guint i;
+
+        surface = gwy_surface_new_sized(k);
+        data = gwy_surface_get_data(surface);
+        for (i = 0; i < k; i++) {
+            GwyXYZ pt;
+
+            pt.x = g_array_index(alldata, gdouble, (nchannels + 2)*i);
+            pt.y = g_array_index(alldata, gdouble, (nchannels + 2)*i + 1);
+            pt.z = g_array_index(alldata, gdouble, (nchannels + 2)*i + 2 + id);
+            data[i] = pt;
+        }
+        unit = gwy_surface_get_si_unit_xy(surface);
+        gwy_serializable_clone(G_OBJECT(header[25].unit.unit), G_OBJECT(unit));
+        unit = gwy_surface_get_si_unit_z(surface);
+        if (experiment == ISO28600_EXPERIMENT_MAP_SC) {
+            gwy_serializable_clone(G_OBJECT(header[69].unit.unit),
+                                   G_OBJECT(unit));
+        }
+        else {
+            gwy_serializable_clone(G_OBJECT(header[95 + 3*id].unit.unit),
+                                   G_OBJECT(unit));
+        }
+
+        quark = gwy_app_get_data_key_for_id(id);
+        gwy_container_set_object(container, quark, surface);
+
+        if ((meta = get_meta(header, strings, id))) {
+            quark = gwy_app_get_surface_meta_key_for_id(id);
+            gwy_container_set_object(container, quark, meta);
+            g_object_unref(meta);
+        }
+
+        if (experiment == ISO28600_EXPERIMENT_MAP_SC)
+            title = header[68].s;
+        else
+            title = header[94 + 3*id].s;
+
+        if (strlen(title)) {
+            quark = gwy_app_get_surface_title_key_for_id(id);
+            gwy_container_set_const_string(container, quark, title);
+        }
+
+        gwy_file_xyz_import_log_add(container, id, NULL, filename);
+        g_object_unref(surface);
+    }
+
+fail:
+    g_array_free(alldata, TRUE);
+
+    return container;
+}
+
 /* XXX: The data format for spectroscopy is not well described so I estimate
  * it is how I would do it. */
 static GwyContainer*
@@ -940,7 +1076,7 @@ get_meta(ISO28600FieldValue *header,
     static const GwyEnum fields_without_units[] = {
         { "deg", 33 }, { "V", 40 }, { "K", 49 }, { "Pa", 50 }, { "%", 51 },
         { "N/m", 56 }, { "Hz", 57 }, { "deg", 59 }, { "deg", 60 },
-        { "deg", 61 }, 
+        { "deg", 61 },
     };
     gint year, month, day, hour, minute, second, offset;
     GwyContainer *meta = gwy_container_new();
