@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: jeol.c 17859 2015-12-17 11:59:01Z yeti-dn $
+ *  @(#) $Id: jeol.c 19948 2017-06-22 14:05:41Z yeti-dn $
  *  Copyright (C) 2006 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -541,7 +541,7 @@ static GwyModuleInfo module_info = {
     "2006",
 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, jeol)
 
 static gboolean
 module_register(void)
