@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: jspmfile.c 16831 2014-11-29 10:08:47Z yeti-dn $
+ *  @(#) $Id: jspmfile.c 19948 2017-06-22 14:05:41Z yeti-dn $
  *  Copyright (C) 2014 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
@@ -192,7 +192,7 @@ static GwyModuleInfo module_info = {
     "2014",
 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, jspmfile)
 
 static gboolean
 module_register(void)
