@@ -1,5 +1,5 @@
 /*
- *  $Id: keyence.c 18034 2016-01-08 14:02:03Z yeti-dn $
+ *  $Id: keyence.c 19948 2017-06-22 14:05:41Z yeti-dn $
  *  Copyright (C) 2015 David Necas (Yeti).
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -319,7 +319,7 @@ static GwyModuleInfo module_info = {
     "2015",
 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, keyence)
 
 static gboolean
 module_register(void)
