@@ -1,5 +1,5 @@
 /*
- *  $Id: leica.c 19130 2016-10-27 20:58:23Z dn2010 $
+ *  $Id: leica.c 19948 2017-06-22 14:05:41Z yeti-dn $
  *  Copyright (C) 2014 Daniil Bratashov (dn2010), David Necas (Yeti)..
  *
  *  E-mail: dn2010@gmail.com.
@@ -180,7 +180,7 @@ static GwyModuleInfo module_info = {
     "2016",
 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, leica)
 
 static gboolean
 module_register(void)
