@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: lextfile.c 16387 2014-07-10 10:41:50Z yeti-dn $
+ *  @(#) $Id: lextfile.c 19948 2017-06-22 14:05:41Z yeti-dn $
  *  Copyright (C) 2010 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -84,7 +84,7 @@ static GwyModuleInfo module_info = {
     "2010",
 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, lextfile)
 
 static gboolean
 module_register(void)
