@@ -1,5 +1,5 @@
 /*
- *  $Id: mapvue.c 16387 2014-07-10 10:41:50Z yeti-dn $
+ *  $Id: mapvue.c 19948 2017-06-22 14:05:41Z yeti-dn $
  *  Copyright (C) 2009,2011 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
@@ -471,7 +471,7 @@ static GwyModuleInfo module_info = {
     "2009",
 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, mapvue)
 
 static gboolean
 module_register(void)
