@@ -1,5 +1,5 @@
 /*
- *  $Id: metropro.c 19044 2016-10-08 19:10:46Z yeti-dn $
+ *  $Id: metropro.c 19948 2017-06-22 14:05:41Z yeti-dn $
  *  Copyright (C) 2006,2014 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -344,7 +344,7 @@ static GwyModuleInfo module_info = {
     "2006",
 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, metropro)
 
 static gboolean
 module_register(void)
