@@ -1,6 +1,6 @@
 /*
  *  $Id: microprof.c 6038 2006-05-23 09:16:26Z yeti-dn $
- *  Copyright (C) 2005 David Necas (Yeti), Petr Klapetek.
+ *  Copyright (C) 2005-2016 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -84,11 +84,13 @@
 #define EXTENSION_TXT ".txt"
 
 enum {
-    MICROPROF_HEADER_SIZE = 124,
+    MICROPROF_HEADER_SIZE = 122,
     MICROPROF_MIN_TEXT_SIZE = 80,
 };
 
 typedef struct {
+    gchar *comment1;
+    gchar *comment2;
     guint xres;
     guint yres;
     gdouble xrange;
@@ -105,6 +107,12 @@ static gint          microprof_txt_detect     (const GwyFileDetectInfo *fileinfo
 static GwyContainer* microprof_load           (const gchar *filename,
                                                GwyRunType mode,
                                                GError **error);
+static gboolean      microprof_read_string    (const guchar *buffer,
+                                               gsize size,
+                                               gsize pos,
+                                               gchar **pstr,
+                                               guint *len,
+                                               GError **error);
 static GwyDataField* microprof_read_data_field(const MicroProfFile *mfile,
                                                const guchar *buffer);
 static GwyContainer* microprof_txt_load       (const gchar *filename,
@@ -116,12 +124,12 @@ static GwyModuleInfo module_info = {
     &module_register,
     N_("Imports MicroProf FRT profilometer data files."),
     "Yeti <yeti@gwyddion.net>",
-    "0.5",
+    "0.6",
     "David Nečas (Yeti) & Petr Klapetek",
     "2006",
 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, microprof)
 
 static gboolean
 module_register(void)
@@ -149,7 +157,7 @@ microprof_detect(const GwyFileDetectInfo *fileinfo,
     if (only_name)
         return g_str_has_suffix(fileinfo->name_lowercase, EXTENSION) ? 10 : 0;
 
-    if (fileinfo->file_size < MICROPROF_HEADER_SIZE
+    if (fileinfo->file_size < MICROPROF_HEADER_SIZE + 1
         || fileinfo->buffer_len < MAGIC_SIZE
         || memcmp(fileinfo->head, MAGIC, MAGIC_SIZE) != 0)
         return 0;
@@ -205,24 +213,29 @@ microprof_load(const gchar *filename,
                GError **error)
 {
     enum {
-        XRES = 0x0026, YRES = 0x002a,
-        XRANGE = 0x0038, YRANGE = 0x0040,
-        ZRANGE = 0x006e,
+        COMMENT1_OFFSET = 0x0014,
+        COMMENT2_OFFSET = 0x001a,
+        XRES_OFFSET = 0x0024,
+        YRES_OFFSET = 0x0028,
+        XRANGE_OFFSET = 0x0036,
+        YRANGE_OFFSET = 0x003e,
+        ZRANGE_OFFSET = 0x006c,
     };
-    GwyContainer *container = NULL;
+    GwyContainer *container = NULL, *meta = NULL;
     guchar *buffer = NULL;
     const guchar *p;
     MicroProfFile mfile;
-    gsize size = 0;
+    gsize size = 0, extra_len = 0;
     GError *err = NULL;
-    guint i, ndata, datasize;
+    guint i, ndata, datasize, len;
 
     if (!gwy_file_get_contents(filename, &buffer, &size, &err)) {
         err_GET_FILE_CONTENTS(error, &err);
         return NULL;
     }
 
-    if (size < MICROPROF_HEADER_SIZE) {
+    gwy_clear(&mfile, 1);
+    if (size < MICROPROF_HEADER_SIZE + 1) {
         err_TOO_SHORT(error);
         goto fail;
     }
@@ -232,37 +245,60 @@ microprof_load(const gchar *filename,
         goto fail;
     }
 
-    p = buffer + XRES;
+    if (!microprof_read_string(buffer, size, COMMENT1_OFFSET + extra_len,
+                               &mfile.comment1, &len, error))
+        goto fail;
+    extra_len += len;
+
+    if (!microprof_read_string(buffer, size, COMMENT2_OFFSET + extra_len,
+                               &mfile.comment2, &len, error))
+        goto fail;
+    extra_len += len;
+
+    gwy_debug("reading xres from offset 0x%04lx",
+              (gulong)(XRES_OFFSET + extra_len));
+    p = buffer + XRES_OFFSET + extra_len;
     mfile.xres = gwy_get_guint16_le(&p);
+    gwy_debug("xres %u", mfile.xres);
     if (err_DIMENSION(error, mfile.xres))
         goto fail;
 
-    p = buffer + YRES;
+    gwy_debug("reading yres from offset 0x%04lx",
+              (gulong)(YRES_OFFSET + extra_len));
+    p = buffer + YRES_OFFSET + extra_len;
     mfile.yres = gwy_get_guint16_le(&p);
+    gwy_debug("yres %u", mfile.yres);
     if (err_DIMENSION(error, mfile.xres))
         goto fail;
 
-    p = buffer + XRANGE;
+    gwy_debug("reading xrange from offset 0x%04lx",
+              (gulong)(XRANGE_OFFSET + extra_len));
+    p = buffer + XRANGE_OFFSET + extra_len;
     mfile.xrange = gwy_get_gdouble_le(&p);
     if (!(mfile.xrange = fabs(mfile.xrange))) {
         g_warning("Real x size is 0.0, fixing to 1.0");
         mfile.xrange = 1.0;
     }
 
-    p = buffer + YRANGE;
+    gwy_debug("reading yrange from offset 0x%04lx",
+              (gulong)(YRANGE_OFFSET + extra_len));
+    p = buffer + YRANGE_OFFSET + extra_len;
     mfile.yrange = gwy_get_gdouble_le(&p);
     if (!(mfile.yrange = fabs(mfile.yrange))) {
         g_warning("Real y size is 0.0, fixing to 1.0");
         mfile.yrange = 1.0;
     }
 
-    p = buffer + ZRANGE;
+    p = buffer + ZRANGE_OFFSET + extra_len;
     mfile.zscale = gwy_get_gdouble_le(&p);
 
     datasize = 2*mfile.xres*mfile.yres;
-    if (err_SIZE_MISMATCH(error, datasize, size - MICROPROF_HEADER_SIZE, FALSE))
+    if (err_SIZE_MISMATCH(error, datasize,
+                          size - MICROPROF_HEADER_SIZE - extra_len, FALSE))
         goto fail;
     /* FIXME: There is weird stuff between channels.  Need specs.
+     * Moreover, the second image seems to be byte-to-byte identical.
+     * So maybe ignoring it is the right thing to do.
     ndata = (size - MICROPROF_HEADER_SIZE)/datasize;
     if (!ndata) {
         err_NO_DATA(error);
@@ -272,26 +308,77 @@ microprof_load(const gchar *filename,
     ndata = 1;
     container = gwy_container_new();
 
-    mfile.data = buffer + MICROPROF_HEADER_SIZE;
+    if (mfile.comment1 || mfile.comment2) {
+        meta = gwy_container_new();
+        if (mfile.comment1) {
+            gwy_container_set_const_string_by_name(meta, "Comment 1",
+                                                   mfile.comment1);
+        }
+        if (mfile.comment2) {
+            gwy_container_set_const_string_by_name(meta, "Comment 2",
+                                                   mfile.comment2);
+        }
+    }
+
+    mfile.data = buffer + MICROPROF_HEADER_SIZE + extra_len;
     for (i = 0; i < ndata; i++) {
         GwyDataField *dfield;
         GQuark quark;
 
-        dfield = microprof_read_data_field(&mfile,
-                                           mfile.data + i*datasize);
+        dfield = microprof_read_data_field(&mfile, mfile.data + i*datasize);
         quark = gwy_app_get_data_key_for_id(i);
         gwy_container_set_object(container, quark, dfield);
         g_object_unref(dfield);
 
+        /* FIXME: Duplicate meta if we ever are going to have multiple
+         * channels here. */
+        if (meta) {
+            quark = gwy_app_get_data_meta_key_for_id(i);
+            gwy_container_set_object(container, quark, meta);
+        }
+
         gwy_app_channel_title_fall_back(container, i);
         gwy_file_channel_import_log_add(container, i, NULL, filename);
     }
 
+    GWY_OBJECT_UNREF(meta);
+
 fail:
+    g_free(mfile.comment1);
+    g_free(mfile.comment2);
     gwy_file_abandon_contents(buffer, size, NULL);
     return container;
 }
 
+static gboolean
+microprof_read_string(const guchar *buffer, gsize size, gsize pos,
+                      gchar **pstr, guint *len, GError **error)
+{
+    const guchar *p;
+
+    if (pos > size - sizeof(guint32)) {
+        g_set_error(error, GWY_MODULE_FILE_ERROR, GWY_MODULE_FILE_ERROR_DATA,
+                    _("File header is truncated."));
+        return FALSE;
+    }
+
+    gwy_debug("reading string len from offset 0x%04lx", (gulong)pos);
+    p = buffer + pos;
+    *len = gwy_get_guint32_le(&p);
+    gwy_debug("string length %u", *len);
+    if (*len < 2)
+        return TRUE;
+
+    pos += sizeof(guint32);
+    if (*len > size - pos) {
+        g_set_error(error, GWY_MODULE_FILE_ERROR, GWY_MODULE_FILE_ERROR_DATA,
+                    _("File header is truncated."));
+        return FALSE;
+    }
+    *pstr = g_strndup(p, *len);
+    return TRUE;
+}
+
 static GwyDataField*
 microprof_read_data_field(const MicroProfFile *mfile,
                           const guchar *buffer)
