@@ -1,5 +1,5 @@
 /*
- *  $Id: mifile.c 17957 2016-01-03 11:11:32Z dn2010 $
+ *  $Id: mifile.c 19948 2017-06-22 14:05:41Z yeti-dn $
  *  Copyright (C) 2005 Chris Anderson, Molecular Imaging Corp.
  *  E-mail: sidewinder.asu@gmail.com
  *
@@ -181,7 +181,7 @@ static GwyModuleInfo module_info = {
     "2006",
 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, mifile)
 
 static gboolean
 module_register(void)
