@@ -1,5 +1,5 @@
 /*
- *  $Id: mulfile.c 19071 2016-10-14 09:02:41Z yeti-dn $
+ *  $Id: mulfile.c 19948 2017-06-22 14:05:41Z yeti-dn $
  *  Copyright (C) 2011 David Necas (Yeti).
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -164,7 +164,7 @@ static GwyModuleInfo module_info = {
     "2011",
 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, mulfile)
 
 static gboolean
 module_register(void)
