@@ -1,5 +1,5 @@
 /*
- *  $Id: nanoeducator.c 19071 2016-10-14 09:02:41Z yeti-dn $
+ *  $Id: nanoeducator.c 19948 2017-06-22 14:05:41Z yeti-dn $
  *  Copyright (C) 2009 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
@@ -294,7 +294,7 @@ static GwyModuleInfo module_info = {
     "2009",
 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, nanoeducator)
 
 static gboolean
 module_register(void)
