@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: nanomagnetics.c 19216 2016-11-09 10:39:06Z yeti-dn $
+ *  @(#) $Id: nanomagnetics.c 19948 2017-06-22 14:05:41Z yeti-dn $
  *  Copyright (C) 2012 Sameer Grover, David Necas (Yeti).
  *  E-mail: sameer.grover.1@gmail.com, yeti@gwyddion.net.
  *
@@ -406,7 +406,7 @@ static GwyModuleInfo module_info = {
     "2012",
 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, nanomagnetics)
 
 static gboolean
 module_register(void)
