@@ -1,5 +1,5 @@
 /*
- *  $Id: nanonics.c 17180 2015-05-25 09:21:15Z yeti-dn $
+ *  $Id: nanonics.c 19948 2017-06-22 14:05:41Z yeti-dn $
  *  Copyright (C) 2009-2011 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
@@ -108,7 +108,7 @@ static GwyModuleInfo module_info = {
     "2009",
 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, nanonics)
 
 static gboolean
 module_register(void)
