@@ -1,5 +1,5 @@
 /*
- *  $Id: nanonis.c 19029 2016-10-04 12:37:34Z yeti-dn $
+ *  $Id: nanonis.c 19948 2017-06-22 14:05:41Z yeti-dn $
  *  Copyright (C) 2006,2015 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -122,7 +122,7 @@ static const GwyEnum directions[] = {
     { "both",     DIR_BOTH,     },
 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, nanonis)
 
 static gboolean
 module_register(void)
