@@ -1,5 +1,5 @@
 /*
- *  $Id: nanoscan.c 19044 2016-10-08 19:10:46Z yeti-dn $
+ *  $Id: nanoscan.c 20152 2017-08-03 08:50:44Z yeti-dn $
  *  Copyright (C) 2009 David Necas (Yeti).
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -44,6 +44,7 @@
 #include <libgwyddion/gwymath.h>
 #include <libgwyddion/gwyutils.h>
 #include <libprocess/stats.h>
+#include <libprocess/correct.h>
 #include <libgwymodule/gwymodule-file.h>
 #include <app/gwymoduleutils-file.h>
 #include <app/data-browser.h>
@@ -101,6 +102,7 @@ typedef struct {
     gchar *name;
     gchar *zunits;
     gfloat *data;
+    guint ndata;  /* May be smaller than expected for incomplete measurement. */
     NanoScanDirection direction;
     gboolean already_added;
 } NanoScanChannel;
@@ -180,6 +182,7 @@ static void          add_meta            (NanoScanFile *nfile,
                                           gchar *value);
 static gfloat*       read_channel_data   (const gchar *value,
                                           guint npixels,
+                                          guint *actual_npixels,
                                           GError **error);
 
 static GwyModuleInfo module_info = {
@@ -187,12 +190,12 @@ static GwyModuleInfo module_info = {
     &module_register,
     N_("Imports NanoScan XML files."),
     "Yeti <yeti@gwyddion.net>",
-    "0.5",
+    "0.7",
     "David Nečas (Yeti)",
     "2009",
 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, nanoscan)
 
 static gboolean
 module_register(void)
@@ -367,42 +370,62 @@ add_channel(GwyContainer *container,
             NanoScanChannel *channel,
             gint id)
 {
-    GwyDataField *dfield;
+    GwyDataField *dfield, *mask = NULL;
     GwySIUnit *unit;
-    gint power10;
     gdouble *d;
     GQuark quark;
-    gchar *key, *title;
-    gdouble q = 1.0;
-    gint i, j;
+    gchar *title;
+    gdouble yreal, q = 1.0;
+    gint nrows, i, power10;
 
-    dfield = gwy_data_field_new(nfile->xres, nfile->yres,
-                                nfile->xreal, nfile->yreal,
+    nrows = (channel->ndata + nfile->xres-1)/nfile->xres;
+    gwy_debug("nrows %d, yres %d", nrows, nfile->yres);
+    yreal = nfile->yreal*nrows/nfile->yres;
+    dfield = gwy_data_field_new(nfile->xres, nrows, nfile->xreal, yreal,
                                 FALSE);
     if (nfile->xyunits) {
         unit = gwy_data_field_get_si_unit_xy(dfield);
         gwy_si_unit_set_from_string_parse(unit, nfile->xyunits, &power10);
         gwy_data_field_set_xreal(dfield, pow10(power10)*nfile->xreal);
-        gwy_data_field_set_yreal(dfield, pow10(power10)*nfile->yreal);
+        gwy_data_field_set_yreal(dfield, pow10(power10)*yreal);
     }
     if (channel->zunits) {
         unit = gwy_data_field_get_si_unit_z(dfield);
         gwy_si_unit_set_from_string_parse(unit, channel->zunits, &power10);
         q = pow10(power10);
     }
+
     d = gwy_data_field_get_data(dfield);
-    for (i = 0; i < nfile->yres; i++) {
-        for (j = 0; j < nfile->xres; j++) {
-            d[(nfile->yres-1 - i)*nfile->xres + j]
-                = q*channel->data[i*nfile->xres + j];
-        }
+    for (i = 0; i < channel->ndata; i++)
+        d[i] = q*channel->data[i];
+    gwy_data_field_invert(dfield, TRUE, FALSE, FALSE);
+
+    /* Create a mask that is the union of invalid and missing values. */
+    mask = gwy_app_channel_mask_of_nans(dfield, FALSE);
+    if (channel->ndata % nfile->xres != 0) {
+        if (!mask)
+            mask = gwy_data_field_new_alike(dfield, TRUE);
+
+        d = gwy_data_field_get_data(mask);
+        for (i = channel->ndata; i < nfile->xres*nrows; i++)
+            d[i] = 1.0;
     }
+
+    if (mask)
+        gwy_data_field_laplace_solve(dfield, mask, -1, 1.0);
+
     quark = gwy_app_get_data_key_for_id(id);
     gwy_container_set_object(container, quark, dfield);
     g_object_unref(dfield);
 
+    if (mask) {
+        quark = gwy_app_get_mask_key_for_id(id);
+        gwy_container_set_object(container, quark, mask);
+        g_object_unref(mask);
+    }
+
     if (channel->name) {
-        key = g_strconcat(g_quark_to_string(quark), "/title", NULL);
+        quark = gwy_app_get_data_title_key_for_id(id);
         if (channel->direction == SCAN_FORWARD)
             title = g_strconcat(channel->name, " [Forward]", NULL);
         else if (channel->direction == SCAN_BACKWARD)
@@ -411,8 +434,7 @@ add_channel(GwyContainer *container,
             title = channel->name;
             channel->name = NULL;
         }
-        gwy_container_set_string_by_name(container, key, title);
-        g_free(key);
+        gwy_container_set_string(container, quark, title);
     }
     gwy_file_channel_import_log_add(container, id, NULL, filename);
     channel->already_added = TRUE;
@@ -466,8 +488,8 @@ add_curve_model(NanoScanFile *nfile,
     gdouble *d;
     gint power10, j;
 
-    real = axis0->stop - axis0->start;
-    dline = gwy_data_line_new(nfile->xres, real, FALSE);
+    real = (axis0->stop - axis0->start)*channel->ndata/nfile->xres;
+    dline = gwy_data_line_new(channel->ndata, real, FALSE);
     gwy_data_line_set_offset(dline, axis0->start);
     if (axis0->units) {
         unit = gwy_data_line_get_si_unit_x(dline);
@@ -481,9 +503,8 @@ add_curve_model(NanoScanFile *nfile,
         q = pow10(power10);
     }
     d = gwy_data_line_get_data(dline);
-    for (j = 0; j < nfile->xres; j++) {
+    for (j = 0; j < channel->ndata; j++)
         d[j] = q*channel->data[j];
-    }
     gcmodel = gwy_graph_curve_model_new();
     gwy_graph_curve_model_set_data_from_dataline(gcmodel, dline, 0, 0);
     g_object_set(gcmodel,
@@ -558,10 +579,16 @@ add_multicurve_model(NanoScanFile *nfile,
     gdouble real, yval, q = 1.0;
     gdouble *d;
     gchar *descr;
-    gint power10, j;
+    gint start, npts, power10, j;
 
-    real = axis0->stop - axis0->start;
-    dline = gwy_data_line_new(nfile->xres, real, FALSE);
+    /* Completely missing line. */
+    start = i*nfile->xres;
+    if (start >= channel->ndata)
+        return;
+
+    npts = MAX(channel->ndata - start, nfile->xres);
+    real = (axis0->stop - axis0->start)*npts/nfile->xres;
+    dline = gwy_data_line_new(nfile->xres, real, TRUE);
     gwy_data_line_set_offset(dline, axis0->start);
     if (axis0->units) {
         unit = gwy_data_line_get_si_unit_x(dline);
@@ -575,9 +602,8 @@ add_multicurve_model(NanoScanFile *nfile,
         q = pow10(power10);
     }
     d = gwy_data_line_get_data(dline);
-    for (j = 0; j < nfile->xres; j++) {
-        d[j] = q*channel->data[i*nfile->xres + j];
-    }
+    for (j = 0; j < npts; j++)
+        d[j] = q*channel->data[start + j];
     gcmodel = gwy_graph_curve_model_new();
     gwy_graph_curve_model_set_data_from_dataline(gcmodel, dline, 0, 0);
     yval = i/(nfile->yres - 1.0)*(axis1->stop - axis1->start) + axis1->start;
@@ -825,7 +851,7 @@ text(G_GNUC_UNUSED GMarkupParseContext *context,
         else if (gwy_strequal(path, "/data")) {
             g_free(channel->data);
             channel->data = read_channel_data(val, nfile->xres * nfile->yres,
-                                              error);
+                                              &channel->ndata, error);
             gwy_debug("DATA: %p", channel->data);
         }
     }
@@ -899,19 +925,22 @@ add_meta(NanoScanFile *nfile,
 static gfloat*
 read_channel_data(const gchar *value,
                   guint npixels,
+                  guint *actual_npixels,
                   GError **error)
 {
     guchar *mem;
     gsize len;
 
     mem = g_base64_decode(value, &len);
-    if (len != npixels*sizeof(gfloat)) {
+    if (!len || len % sizeof(gfloat) != 0 || len > npixels*sizeof(gfloat)) {
         g_set_error(error, G_MARKUP_ERROR, G_MARKUP_ERROR_INVALID_CONTENT,
                     _("Wrong size of Base64 encoded data."));
         g_free(mem);
+        *actual_npixels = 0;
         return NULL;
     }
 
+    *actual_npixels = len/sizeof(gfloat);
     return (gfloat*)mem;
 }
 
