@@ -1,6 +1,6 @@
 /*
- *  @(#) $Id: nanoscope.c 19044 2016-10-08 19:10:46Z yeti-dn $
- *  Copyright (C) 2004-2015 David Necas (Yeti), Petr Klapetek.
+ *  @(#) $Id: nanoscope.c 19948 2017-06-22 14:05:41Z yeti-dn $
+ *  Copyright (C) 2004-2017 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -25,6 +25,7 @@
  *   <comment>Nanoscope III SPM data</comment>
  *   <magic priority="80">
  *     <match type="string" offset="0" value="\\*File list\r\n"/>
+ *     <match type="string" offset="0" value="\\*EC File list\r\n"/>
  *     <match type="string" offset="0" value="?*File list\r\n"/>
  *   </magic>
  * </mime-type>
@@ -35,6 +36,7 @@
  * # Nanoscope III
  * # Two header variants.
  * 0 string \\*File\ list\x0d\x0a Nanoscope III SPM binary data
+ * 0 string \\*EC\ File\ list\x0d\x0a Nanoscope III electrochemistry SPM binary data
  * 0 string ?*File\ list\x0d\x0a Nanoscope III SPM text data
  **/
 
@@ -72,6 +74,9 @@
 #define MAGIC_FORCE_BIN "\\*Force file list\r\n"
 #define MAGIC_FORCE_SIZE (sizeof(MAGIC_FORCE_BIN)-1)
 
+#define MAGIC_EC_BIN "\\*EC File list\r\n"
+#define MAGIC_EC_SIZE (sizeof(MAGIC_EC_BIN)-1)
+
 typedef enum {
     NANOSCOPE_FILE_TYPE_NONE = 0,
     NANOSCOPE_FILE_TYPE_BIN,
@@ -207,12 +212,12 @@ static GwyModuleInfo module_info = {
     N_("Imports Veeco (Digital Instruments) Nanoscope data files, "
        "version 3 or newer."),
     "Yeti <yeti@gwyddion.net>",
-    "0.34",
+    "0.35",
     "David Nečas (Yeti) & Petr Klapetek",
     "2004",
 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, nanoscope)
 
 static gboolean
 module_register(void)
@@ -239,7 +244,8 @@ nanoscope_detect(const GwyFileDetectInfo *fileinfo,
     if (fileinfo->buffer_len > MAGIC_SIZE
         && (!memcmp(fileinfo->head, MAGIC_TXT_PARTIAL, MAGIC_SIZE_PARTIAL)
             || !memcmp(fileinfo->head, MAGIC_BIN_PARTIAL, MAGIC_SIZE_PARTIAL)
-            || !memcmp(fileinfo->head, MAGIC_FORCE_BIN, MAGIC_FORCE_SIZE)))
+            || !memcmp(fileinfo->head, MAGIC_FORCE_BIN, MAGIC_FORCE_SIZE)
+            || !memcmp(fileinfo->head, MAGIC_EC_BIN, MAGIC_EC_SIZE)))
         score = 100;
 
     return score;
@@ -275,7 +281,8 @@ nanoscope_load(const gchar *filename,
     if (size > MAGIC_SIZE) {
         if (!memcmp(buffer, MAGIC_TXT, MAGIC_SIZE))
             file_type = NANOSCOPE_FILE_TYPE_TXT;
-        else if (!memcmp(buffer, MAGIC_BIN, MAGIC_SIZE))
+        else if (!memcmp(buffer, MAGIC_BIN, MAGIC_SIZE)
+                 || !memcmp(buffer, MAGIC_EC_BIN, MAGIC_EC_SIZE))
             file_type = NANOSCOPE_FILE_TYPE_BIN;
         else if (!memcmp(buffer, MAGIC_FORCE_BIN, MAGIC_FORCE_SIZE))
             file_type = NANOSCOPE_FILE_TYPE_FORCE_BIN;
