@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: netcdf.c 16816 2014-11-21 10:34:00Z yeti-dn $
+ *  @(#) $Id: netcdf.c 19948 2017-06-22 14:05:41Z yeti-dn $
  *  Copyright (C) 2006 David Necas (Yeti), Petr Klapetek, Niv Levy.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net, nivl2000@gmail.com.
  *
@@ -193,7 +193,7 @@ static GwyModuleInfo module_info = {
     "2006",
 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, netcdf)
 
 static gboolean
 module_register(void)
