@@ -1,5 +1,5 @@
 /*
- *  $Id: nmmxyz.c 19280 2016-11-16 17:31:41Z yeti-dn $
+ *  $Id: nmmxyz.c 19948 2017-06-22 14:05:41Z yeti-dn $
  *  Copyright (C) 2016 David Necas (Yeti).
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -206,7 +206,7 @@ static GwyModuleInfo module_info = {
     "2016",
 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, nmmxyz)
 
 static gboolean
 module_register(void)
