@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: nxiifile.c 16650 2014-10-08 07:47:07Z yeti-dn $
+ *  @(#) $Id: nxiifile.c 19948 2017-06-22 14:05:41Z yeti-dn $
  *  Copyright (C) 2014 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
@@ -120,7 +120,7 @@ static GwyModuleInfo module_info = {
     "2014",
 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, nxiifile)
 
 static gboolean
 module_register(void)
