@@ -1,5 +1,5 @@
 /*
- *  $Id: oldmda.c 18234 2016-01-27 14:57:31Z yeti-dn $
+ *  $Id: oldmda.c 19948 2017-06-22 14:05:41Z yeti-dn $
  *  Copyright (C) 2010-2011 David Necas (Yeti), Petr Klapetek,
  *  Daniil Bratashov (dn2010)
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net, dn2010@gmail.com
@@ -155,7 +155,7 @@ static GwyModuleInfo module_info = {
     "2012",
 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, oldmda)
 
 static gboolean
 module_register(void)
