@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: ometiff.c 18616 2016-04-21 15:06:40Z yeti-dn $
+ *  @(#) $Id: ometiff.c 19948 2017-06-22 14:05:41Z yeti-dn $
  *  Copyright (C) 2013-2016 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
@@ -158,7 +158,7 @@ static GwyModuleInfo module_info = {
     "2013",
 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, ometiff)
 
 static gboolean
 module_register(void)
