@@ -1,5 +1,5 @@
 /*
- *  $Id: omicron.c 19071 2016-10-14 09:02:41Z yeti-dn $
+ *  $Id: omicron.c 19948 2017-06-22 14:05:41Z yeti-dn $
  *  Copyright (C) 2006-2011 David Necas (Yeti), Petr Klapetek, Markus Pristovsek
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net,
  *  prissi@gift.physik.tu-berlin.de.
@@ -168,7 +168,7 @@ static GwyModuleInfo module_info = {
     "2006",
 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, omicron)
 
 static gboolean
 module_register(void)
