@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: omicronmatrix.c 18440 2016-03-15 18:44:30Z yeti-dn $
+ *  @(#) $Id: omicronmatrix.c 19948 2017-06-22 14:05:41Z yeti-dn $
  *  Copyright (C) 2008, Philipp Rahe, David Necas
  *  E-mail: hquerquadrat@gmail.com
  *
@@ -204,7 +204,7 @@ static GwyModuleInfo module_info = {
     "2008",
 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, omicronmatrix)
 
 static gboolean module_register(void)
 {
