@@ -1,6 +1,6 @@
 /*
- *  $Id: opdfile.c 19044 2016-10-08 19:10:46Z yeti-dn $
- *  Copyright (C) 2008 David Necas (Yeti).
+ *  $Id: opdfile.c 20092 2017-07-26 10:28:17Z yeti-dn $
+ *  Copyright (C) 2008-2017 David Necas (Yeti).
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -82,7 +82,7 @@
 #define MAGIC_SIZE (sizeof(MAGIC)-1)
 #define EXTENSION ".opd"
 
-#define MAGIC_ASC "Wyko ASCII Data File Format 0\t0\t1"
+#define MAGIC_ASC "Wyko ASCII Data File Format "
 #define MAGIC_ASC_SIZE (sizeof(MAGIC_ASC)-1)
 #define EXTENSION_ASC ".asc"
 
@@ -105,6 +105,10 @@ enum {
     OPD_FLOAT = 7,
     OPD_DOUBLE = 8,
     OPD_LONG = 12,
+    /* Serialised structs; some look like bits of OPDx, some do not.  If this
+     * appears positions in the file are off.  Unfortunately not just of the
+     * binary stuff but apparently also of other things. */
+    OPD_BINARY_STUFF = 15,
 } OPDDataType;
 
 typedef enum {
@@ -113,6 +117,12 @@ typedef enum {
     OPD_ARRAY_BYTE = 1,
 } OPDArrayType;
 
+typedef enum {
+    OPD_STANDARD_IMAGE = 0,
+    OPD_XYZ_PIXEL = 1,
+    OPD_XYZ_REAL = 2,
+} OPDArrayFormat;
+
 /* The header consists of a sequence of these creatures. */
 typedef struct {
     /* This is in the file */
@@ -159,6 +169,7 @@ static void          store_asc_meta    (gpointer key,
                                         gpointer value,
                                         gpointer user_data);
 static GwyDataField* get_asc_data_field(gchar **p,
+                                        OPDArrayFormat format,
                                         guint xres,
                                         guint yres,
                                         gdouble pixel_size,
@@ -187,12 +198,12 @@ static GwyModuleInfo module_info = {
     &module_register,
     N_("Imports Wyko OPD and ASC files."),
     "Yeti <yeti@gwyddion.net>",
-    "0.8",
+    "0.11",
     "David Nečas (Yeti)",
     "2008",
 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, opdfile)
 
 static gboolean
 module_register(void)
@@ -303,6 +314,11 @@ opd_load(const gchar *filename,
     }
     nblocks = j;
 
+    /* XXX: There can be a block called "\xcaxtendedKe\xfds" at the end that
+     * provides mapping from the names truncated to 16 bytes to full names.
+     * Unfortunately, it is of type OPD_BINARY_STUFF and therefore in a
+     * different position in the file than @pos says... */
+
     if (!check_sizes(header, nblocks, error))
         goto fail;
 
@@ -416,10 +432,16 @@ get_block(OPDBlock *block, const guchar **p)
     if (strncmp(block->name, "AdjustVSI_", sizeof("AdjustVSI_")-1) == 0
         && block->type == 7
         && block->size == 2) {
-        g_warning("Changing the type of field %s from float to short.",
-                  block->name);
+        gwy_info("Changing the type of field %s from float to short.",
+                 block->name);
         block->type = 6;
     }
+    if (gwy_strequal(block->name, "ImageModificat~0")
+        && block->type == 7
+        && block->size == 40) {
+        gwy_info("Changing the size of field %s from 40 to 4.", block->name);
+        block->size = 4;
+    }
 }
 
 static gboolean
@@ -705,6 +727,9 @@ opd_asc_load(const gchar *filename,
     gchar *line, *p, *s, *buffer = NULL;
     GHashTable *hash = NULL;
     guint j, xres = 0, yres = 0;
+    OPDArrayFormat format;
+    gint tmp;
+    gboolean real_units, is_float;
     gsize size;
     GError *err = NULL;
 
@@ -715,10 +740,22 @@ opd_asc_load(const gchar *filename,
 
     p = buffer;
     line = gwy_str_next_line(&p);
-    if (!gwy_strequal(line, MAGIC_ASC)) {
+    if (!g_str_has_prefix(line, MAGIC_ASC)) {
         err_FILE_TYPE(error, "Wyko ASC data");
         goto fail;
     }
+    if (sscanf(line + MAGIC_ASC_SIZE, "%d %d %d",
+               &tmp, &real_units, &is_float) != 3) {
+        err_INVALID(error, "Data File Format");
+        goto fail;
+    }
+    format = tmp;
+    gwy_debug("array format %d, real units %d, is float %d",
+              format, real_units, is_float);
+    if (format < 0 || format > 2) {
+        err_UNSUPPORTED(error, "Array Format");
+        goto fail;
+    }
 
     container = gwy_container_new();
     hash = g_hash_table_new(g_str_hash, g_str_equal);
@@ -754,7 +791,7 @@ opd_asc_load(const gchar *filename,
         if (gwy_stramong(line, "OPD", "SAMPLE_DATA", "RAW_DATA", "RAW DATA",
                          "Image", "Intensity", "SecArr_0", "Raw",
                          NULL)) {
-            gdouble pixel_size, wavelength, mult = 1.0, aspect = 1.0;
+            gdouble pixel_size, wavelength, mult = 1.0, aspect = 1.0, zcalib;
             gboolean intensity;
             gchar *k;
 
@@ -782,27 +819,28 @@ opd_asc_load(const gchar *filename,
 
             if ((s = g_hash_table_lookup(hash, "Aspect")))
                 aspect = g_ascii_strtod(s, NULL);
+            /* Should only occur in integer-data files.  Have not seen any... */
             if ((s = g_hash_table_lookup(hash, "Mult")))
                 mult = g_ascii_strtod(s, NULL);
 
-            /* TODO: mult, aspect */
-
-            wavelength *= Nanometer;
-            pixel_size *= Milimeter;
-            wavelength /= mult;
-
-            dfield = mfield = NULL;
             intensity = gwy_stramong(line,
                                      "Image", "Intensity", "SecArr_0", NULL);
-            dfield = get_asc_data_field(&p, xres, yres,
-                                        pixel_size, aspect,
-                                        intensity ? 1.0 : wavelength,
+
+            pixel_size *= Milimeter;
+            zcalib = Nanometer*mult;
+            if (!intensity && !real_units)
+                zcalib *= wavelength;
+
+            dfield = mfield = NULL;
+            dfield = get_asc_data_field(&p, format, xres, yres,
+                                        pixel_size, aspect, zcalib,
                                         intensity ? "" : "m",
                                         intensity ? NULL : &mfield);
             if (!dfield) {
                 g_set_error(error, GWY_MODULE_FILE_ERROR,
                             GWY_MODULE_FILE_ERROR_DATA,
                             _("Truncated data in block %s"), line);
+                GWY_OBJECT_UNREF(container);
                 goto fail;
             }
 
@@ -851,7 +889,7 @@ opd_asc_load(const gchar *filename,
         g_object_unref(meta);
     }
     else {
-        g_object_unref(container);
+        GWY_OBJECT_UNREF(container);
         err_NO_DATA(error);
     }
 
@@ -881,14 +919,15 @@ store_asc_meta(gpointer key,
 
 static GwyDataField*
 get_asc_data_field(gchar **p,
-                   guint xres, guint yres,
-                   gdouble pixel_size, gdouble aspect, gdouble wavelength,
+                   OPDArrayFormat format, guint xres, guint yres,
+                   gdouble pixel_size, gdouble aspect, gdouble zcalib,
                    const gchar *zunits,
                    GwyDataField **maskfield)
 {
     GwyDataField *dfield, *mfield;
     GwySIUnit *siunit;
     gdouble *data, *mdata;
+    const gchar *sprev;
     guint mcount, i, j;
     gchar *s;
 
@@ -912,27 +951,60 @@ get_asc_data_field(gchar **p,
     data = gwy_data_field_get_data(dfield);
     mdata = gwy_data_field_get_data(mfield);
 
-    for (j = 0; j < xres; j++) {
-        if (!(s = gwy_str_next_line(p)))
-            goto fail;
+    if (format == OPD_XYZ_PIXEL || format == OPD_XYZ_REAL) {
+        gwy_debug("assuming XYZ format");
+        for (j = 0; j < xres; j++) {
+            for (i = yres; i; i--) {
+                if (!(s = gwy_str_next_line(p)))
+                    goto fail;
 
-        for (i = yres; i; i--) {
-            const gchar *sprev = s;
-
-            if (strncmp(s, "Bad", 3) == 0) {
-                mdata[(i - 1)*xres + j] = 0.0;
-                s += 3;
-            }
-            else
-                data[(i - 1)*xres + j] = g_ascii_strtod(s, &s)*wavelength;
-
-            while (g_ascii_isspace(*s))
+                /* Y and X, we just ignore them */
+                if (!(s = strchr(s, '\t')))
+                    goto fail;
+                s++;
+                if (!(s = strchr(s, '\t')))
+                    goto fail;
                 s++;
 
-            if (s == sprev)
-                goto fail;
+                sprev = s;
+                if (strncmp(s, "Bad", 3) == 0) {
+                    mdata[(i - 1)*xres + j] = 0.0;
+                    s += 3;
+                }
+                else
+                    data[(i - 1)*xres + j] = g_ascii_strtod(s, &s)*zcalib;
+
+                if (s == sprev)
+                    goto fail;
+            }
         }
     }
+    else if (format == OPD_STANDARD_IMAGE) {
+        gwy_debug("assuming data matrix format");
+        for (j = 0; j < xres; j++) {
+            if (!(s = gwy_str_next_line(p)))
+                goto fail;
+
+            for (i = yres; i; i--) {
+                sprev = s;
+                if (strncmp(s, "Bad", 3) == 0) {
+                    mdata[(i - 1)*xres + j] = 0.0;
+                    s += 3;
+                }
+                else
+                    data[(i - 1)*xres + j] = g_ascii_strtod(s, &s)*zcalib;
+
+                while (g_ascii_isspace(*s))
+                    s++;
+
+                if (s == sprev)
+                    goto fail;
+            }
+        }
+    }
+    else {
+        g_assert_not_reached();
+    }
 
     mcount = gwy_app_channel_remove_bad_data(dfield, mfield);
 
