@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: psia.c 18034 2016-01-08 14:02:03Z yeti-dn $
+ *  @(#) $Id: psia.c 19948 2017-06-22 14:05:41Z yeti-dn $
  *  Copyright (C) 2006 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -245,7 +245,7 @@ static GwyModuleInfo module_info = {
     "2006",
 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, psia)
 
 static gboolean
 module_register(void)
