@@ -1,5 +1,5 @@
 /*
- *  $Id: pt3file.c 19216 2016-11-09 10:39:06Z yeti-dn $
+ *  $Id: pt3file.c 19948 2017-06-22 14:05:41Z yeti-dn $
  *  Copyright (C) 2009 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
@@ -300,7 +300,7 @@ static GwyModuleInfo module_info = {
     "2009",
 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, pt3file)
 
 static gboolean
 module_register(void)
