@@ -72,7 +72,7 @@ static GwyModuleInfo module_info = {
     "2008",
 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, quesant)
 
 static gboolean
 module_register(void)
