@@ -1,5 +1,5 @@
 /*
- *  $Id: rawgraph.c 19044 2016-10-08 19:10:46Z yeti-dn $
+ *  $Id: rawgraph.c 19948 2017-06-22 14:05:41Z yeti-dn $
  *  Copyright (C) 2009 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
@@ -111,7 +111,7 @@ static GwyModuleInfo module_info = {
     "2009",
 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, rawgraph)
 
 static gboolean
 module_register(void)
