@@ -1,5 +1,5 @@
 /*
- *  $Id: renishaw.c 18238 2016-01-27 21:14:14Z yeti-dn $
+ *  $Id: renishaw.c 19948 2017-06-22 14:05:41Z yeti-dn $
  *  Copyright (C) 2014 Daniil Bratashov (dn2010), David Necas (Yeti)..
  *  Data structures and constants are copyright (c) 2011 Renishaw plc.
  *
@@ -372,7 +372,7 @@ static GwyModuleInfo module_info = {
     "2014",
 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, renishaw)
 
 static gboolean
 module_register(void)
@@ -715,6 +715,9 @@ wdf_load(const gchar *filename,
         gwy_graph_curve_model_set_data(gcmodel, xdata, ydata, zres);
         g_free(xdata);
         g_free(ydata);
+        if (!gwy_graph_curve_model_is_ordered(gcmodel)) {
+            gwy_graph_curve_model_enforce_order(gcmodel);
+        }
         gwy_graph_model_add_curve(gmodel, gcmodel);
         g_object_unref(gcmodel);
         g_free(title);
@@ -764,6 +767,9 @@ wdf_load(const gchar *filename,
             g_free(title);
             gwy_graph_curve_model_set_data(gcmodel, xdata, ydata, zres);
             g_free(ydata);
+            if (!gwy_graph_curve_model_is_ordered(gcmodel)) {
+                gwy_graph_curve_model_enforce_order(gcmodel);
+            }
             gwy_graph_model_add_curve(gmodel, gcmodel);
             g_object_unref(gcmodel);
         }
@@ -1235,6 +1241,9 @@ wdf_load(const gchar *filename,
                                        NULL);
                 gwy_graph_curve_model_set_data(gcmodel,
                                                xdata, ydata, zres);
+                if (!gwy_graph_curve_model_is_ordered(gcmodel)) {
+                    gwy_graph_curve_model_enforce_order(gcmodel);
+                }                                               
                 gwy_graph_model_add_curve(gmodel, gcmodel);
                 g_object_unref(gcmodel);
                 g_free(title);
