@@ -1,5 +1,5 @@
 /*
- *  $Id: rhk-sm3.c 17795 2015-11-30 13:56:39Z yeti-dn $
+ *  $Id: rhk-sm3.c 19948 2017-06-22 14:05:41Z yeti-dn $
  *  Copyright (C) 2005,2008 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -247,7 +247,7 @@ static const GwyEnum scan_directions[] = {
     { "Down",  RHK_SCAN_DOWN,  },
 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, rhk_sm3)
 
 static gboolean
 module_register(void)
