@@ -1,5 +1,5 @@
 /*
- *  $Id: rhk-spm32.c 19216 2016-11-09 10:39:06Z yeti-dn $
+ *  $Id: rhk-spm32.c 19948 2017-06-22 14:05:41Z yeti-dn $
  *  Copyright (C) 2005 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -187,7 +187,7 @@ static const GwyEnum scan_directions[] = {
     { "Down",  RHK_SCAN_DOWN,  },
 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, rhk_spm32)
 
 static gboolean
 module_register(void)
