@@ -85,7 +85,7 @@ static GwyModuleInfo module_info = {
     "2011",
 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, robotics)
 
 static gboolean
 module_register(void)
