@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: s94file.c 17718 2015-11-06 08:04:04Z pecold $
+ *  @(#) $Id: s94file.c 19948 2017-06-22 14:05:41Z yeti-dn $
  *  Copyright (C) 2013 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
@@ -100,7 +100,7 @@ static GwyModuleInfo module_info = {
     "2013",
 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, s94file)
 
 static gboolean
 module_register(void)
