@@ -1,5 +1,5 @@
 /*
- *  $Id: sdfile.c 17718 2015-11-06 08:04:04Z pecold $
+ *  $Id: sdfile.c 19948 2017-06-22 14:05:41Z yeti-dn $
  *  Copyright (C) 2005 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -161,7 +161,7 @@ static GwyModuleInfo module_info = {
 
 static const guint type_sizes[] = { 1, 2, 4, 4, 1, 2, 4, 8 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, sdfile)
 
 static gboolean
 module_register(void)
