@@ -1,5 +1,5 @@
 /*
- *  $Id: seiko.c 18613 2016-04-19 19:35:15Z yeti-dn $
+ *  $Id: seiko.c 19948 2017-06-22 14:05:41Z yeti-dn $
  *  Copyright (C) 2006 David Necas (Yeti), Markus Pristovsek.
  *  E-mail: yeti@gwyddion.net, prissi@gift.physik.tu-berlin.de.
  *
@@ -117,12 +117,12 @@ static GwyModuleInfo module_info = {
     &module_register,
     N_("Imports Seiko XQB, XQD, XQT and XQP files."),
     "Yeti <yeti@gwyddion.net>",
-    "0.12",
+    "0.13",
     "David Nečas (Yeti) & Markus Pristovsek",
     "2006",
 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, seiko)
 
 static gboolean
 module_register(void)
@@ -183,6 +183,7 @@ seiko_load(const gchar *filename,
     GwyDataField *dfield = NULL;
     SeikoDataType datatype = SEIKO_TOPOGRAPHY;
     gchar *comment;
+    const gchar *extension;
 
     if (!gwy_file_get_contents(filename, &buffer, &size, &err)) {
         err_GET_FILE_CONTENTS(error, &err);
@@ -206,12 +207,12 @@ seiko_load(const gchar *filename,
 
     /* FIXME: I was not able to reverse-engineer what identifies the type.
      * May need a large set of files.  */
-    if (g_str_has_suffix(filename, ".xqp")
-        || g_str_has_suffix(filename, ".XQP"))
-        datatype = SEIKO_PHASE;
-    else if (g_str_has_suffix(filename, ".xqi")
-        || g_str_has_suffix(filename, ".XQI"))
-        datatype = SEIKO_CURRENT;
+    if ((extension = strrchr(filename, '.'))) {
+       if (gwy_stramong(extension+1, "xqp", "XQP", "xqpx", "XQPX", NULL))
+           datatype = SEIKO_PHASE;
+       else if (gwy_stramong(extension+1, "xqi", "XQI", "xqix", "XQIX", NULL))
+           datatype = SEIKO_CURRENT;
+    }
 
     dfield = read_data_field(buffer, size, datatype, error);
     if (!dfield) {
@@ -258,7 +259,7 @@ read_data_field(const guchar *buffer,
     };
     gint xres, yres;
     G_GNUC_UNUSED guint version;
-    guint endfile, datastart;
+    guint endfile, datastart, imgsize;
     gdouble xreal, yreal, q, z0;
     GwyDataField *dfield;
     GwySIUnit *siunit;
@@ -284,9 +285,18 @@ read_data_field(const guchar *buffer,
     if (err_DIMENSION(error, xres) || err_DIMENSION(error, yres))
         return NULL;
 
-    if (err_SIZE_MISMATCH(error, xres*yres*sizeof(gint16), endfile - datastart,
-                          TRUE))
-        return NULL;
+    imgsize = xres*yres*sizeof(guint16);
+    if (err_SIZE_MISMATCH(error, imgsize, endfile - datastart, TRUE)) {
+        /* The XQ?X files can have multiple images.  And each also comes with
+         * an extra headers.  We at least try to import the first one. */
+        guint nimages = (endfile - datastart)/imgsize;
+
+        gwy_debug("nimages: %u", nimages);
+        if (endfile - datastart == nimages*imgsize + (nimages-1)*HEADER_SIZE)
+            g_clear_error(error);
+        else
+            return NULL;
+    }
 
     p = buffer + XSCALE_OFFSET;
     xreal = gwy_get_gdouble_le(&p) * Nanometer;
