@@ -1,5 +1,5 @@
 /*
- *  $Id: sensolytics.c 17718 2015-11-06 08:04:04Z pecold $
+ *  $Id: sensolytics.c 19948 2017-06-22 14:05:41Z yeti-dn $
  *  Copyright (C) 2009 David Necas (Yeti).
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -115,7 +115,7 @@ static GwyModuleInfo module_info = {
     "2009",
 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, sensolytics)
 
 static gboolean
 module_register(void)
