@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: sis.c 19216 2016-11-09 10:39:06Z yeti-dn $
+ *  @(#) $Id: sis.c 19948 2017-06-22 14:05:41Z yeti-dn $
  *  Copyright (C) 2004 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -468,7 +468,7 @@ static GwyModuleInfo module_info = {
     "2004",
 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, sis)
 
 static gboolean
 module_register(void)
