@@ -1,5 +1,5 @@
 /*
- *  $Id: spmlabf.c 19044 2016-10-08 19:10:46Z yeti-dn $
+ *  $Id: spmlabf.c 19948 2017-06-22 14:05:41Z yeti-dn $
  *  Copyright (C) 2008 David Necas (Yeti).
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -83,7 +83,7 @@ static GwyModuleInfo module_info = {
     "2008",
 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, spmlabf)
 
 static gboolean
 module_register(void)
