@@ -1,5 +1,5 @@
 /*
- *  $Id: stmprg.c 16611 2014-09-27 15:59:35Z yeti-dn $
+ *  $Id: stmprg.c 19948 2017-06-22 14:05:41Z yeti-dn $
  *  Copyright (C) 2004 Rok Zitko
  *  E-mail: rok.zitko@ijs.si
  *
@@ -236,7 +236,7 @@ static GwyModuleInfo module_info = {
     "2004",
 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, stmprg)
 
 static gboolean
 module_register(void)
