@@ -1,5 +1,5 @@
 /*
- *  $Id: stpfile.c 19216 2016-11-09 10:39:06Z yeti-dn $
+ *  $Id: stpfile.c 19948 2017-06-22 14:05:41Z yeti-dn $
  *  Copyright (C) 2005 David Necas (Yeti), Petr Klstptek.
  *  E-mail: yeti@gwyddion.net, klstptek@gwyddion.net.
  *
@@ -144,7 +144,7 @@ static GwyModuleInfo module_info = {
     "2006",
 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, stpfile)
 
 static gboolean
 module_register(void)
