@@ -1,5 +1,5 @@
 /*
- *  $Id: surffile.c 17719 2015-11-06 08:46:13Z pecold $
+ *  $Id: surffile.c 19948 2017-06-22 14:05:41Z yeti-dn $
  *  Copyright (C) 2005 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -296,7 +296,7 @@ static GwyModuleInfo module_info = {
     "2006",
 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, surffile)
 
 static gboolean
 module_register(void)
