@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: tescan.c 16387 2014-07-10 10:41:50Z yeti-dn $
+ *  @(#) $Id: tescan.c 19948 2017-06-22 14:05:41Z yeti-dn $
  *  Copyright (C) 2013 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
@@ -98,7 +98,7 @@ static GwyModuleInfo module_info = {
     "2013",
 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, tescan)
 
 static gboolean
 module_register(void)
