@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: tiaser.c 17718 2015-11-06 08:04:04Z pecold $
+ *  @(#) $Id: tiaser.c 19948 2017-06-22 14:05:41Z yeti-dn $
  *  Copyright (C) 2012 David Necas (Yeti), Daniil Bratashov (dn2010).
  *  E-mail: yeti@gwyddion.net, dn2010@gmail.com.
  *
@@ -183,7 +183,7 @@ static GwyModuleInfo module_info = {
     "2012",
 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, tiaser)
 
 static gboolean
 module_register(void)
