@@ -1,5 +1,5 @@
 /*
- *  $Id: unisoku.c 16387 2014-07-10 10:41:50Z yeti-dn $
+ *  $Id: unisoku.c 19948 2017-06-22 14:05:41Z yeti-dn $
  *  Copyright (C) 2005 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -151,7 +151,7 @@ static GwyModuleInfo module_info = {
 
 static const guint type_sizes[] = { 0, 0, 1, 1, 2, 2, 0, 0, 4 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, unisoku)
 
 static gboolean
 module_register(void)
