@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: vtkfile.c 17719 2015-11-06 08:46:13Z pecold $
+ *  @(#) $Id: vtkfile.c 19948 2017-06-22 14:05:41Z yeti-dn $
  *  Copyright (C) 2012 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
@@ -58,7 +58,7 @@ static GwyModuleInfo module_info = {
     "2012",
 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, vtkfile)
 
 static gboolean
 module_register(void)
