@@ -1,5 +1,5 @@
 /*
- *  $Id: wipfile.c 19130 2016-10-27 20:58:23Z dn2010 $
+ *  $Id: wipfile.c 19948 2017-06-22 14:05:41Z yeti-dn $
  *  Copyright (C) 2010-2011 David Necas (Yeti), Petr Klapetek,
  *  Daniil Bratashov (dn2010)
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net, dn2010@gmail.com
@@ -77,6 +77,9 @@
 
 #define EXTENSION ".wip"
 
+#define H (4.135667662E-15)
+#define C (299792458)
+
 typedef enum {
     WIP_TAG_LIST     = 0, /* list of other tags */
     WIP_TAG_EXTENDED = 1, /* x86 FPU native type, 10 bytes */
@@ -155,6 +158,13 @@ typedef struct {
     gchar   *unitname; /* nm */
 } WIPSpectralTransform;
 
+/* TDSpectralInterpretation for spectra */
+typedef struct {
+    guint        id;
+    WIPUnitIndex unitindex;
+    gdouble      excitation_wavelength;
+} WIPSpectralInterpretation;
+
 typedef struct {
     guint id;
     gchar *unitname;
@@ -185,6 +195,7 @@ typedef struct {
 } WIPGraph;
 
 typedef struct {
+    guint version;
     guint sizex;
     guint sizey;
     guint postransformid;
@@ -217,66 +228,64 @@ typedef struct {
     GNode *node;
 } WIPIdNode;
 
-static gboolean      module_register           (void);
-static gint          wip_detect (const GwyFileDetectInfo *fileinfo,
-                                 gboolean only_name);
-static WIPTag*       wip_read_tag              (guchar **pos,
-                                                gsize *start,
-                                                gsize *end);
-static void          wip_free_tag              (WIPTag *tag);
-static GwyContainer* wip_load                  (const gchar *filename,
-                                                GwyRunType mode,
-                                                GError **error);
-static void          wip_read_all_tags         (const guchar *buffer,
-                                                gsize start, gsize end,
-                                                GNode *tagtree, gint n);
-static gboolean      wip_free_leave            (GNode *node,
-                                           G_GNUC_UNUSED gpointer data);
-static gboolean      wip_read_graph_tags       (GNode *node,
-                                                gpointer header);
-static gboolean      wip_read_sp_transform_tags(GNode *node,
-                                                gpointer transform);
-static gboolean      wip_read_space_tr_tag     (GNode *node,
-                                                gpointer transform);
-static gboolean      wip_read_axis_tags        (GNode *node,
-                                                gpointer axis);
-static gboolean      wip_read_bitmap_tags      (GNode *node,
-                                                gpointer data);
-static gboolean      wip_find_by_id            (GNode *node,
-                                                gpointer idnode);
-static gboolean      wip_read_caption          (GNode *node,
-                                                gpointer caption);
-static GwyDataField *
-                     wip_read_bmp              (const guchar *bmpdata,
-                                                gsize datasize,
-                                                gdouble xscale,
-                                                gdouble yscale,
-                                                gint power10xy);
-static gdouble       wip_pixel_to_lambda       (gint i,
-                                       WIPSpectralTransform *transform);
-static GwyGraphModel*
-                     wip_read_graph            (GNode *node);
-static GwyBrick*     wip_read_graph_image      (GNode *node);
-static void          wip_flip_xy               (GwyDataField *source,
-                                                GwyDataField *dest);
-static GwyDataField *
-                     wip_read_image            (GNode *node);
-static GwyDataField *
-                     wip_read_bitmap           (GNode *node);
-static gboolean      wip_read_data             (GNode *node,
-                                                gpointer filedata);
+static gboolean       module_register           (void);
+static gint           wip_detect                (const GwyFileDetectInfo *fileinfo,
+                                                 gboolean only_name);
+static WIPTag*        wip_read_tag              (guchar **pos,
+                                                 gsize *start,
+                                                 gsize *end);
+static void           wip_free_tag              (WIPTag *tag);
+static GwyContainer*  wip_load                  (const gchar *filename,
+                                                 GwyRunType mode,
+                                                 GError **error);
+static void           wip_read_all_tags         (const guchar *buffer,
+                                                 gsize start,
+                                                 gsize end,
+                                                 GNode *tagtree,
+                                                 gint n);
+static gboolean       wip_free_leave            (GNode *node,
+                                                 G_GNUC_UNUSED gpointer data);
+static gboolean       wip_read_graph_tags       (GNode *node,
+                                                 gpointer header);
+static gboolean       wip_read_sp_transform_tags(GNode *node,
+                                                 gpointer transform);
+static gboolean       wip_read_sp_interpr_tags  (GNode *node,
+                                                 gpointer interp);
+static gboolean       wip_read_space_tr_tag     (GNode *node,
+                                                 gpointer transform);
+static gboolean       wip_read_axis_tags        (GNode *node,
+                                                 gpointer axis);
+static gboolean       wip_read_bitmap_tags      (GNode *node,
+                                                 gpointer data);
+static gboolean       wip_find_by_id            (GNode *node,
+                                                 gpointer idnode);
+static gboolean       wip_read_caption          (GNode *node,
+                                                 gpointer caption);
+static GwyDataField*  wip_read_bmp              (const guchar *bmpdata,
+                                                 gsize datasize,
+                                                 gdouble xscale,
+                                                 gdouble yscale,
+                                                 gint power10xy);
+static gdouble        wip_pixel_to_lambda       (gint i,
+                                                 WIPSpectralTransform *transform);
+static GwyGraphModel* wip_read_graph            (GNode *node);
+static GwyBrick*      wip_read_graph_image      (GNode *node);
+static GwyDataField*  wip_read_image            (GNode *node);
+static GwyDataField*  wip_read_bitmap           (GNode *node);
+static gboolean       wip_read_data             (GNode *node,
+                                                 gpointer filedata);
 
 static GwyModuleInfo module_info = {
     GWY_MODULE_ABI_VERSION,
     &module_register,
     N_("Imports WItec Project data files."),
     "Daniil Bratashov <dn2010@gmail.com>",
-    "0.6",
+    "0.8",
     "David Nečas (Yeti) & Petr Klapetek & Daniil Bratashov",
     "2010",
 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, wipfile)
 
 static gboolean
 module_register(void)
@@ -338,8 +347,9 @@ wip_read_tag(guchar **pos, gsize *start, gsize *end)
     }
     tag->data = (gpointer)p;
 
-    gwy_debug("%d %s %d %lld %lld\n",  tag->name_length,
-              tag->name, tag->type, tag->data_start, tag->data_end);
+    gwy_debug("%d %s %d %" G_GUINT64_FORMAT " %" G_GUINT64_FORMAT "\n",
+              tag->name_length, tag->name, tag->type, tag->data_start,
+              tag->data_end);
 
     *pos = (guchar *)p;
 
@@ -438,7 +448,9 @@ wip_read_image_tags(GNode *node, gpointer header)
     tag = node->data;
     imageheader = (WIPImage *)header;
     p = tag->data;
-    if (!strncmp(tag->name, "SizeX", 5))
+    if (!strncmp(tag->name, "Version", 7))
+        imageheader->version = gwy_get_gint32_le(&p);
+    else if (!strncmp(tag->name, "SizeX", 5))
         imageheader->sizex = gwy_get_gint32_le(&p);
     else if (!strncmp(tag->name, "SizeY", 5))
         imageheader->sizey = gwy_get_gint32_le(&p);
@@ -509,6 +521,25 @@ wip_read_sp_transform_tags(GNode *node,
     return FALSE;
 }
 
+static gboolean
+wip_read_sp_interpr_tags(GNode *node,
+                         gpointer interp)
+{
+    WIPTag *tag;
+    WIPSpectralInterpretation *sp_interp;
+    const guchar *p;
+
+    tag = node->data;
+    sp_interp = (WIPSpectralInterpretation *)interp;
+    p = tag->data;
+    if (!strncmp(tag->name, "UnitIndex", 9))
+        sp_interp->unitindex = gwy_get_gint32_le(&p);
+    else if (!strncmp(tag->name, "ExcitationWaveLength", 20))
+        sp_interp->excitation_wavelength = gwy_get_gdouble_le(&p);
+
+    return FALSE;
+}
+
 static gboolean
 wip_read_space_tr_tag(GNode *node, gpointer transform)
 {
@@ -733,6 +764,7 @@ wip_read_graph(GNode *node)
 {
     WIPGraph *header;
     WIPSpectralTransform *xtransform;
+    WIPSpectralInterpretation *xinterp;
     WIPAxis *yaxis;
     WIPIdNode *idnode;
     GwyGraphModel *gmodel;
@@ -801,10 +833,69 @@ wip_read_graph(GNode *node)
             xdata[i] = wip_pixel_to_lambda(i, xtransform);
     }
 
+    idnode->id = header->xinterpid;
+    g_node_traverse(g_node_get_root(node),
+                    G_LEVEL_ORDER, G_TRAVERSE_ALL, -1,
+                    wip_find_by_id, (gpointer)idnode);
+
+    xinterp = g_new0(WIPSpectralInterpretation, 1);
+    g_node_traverse(idnode->node->parent->parent,
+                    G_LEVEL_ORDER, G_TRAVERSE_ALL, -1,
+                    wip_read_sp_interpr_tags,
+                    (gpointer)xinterp);
+
+    /* recalculating to right units */
     if (xtransform->unitname != NULL) {
-        siunitx = gwy_si_unit_new("m");
-        for (i = 0; i < numpoints; i++)
-            xdata[i] = xdata[i] * 1e-9;
+        if ((xinterp->unitindex == WIP_UNIT_NANOMETER)
+         || (xinterp->unitindex == WIP_UNIT_MIKROMETER)) {
+            siunitx = gwy_si_unit_new("m");
+            for (i = 0; i < numpoints; i++)
+                xdata[i] = xdata[i] * 1e-9;
+        }
+        else if (xinterp->unitindex == WIP_UNIT_SM_1) {
+            siunitx = gwy_si_unit_new("1/m");
+            for (i = 0; i < numpoints; i++)
+                xdata[i] = 1.0 / (xdata[i] * 1e-9);
+        }
+        else if (xinterp->unitindex == WIP_UNIT_RAMAN_SHIFT) {
+            if (xinterp->excitation_wavelength == 0.0) {
+                siunitx = gwy_si_unit_new("m");
+                for (i = 0; i < numpoints; i++)
+                    xdata[i] = xdata[i] * 1e-9;
+            }
+            else {
+                siunitx = gwy_si_unit_new("1/m");
+                for (i = 0; i < numpoints; i++)
+                    xdata[i]
+                         = 1.0 / (xinterp->excitation_wavelength * 1e-9)
+                                              - 1.0 / (xdata[i] * 1e-9);
+            }
+        }
+        else if ((xinterp->unitindex == WIP_UNIT_EV)
+              || (xinterp->unitindex == WIP_UNIT_MEV)) {
+            siunitx = gwy_si_unit_new("eV");
+            for (i = 0; i < numpoints; i++)
+                xdata[i] = H * C / (xdata[i] * 1e-9);
+        }
+        else if ((xinterp->unitindex == WIP_UNIT_EV_REL)
+              || (xinterp->unitindex == WIP_UNIT_MEV_REL)) {
+            if (xinterp->excitation_wavelength == 0.0) {
+                siunitx = gwy_si_unit_new("m");
+                for (i = 0; i < numpoints; i++)
+                    xdata[i] = xdata[i] * 1e-9;
+            }
+            else {
+                siunitx = gwy_si_unit_new("eV");
+                for (i = 0; i < numpoints; i++)
+                    xdata[i] = (H * C / (xinterp->excitation_wavelength * 1e-9)
+                                - H * C / (xdata[i] * 1e-9));
+            }
+        }
+        else {
+            siunitx = gwy_si_unit_new("m");
+            for (i = 0; i < numpoints; i++)
+                xdata[i] = xdata[i] * 1e-9;
+        }
     }
     else
         siunitx = gwy_si_unit_new("pixels");
@@ -813,21 +904,22 @@ wip_read_graph(GNode *node)
         g_free(xtransform->unitname);
     }
     g_free(xtransform);
+    g_free(xinterp);
 
     /* Try to read y units */
     idnode->id = header->zinterpid;
     g_node_traverse(g_node_get_root(node),
-                     G_LEVEL_ORDER, G_TRAVERSE_ALL, -1,
-                     wip_find_by_id, (gpointer)idnode);
+                    G_LEVEL_ORDER, G_TRAVERSE_ALL, -1,
+                    wip_find_by_id, (gpointer)idnode);
     yaxis = g_new0(WIPAxis, 1);
     g_node_traverse(idnode->node->parent->parent,
-                     G_LEVEL_ORDER, G_TRAVERSE_ALL, -1,
-                     wip_read_axis_tags,
-                     (gpointer)yaxis);
+                    G_LEVEL_ORDER, G_TRAVERSE_ALL, -1,
+                    wip_read_axis_tags,
+                    (gpointer)yaxis);
     if (yaxis->unitname)
         siunity = gwy_si_unit_new(yaxis->unitname);
     else
-        siunity = gwy_si_unit_new("");
+        siunity = gwy_si_unit_new(NULL);
     g_free(yaxis);
 
     /* Packing */
@@ -847,6 +939,9 @@ wip_read_graph(GNode *node)
     gwy_graph_curve_model_set_data(gcmodel, xdata, ydata, numpoints);
     g_free(xdata);
     g_free(ydata);
+    if (!gwy_graph_curve_model_is_ordered(gcmodel)) {
+        gwy_graph_curve_model_enforce_order(gcmodel);
+    }
     gwy_graph_model_add_curve(gmodel, gcmodel);
     g_object_unref(gcmodel);
     g_string_free(caption, TRUE);
@@ -860,6 +955,7 @@ wip_read_graph_image(GNode *node)
 {
     WIPGraph *header;
     WIPSpectralTransform *xtransform;
+    WIPSpectralInterpretation *xinterp;
     WIPAxis *waxis;
     WIPSpaceTransform *xyaxis;
     WIPIdNode *idnode;
@@ -893,13 +989,13 @@ wip_read_graph_image(GNode *node)
     yres = header->sizey;
     zres = header->sizegraph;
 
-    gwy_debug("numpoints * databytes = %d, datasize = %d\n",
-            xres * yres * zres * WIPDataSize[header->datatype],
-            header->datasize);
+    gwy_debug("numpoints * databytes = %" G_GSIZE_FORMAT ", datasize = %" G_GSIZE_FORMAT "\n",
+              xres * yres * zres * WIPDataSize[header->datatype],
+              header->datasize);
     if ((xres * yres * zres <= 0)
-     || (header->datatype > 10)
-     || (header->datasize != WIPDataSize[header->datatype]
-                           * xres * yres * zres)) {
+        || (header->datatype > 10)
+        || (header->datasize != (WIPDataSize[header->datatype]
+                                 * xres * yres * zres))) {
         g_free(header);
         return NULL;
     }
@@ -908,18 +1004,18 @@ wip_read_graph_image(GNode *node)
     idnode = g_new0(WIPIdNode, 1);
     idnode->id = header->spacetransformid;
     g_node_traverse(g_node_get_root(node),
-                     G_LEVEL_ORDER, G_TRAVERSE_ALL, -1,
-                     wip_find_by_id, (gpointer)idnode);
+                    G_LEVEL_ORDER, G_TRAVERSE_ALL, -1,
+                    wip_find_by_id, (gpointer)idnode);
 
     xyaxis = g_new0(WIPSpaceTransform, 1);
     g_node_traverse(idnode->node->parent->parent,
-                     G_LEVEL_ORDER, G_TRAVERSE_ALL, -1,
-                     wip_read_space_tr_tag, (gpointer)xyaxis);
+                    G_LEVEL_ORDER, G_TRAVERSE_ALL, -1,
+                    wip_read_space_tr_tag, (gpointer)xyaxis);
 
     if (xyaxis->unitname)
         siunitxy = gwy_si_unit_new_parse(xyaxis->unitname, &power10xy);
     else
-        siunitxy = gwy_si_unit_new("");
+        siunitxy = gwy_si_unit_new(NULL);
     xscale = xyaxis->scale[0];
     yscale = xyaxis->scale[4];
     if (xscale == 0.0) {
@@ -941,17 +1037,17 @@ wip_read_graph_image(GNode *node)
     /* Try to read w units */
     idnode->id = header->zinterpid;
     g_node_traverse(g_node_get_root(node),
-                     G_LEVEL_ORDER, G_TRAVERSE_ALL, -1,
-                     wip_find_by_id, (gpointer)idnode);
+                    G_LEVEL_ORDER, G_TRAVERSE_ALL, -1,
+                    wip_find_by_id, (gpointer)idnode);
     waxis = g_new0(WIPAxis, 1);
     g_node_traverse(idnode->node->parent->parent,
-                     G_LEVEL_ORDER, G_TRAVERSE_ALL, -1,
-                     wip_read_axis_tags,
-                     (gpointer)waxis);
+                    G_LEVEL_ORDER, G_TRAVERSE_ALL, -1,
+                    wip_read_axis_tags,
+                    (gpointer)waxis);
     if (waxis->unitname)
         siunitw = gwy_si_unit_new_parse(waxis->unitname, &power10w);
     else
-        siunitw = gwy_si_unit_new("");
+        siunitw = gwy_si_unit_new(NULL);
     g_free(waxis);
     wscale = pow(10.0, power10w);
     if (wscale == 0.0)
@@ -1065,6 +1161,17 @@ wip_read_graph_image(GNode *node)
             g_warning("Wrong datatype");
     }
 
+    idnode->id = header->xinterpid;
+    g_node_traverse(g_node_get_root(node),
+                    G_LEVEL_ORDER, G_TRAVERSE_ALL, -1,
+                    wip_find_by_id, (gpointer)idnode);
+
+    xinterp = g_new0(WIPSpectralInterpretation, 1);
+    g_node_traverse(idnode->node->parent->parent,
+                    G_LEVEL_ORDER, G_TRAVERSE_ALL, -1,
+                    wip_read_sp_interpr_tags,
+                    (gpointer)xinterp);
+
     /* Try to read zcalibration */
     idnode->id = header->xtransformid;
     g_node_traverse(g_node_get_root(node),
@@ -1087,13 +1194,63 @@ wip_read_graph_image(GNode *node)
         for (i = 0; i < zres; i++)
             data[i] = wip_pixel_to_lambda(i, xtransform);
 
+        /* recalculating to right units */
         if (xtransform->unitname != NULL) {
-            siunitz = gwy_si_unit_new("m");
-            for (i = 0; i < zres; i++)
-                data[i] *= 1e-9;
+            if ((xinterp->unitindex == WIP_UNIT_NANOMETER)
+             || (xinterp->unitindex == WIP_UNIT_MIKROMETER)) {
+                siunitz = gwy_si_unit_new("m");
+                for (i = 0; i < zres; i++)
+                    data[i] = data[i] * 1e-9;
+            }
+            else if (xinterp->unitindex == WIP_UNIT_SM_1) {
+                siunitz = gwy_si_unit_new("1/m");
+                for (i = 0; i < zres; i++)
+                    data[i] = 1.0 / (data[i] * 1e-9);
+            }
+            else if (xinterp->unitindex == WIP_UNIT_RAMAN_SHIFT) {
+                if (xinterp->excitation_wavelength == 0.0) {
+                    siunitz = gwy_si_unit_new("m");
+                    for (i = 0; i < zres; i++)
+                        data[i] = data[i] * 1e-9;
+                }
+                else {
+                    siunitz = gwy_si_unit_new("1/m");
+                    for (i = 0; i < zres; i++)
+                        data[i]
+                         = 1.0 / (xinterp->excitation_wavelength * 1e-9)
+                                               - 1.0 / (data[i] * 1e-9);
+                }
+            }
+            else if ((xinterp->unitindex == WIP_UNIT_EV)
+                  || (xinterp->unitindex == WIP_UNIT_MEV)) {
+                siunitz = gwy_si_unit_new("eV");
+                for (i = 0; i < zres; i++)
+                    data[i] = H * C / (data[i] * 1e-9);
+            }
+            else if ((xinterp->unitindex == WIP_UNIT_EV_REL)
+                  || (xinterp->unitindex == WIP_UNIT_MEV_REL)) {
+                if (xinterp->excitation_wavelength == 0.0) {
+                    siunitz = gwy_si_unit_new("m");
+                    for (i = 0; i < zres; i++)
+                        data[i] = data[i] * 1e-9;
+                }
+                else {
+                    siunitz = gwy_si_unit_new("eV");
+                    for (i = 0; i < zres; i++)
+                        data[i]
+                         = H*C / (xinterp->excitation_wavelength * 1e-9)
+                                             - H * C / (data[i] * 1e-9);
+                }
+            }
+            else {
+                siunitz = gwy_si_unit_new("m");
+                for (i = 0; i < zres; i++)
+                    data[i] = data[i] * 1e-9;
+            }
         }
         else
             siunitz = gwy_si_unit_new("pixels");
+
         gwy_data_line_set_si_unit_y(cal, siunitz);
         gwy_brick_set_zcalibration(brick, cal);
         g_object_unref(cal);
@@ -1106,6 +1263,7 @@ wip_read_graph_image(GNode *node)
         g_free(xtransform->unitname);
     }
     g_free(xtransform);
+    g_free(xinterp);
 
     gwy_brick_set_si_unit_x(brick, siunitxy);
     gwy_brick_set_si_unit_y(brick, siunitxy);
@@ -1121,29 +1279,6 @@ wip_read_graph_image(GNode *node)
     return brick;
 }
 
-static void
-wip_flip_xy(GwyDataField *source, GwyDataField *dest)
-{
-    gint xres, yres, i, j;
-    gdouble *dd;
-    const gdouble *sd;
-
-    xres = gwy_data_field_get_xres(source);
-    yres = gwy_data_field_get_yres(source);
-    gwy_data_field_resample(dest, yres, xres, GWY_INTERPOLATION_NONE);
-    sd = gwy_data_field_get_data_const(source);
-    dd = gwy_data_field_get_data(dest);
-
-    for (i = 0; i < xres; i++) {
-        for (j = 0; j < yres; j++) {
-            dd[i*yres + (yres - 1 - j)] = sd[j*xres + i];
-        }
-    }
-
-    gwy_data_field_set_xreal(dest, gwy_data_field_get_yreal(source));
-    gwy_data_field_set_yreal(dest, gwy_data_field_get_xreal(source));
-}
-
 static GwyDataField*
 wip_read_image(GNode *node)
 {
@@ -1165,13 +1300,13 @@ wip_read_image(GNode *node)
     header = g_new0(WIPImage, 1);
 
     g_node_traverse(node, G_LEVEL_ORDER, G_TRAVERSE_ALL, -1,
-                     wip_read_image_tags, (gpointer)header);
+                    wip_read_image_tags, (gpointer)header);
 
     if ((header->datatype > 11)
-     || (header->sizex != header->xrange)
-     || (header->sizey != header->yrange)
-     || (header->datasize != WIPDataSize[header->datatype]
-       * header->sizex * header->sizey)) {
+        || (header->sizex != header->xrange)
+        || (header->sizey != header->yrange)
+        || (header->datasize != (WIPDataSize[header->datatype]
+                                 * header->sizex * header->sizey))) {
         g_free(header);
         return NULL;
     }
@@ -1180,32 +1315,32 @@ wip_read_image(GNode *node)
     idnode = g_new0(WIPIdNode, 1);
     idnode->id = header->zinterpid;
     g_node_traverse(g_node_get_root(node),
-                     G_LEVEL_ORDER, G_TRAVERSE_ALL, -1,
-                     wip_find_by_id, (gpointer)idnode);
+                    G_LEVEL_ORDER, G_TRAVERSE_ALL, -1,
+                    wip_find_by_id, (gpointer)idnode);
     zaxis = g_new0(WIPAxis, 1);
     g_node_traverse(idnode->node->parent->parent,
-                     G_LEVEL_ORDER, G_TRAVERSE_ALL, -1,
-                     wip_read_axis_tags,
-                     (gpointer)zaxis);
+                    G_LEVEL_ORDER, G_TRAVERSE_ALL, -1,
+                    wip_read_axis_tags,
+                    (gpointer)zaxis);
     if (zaxis->unitname)
         siunitz = gwy_si_unit_new_parse(zaxis->unitname, &power10z);
     else
-        siunitz = gwy_si_unit_new("");
+        siunitz = gwy_si_unit_new(NULL);
     g_free(zaxis);
 
     /* Try to read xy units and scale */
     idnode->id = header->postransformid;
     g_node_traverse(g_node_get_root(node),
-                     G_LEVEL_ORDER, G_TRAVERSE_ALL, -1,
-                     wip_find_by_id, (gpointer)idnode);
+                    G_LEVEL_ORDER, G_TRAVERSE_ALL, -1,
+                    wip_find_by_id, (gpointer)idnode);
     xyaxis = g_new0(WIPSpaceTransform, 1);
     g_node_traverse(idnode->node->parent->parent,
-                     G_LEVEL_ORDER, G_TRAVERSE_ALL, -1,
-                     wip_read_space_tr_tag, (gpointer)xyaxis);
+                    G_LEVEL_ORDER, G_TRAVERSE_ALL, -1,
+                    wip_read_space_tr_tag, (gpointer)xyaxis);
     if (xyaxis->unitname)
         siunitxy = gwy_si_unit_new_parse(xyaxis->unitname, &power10xy);
     else
-        siunitxy = gwy_si_unit_new("");
+        siunitxy = gwy_si_unit_new(NULL);
     xscale = xyaxis->scale[0];
     yscale = xyaxis->scale[4];
     if (yscale == 0.0) {
@@ -1227,79 +1362,141 @@ wip_read_image(GNode *node)
     g_free(xyaxis);
     g_free(idnode);
 
-    /* Reading actual data
-     * data is stored in strange way in TDImage, so it is more
-     * simple to swap X and Y axes here to read them correctly
-     * and rotate datafield in the end of procedure */
-    dfield2 = gwy_data_field_new(header->sizey, header->sizex,
-                          header->sizey * pow(10.0, power10xy) * yscale,
-                          header->sizex * pow(10.0, power10xy) * xscale,
-                          FALSE);
-    data = gwy_data_field_get_data(dfield2);
-
     zscale = pow(10.0, power10z);
     if (zscale == 0.0)
         zscale = 1.0;
     p = header->data;
-    switch (header->datatype) {
-        case WIP_DATA_LIST:
-        case WIP_DATA_EXTENDED:
-            /* cannot read this */
-            break;
-        case WIP_DATA_FLOAT:
-            for (i = 0; i < header->sizex * header->sizey; i++)
-                data[i] = zscale * gwy_get_gfloat_le(&p);
-            break;
-        case WIP_DATA_DOUBLE:
-            for (i = 0; i < header->sizex * header->sizey; i++)
-                data[i] = zscale * gwy_get_gdouble_le(&p);
-            break;
-        case WIP_DATA_INT8:
-        case WIP_DATA_UINT8:
-        case WIP_DATA_BOOL:
-            for (i = 0; i < header->sizex * header->sizey; i++)
-                data[i] = *(p++) * zscale;
-            break;
-        case WIP_DATA_INT64:
-            for (i = 0; i < header->sizex * header->sizey; i++) {
-                data[i] = GINT64_FROM_LE(*(const gint64 *)p) * zscale;
-                p += 8;
-            }
-            break;
-        case WIP_DATA_INT32:
-            for (i = 0; i < header->sizex * header->sizey; i++) {
-                data[i] = GINT32_FROM_LE(*(const gint32 *)p) * zscale;
-                p += 4;
-            }
-            break;
-        case WIP_DATA_INT16:
-            for (i = 0; i < header->sizex * header->sizey; i++) {
-                data[i] = GINT16_FROM_LE(*(const gint16 *)p) * zscale;
-                p += 2;
-            }
-            break;
-        case WIP_DATA_UINT32:
-            for (i = 0; i < header->sizex * header->sizey; i++) {
-                data[i] = GUINT32_FROM_LE(*(const guint32 *)p) * zscale;
-                p += 4;
-            }
-            break;
-        case WIP_DATA_UINT16:
-            for (i = 0; i < header->sizex * header->sizey; i++) {
-                data[i] = GUINT16_FROM_LE(*(const guint16 *)p) * zscale;
-                p += 2;
-            }
-            break;
-        default:
-            g_warning("Wrong datatype");
-    }
 
-    dfield = gwy_data_field_new(header->sizex, header->sizey,
-                          header->sizex * pow(10.0, power10xy) * xscale,
-                          header->sizey * pow(10.0, power10xy) * yscale,
-                          FALSE);
-    wip_flip_xy(dfield2, dfield);
-    g_object_unref(dfield2);
+    /* Reading actual data
+     *
+     * FIXME
+     *
+     * data is stored in strange way in TDImage, so it is more
+     * simple to swap X and Y axes here to read them correctly
+     * and rotate datafield in the end of procedure */
+    if (header->version == 0) {
+        dfield2 = gwy_data_field_new(header->sizey, header->sizex,
+                                     header->sizey * pow(10.0, power10xy) * yscale,
+                                     header->sizex * pow(10.0, power10xy) * xscale,
+                                     FALSE);
+        data = gwy_data_field_get_data(dfield2);
+
+        switch (header->datatype) {
+            case WIP_DATA_LIST:
+            case WIP_DATA_EXTENDED:
+                /* cannot read this */
+                break;
+            case WIP_DATA_FLOAT:
+                for (i = 0; i < header->sizex * header->sizey; i++)
+                    data[i] = zscale * gwy_get_gfloat_le(&p);
+                break;
+            case WIP_DATA_DOUBLE:
+                for (i = 0; i < header->sizex * header->sizey; i++)
+                    data[i] = zscale * gwy_get_gdouble_le(&p);
+                break;
+            case WIP_DATA_INT8:
+            case WIP_DATA_UINT8:
+            case WIP_DATA_BOOL:
+                for (i = 0; i < header->sizex * header->sizey; i++)
+                    data[i] = *(p++) * zscale;
+                break;
+            case WIP_DATA_INT64:
+                for (i = 0; i < header->sizex * header->sizey; i++) {
+                    data[i] = GINT64_FROM_LE(*(const gint64 *)p) * zscale;
+                    p += 8;
+                }
+                break;
+            case WIP_DATA_INT32:
+                for (i = 0; i < header->sizex * header->sizey; i++) {
+                    data[i] = GINT32_FROM_LE(*(const gint32 *)p) * zscale;
+                    p += 4;
+                }
+                break;
+            case WIP_DATA_INT16:
+                for (i = 0; i < header->sizex * header->sizey; i++) {
+                    data[i] = GINT16_FROM_LE(*(const gint16 *)p) * zscale;
+                    p += 2;
+                }
+                break;
+            case WIP_DATA_UINT32:
+                for (i = 0; i < header->sizex * header->sizey; i++) {
+                    data[i] = GUINT32_FROM_LE(*(const guint32 *)p) * zscale;
+                    p += 4;
+                }
+                break;
+            case WIP_DATA_UINT16:
+                for (i = 0; i < header->sizex * header->sizey; i++) {
+                    data[i] = GUINT16_FROM_LE(*(const guint16 *)p) * zscale;
+                    p += 2;
+                }
+                break;
+            default:
+                g_warning("Wrong datatype");
+        }
+
+        dfield = gwy_data_field_new_rotated_90(dfield2, TRUE);
+        g_object_unref(dfield2);
+    }
+    else {
+        dfield = gwy_data_field_new(header->sizex, header->sizey,
+                                     header->sizex * pow(10.0, power10xy) * xscale,
+                                     header->sizey * pow(10.0, power10xy) * yscale,
+                                     FALSE);
+        data = gwy_data_field_get_data(dfield);
+
+        switch (header->datatype) {
+            case WIP_DATA_LIST:
+            case WIP_DATA_EXTENDED:
+                /* cannot read this */
+                break;
+            case WIP_DATA_FLOAT:
+                for (i = 0; i < header->sizex * header->sizey; i++)
+                    data[i] = zscale * gwy_get_gfloat_le(&p);
+                break;
+            case WIP_DATA_DOUBLE:
+                for (i = 0; i < header->sizex * header->sizey; i++)
+                    data[i] = zscale * gwy_get_gdouble_le(&p);
+                break;
+            case WIP_DATA_INT8:
+            case WIP_DATA_UINT8:
+            case WIP_DATA_BOOL:
+                for (i = 0; i < header->sizex * header->sizey; i++)
+                    data[i] = *(p++) * zscale;
+                break;
+            case WIP_DATA_INT64:
+                for (i = 0; i < header->sizex * header->sizey; i++) {
+                    data[i] = GINT64_FROM_LE(*(const gint64 *)p) * zscale;
+                    p += 8;
+                }
+                break;
+            case WIP_DATA_INT32:
+                for (i = 0; i < header->sizex * header->sizey; i++) {
+                    data[i] = GINT32_FROM_LE(*(const gint32 *)p) * zscale;
+                    p += 4;
+                }
+                break;
+            case WIP_DATA_INT16:
+                for (i = 0; i < header->sizex * header->sizey; i++) {
+                    data[i] = GINT16_FROM_LE(*(const gint16 *)p) * zscale;
+                    p += 2;
+                }
+                break;
+            case WIP_DATA_UINT32:
+                for (i = 0; i < header->sizex * header->sizey; i++) {
+                    data[i] = GUINT32_FROM_LE(*(const guint32 *)p) * zscale;
+                    p += 4;
+                }
+                break;
+            case WIP_DATA_UINT16:
+                for (i = 0; i < header->sizex * header->sizey; i++) {
+                    data[i] = GUINT16_FROM_LE(*(const guint16 *)p) * zscale;
+                    p += 2;
+                }
+                break;
+            default:
+                g_warning("Wrong datatype");
+        }
+    }
 
     gwy_data_field_set_si_unit_z(dfield, siunitz);
     gwy_data_field_set_si_unit_xy(dfield, siunitxy);
@@ -1343,7 +1540,7 @@ wip_read_bitmap(GNode *node)
     if (xyaxis->unitname)
         siunitxy = gwy_si_unit_new_parse(xyaxis->unitname, &power10xy);
     else
-        siunitxy = gwy_si_unit_new("");
+        siunitxy = gwy_si_unit_new(NULL);
     xscale = xyaxis->scale[0];
     yscale = xyaxis->scale[4];
     if (yscale == 0.0) {
