@@ -1,5 +1,5 @@
 /*
- *  $Id: wsxmfile.c 18379 2016-03-03 11:42:28Z yeti-dn $
+ *  $Id: wsxmfile.c 19948 2017-06-22 14:05:41Z yeti-dn $
  *  Copyright (C) 2005 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -102,7 +102,7 @@ static GwyModuleInfo module_info = {
     "2005",
 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, wsxmfile)
 
 static gboolean
 module_register(void)
