@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: xyzexport.c 18474 2016-03-21 10:33:53Z yeti-dn $
+ *  @(#) $Id: xyzexport.c 19948 2017-06-22 14:05:41Z yeti-dn $
  *  Copyright (C) 2015-2016 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
@@ -93,7 +93,7 @@ static GwyModuleInfo module_info = {
     "2015",
 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, xyzexport)
 
 static gboolean
 module_register(void)
@@ -210,6 +210,9 @@ xyzexport_export(G_GNUC_UNUSED GwyContainer *data,
                                  &title);
     }
 
+    if (!title)
+        title = _("Untitled");
+
     if (mode == GWY_RUN_INTERACTIVE) {
         ok = xyzexport_export_dialog(&args, !!mfield, needs_decimal_dot,
                                      pageno, title);
