@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: zeiss.c 17800 2015-12-03 15:01:54Z yeti-dn $
+ *  @(#) $Id: zeiss.c 19948 2017-06-22 14:05:41Z yeti-dn $
  *  Copyright (C) 2011 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
@@ -65,7 +65,7 @@ static GwyModuleInfo module_info = {
     "2011",
 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, zeiss)
 
 static gboolean
 module_register(void)
