@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: graph_cd.c 18290 2016-02-18 20:54:52Z yeti-dn $
+ *  @(#) $Id: graph_cd.c 19948 2017-06-22 14:05:41Z yeti-dn $
  *  Copyright (C) 2003-2016 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -140,7 +140,7 @@ static GwyModuleInfo module_info = {
     "2004",
 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, graph_cd)
 
 static gboolean
 module_register(void)
