@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: graph_cut.c 18953 2016-09-13 09:47:56Z yeti-dn $
+ *  @(#) $Id: graph_cut.c 19999 2017-06-29 21:48:28Z yeti-dn $
  *  Copyright (C) 2003-2016 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -52,7 +52,6 @@ typedef struct {
     GtkWidget *from;
     GtkWidget *to;
     GtkWidget *curve;
-    GtkWidget *curve_label;
     GtkWidget *all;
 } CutControls;
 
@@ -92,7 +91,7 @@ static GwyModuleInfo module_info = {
     "2007",
 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, graph_cut)
 
 static gboolean
 module_register(void)
@@ -163,25 +162,19 @@ cut_dialog(CutArgs *args)
     row = 0;
 
     /* Curve to cut */
-    controls.curve_label = gtk_label_new_with_mnemonic(_("_Graph curve:"));
-    gtk_misc_set_alignment(GTK_MISC(controls.curve_label), 0.0, 0.5);
-    gtk_table_attach(GTK_TABLE(table), controls.curve_label,
-                     0, 1, row, row+1, GTK_FILL, 0, 0, 0);
-
-    controls.curve
-        = gwy_combo_box_graph_curve_new(G_CALLBACK(curve_changed), &controls,
-                                        gmodel, args->curve);
-    gtk_label_set_mnemonic_widget(GTK_LABEL(controls.curve_label),
-                                  controls.curve);
-    gtk_table_attach(GTK_TABLE(table), controls.curve,
-                     1, 2, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
+    controls.curve = gwy_combo_box_graph_curve_new(G_CALLBACK(curve_changed),
+                                                   &controls,
+                                                   gmodel, args->curve);
+    gwy_table_attach_adjbar(table, row, _("_Graph curve:"), NULL,
+                            GTK_OBJECT(controls.curve),
+                            GWY_HSCALE_WIDGET_NO_EXPAND);
     row++;
 
     controls.all = gtk_check_button_new_with_mnemonic(_("Cut _all curves"));
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(controls.all),
                                                    args->all);
     gtk_table_attach(GTK_TABLE(table), controls.all,
-                     0, 2, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
+                     0, 2, row, row+1, GTK_FILL, 0, 0, 0);
     g_signal_connect(controls.all, "toggled",
                      G_CALLBACK(all_changed), &controls);
     row++;
@@ -243,26 +236,12 @@ cut_dialog(CutArgs *args)
     pick_curves(&controls);
     update_sensitivity(&controls);
 
-    do {
-        response = gtk_dialog_run(GTK_DIALOG(dialog));
+    response = gtk_dialog_run(GTK_DIALOG(dialog));
+    if (response == GTK_RESPONSE_OK)
         cut_fetch_entry(&controls);
-        switch (response) {
-            case GTK_RESPONSE_CANCEL:
-            case GTK_RESPONSE_DELETE_EVENT:
-            gtk_widget_destroy(dialog);
-            return;
-            break;
-
-            case GTK_RESPONSE_OK:
-            do_cut(args);
-            gtk_widget_destroy(dialog);
-            break;
-
-            default:
-            g_assert_not_reached();
-            break;
-        }
-    } while (response != GTK_RESPONSE_OK);
+    gtk_widget_destroy(dialog);
+    if (response == GTK_RESPONSE_OK)
+        do_cut(args);
 }
 
 static void
@@ -411,7 +390,6 @@ graph_selected(GwySelection* selection,
 
 }
 
-
 static void
 range_changed(GtkWidget *entry,
               CutControls *controls)
@@ -491,8 +469,7 @@ update_sensitivity(CutControls *controls)
 {
     gboolean csens = !controls->args->all;
 
-    gtk_widget_set_sensitive(controls->curve, csens);
-    gtk_widget_set_sensitive(controls->curve_label, csens);
+    gwy_table_hscale_set_sensitive(GTK_OBJECT(controls->curve), csens);
 }
 
 static const gchar all_key[] = "/module/graph_cut/all";
