@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: graph_dos_spectrum.c 18256 2016-02-05 19:53:16Z yeti-dn $
+ *  @(#) $Id: graph_dos_spectrum.c 19948 2017-06-22 14:05:41Z yeti-dn $
  *  Copyright (C) 2010, David Necas (Yeti), Petr Klapetek, Daniil Bratashov
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net, dn2010@gmail.com
  *
@@ -46,7 +46,7 @@ static GwyModuleInfo module_info = {
     "2010",
 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, graph_dos_spectrum)
 
 static gboolean
 module_register(void)
