@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: graph_export_ascii.c 19205 2016-11-08 10:24:40Z yeti-dn $
+ *  @(#) $Id: graph_export_ascii.c 19948 2017-06-22 14:05:41Z yeti-dn $
  *  Copyright (C) 2006,2014-2016 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -67,7 +67,7 @@ static GwyModuleInfo module_info = {
     "2006",
 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, graph_export_ascii)
 
 static gboolean
 module_register(void)
