@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: graph_export_bitmap.c 18256 2016-02-05 19:53:16Z yeti-dn $
+ *  @(#) $Id: graph_export_bitmap.c 19948 2017-06-22 14:05:41Z yeti-dn $
  *  Copyright (C) 2006 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -40,7 +40,7 @@ static GwyModuleInfo module_info = {
     "2006",
 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, graph_export_bitmap)
 
 static gboolean
 module_register(void)
