@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: graph_export_vector.c 18234 2016-01-27 14:57:31Z yeti-dn $
+ *  @(#) $Id: graph_export_vector.c 20278 2017-08-14 15:11:19Z yeti-dn $
  *  Copyright (C) 2006 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -23,6 +23,7 @@
 #include <gtk/gtk.h>
 #include <libgwyddion/gwymacros.h>
 #include <libgwydgets/gwygraphmodel.h>
+#include <libgwydgets/gwystock.h>
 #include <libgwymodule/gwymodule-graph.h>
 #include <app/gwyapp.h>
 
@@ -39,7 +40,7 @@ static GwyModuleInfo module_info = {
     "2006",
 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, graph_export_vector)
 
 static gboolean
 module_register(void)
@@ -47,7 +48,7 @@ module_register(void)
     gwy_graph_func_register("graph_export_vector",
                             (GwyGraphFunc)&export,
                             N_("/Export _PostScript"),
-                            NULL,
+                            GWY_STOCK_GRAPH_EXPORT_VECTOR,
                             GWY_MENU_FLAG_GRAPH,
                             N_("Export graph to PostScript"));
 
