@@ -1,6 +1,6 @@
 /*
- *  @(#) $Id: graph_fit.c 19147 2016-10-31 16:30:37Z yeti-dn $
- *  Copyright (C) 2003-2016 David Necas (Yeti), Petr Klapetek.
+ *  @(#) $Id: graph_fit.c 19948 2017-06-22 14:05:41Z yeti-dn $
+ *  Copyright (C) 2003-2017 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -44,6 +44,7 @@ enum {
     RESPONSE_FIT,
     RESPONSE_PLOT,
     RESPONSE_SAVE,
+    RESPONSE_COPY,
 };
 
 typedef struct {
@@ -180,12 +181,12 @@ static GwyModuleInfo module_info = {
     &module_register,
     N_("Fit graph with function"),
     "Petr Klapetek <klapetek@gwyddion.net>",
-    "2.9",
+    "2.10",
     "David Nečas (Yeti) & Petr Klapetek",
     "2004",
 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, graph_fit)
 
 static gboolean
 module_register(void)
@@ -246,6 +247,8 @@ fit_dialog(FitArgs *args, GwyContainer *container)
     FitControls controls;
     gint response, row, ncurves;
     GString *report;
+    GtkClipboard *clipboard;
+    GdkDisplay *display;
     gdouble xmin, xmax;
 
     controls.args = args;
@@ -274,8 +277,12 @@ fit_dialog(FitArgs *args, GwyContainer *container)
                           gwy_sgettext("verb|_Estimate"), RESPONSE_ESTIMATE);
     gtk_dialog_add_button(GTK_DIALOG(dialog),
                           _("_Plot Inits"), RESPONSE_PLOT);
+    gtk_dialog_add_button(GTK_DIALOG(dialog),
+                          GTK_STOCK_COPY, RESPONSE_COPY);
+    gtk_dialog_set_response_sensitive(GTK_DIALOG(dialog), RESPONSE_COPY, FALSE);
     gtk_dialog_add_button(GTK_DIALOG(dialog),
                           GTK_STOCK_SAVE, RESPONSE_SAVE);
+    gtk_dialog_set_response_sensitive(GTK_DIALOG(dialog), RESPONSE_SAVE, FALSE);
     gtk_dialog_add_button(GTK_DIALOG(dialog),
                           GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL);
     gtk_dialog_add_button(GTK_DIALOG(dialog),
@@ -533,6 +540,15 @@ fit_dialog(FitArgs *args, GwyContainer *container)
             g_string_free(report, TRUE);
             break;
 
+            case RESPONSE_COPY:
+            report = create_fit_report(args);
+            display = gtk_widget_get_display(dialog);
+            clipboard = gtk_clipboard_get_for_display(display,
+                                                      GDK_SELECTION_CLIPBOARD);
+            gtk_clipboard_set_text(clipboard, report->str, -1);
+            g_string_free(report, TRUE);
+            break;
+
             case RESPONSE_ESTIMATE:
             fit_estimate(&controls);
             break;
@@ -826,7 +842,7 @@ fit_do(FitControls *controls)
     for (i = 0; i < nparams; i++) {
         arg = &g_array_index(args->param, FitParamArg, i);
         arg->value = param[i];
-        arg->error = error[i];
+        arg->error = arg->fix ? 0.0 : error[i];
         fit_param_row_update_value(controls, i, errorknown);
     }
 
@@ -987,6 +1003,8 @@ fit_set_state(FitControls *controls,
 
     gtk_dialog_set_response_sensitive(GTK_DIALOG(controls->dialog),
                                       RESPONSE_SAVE, is_fitted);
+    gtk_dialog_set_response_sensitive(GTK_DIALOG(controls->dialog),
+                                      RESPONSE_COPY, is_fitted);
 
     if (args->is_fitted && !is_fitted) {
         if (gwy_graph_model_get_n_curves(args->graph_model) == 2)
