@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: graph_level.c 18262 2016-02-07 07:19:02Z yeti-dn $
+ *  @(#) $Id: graph_level.c 19948 2017-06-22 14:05:41Z yeti-dn $
  *  Copyright (C) 2003 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -43,7 +43,7 @@ static GwyModuleInfo module_info = {
     "2005",
 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, graph_level)
 
 static gboolean
 module_register(void)
