@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: graph_peaks.c 19071 2016-10-14 09:02:41Z yeti-dn $
+ *  @(#) $Id: graph_peaks.c 19999 2017-06-29 21:48:28Z yeti-dn $
  *  Copyright (C) 2016 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
@@ -117,12 +117,12 @@ static GwyModuleInfo module_info = {
     &module_register,
     N_("Finds peaks on graph curves."),
     "Yeti <yeti@gwyddion.net>",
-    "1.2",
+    "1.3",
     "David Nečas (Yeti)",
     "2016",
 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, graph_peaks)
 
 static gboolean
 module_register(void)
@@ -141,11 +141,9 @@ static void
 graph_peaks(GwyGraph *graph)
 {
     PeaksArgs args;
-    GwyGraphModel *parent_gmodel;
 
-    parent_gmodel = gwy_graph_get_model(graph);
     load_args(gwy_app_settings_get(), &args);
-    graph_peaks_dialogue(parent_gmodel, &args);
+    graph_peaks_dialogue(gwy_graph_get_model(graph), &args);
     save_args(gwy_app_settings_get(), &args);
 }
 
@@ -162,11 +160,11 @@ graph_peaks_dialogue(GwyGraphModel *parent_gmodel, PeaksArgs *args)
         { N_("Bilateral minimum"), GWY_PEAK_BACKGROUND_MMSTEP, },
     };
 
-    GtkWidget *dialogue, *hbox, *table, *label, *scwin, *hbox2, *button;
+    GtkWidget *dialogue, *hbox, *table, *scwin, *hbox2, *button;
     GwyGraphModel *gmodel;
     GwyGraphArea *area;
     PeaksControls controls;
-    gint response, row;
+    gint row;
 
     gwy_clear(&controls, 1);
     controls.args = args;
@@ -177,10 +175,9 @@ graph_peaks_dialogue(GwyGraphModel *parent_gmodel, PeaksArgs *args)
 
     dialogue = gtk_dialog_new_with_buttons(_("Graph Peaks"), NULL, 0, NULL);
     controls.dialogue = dialogue;
-    gtk_dialog_add_button(GTK_DIALOG(dialogue),
-                          GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL);
-    gtk_dialog_add_button(GTK_DIALOG(dialogue),
-                          GTK_STOCK_OK, GTK_RESPONSE_OK);
+    gtk_dialog_add_button(GTK_DIALOG(dialogue), GTK_STOCK_OK, GTK_RESPONSE_OK);
+    gtk_dialog_add_button(GTK_DIALOG(dialogue), GTK_STOCK_CANCEL,
+                          GTK_RESPONSE_CANCEL);
     gwy_help_add_to_graph_dialog(GTK_DIALOG(dialogue), GWY_HELP_DEFAULT);
     gtk_dialog_set_default_response(GTK_DIALOG(dialogue), GTK_RESPONSE_OK);
 
@@ -189,58 +186,44 @@ graph_peaks_dialogue(GwyGraphModel *parent_gmodel, PeaksArgs *args)
                        TRUE, TRUE, 0);
 
     /* Parameters */
-    table = gtk_table_new(6, 4, FALSE);
+    table = gtk_table_new(6, 2, FALSE);
     gtk_table_set_row_spacings(GTK_TABLE(table), 2);
     gtk_table_set_col_spacings(GTK_TABLE(table), 6);
     gtk_box_pack_start(GTK_BOX(hbox), table, FALSE, FALSE, 0);
     gtk_container_set_border_width(GTK_CONTAINER(table), 4);
     row = 0;
 
-    label = gtk_label_new_with_mnemonic(_("_Graph curve:"));
-    gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
-    gtk_table_attach(GTK_TABLE(table), label,
-                     0, 1, row, row+1, GTK_FILL, 0, 0, 0);
-
-    controls.curve
-        = gwy_combo_box_graph_curve_new(G_CALLBACK(curve_changed), &controls,
-                                        parent_gmodel, args->curve);
-    gtk_label_set_mnemonic_widget(GTK_LABEL(label), controls.curve);
-    gtk_table_attach(GTK_TABLE(table), controls.curve,
-                     1, 3, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
+    controls.curve = gwy_combo_box_graph_curve_new(G_CALLBACK(curve_changed),
+                                                   &controls,
+                                                   parent_gmodel, args->curve);
+    gwy_table_attach_adjbar(table, row, _("_Graph curve:"), NULL,
+                            GTK_OBJECT(controls.curve),
+                            GWY_HSCALE_WIDGET_NO_EXPAND);
     row++;
 
-    label = gtk_label_new_with_mnemonic(_("_Background type:"));
-    gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
-    gtk_table_attach(GTK_TABLE(table), label,
-                     0, 1, row, row+1, GTK_FILL, 0, 0, 0);
-
-    controls.background
-        = gwy_enum_combo_box_new(background_types,
-                                 G_N_ELEMENTS(background_types),
-                                 G_CALLBACK(background_changed), &controls,
-                                 args->background, TRUE);
-    gtk_label_set_mnemonic_widget(GTK_LABEL(label), controls.background);
-    gtk_table_attach(GTK_TABLE(table), controls.background,
-                     1, 3, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
+    controls.background = gwy_enum_combo_box_new(background_types,
+                                                 G_N_ELEMENTS(background_types),
+                                                 G_CALLBACK(background_changed),
+                                                 &controls,
+                                                 args->background, TRUE);
+    gwy_table_attach_adjbar(table, row, _("_Background type:"), NULL,
+                            GTK_OBJECT(controls.background),
+                            GWY_HSCALE_WIDGET_NO_EXPAND);
     row++;
 
-    label = gtk_label_new_with_mnemonic(_("Order peaks _by:"));
-    gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
-    gtk_table_attach(GTK_TABLE(table), label,
-                     0, 1, row, row+1, GTK_FILL, 0, 0, 0);
-
-    controls.order
-        = gwy_enum_combo_box_new(order_types, G_N_ELEMENTS(order_types),
-                                 G_CALLBACK(order_changed), &controls,
-                                 args->order, TRUE);
-    gtk_label_set_mnemonic_widget(GTK_LABEL(label), controls.order);
-    gtk_table_attach(GTK_TABLE(table), controls.order,
-                     1, 3, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
+    controls.order = gwy_enum_combo_box_new(order_types,
+                                            G_N_ELEMENTS(order_types),
+                                            G_CALLBACK(order_changed),
+                                            &controls,
+                                            args->order, TRUE);
+    gwy_table_attach_adjbar(table, row, _("Order peaks _by:"), NULL,
+                            GTK_OBJECT(controls.order),
+                            GWY_HSCALE_WIDGET_NO_EXPAND);
     row++;
 
     controls.npeaks = gtk_adjustment_new(args->npeaks, 1, 128, 1, 10, 0);
-    gwy_table_attach_hscale(table, row, _("Number of _peaks:"), NULL,
-                            controls.npeaks, GWY_HSCALE_DEFAULT);
+    gwy_table_attach_adjbar(table, row, _("Number of _peaks:"), NULL,
+                            controls.npeaks, GWY_HSCALE_SQRT | GWY_HSCALE_SNAP);
     g_signal_connect(controls.npeaks, "value-changed",
                      G_CALLBACK(npeaks_changed), &controls);
     row++;
@@ -252,13 +235,12 @@ graph_peaks_dialogue(GwyGraphModel *parent_gmodel, PeaksArgs *args)
                                    GTK_POLICY_NEVER, GTK_POLICY_AUTOMATIC);
     gtk_container_add(GTK_CONTAINER(scwin), controls.peaklist);
     gtk_table_attach(GTK_TABLE(table), scwin,
-                     0, 3, row, row+1,
-                     GTK_EXPAND | GTK_FILL, GTK_EXPAND | GTK_FILL, 0, 0);
+                     0, 2, row, row+1, GTK_FILL, GTK_EXPAND | GTK_FILL, 0, 0);
     row++;
 
     hbox2 = gtk_hbox_new(FALSE, 0);
     gtk_table_attach(GTK_TABLE(table), hbox2,
-                     0, 4, row, row+1, GTK_FILL, 0, 0, 0);
+                     0, 2, row, row+1, GTK_FILL, 0, 0, 0);
 
     button = add_aux_button(hbox2, GTK_STOCK_SAVE, _("Save table to a file"));
     g_signal_connect_swapped(button, "clicked",
@@ -284,25 +266,8 @@ graph_peaks_dialogue(GwyGraphModel *parent_gmodel, PeaksArgs *args)
     curve_changed(GTK_COMBO_BOX(controls.curve), &controls);
 
     gtk_widget_show_all(dialogue);
-
-    do {
-        response = gtk_dialog_run(GTK_DIALOG(dialogue));
-        switch (response) {
-            case GTK_RESPONSE_CANCEL:
-            case GTK_RESPONSE_DELETE_EVENT:
-            gtk_widget_destroy(dialogue);
-            return;
-            break;
-
-            case GTK_RESPONSE_OK:
-            gtk_widget_destroy(dialogue);
-            break;
-
-            default:
-            g_assert_not_reached();
-            break;
-        }
-    } while (response != GTK_RESPONSE_OK);
+    gtk_dialog_run(GTK_DIALOG(dialogue));
+    gtk_widget_destroy(dialogue);
 
     g_array_free(controls.peaks_sorted, TRUE);
     g_array_free(controls.peaks, TRUE);
@@ -454,7 +419,6 @@ curve_changed(GtkComboBox *combo,
     g_object_set(controls->npeaks,
                  "upper", (gdouble)controls->peaks->len,
                  NULL);
-
 }
 
 static void
