@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: axis.c 17612 2015-10-19 12:54:58Z yeti-dn $
+ *  @(#) $Id: axis.c 19948 2017-06-22 14:05:41Z yeti-dn $
  *  Copyright (C) 2003-2006 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -147,7 +147,7 @@ static GwyModuleInfo module_info = {
     "2004",
 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, axis)
 
 G_DEFINE_TYPE_EXTENDED
     (GwySelectionAxis, gwy_selection_axis, GWY_TYPE_SELECTION, 0,
