@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: lattice.c 15691 2013-12-02 00:07:14Z yeti-dn $
+ *  @(#) $Id: lattice.c 19948 2017-06-22 14:05:41Z yeti-dn $
  *  Copyright (C) 2013 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -130,7 +130,7 @@ static GwyModuleInfo module_info = {
     "2013",
 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, lattice)
 
 G_DEFINE_TYPE(GwySelectionLattice, gwy_selection_lattice, GWY_TYPE_SELECTION)
 G_DEFINE_TYPE(GwyLayerLattice, gwy_layer_lattice, GWY_TYPE_VECTOR_LAYER)
