@@ -175,7 +175,7 @@ static GwyModuleInfo module_info = {
     "2016",
 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, path)
 
 G_DEFINE_TYPE_EXTENDED
     (GwySelectionPath, gwy_selection_path, GWY_TYPE_SELECTION, 0,
