@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: rectangle.c 17612 2015-10-19 12:54:58Z yeti-dn $
+ *  @(#) $Id: rectangle.c 19948 2017-06-22 14:05:41Z yeti-dn $
  *  Copyright (C) 2003-2006 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -151,7 +151,7 @@ static GwyModuleInfo module_info = {
     "2004",
 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, rectangle)
 
 G_DEFINE_TYPE(GwySelectionRectangle, gwy_selection_rectangle,
               GWY_TYPE_SELECTION)
