@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: acf2d.c 16388 2014-07-10 14:26:53Z yeti-dn $
+ *  @(#) $Id: acf2d.c 19948 2017-06-22 14:05:41Z yeti-dn $
  *  Copyright (C) 2007 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
@@ -41,7 +41,7 @@ static GwyModuleInfo module_info = {
     "2007",
 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, acf2d)
 
 static gboolean
 module_register(void)
