@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: angle_dist.c 18665 2016-04-26 20:42:48Z yeti-dn $
+ *  @(#) $Id: angle_dist.c 19948 2017-06-22 14:05:41Z yeti-dn $
  *  Copyright (C) 2004 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -102,12 +102,12 @@ static GwyModuleInfo module_info = {
     N_("Calculates two-dimensional distribution of angles, "
        "that is projections of slopes to all directions."),
     "Yeti <yeti@gwyddion.net>",
-    "1.8",
+    "1.9",
     "David Nečas (Yeti) & Petr Klapetek",
     "2004",
 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, angle_dist)
 
 static gboolean
 module_register(void)
@@ -176,7 +176,7 @@ angle_dialog(AngleArgs *args)
     gtk_dialog_set_default_response(GTK_DIALOG(dialog), GTK_RESPONSE_OK);
     gwy_help_add_to_proc_dialog(GTK_DIALOG(dialog), GWY_HELP_DEFAULT);
 
-    table = gtk_table_new(5, 4, FALSE);
+    table = gtk_table_new(5, 3, FALSE);
     gtk_table_set_row_spacings(GTK_TABLE(table), 2);
     gtk_table_set_col_spacings(GTK_TABLE(table), 6);
     gtk_container_set_border_width(GTK_CONTAINER(table), 4);
@@ -185,33 +185,33 @@ angle_dialog(AngleArgs *args)
     row = 0;
 
     controls.size = gtk_adjustment_new(args->size, 10, MAX_OUT_SIZE, 1, 10, 0);
-    gwy_table_attach_hscale(table, row, _("Output _size:"), "px",
-                            controls.size, 0);
+    gwy_table_attach_adjbar(table, row, _("Output _size:"), _("px"),
+                            controls.size, GWY_HSCALE_SQRT);
     row++;
 
     controls.steps = gtk_adjustment_new(args->steps, 6, MAX_STEPS, 1, 10, 0);
-    gwy_table_attach_hscale(table, row, _("_Number of steps:"), NULL,
+    gwy_table_attach_adjbar(table, row, _("_Number of steps:"), NULL,
                             controls.steps, GWY_HSCALE_SQRT);
     row++;
 
     controls.logscale
         = gtk_check_button_new_with_mnemonic(_("_Logarithmic value scale"));
     gtk_table_attach(GTK_TABLE(table), controls.logscale,
-                     0, 4, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
+                     0, 2, row, row+1, GTK_FILL, 0, 0, 0);
     row++;
 
     controls.fit_plane
         = gtk_check_button_new_with_mnemonic(_("Use local plane _fitting"));
     gtk_table_attach(GTK_TABLE(table), controls.fit_plane,
-                     0, 4, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
+                     0, 2, row, row+1, GTK_FILL, 0, 0, 0);
     g_signal_connect(controls.fit_plane, "toggled",
                      G_CALLBACK(angle_fit_plane_cb), &controls);
     row++;
 
     controls.kernel_size = gtk_adjustment_new(args->kernel_size,
                                               2, 16, 1, 4, 0);
-    gwy_table_attach_hscale(table, row, _("_Plane size:"), "px",
-                            controls.kernel_size, 0);
+    gwy_table_attach_adjbar(table, row, _("_Plane size:"), _("px"),
+                            controls.kernel_size, GWY_HSCALE_LINEAR);
     row++;
 
     angle_dialog_update_controls(&controls, args);
