@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: arithmetic.c 19216 2016-11-09 10:39:06Z yeti-dn $
+ *  @(#) $Id: arithmetic.c 19948 2017-06-22 14:05:41Z yeti-dn $
  *  Copyright (C) 2003-2013 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
@@ -144,7 +144,7 @@ static GwyModuleInfo module_info = {
     "2004",
 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, arithmetic)
 
 static gboolean
 module_register(void)
@@ -270,7 +270,7 @@ arithmetic_dialog(GwyContainer *data,
     label = gtk_label_new_with_mnemonic(_("_Expression:"));
     gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
     gtk_table_attach(GTK_TABLE(table), label, 0, 2, row, row+1,
-                     GTK_EXPAND | GTK_FILL, 0, 0, 0);
+                     GTK_FILL, 0, 0, 0);
     row++;
 
     entry = gtk_combo_box_entry_new_with_model(args->history, 0);
@@ -285,22 +285,22 @@ arithmetic_dialog(GwyContainer *data,
     gtk_label_set_mnemonic_widget(GTK_LABEL(label), entry);
     row++;
 
-    controls.result = label = gtk_label_new("");
+    controls.result = label = gtk_label_new(NULL);
     gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
     gtk_table_attach(GTK_TABLE(table), label, 0, 2, row, row+1,
-                     GTK_EXPAND | GTK_FILL, 0, 0, 0);
+                     GTK_FILL, 0, 0, 0);
     row++;
 
     gtk_table_set_row_spacing(GTK_TABLE(table), row-1, 8);
     label = gtk_label_new(_("Operands"));
     gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
     gtk_table_attach(GTK_TABLE(table), label, 0, 2, row, row+1,
-                     GTK_EXPAND | GTK_FILL, 0, 0, 0);
+                     GTK_FILL, 0, 0, 0);
 
     label = gtk_label_new(_("Units"));
     gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
     gtk_table_attach(GTK_TABLE(table), label, 2, 3, row, row+1,
-                     GTK_EXPAND | GTK_FILL, 0, 0, 0);
+                     GTK_FILL, 0, 0, 0);
     row++;
 
     controls.dataunits = NULL;
@@ -311,7 +311,7 @@ arithmetic_dialog(GwyContainer *data,
         gwy_strkill(args->name[i], "_");
         gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
         gtk_table_attach(GTK_TABLE(table), label, 0, 1, row, row+1,
-                         GTK_EXPAND | GTK_FILL, 0, 0, 0);
+                         GTK_FILL, 0, 0, 0);
 
         args->name[NARGS*ARITHMETIC_MASK + i] = g_strdup_printf("m%d", i+1);
         args->name[NARGS*ARITHMETIC_DER_X + i] = g_strdup_printf("bx%d", i+1);
@@ -348,7 +348,7 @@ arithmetic_dialog(GwyContainer *data,
 
     hbox2 = gtk_hbox_new(FALSE, 6);
     gtk_table_attach(GTK_TABLE(table), hbox2, 0, 2, row, row+1,
-                     GTK_EXPAND | GTK_FILL, 0, 0, 0);
+                     GTK_FILL, 0, 0, 0);
 
     label = gtk_label_new_with_mnemonic(_("Specify un_its:"));
     gtk_box_pack_start(GTK_BOX(hbox2), label, FALSE, FALSE, 0);
