@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: averaging.c 18234 2016-01-27 14:57:31Z yeti-dn $
+ *  @(#) $Id: averaging.c 19948 2017-06-22 14:05:41Z yeti-dn $
  *  Copyright (C) 2011, David Necas (Yeti), Petr Klapetek, Daniil Bratashov
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net, dn2010@gmail.com
  *
@@ -57,7 +57,7 @@ static GwyModuleInfo module_info = {
     "2011",
 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, averaging)
 
 static gboolean
 module_register(void)
