@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: basicops.c 18937 2016-09-09 09:04:59Z yeti-dn $
+ *  @(#) $Id: basicops.c 19948 2017-06-22 14:05:41Z yeti-dn $
  *  Copyright (C) 2003-2004 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -58,7 +58,7 @@ static GwyModuleInfo module_info = {
     "2003",
 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, basicops)
 
 static gboolean
 module_register(void)
@@ -116,7 +116,7 @@ module_register(void)
     gwy_process_func_register("null_offsets",
                               (GwyProcessFunc)&null_offsets,
                               N_("/_Basic Operations/_Null Offsets"),
-                              NULL,
+                              GWY_STOCK_NULL_OFFSETS,
                               BASICOPS_RUN_MODES,
                               GWY_MENU_FLAG_DATA,
                               N_("Null horizontal offsets, moving the origin "
