@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: bdep_synth.c 19044 2016-10-08 19:10:46Z yeti-dn $
+ *  @(#) $Id: bdep_synth.c 19948 2017-06-22 14:05:41Z yeti-dn $
  *  Copyright (C) 2015 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
@@ -149,19 +149,19 @@ static GwyModuleInfo module_info = {
     &module_register,
     N_("Generates surfaces by ballistic deposition."),
     "Yeti <yeti@gwyddion.net>",
-    "1.1",
+    "1.2",
     "David Nečas (Yeti)",
     "2015",
 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, bdep_synth)
 
 static gboolean
 module_register(void)
 {
     gwy_process_func_register("bdep_synth",
                               (GwyProcessFunc)&bdep_synth,
-                              N_("/S_ynthetic/_Ballistic..."),
+                              N_("/S_ynthetic/_Deposition/_Ballistic..."),
                               GWY_STOCK_SYNTHETIC_BALLISTIC_DEPOSITION,
                               BDEP_SYNTH_RUN_MODES,
                               0,
@@ -406,7 +406,7 @@ bdep_synth_dialog(BDepSynthArgs *args,
                              gwy_dimensions_get_widget(controls.dims),
                              gtk_label_new(_("Dimensions")));
 
-    table = gtk_table_new(4 + (dfield_template ? 1 : 0), 4, FALSE);
+    table = gtk_table_new(4 + (dfield_template ? 1 : 0), 3, FALSE);
     /* This is used only for synt.h helpers. */
     controls.table = GTK_TABLE(table);
     gtk_table_set_row_spacings(GTK_TABLE(table), 2);
@@ -419,7 +419,7 @@ bdep_synth_dialog(BDepSynthArgs *args,
     controls.coverage = gtk_adjustment_new(args->coverage,
                                            0.01, 10000.0, 0.01, 1.0, 0);
     g_object_set_data(G_OBJECT(controls.coverage), "target", &args->coverage);
-    gwy_table_attach_hscale(table, row, _("Co_verage:"), NULL,
+    gwy_table_attach_adjbar(table, row, _("Co_verage:"), NULL,
                             controls.coverage, GWY_HSCALE_LOG);
     g_signal_connect_swapped(controls.coverage, "value-changed",
                              G_CALLBACK(gwy_synth_double_changed), &controls);
@@ -431,11 +431,11 @@ bdep_synth_dialog(BDepSynthArgs *args,
 
     if (dfield_template) {
         controls.height_init
-            = gtk_button_new_with_mnemonic(_("_Like Current Channel"));
+            = gtk_button_new_with_mnemonic(_("_Like Current Image"));
         g_signal_connect_swapped(controls.height_init, "clicked",
                                  G_CALLBACK(height_init_clicked), &controls);
         gtk_table_attach(GTK_TABLE(table), controls.height_init,
-                         1, 3, row, row+1, GTK_FILL, 0, 0, 0);
+                         0, 2, row, row+1, GTK_FILL, 0, 0, 0);
         row++;
     }
 
@@ -443,7 +443,7 @@ bdep_synth_dialog(BDepSynthArgs *args,
                                     &controls.height_noise,
                                     &args->height_noise);
 
-    table = gtk_table_new(1 + GRAPH_NFLAGS, 4, FALSE);
+    table = gtk_table_new(1 + GRAPH_NFLAGS, 3, FALSE);
     /* This is used only for synt.h helpers. */
     controls.table = GTK_TABLE(table);
     gtk_table_set_row_spacings(GTK_TABLE(table), 2);
@@ -456,7 +456,7 @@ bdep_synth_dialog(BDepSynthArgs *args,
     label = gtk_label_new(_("Plot graphs:"));
     gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
     gtk_table_attach(GTK_TABLE(table), label,
-                     0, 3, row, row+1, GTK_FILL, 0, 0, 0);
+                     0, 2, row, row+1, GTK_FILL, 0, 0, 0);
     row++;
 
     for (i = 0; i < GRAPH_NFLAGS; i++) {
