@@ -173,7 +173,7 @@ static GwyModuleInfo module_info = {
     "2010",
 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, calcoefs_simple)
 
 static gboolean
 module_register(void)
