@@ -240,7 +240,7 @@ static GwyModuleInfo module_info = {
     "2010",
 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, calcoefs_view)
 
 static gboolean
 module_register(void)
