@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: calibrate.c 18537 2016-03-28 18:11:19Z yeti-dn $
+ *  @(#) $Id: calibrate.c 19967 2017-06-23 20:54:47Z yeti-dn $
  *  Copyright (C) 2003-2013 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -77,10 +77,6 @@ typedef struct {
     GtkObject *xratio;
     GtkObject *yratio;
     GtkObject *zratio;
-    GtkWidget *xratio_spin;
-    GtkWidget *xratio_label;
-    GtkWidget *yratio_spin;
-    GtkWidget *yratio_label;
     GtkWidget *match_size;
     GtkWidget *size_chooser;
     GtkWidget *xyexponent;
@@ -93,10 +89,6 @@ typedef struct {
     GtkObject *xreal;
     GtkObject *yreal;
     GtkObject *zreal;
-    GtkWidget *xreal_spin;
-    GtkWidget *xreal_label;
-    GtkWidget *yreal_spin;
-    GtkWidget *yreal_label;
     GtkObject *x0;
     GtkObject *y0;
     GtkObject *zshift;
@@ -179,12 +171,12 @@ static GwyModuleInfo module_info = {
     &module_register,
     N_("Recalibrates scan lateral dimensions or value range."),
     "Petr Klapetek <klapetek@gwyddion.net>",
-    "2.14",
+    "2.16",
     "David Nečas (Yeti) & Petr Klapetek",
     "2003",
 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, calibrate)
 
 static gboolean
 module_register(void)
@@ -381,7 +373,7 @@ static gboolean
 calibrate_dialog(CalibrateArgs *args,
                  GwyDataField *dfield)
 {
-    GtkWidget *dialog, *spin, *table, *label;
+    GtkWidget *dialog, *spin, *table, *label, *hbox;
     GwyDataChooser *chooser;
     GwySIUnit *unit;
     CalibrateControls controls;
@@ -408,211 +400,173 @@ calibrate_dialog(CalibrateArgs *args,
     row = 0;
 
     /***** New Real Dimensions *****/
-    label = gwy_label_new_header(_("New Real Dimensions"));
-    gtk_table_attach(GTK_TABLE(table), label,
-                     0, 3, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
-    row++;
 
-    controls.match_size
-        = gtk_check_button_new_with_mnemonic(_("_Match pixel size:"));
-    gtk_table_attach(GTK_TABLE(table), controls.match_size,
-                     0, 1, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
-    g_signal_connect(controls.match_size, "toggled",
-                     G_CALLBACK(match_size_changed), &controls);
+    gtk_table_attach(GTK_TABLE(table),
+                     gwy_label_new_header(_("New Real Dimensions")),
+                     0, 3, row, row+1, GTK_FILL, 0, 0, 0);
+    row++;
 
     controls.size_chooser = gwy_data_chooser_new_channels();
     chooser = GWY_DATA_CHOOSER(controls.size_chooser);
-    gtk_widget_set_sensitive(controls.size_chooser, FALSE);
     gwy_data_chooser_set_filter(chooser, mould_filter, &args->targetid, NULL);
     if (!gwy_data_chooser_set_active_id(chooser, &args->sizeid))
         args->match_size = FALSE;
 
+    gwy_table_attach_adjbar(table, row, _("_Match pixel size:"), NULL,
+                            GTK_OBJECT(controls.size_chooser),
+                            GWY_HSCALE_CHECK | GWY_HSCALE_WIDGET_NO_EXPAND);
+    controls.match_size
+        = gwy_table_hscale_get_check(GTK_OBJECT(controls.size_chooser));
+    g_signal_connect(controls.match_size, "toggled",
+                     G_CALLBACK(match_size_changed), &controls);
+
     if (gwy_data_chooser_get_active(chooser, NULL)) {
+        /* XXX: Extend the chooser one column to the right.  Dirty. */
+        if ((hbox = gtk_widget_get_parent(controls.size_chooser))
+            && GTK_IS_HBOX(hbox)) {
+            gtk_container_child_set(GTK_CONTAINER(table), hbox,
+                                    "right-attach", 3,
+                                    NULL);
+        }
         g_signal_connect(controls.size_chooser, "changed",
                          G_CALLBACK(size_channel_changed), &controls);
     }
     else {
-        gtk_widget_set_sensitive(controls.match_size, FALSE);
+        gwy_table_hscale_set_sensitive(GTK_OBJECT(controls.size_chooser),
+                                       FALSE);
         gtk_widget_set_no_show_all(controls.match_size, TRUE);
         gtk_widget_set_no_show_all(controls.size_chooser, TRUE);
         args->match_size = FALSE;
     }
-    gtk_table_attach_defaults(GTK_TABLE(table), controls.size_chooser,
-                              1, 3, row, row+1);
+    gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(controls.match_size),
+                                 args->match_size);
     row++;
 
-    label = gtk_label_new_with_mnemonic(_("_X range:"));
-    controls.xreal_label = label;
-    gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
-    gtk_table_attach(GTK_TABLE(table), label,
-                     0, 1, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
-
     controls.xreal = gtk_adjustment_new(args->xreal/pow10(args->xyexponent),
                                         0.01, 10000, 1, 10, 0);
-    spin = gtk_spin_button_new(GTK_ADJUSTMENT(controls.xreal), 1, 2);
-    controls.xreal_spin = spin;
-    gtk_spin_button_set_numeric(GTK_SPIN_BUTTON(spin), TRUE);
-    gtk_table_attach(GTK_TABLE(table), spin,
-                     1, 2, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
+    spin = gwy_table_attach_adjbar(table, row, _("_X range:"), NULL,
+                                   controls.xreal, GWY_HSCALE_LOG);
+    gtk_spin_button_set_digits(GTK_SPIN_BUTTON(spin), 3);
 
     unit = gwy_data_field_get_si_unit_xy(dfield);
     controls.xyexponent
         = gwy_combo_box_metric_unit_new(G_CALLBACK(xyexponent_changed),
                                         &controls, -15, 6, unit,
                                         args->xyexponent);
-    gtk_table_attach(GTK_TABLE(table), controls.xyexponent, 2, 3, row, row+2,
-                     GTK_EXPAND | GTK_FILL | GTK_SHRINK, 0, 0, 0);
+    gtk_table_attach(GTK_TABLE(table), controls.xyexponent,
+                     2, 3, row, row+2, GTK_FILL | GTK_SHRINK, 0, 0, 0);
 
     controls.xyunits = gtk_button_new_with_label(gwy_sgettext("verb|Change"));
     g_object_set_data(G_OBJECT(controls.xyunits), "id", (gpointer)"xy");
     gtk_table_attach(GTK_TABLE(table), controls.xyunits,
-                     3, 4, row, row+2,
-                     GTK_EXPAND | GTK_FILL | GTK_SHRINK, 0, 0, 0);
+                     3, 4, row, row+2, GTK_FILL | GTK_SHRINK, 0, 0, 0);
     row++;
 
-    label = gtk_label_new_with_mnemonic(_("_Y range:"));
-    controls.yreal_label = label;
-    gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
-    gtk_table_attach(GTK_TABLE(table), label,
-                     0, 1, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
-
     controls.yreal = gtk_adjustment_new(args->yreal/pow10(args->xyexponent),
                                         0.01, 10000, 1, 10, 0);
-    spin = gtk_spin_button_new(GTK_ADJUSTMENT(controls.yreal), 1, 2);
-    controls.yreal_spin = spin;
-    gtk_spin_button_set_numeric(GTK_SPIN_BUTTON(spin), TRUE);
-    gtk_table_attach(GTK_TABLE(table), spin,
-                     1, 2, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
+    spin = gwy_table_attach_adjbar(table, row, _("_Y range:"), NULL,
+                                   controls.yreal, GWY_HSCALE_LOG);
+    gtk_spin_button_set_digits(GTK_SPIN_BUTTON(spin), 3);
     row++;
 
-    controls.square
-        = gtk_check_button_new_with_mnemonic(_("_Square samples"));
+    controls.square = gtk_check_button_new_with_mnemonic(_("_Square samples"));
     gtk_table_attach(GTK_TABLE(table), controls.square,
-                     0, 3, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
+                     0, 2, row, row+1, GTK_FILL, 0, 0, 0);
     row++;
 
     /***** Lateral Offsets *****/
 
-    label = gtk_label_new_with_mnemonic(_("_X offset:"));
-    gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
-    gtk_table_attach(GTK_TABLE(table), label,
-                     0, 1, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
-
     controls.x0 = gtk_adjustment_new(args->x0/pow10(args->xyexponent),
                                      -10000, 10000, 1, 10, 0);
-    spin = gtk_spin_button_new(GTK_ADJUSTMENT(controls.x0), 1, 2);
-    gtk_spin_button_set_numeric(GTK_SPIN_BUTTON(spin), TRUE);
-    gtk_table_attach(GTK_TABLE(table), spin,
-                     1, 2, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
+    spin = gwy_table_attach_adjbar(table, row, _("_X offset:"), NULL,
+                                   controls.x0, GWY_HSCALE_SQRT);
+    gtk_spin_button_set_digits(GTK_SPIN_BUTTON(spin), 2);
     row++;
 
-    label = gtk_label_new_with_mnemonic(_("_Y offset:"));
-    gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
-    gtk_table_attach(GTK_TABLE(table), label,
-                     0, 1, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
-
     controls.y0 = gtk_adjustment_new(args->y0/pow10(args->xyexponent),
                                      -10000, 10000, 1, 10, 0);
-    spin = gtk_spin_button_new(GTK_ADJUSTMENT(controls.y0), 1, 2);
-    gtk_spin_button_set_numeric(GTK_SPIN_BUTTON(spin), TRUE);
-    gtk_table_attach(GTK_TABLE(table), spin,
-                     1, 2, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
-    gtk_table_set_row_spacing(GTK_TABLE(table), row, 8);
+    spin = gwy_table_attach_adjbar(table, row, _("_Y offset:"), NULL,
+                                   controls.y0, GWY_HSCALE_SQRT);
+    gtk_spin_button_set_digits(GTK_SPIN_BUTTON(spin), 2);
     row++;
 
     /***** Value Range *****/
-    label = gwy_label_new_header(_("Value Range"));
-    gtk_table_attach(GTK_TABLE(table), label,
-                     0, 3, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
+
+    gtk_table_set_row_spacing(GTK_TABLE(table), row-1, 8);
+    gtk_table_attach(GTK_TABLE(table), gwy_label_new_header(_("Value Range")),
+                     0, 2, row, row+1, GTK_FILL, 0, 0, 0);
     row++;
 
-    label = gtk_label_new_with_mnemonic(_("_Z range:"));
-    gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
-    gtk_table_attach(GTK_TABLE(table), label,
-                     0, 1, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
-
-    controls.zreal = gtk_adjustment_new(args->zreal/pow10(args->zexponent),
-                                        -10000, 10000, 1, 10, 0);
-    spin = gtk_spin_button_new(GTK_ADJUSTMENT(controls.zreal), 1, 2);
-    gtk_spin_button_set_numeric(GTK_SPIN_BUTTON(spin), TRUE);
-    gtk_table_attach(GTK_TABLE(table), spin,
-                     1, 2, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
+    controls.zreal = gtk_adjustment_new(args->zreal/pow10(args->xyexponent),
+                                     -10000, 10000, 1, 10, 0);
+    spin = gwy_table_attach_adjbar(table, row, _("_Z range:"), NULL,
+                                   controls.zreal, GWY_HSCALE_SQRT);
+    gtk_spin_button_set_digits(GTK_SPIN_BUTTON(spin), 2);
 
     unit = gwy_data_field_get_si_unit_z(dfield);
     controls.zexponent
         = gwy_combo_box_metric_unit_new(G_CALLBACK(zexponent_changed),
                                         &controls, -15, 6, unit,
                                         args->zexponent);
-    gtk_table_attach(GTK_TABLE(table), controls.zexponent, 2, 3, row, row+1,
-                     GTK_EXPAND | GTK_FILL | GTK_SHRINK, 0, 0, 0);
+    gtk_table_attach(GTK_TABLE(table), controls.zexponent,
+                     2, 3, row, row+1, GTK_FILL | GTK_SHRINK, 0, 0, 0);
 
     controls.zunits = gtk_button_new_with_label(gwy_sgettext("verb|Change"));
     g_object_set_data(G_OBJECT(controls.zunits), "id", (gpointer)"z");
     gtk_table_attach(GTK_TABLE(table), controls.zunits,
-                     3, 4, row, row+1,
-                     GTK_EXPAND | GTK_FILL | GTK_SHRINK, 0, 0, 0);
+                     3, 4, row, row+1, GTK_FILL | GTK_SHRINK, 0, 0, 0);
     row++;
 
     /***** Value Shift *****/
 
-    label = gtk_label_new_with_mnemonic(_("Z shi_ft:"));
-    gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
-    gtk_table_attach(GTK_TABLE(table), label,
-                     0, 1, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
-
-    controls.zshift = gtk_adjustment_new(args->zshift/pow10(args->zexponent),
-                                         -10000, 10000, 1, 10, 0);
-    spin = gtk_spin_button_new(GTK_ADJUSTMENT(controls.zshift), 1, 2);
-    gtk_spin_button_set_numeric(GTK_SPIN_BUTTON(spin), TRUE);
-    gtk_table_attach(GTK_TABLE(table), spin,
-                     1, 2, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
-    gtk_table_set_row_spacing(GTK_TABLE(table), row, 8);
+    controls.zshift = gtk_adjustment_new(args->zshift/pow10(args->xyexponent),
+                                     -10000, 10000, 1, 10, 0);
+    spin = gwy_table_attach_adjbar(table, row, _("Z shi_ft:"), NULL,
+                                   controls.zshift, GWY_HSCALE_SQRT);
+    gtk_spin_button_set_digits(GTK_SPIN_BUTTON(spin), 2);
     row++;
 
     /***** Calibration Coefficients *****/
-    label = gwy_label_new_header(_("Calibration Coefficients"));
-    gtk_table_attach(GTK_TABLE(table), label,
-                     0, 3, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
+
+    gtk_table_set_row_spacing(GTK_TABLE(table), row-1, 8);
+    gtk_table_attach(GTK_TABLE(table),
+                     gwy_label_new_header(_("Calibration Coefficients")),
+                     0, 2, row, row+1, GTK_FILL, 0, 0, 0);
     row++;
 
     controls.xratio = gtk_adjustment_new(args->xratio, 0.001, 1000, 0.1, 1, 0);
-    spin = gwy_table_attach_spinbutton(table, row,
-                                       _("_X calibration factor:"), "",
-                                       controls.xratio);
-    controls.xratio_spin = spin;
-    controls.xratio_label = gwy_table_get_child_widget(table, row, 0);
-    controls.xpower10 = gwy_table_get_child_widget(table, row, 2);
+    spin = gwy_table_attach_adjbar(table, row, _("_X calibration factor:"), " ",
+                                   controls.xratio, GWY_HSCALE_LOG);
     gtk_spin_button_set_digits(GTK_SPIN_BUTTON(spin), 3);
+    controls.xpower10 = gwy_table_hscale_get_units(controls.xratio);
     row++;
 
     controls.yratio = gtk_adjustment_new(args->yratio, 0.001, 1000, 0.1, 1, 0);
-    spin = gwy_table_attach_spinbutton(table, row,
-                                       _("_Y calibration factor:"), "",
-                                       controls.yratio);
-    controls.yratio_spin = spin;
-    controls.yratio_label = gwy_table_get_child_widget(table, row, 0);
-    controls.ypower10 = gwy_table_get_child_widget(table, row, 2);
+    spin = gwy_table_attach_adjbar(table, row, _("_Y calibration factor:"), " ",
+                                   controls.yratio, GWY_HSCALE_LOG);
     gtk_spin_button_set_digits(GTK_SPIN_BUTTON(spin), 3);
+    controls.ypower10 = gwy_table_hscale_get_units(controls.yratio);
     row++;
 
     controls.zratio = gtk_adjustment_new(args->zratio, -1000, 1000, 0.1, 1, 0);
-    spin = gwy_table_attach_spinbutton(table, row,
-                                       _("_Z calibration factor:"), "",
-                                       controls.zratio);
-    controls.zpower10 = gwy_table_get_child_widget(table, row, 2);
+    spin = gwy_table_attach_adjbar(table, row, _("_Z calibration factor:"), " ",
+                                   controls.zratio, GWY_HSCALE_SQRT);
     gtk_spin_button_set_digits(GTK_SPIN_BUTTON(spin), 3);
+    controls.zpower10 = gwy_table_hscale_get_units(controls.zratio);
     row++;
 
     /***** Options *****/
+
+    gtk_table_set_row_spacing(GTK_TABLE(table), row-1, 8);
     label = gwy_label_new_header(_("Options"));
     gtk_table_attach(GTK_TABLE(table), label,
-                     0, 3, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
+                     0, 2, row, row+1, GTK_FILL, 0, 0, 0);
     row++;
 
     controls.new_channel
-        = gtk_check_button_new_with_mnemonic(_("Create new channel"));
+        = gtk_check_button_new_with_mnemonic(_("Create new image"));
     gtk_table_attach(GTK_TABLE(table), controls.new_channel,
-                     0, 3, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
+                     0, 2, row, row+1, GTK_FILL, 0, 0, 0);
     row++;
 
     g_signal_connect(controls.xreal, "value-changed",
@@ -718,6 +672,12 @@ dialog_reset(CalibrateControls *controls,
                              calibrate_defaults.zshift);
 
     calibrate_dialog_update(controls, args);
+
+    args->zreal = args->zorig;
+    args->xreal = args->xorig;
+    args->yreal = args->yorig;
+    args->x0 = args->x0orig;
+    args->y0 = args->y0orig;
 }
 
 static void
@@ -725,13 +685,22 @@ xratio_changed(GtkAdjustment *adj,
                CalibrateControls *controls)
 {
     CalibrateArgs *args = controls->args;
+    gdouble newratio;
 
     if (controls->in_update)
         return;
 
     controls->in_update = TRUE;
-    args->xratio = gtk_adjustment_get_value(adj)
-                   * pow10(args->xyexponent - args->xyorigexp);
+    newratio = gtk_adjustment_get_value(adj) * pow10(args->xyexponent
+                                                     - args->xyorigexp);
+    /* XXX: Sometimes a strange infinite update cycle far in non-significant
+     * digits can occur.  Not sure why. */
+    if (fabs(log(newratio/args->xratio)) < 1e-8) {
+        controls->in_update = FALSE;
+        return;
+    }
+
+    args->xratio = newratio;
     args->xreal = args->xratio * args->xorig;
     if (args->square) {
         args->yreal = args->xreal/args->xres * args->yres;
@@ -746,13 +715,22 @@ yratio_changed(GtkAdjustment *adj,
                CalibrateControls *controls)
 {
     CalibrateArgs *args = controls->args;
+    gdouble newratio;
 
     if (controls->in_update)
         return;
 
     controls->in_update = TRUE;
-    args->yratio = gtk_adjustment_get_value(adj)
-                   * pow10(args->xyexponent - args->xyorigexp);
+    newratio = gtk_adjustment_get_value(adj) * pow10(args->xyexponent
+                                                     - args->xyorigexp);
+    /* XXX: Sometimes a strange infinite update cycle far in non-significant
+     * digits can occur.  Not sure why. */
+    if (fabs(log(newratio/args->yratio)) < 1e-8) {
+        controls->in_update = FALSE;
+        return;
+    }
+
+    args->yratio = newratio;
     args->yreal = args->yratio * args->yorig;
     if (args->square) {
         args->xreal = args->yreal/args->yres * args->xres;
@@ -767,16 +745,23 @@ zratio_changed(GtkAdjustment *adj,
                CalibrateControls *controls)
 {
     CalibrateArgs *args = controls->args;
+    gdouble newratio;
 
     if (controls->in_update)
         return;
 
     controls->in_update = TRUE;
-    args->zratio = gtk_adjustment_get_value(adj)
-                   * pow10(args->zexponent - args->zorigexp);
+    newratio = gtk_adjustment_get_value(adj) * pow10(args->zexponent
+                                                     - args->zorigexp);
+    /* XXX: Sometimes a strange infinite update cycle far in non-significant
+     * digits can occur.  Not sure why. */
+    if (fabs(log(newratio/args->zratio)) < 1e-8) {
+        controls->in_update = FALSE;
+        return;
+    }
 
+    args->zratio = newratio;
     args->zreal = args->zratio * args->zorig;
-
     calibrate_dialog_update(controls, args);
     controls->in_update = FALSE;
 }
@@ -786,12 +771,21 @@ xreal_changed(GtkAdjustment *adj,
               CalibrateControls *controls)
 {
     CalibrateArgs *args = controls->args;
+    gdouble newxreal;
 
     if (controls->in_update)
         return;
 
     controls->in_update = TRUE;
-    args->xreal = gtk_adjustment_get_value(adj) * pow10(args->xyexponent);
+    newxreal = gtk_adjustment_get_value(adj) * pow10(args->xyexponent);
+    /* XXX: Sometimes a strange infinite update cycle far in non-significant
+     * digits can occur.  Not sure why. */
+    if (fabs(log(newxreal/args->xreal)) < 1e-8) {
+        controls->in_update = FALSE;
+        return;
+    }
+
+    args->xreal = newxreal;
     args->xratio = args->xreal/args->xorig;
     if (args->square) {
         args->yreal = args->xreal/args->xres * args->yres;
@@ -807,13 +801,21 @@ yreal_changed(GtkAdjustment *adj,
               CalibrateControls *controls)
 {
     CalibrateArgs *args = controls->args;
+    gdouble newyreal;
 
     if (controls->in_update)
         return;
 
     controls->in_update = TRUE;
+    newyreal = gtk_adjustment_get_value(adj) * pow10(args->xyexponent);
+    /* XXX: Sometimes a strange infinite update cycle far in non-significant
+     * digits can occur.  Not sure why. */
+    if (fabs(log(newyreal/args->yreal)) < 1e-8) {
+        controls->in_update = FALSE;
+        return;
+    }
 
-    args->yreal = gtk_adjustment_get_value(adj) * pow10(args->xyexponent);
+    args->yreal = newyreal;
     args->yratio = args->yreal/args->yorig;
     if (args->square) {
         args->xreal = args->yreal/args->yres * args->xres;
@@ -828,15 +830,23 @@ x0_changed(GtkAdjustment *adj,
            CalibrateControls *controls)
 {
     CalibrateArgs *args = controls->args;
+    gdouble newx0;
 
     if (controls->in_update)
         return;
 
     controls->in_update = TRUE;
-    args->x0 = gtk_adjustment_get_value(adj) * pow10(args->xyexponent);
+    newx0 = gtk_adjustment_get_value(adj) * pow10(args->xyexponent);
+    /* XXX: Sometimes a strange infinite update cycle far in non-significant
+     * digits can occur.  Not sure why. */
+    if (newx0 == args->x0 || fabs(log(newx0/args->x0)) < 1e-8) {
+        controls->in_update = FALSE;
+        return;
+    }
+
+    args->x0 = newx0;
     calibrate_dialog_update(controls, args);
     controls->in_update = FALSE;
-
 }
 
 static void
@@ -844,13 +854,21 @@ y0_changed(GtkAdjustment *adj,
            CalibrateControls *controls)
 {
     CalibrateArgs *args = controls->args;
+    gdouble newy0;
 
     if (controls->in_update)
         return;
 
     controls->in_update = TRUE;
+    newy0 = gtk_adjustment_get_value(adj) * pow10(args->xyexponent);
+    /* XXX: Sometimes a strange infinite update cycle far in non-significant
+     * digits can occur.  Not sure why. */
+    if (newy0 == args->y0 || fabs(log(newy0/args->y0)) < 1e-8) {
+        controls->in_update = FALSE;
+        return;
+    }
 
-    args->y0 = gtk_adjustment_get_value(adj) * pow10(args->xyexponent);
+    args->y0 = newy0;
     calibrate_dialog_update(controls, args);
     controls->in_update = FALSE;
 }
@@ -860,13 +878,21 @@ zshift_changed(GtkAdjustment *adj,
                CalibrateControls *controls)
 {
     CalibrateArgs *args = controls->args;
+    gdouble newzshift;
 
     if (controls->in_update)
         return;
 
     controls->in_update = TRUE;
+    newzshift = gtk_adjustment_get_value(adj) * pow10(args->zexponent);
+    /* XXX: Sometimes a strange infinite update cycle far in non-significant
+     * digits can occur.  Not sure why. */
+    if (newzshift == args->zshift || fabs(log(newzshift/args->zshift)) < 1e-8) {
+        controls->in_update = FALSE;
+        return;
+    }
 
-    args->zshift = gtk_adjustment_get_value(adj) * pow10(args->zexponent);
+    args->zshift = newzshift;
     calibrate_dialog_update(controls, args);
     controls->in_update = FALSE;
 }
@@ -876,13 +902,21 @@ zreal_changed(GtkAdjustment *adj,
               CalibrateControls *controls)
 {
     CalibrateArgs *args = controls->args;
+    gdouble newzreal;
 
     if (controls->in_update)
         return;
 
     controls->in_update = TRUE;
+    newzreal = gtk_adjustment_get_value(adj) * pow10(args->zexponent);
+    /* XXX: Sometimes a strange infinite update cycle far in non-significant
+     * digits can occur.  Not sure why. */
+    if (fabs(log(newzreal/args->zreal)) < 1e-8) {
+        controls->in_update = FALSE;
+        return;
+    }
 
-    args->zreal = gtk_adjustment_get_value(adj) * pow10(args->zexponent);
+    args->zreal = newzreal;
     args->zratio = args->zreal/args->zorig;
     calibrate_dialog_update(controls, args);
     controls->in_update = FALSE;
@@ -1029,15 +1063,10 @@ match_size_changed(GtkToggleButton *toggle,
     gboolean matching = gtk_toggle_button_get_active(toggle);
 
     controls->args->match_size = matching;
-    gtk_widget_set_sensitive(controls->size_chooser, matching);
-    gtk_widget_set_sensitive(controls->xreal_spin, !matching);
-    gtk_widget_set_sensitive(controls->xreal_label, !matching);
-    gtk_widget_set_sensitive(controls->yreal_spin, !matching);
-    gtk_widget_set_sensitive(controls->yreal_label, !matching);
-    gtk_widget_set_sensitive(controls->xratio_spin, !matching);
-    gtk_widget_set_sensitive(controls->xratio_label, !matching);
-    gtk_widget_set_sensitive(controls->yratio_spin, !matching);
-    gtk_widget_set_sensitive(controls->yratio_label, !matching);
+    gwy_table_hscale_set_sensitive(controls->xreal, !matching);
+    gwy_table_hscale_set_sensitive(controls->yreal, !matching);
+    gwy_table_hscale_set_sensitive(controls->xratio, !matching);
+    gwy_table_hscale_set_sensitive(controls->yratio, !matching);
     gtk_widget_set_sensitive(controls->xyunits, !matching);
     gtk_widget_set_sensitive(controls->xyexponent, !matching);
     gtk_widget_set_sensitive(controls->square, !matching);
@@ -1046,9 +1075,10 @@ match_size_changed(GtkToggleButton *toggle,
     gtk_dialog_set_response_sensitive(GTK_DIALOG(controls->dialog),
                                       GTK_RESPONSE_OK, !matching);
 
-    if (matching)
+    if (matching) {
         size_channel_changed(GWY_DATA_CHOOSER(controls->size_chooser),
                              controls);
+    }
 }
 
 static void
