@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: coerce.c 19044 2016-10-08 19:10:46Z yeti-dn $
+ *  @(#) $Id: coerce.c 19948 2017-06-22 14:05:41Z yeti-dn $
  *  Copyright (C) 2016 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
@@ -163,7 +163,7 @@ static GwyModuleInfo module_info = {
     "2016",
 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, coerce)
 
 static gboolean
 module_register(void)
@@ -279,7 +279,7 @@ coerce_dialogue(CoerceArgs *args, GwyContainer *data, gint id)
     gtk_box_pack_start(GTK_BOX(vbox), controls.view, FALSE, FALSE, 0);
 
     table = gtk_table_new(COERCE_NDISTRIBUTIONS + COERCE_NPROCESSING + 6,
-                          4, FALSE);
+                          3, FALSE);
     gtk_table_set_row_spacings(GTK_TABLE(table), 2);
     gtk_table_set_col_spacings(GTK_TABLE(table), 6);
     gtk_container_set_border_width(GTK_CONTAINER(table), 4);
@@ -289,7 +289,7 @@ coerce_dialogue(CoerceArgs *args, GwyContainer *data, gint id)
     label = gtk_label_new(_("Coerce value distribution to:"));
     gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
     gtk_table_attach(GTK_TABLE(table), label,
-                     0, 3, row, row+1, GTK_FILL, 0, 0, 0);
+                     0, 2, row, row+1, GTK_FILL, 0, 0, 0);
     row++;
 
     controls.distribution
@@ -300,8 +300,8 @@ coerce_dialogue(CoerceArgs *args, GwyContainer *data, gint id)
         GtkWidget *widget = GTK_WIDGET(l->data);
         CoerceDistributionType dist = gwy_radio_button_get_value(widget);
 
-        gtk_table_attach(GTK_TABLE(table), widget, 0, 3, row, row + 1,
-                         GTK_EXPAND | GTK_FILL, 0, 0, 0);
+        gtk_table_attach(GTK_TABLE(table), widget, 0, 2, row, row + 1,
+                         GTK_FILL, 0, 0, 0);
         row++;
 
         if (dist == COERCE_DISTRIBUTION_DATA) {
@@ -312,9 +312,9 @@ coerce_dialogue(CoerceArgs *args, GwyContainer *data, gint id)
                                         &template_filter, dfield, NULL);
             gwy_data_chooser_set_active_id(chooser, &args->template);
             gwy_data_chooser_get_active_id(chooser, &args->template);
-            gwy_table_attach_hscale(table, row, _("_Template:"), NULL,
+            gwy_table_attach_adjbar(table, row, _("_Template:"), NULL,
                                     GTK_OBJECT(controls.template),
-                                    GWY_HSCALE_WIDGET);
+                                    GWY_HSCALE_WIDGET_NO_EXPAND);
             g_signal_connect(controls.template, "changed",
                              G_CALLBACK(template_changed), &controls);
             row++;
@@ -328,15 +328,15 @@ coerce_dialogue(CoerceArgs *args, GwyContainer *data, gint id)
                                           _("Same area"),
                                           COERCE_LEVELS_EQUIAREA,
                                           NULL);
-            gwy_table_attach_hscale(table, row, _("_Type:"), NULL,
+            gwy_table_attach_adjbar(table, row, _("_Type:"), NULL,
                                     GTK_OBJECT(controls.level_type),
-                                    GWY_HSCALE_WIDGET);
+                                    GWY_HSCALE_WIDGET_NO_EXPAND);
             row++;
 
             controls.nlevels = gtk_adjustment_new(args->nlevels,
                                                   2.0, 16384.0,
                                                   1.0, 100.0, 0.0);
-            gwy_table_attach_hscale(table, row, _("Number of _levels:"), NULL,
+            gwy_table_attach_adjbar(table, row, _("Number of _levels:"), NULL,
                                     controls.nlevels, GWY_HSCALE_LOG);
             g_signal_connect(controls.nlevels, "value-changed",
                              G_CALLBACK(nlevels_changed), &controls);
@@ -349,7 +349,7 @@ coerce_dialogue(CoerceArgs *args, GwyContainer *data, gint id)
     label = gtk_label_new(_("Data processing:"));
     gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
     gtk_table_attach(GTK_TABLE(table), label,
-                     0, 3, row, row+1, GTK_FILL, 0, 0, 0);
+                     0, 2, row, row+1, GTK_FILL, 0, 0, 0);
     row++;
 
     controls.processing
@@ -357,20 +357,19 @@ coerce_dialogue(CoerceArgs *args, GwyContainer *data, gint id)
                                    G_CALLBACK(processing_changed), &controls,
                                    args->processing);
     row = gwy_radio_buttons_attach_to_table(controls.processing,
-                                            GTK_TABLE(table),
-                                            3, row);
+                                            GTK_TABLE(table), 2, row);
 
     gtk_table_set_row_spacing(GTK_TABLE(table), row-1, 8);
     label = gwy_label_new_header(_("Options"));
     gtk_table_attach(GTK_TABLE(table), label,
-                     0, 3, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
+                     0, 2, row, row+1, GTK_FILL, 0, 0, 0);
     row++;
 
     controls.update = gtk_check_button_new_with_mnemonic(_("I_nstant updates"));
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(controls.update),
                                  args->update);
     gtk_table_attach(GTK_TABLE(table), controls.update,
-                     0, 3, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
+                     0, 2, row, row+1, GTK_FILL, 0, 0, 0);
     g_signal_connect(controls.update, "toggled",
                      G_CALLBACK(update_changed), &controls);
     row++;
