@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: col_synth.c 19124 2016-10-25 19:12:11Z yeti-dn $
+ *  @(#) $Id: col_synth.c 19948 2017-06-22 14:05:41Z yeti-dn $
  *  Copyright (C) 2014 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
@@ -198,14 +198,14 @@ static GwyModuleInfo module_info = {
     "2014",
 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, col_synth)
 
 static gboolean
 module_register(void)
 {
     gwy_process_func_register("col_synth",
                               (GwyProcessFunc)&col_synth,
-                              N_("/S_ynthetic/_Columnar..."),
+                              N_("/S_ynthetic/_Deposition/_Columnar..."),
                               GWY_STOCK_SYNTHETIC_COLUMNAR,
                               COL_SYNTH_RUN_MODES,
                               0,
@@ -457,7 +457,7 @@ col_synth_dialog(ColSynthArgs *args,
                              gwy_dimensions_get_widget(controls.dims),
                              gtk_label_new(_("Dimensions")));
 
-    table = gtk_table_new(20 + (dfield_template ? 1 : 0), 4, FALSE);
+    table = gtk_table_new(20 + (dfield_template ? 1 : 0), 3, FALSE);
     /* This is used only for synt.h helpers. */
     controls.table = GTK_TABLE(table);
     gtk_table_set_row_spacings(GTK_TABLE(table), 2);
@@ -470,7 +470,7 @@ col_synth_dialog(ColSynthArgs *args,
     controls.coverage = gtk_adjustment_new(args->coverage,
                                            0.001, 2000.0, 0.001, 1.0, 0);
     g_object_set_data(G_OBJECT(controls.coverage), "target", &args->coverage);
-    gwy_table_attach_hscale(table, row, _("Co_verage:"), NULL,
+    gwy_table_attach_adjbar(table, row, _("Co_verage:"), NULL,
                             controls.coverage, GWY_HSCALE_SQRT);
     g_signal_connect_swapped(controls.coverage, "value-changed",
                              G_CALLBACK(gwy_synth_double_changed), &controls);
@@ -478,12 +478,12 @@ col_synth_dialog(ColSynthArgs *args,
 
     gtk_table_set_row_spacing(GTK_TABLE(table), row-1, 8);
     gtk_table_attach(GTK_TABLE(table), gwy_label_new_header(_("Particle Size")),
-                     0, 3, row, row+1, GTK_FILL, 0, 0, 0);
+                     0, 2, row, row+1, GTK_FILL, 0, 0, 0);
     row++;
 
     controls.height = gtk_adjustment_new(args->height, 0.1, 10.0, 0.1, 1.0, 0);
     g_object_set_data(G_OBJECT(controls.height), "target", &args->height);
-    gwy_table_attach_hscale(table, row, _("_Height:"), "px",
+    gwy_table_attach_adjbar(table, row, _("_Height:"), _("px"),
                             controls.height, GWY_HSCALE_SQRT);
     g_signal_connect_swapped(controls.height, "value-changed",
                              G_CALLBACK(gwy_synth_double_changed), &controls);
@@ -496,7 +496,7 @@ col_synth_dialog(ColSynthArgs *args,
     gtk_table_set_row_spacing(GTK_TABLE(table), row-1, 8);
     gtk_table_attach(GTK_TABLE(table),
                      gwy_label_new_header(_("Incidence")),
-                     0, 3, row, row+1, GTK_FILL, 0, 0, 0);
+                     0, 2, row, row+1, GTK_FILL, 0, 0, 0);
     row++;
 
     row = gwy_synth_attach_angle(&controls, row, &controls.theta, &args->theta,
@@ -514,24 +514,25 @@ col_synth_dialog(ColSynthArgs *args,
     gtk_table_set_row_spacing(GTK_TABLE(table), row-1, 8);
     gtk_table_attach(GTK_TABLE(table),
                      gwy_label_new_header(_("Options")),
-                     0, 3, row, row+1, GTK_FILL, 0, 0, 0);
+                     0, 2, row, row+1, GTK_FILL, 0, 0, 0);
     row++;
 
     controls.relaxation = relaxation_selector_new(&controls);
-    gwy_table_attach_hscale(table, row, _("Relaxation type:"), NULL,
-                            GTK_OBJECT(controls.relaxation), GWY_HSCALE_WIDGET);
+    gwy_table_attach_adjbar(table, row, _("Relaxation type:"), NULL,
+                            GTK_OBJECT(controls.relaxation),
+                            GWY_HSCALE_WIDGET_NO_EXPAND);
     row++;
 
     controls.melting = gtk_adjustment_new(args->melting,
                                           0.0, 1.0, 0.0001, 0.01, 0);
     g_object_set_data(G_OBJECT(controls.melting), "target", &args->melting);
-    gwy_table_attach_hscale(table, row, _("_Melting:"), NULL,
+    gwy_table_attach_adjbar(table, row, _("_Melting:"), NULL,
                             controls.melting, GWY_HSCALE_SQRT);
     g_signal_connect_swapped(controls.melting, "value-changed",
                              G_CALLBACK(gwy_synth_double_changed), &controls);
     row++;
 
-    table = gtk_table_new(1 + GRAPH_NFLAGS, 4, FALSE);
+    table = gtk_table_new(1 + GRAPH_NFLAGS, 3, FALSE);
     /* This is used only for synt.h helpers. */
     controls.table = GTK_TABLE(table);
     gtk_table_set_row_spacings(GTK_TABLE(table), 2);
@@ -554,7 +555,7 @@ col_synth_dialog(ColSynthArgs *args,
         toggle = GTK_TOGGLE_BUTTON(controls.graph_flags[i]);
         gtk_toggle_button_set_active(toggle, args->graph_flags[i]);
         gtk_table_attach(GTK_TABLE(table), controls.graph_flags[i],
-                         0, 3, row, row+1, GTK_FILL, 0, 0, 0);
+                         0, 2, row, row+1, GTK_FILL, 0, 0, 0);
         g_signal_connect(toggle, "toggled",
                          G_CALLBACK(gwy_synth_boolean_changed_silent),
                          &args->graph_flags[i]);
