@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: convolution_filter.c 19216 2016-11-09 10:39:06Z yeti-dn $
+ *  @(#) $Id: convolution_filter.c 19948 2017-06-22 14:05:41Z yeti-dn $
  *  Copyright (C) 2003 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -136,7 +136,7 @@ static GwyModuleInfo module_info = {
     "2006",
 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, convolution_filter)
 
 static gboolean
 module_register(void)
@@ -347,7 +347,7 @@ convolution_filter_create_filter_tab(ConvolutionControls *controls)
     gtk_box_pack_start(GTK_BOX(hbox2), table, FALSE, FALSE, 0);
 
     gtk_table_attach(GTK_TABLE(table), gwy_label_new_header(_("Size")),
-                     0, 1, 0, 1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
+                     0, 1, 0, 1, GTK_FILL, 0, 0, 0);
     controls->sizes
         = gwy_radio_buttons_create(sizes, nsizes,
                                    G_CALLBACK(convolution_filter_size_changed),
@@ -390,7 +390,7 @@ convolution_filter_create_filter_tab(ConvolutionControls *controls)
 
     controls->divisor_auto = gtk_check_button_new_with_mnemonic(_("_automatic"));
     gtk_table_attach(GTK_TABLE(table), controls->divisor_auto,
-                     2, 3, 0, 1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
+                     2, 3, 0, 1, GTK_FILL, 0, 0, 0);
     g_signal_connect(controls->divisor_auto, "toggled",
                      G_CALLBACK(convolution_filter_autodiv_changed), controls);
 
