@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: crosscor.c 19089 2016-10-16 12:47:38Z yeti-dn $
+ *  @(#) $Id: crosscor.c 19948 2017-06-22 14:05:41Z yeti-dn $
  *  Copyright (C) 2004 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -156,12 +156,12 @@ static GwyModuleInfo module_info = {
     &module_register,
     N_("Calculates cross-correlation of two data fields."),
     "Petr Klapetek <klapetek@gwyddion.net>",
-    "1.10",
+    "1.11",
     "David Nečas (Yeti) & Petr Klapetek",
     "2004",
 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, crosscor)
 
 static gboolean
 module_register(void)
@@ -204,7 +204,7 @@ static gboolean
 crosscor_dialog(CrosscorArgs *args)
 {
     CrosscorControls controls;
-    GtkWidget *dialog, *table, *label, *combo, *button, *spin;
+    GtkWidget *dialog, *table, *label, *combo, *button;
     GwyDataChooser *chooser;
     gint row, response;
     gboolean ok = FALSE;
@@ -218,7 +218,7 @@ crosscor_dialog(CrosscorArgs *args)
     gtk_dialog_set_default_response(GTK_DIALOG(dialog), GTK_RESPONSE_OK);
     gwy_help_add_to_proc_dialog(GTK_DIALOG(dialog), GWY_HELP_DEFAULT);
 
-    table = gtk_table_new(9, 4, FALSE);
+    table = gtk_table_new(9, 3, FALSE);
     gtk_table_set_row_spacings(GTK_TABLE(table), 2);
     gtk_table_set_col_spacings(GTK_TABLE(table), 6);
     gtk_container_set_border_width(GTK_CONTAINER(table), 4);
@@ -235,113 +235,90 @@ crosscor_dialog(CrosscorArgs *args)
     g_signal_connect(chooser, "changed",
                      G_CALLBACK(crosscor_data_changed), &args->op2);
     crosscor_data_changed(chooser, &args->op2);
-    gwy_table_attach_hscale(table, row, _("Co_rrelate with:"), NULL,
-                            GTK_OBJECT(chooser), GWY_HSCALE_WIDGET);
-    gtk_table_set_row_spacing(GTK_TABLE(table), row, 8);
+    gwy_table_attach_adjbar(table, row, _("Co_rrelate with:"), NULL,
+                            GTK_OBJECT(chooser), GWY_HSCALE_WIDGET_NO_EXPAND);
     row++;
 
     /* Search size */
+    gtk_table_set_row_spacing(GTK_TABLE(table), row-1, 8);
     label = gtk_label_new(_("Search size"));
     gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
-    gtk_table_attach(GTK_TABLE(table), label, 0, 4, row, row+1,
-                     GTK_EXPAND | GTK_FILL, 0, 0, 0);
+    gtk_table_attach(GTK_TABLE(table), label, 0, 2, row, row+1,
+                     GTK_FILL, 0, 0, 0);
     row++;
 
     controls.search_area_x = gtk_adjustment_new(args->search_x,
                                                 0.0, 200.0, 1, 5, 0);
-    gwy_table_attach_hscale(table, row, _("_Width:"), "px",
-                            controls.search_area_x, 0);
-
+    gwy_table_attach_adjbar(table, row, _("_Width:"), _("px"),
+                            controls.search_area_x, GWY_HSCALE_SQRT);
     g_signal_connect(controls.search_area_x, "value-changed",
-                     G_CALLBACK(crosscor_update_areas_cb),
-                     &controls);
-
+                     G_CALLBACK(crosscor_update_areas_cb), &controls);
     row++;
 
     controls.search_area_y = gtk_adjustment_new(args->search_y,
                                                 0.0, 200.0, 1, 5, 0);
-    gwy_table_attach_hscale(table, row, _("H_eight:"), "px",
-                            controls.search_area_y, 0);
-    gtk_table_set_row_spacing(GTK_TABLE(table), row, 8);
+    gwy_table_attach_adjbar(table, row, _("H_eight:"), _("px"),
+                            controls.search_area_y, GWY_HSCALE_SQRT);
     g_signal_connect(controls.search_area_y, "value-changed",
-                     G_CALLBACK(crosscor_update_areas_cb),
-                     &controls);
-
+                     G_CALLBACK(crosscor_update_areas_cb), &controls);
     row++;
 
-    label = gtk_label_new(_("Global offset of 2nd channel"));
-    gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
-    gtk_table_attach(GTK_TABLE(table), label, 0, 2, row, row+1,
-                     GTK_EXPAND | GTK_FILL, 0, 0, 0);
-
+    gtk_table_set_row_spacing(GTK_TABLE(table), row-1, 8);
     button = gtk_button_new_with_mnemonic(_("_Guess"));
-    gtk_table_attach(GTK_TABLE(table), button, 2, 4, row, row+1,
-                     GTK_EXPAND | GTK_FILL, 0, 0, 0);
+    gwy_table_attach_adjbar(table, row, _("Global offset of 2nd channel"), NULL,
+                            GTK_OBJECT(button), GWY_HSCALE_WIDGET_NO_EXPAND);
     g_signal_connect_swapped(button, "clicked",
-                        G_CALLBACK(guess_offsets), &controls);
-
-
+                             G_CALLBACK(guess_offsets), &controls);
     row++;
 
-
     controls.search_area_xoffset = gtk_adjustment_new(args->search_xoffset,
                                                 -200.0, 200.0, 1, 5, 0);
-    gwy_table_attach_hscale(table, row, _("_X offset:"), "px",
-                            controls.search_area_xoffset, 0);
-
+    gwy_table_attach_adjbar(table, row, _("_X offset:"), _("px"),
+                            controls.search_area_xoffset, GWY_HSCALE_SQRT);
     g_signal_connect(controls.search_area_xoffset, "value-changed",
-                     G_CALLBACK(crosscor_update_areas_cb),
-                     &controls);
-
+                     G_CALLBACK(crosscor_update_areas_cb), &controls);
     row++;
 
     controls.search_area_yoffset = gtk_adjustment_new(args->search_yoffset,
                                                 -200.0, 200.0, 1, 5, 0);
-    gwy_table_attach_hscale(table, row, _("_Y offset:"), "px",
-                            controls.search_area_yoffset, 0);
-    gtk_table_set_row_spacing(GTK_TABLE(table), row, 8);
+    gwy_table_attach_adjbar(table, row, _("_Y offset:"), _("px"),
+                            controls.search_area_yoffset, GWY_HSCALE_SQRT);
     g_signal_connect(controls.search_area_yoffset, "value-changed",
-                     G_CALLBACK(crosscor_update_areas_cb),
-                     &controls);
-
+                     G_CALLBACK(crosscor_update_areas_cb), &controls);
     row++;
 
-
     /* Window size */
+    gtk_table_set_row_spacing(GTK_TABLE(table), row-1, 8);
     label = gtk_label_new(_("Window size"));
     gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
-    gtk_table_attach(GTK_TABLE(table), label, 0, 4, row, row+1,
-                     GTK_EXPAND | GTK_FILL, 0, 0, 0);
+    gtk_table_attach(GTK_TABLE(table), label, 0, 2, row, row+1,
+                     GTK_FILL, 0, 0, 0);
     row++;
 
     controls.window_area_x = gtk_adjustment_new(args->window_x,
                                                 0.0, 100.0, 1, 5, 0);
-    gwy_table_attach_hscale(table, row, _("W_idth:"), "px",
-                            controls.window_area_x, 0);
+    gwy_table_attach_adjbar(table, row, _("W_idth:"), _("px"),
+                            controls.window_area_x, GWY_HSCALE_SQRT);
     g_signal_connect(controls.window_area_x, "value-changed",
-                     G_CALLBACK(crosscor_update_areas_cb),
-                     &controls);
-
+                     G_CALLBACK(crosscor_update_areas_cb), &controls);
     row++;
 
     controls.window_area_y = gtk_adjustment_new(args->window_y,
                                                 0.0, 100.0, 1, 5, 0);
-    gwy_table_attach_hscale(table, row, _("Hei_ght:"), "px",
-                            controls.window_area_y, 0);
-    gtk_table_set_row_spacing(GTK_TABLE(table), row, 8);
+    gwy_table_attach_adjbar(table, row, _("Hei_ght:"), _("px"),
+                            controls.window_area_y, GWY_HSCALE_SQRT);
     g_signal_connect(controls.window_area_y, "value-changed",
-                     G_CALLBACK(crosscor_update_areas_cb),
-                     &controls);
+                     G_CALLBACK(crosscor_update_areas_cb), &controls);
     row++;
 
-
+    gtk_table_set_row_spacing(GTK_TABLE(table), row-1, 8);
     controls.window
         = gwy_enum_combo_box_new(gwy_windowing_type_get_enum(), -1,
                                  G_CALLBACK(gwy_enum_combo_box_update_int),
                                  &args->window, args->window, TRUE);
-    gwy_table_attach_hscale(table, row, _("_Windowing type:"), NULL,
+    gwy_table_attach_adjbar(table, row, _("_Windowing type:"), NULL,
                             GTK_OBJECT(controls.window),
-                            GWY_HSCALE_WIDGET);
+                            GWY_HSCALE_WIDGET_NO_EXPAND);
     row++;
 
     /* Result */
@@ -354,15 +331,15 @@ crosscor_dialog(CrosscorArgs *args)
                                     _("Angle"), GWY_CROSSCOR_DIR,
                                     _("Score"), GWY_CROSSCOR_SCORE,
                                     NULL);
-    gwy_table_attach_hscale(table, row, _("Output _type:"), NULL,
-                            GTK_OBJECT(combo), GWY_HSCALE_WIDGET);
+    gwy_table_attach_adjbar(table, row, _("Output _type:"), NULL,
+                            GTK_OBJECT(combo), GWY_HSCALE_WIDGET_NO_EXPAND);
     row++;
 
     /* Do mask of thresholds */
     controls.add_ls_mask = gtk_check_button_new_with_mnemonic
                                            (_("Add _low score results mask"));
-    gtk_table_attach(GTK_TABLE(table), controls.add_ls_mask, 0, 4, row, row+1,
-                     GTK_EXPAND | GTK_FILL, 0, 0, 0);
+    gtk_table_attach(GTK_TABLE(table), controls.add_ls_mask, 0, 2, row, row+1,
+                     GTK_FILL, 0, 0, 0);
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(controls.add_ls_mask),
                                  args->add_ls_mask);
     g_signal_connect(controls.add_ls_mask, "toggled",
@@ -371,16 +348,17 @@ crosscor_dialog(CrosscorArgs *args)
 
     controls.threshold = gtk_adjustment_new(args->threshold,
                                             -1, 1, 0.005, 0.05, 0);
-    gwy_table_attach_hscale(table, row, _("T_hreshold:"), NULL,
-                            controls.threshold, 0);
+    gwy_table_attach_adjbar(table, row, _("T_hreshold:"), NULL,
+                            controls.threshold, GWY_HSCALE_LINEAR);
     gwy_table_hscale_set_sensitive(controls.threshold, args->add_ls_mask);
     row++;
 
     /* Allow multiple channel cross-correlation */
+    gtk_table_set_row_spacing(GTK_TABLE(table), row-1, 8);
     controls.multiple = gtk_check_button_new_with_mnemonic
                                            (_("Multichannel cross-corelation"));
-    gtk_table_attach(GTK_TABLE(table), controls.multiple, 0, 4, row, row+1,
-                     GTK_EXPAND | GTK_FILL, 0, 0, 0);
+    gtk_table_attach(GTK_TABLE(table), controls.multiple, 0, 2, row, row+1,
+                     GTK_FILL, 0, 0, 0);
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(controls.multiple),
                                  args->multiple);
     g_signal_connect(controls.multiple, "toggled",
@@ -397,11 +375,10 @@ crosscor_dialog(CrosscorArgs *args)
     g_signal_connect(controls.chooser_op3, "changed",
                      G_CALLBACK(crosscor_data_changed), &args->op3);
     crosscor_data_changed(chooser, &args->op3);
-    gwy_table_attach_hscale(table, row, _("Second _source data:"), NULL,
-                            GTK_OBJECT(controls.chooser_op3), GWY_HSCALE_WIDGET);
-    gtk_table_set_row_spacing(GTK_TABLE(table), row, 8);
+    gwy_table_attach_adjbar(table, row, _("Second _source data:"), NULL,
+                            GTK_OBJECT(controls.chooser_op3),
+                            GWY_HSCALE_WIDGET_NO_EXPAND);
     gtk_widget_set_sensitive(controls.chooser_op3, args->multiple);
-
     row++;
 
     /* Second set to correlate with: second data */
@@ -414,60 +391,56 @@ crosscor_dialog(CrosscorArgs *args)
     g_signal_connect(controls.chooser_op4, "changed",
                      G_CALLBACK(crosscor_data_changed), &args->op4);
     crosscor_data_changed(chooser, &args->op4);
-    gwy_table_attach_hscale(table, row, _("Correlate with:"), NULL,
-                            GTK_OBJECT(controls.chooser_op4), GWY_HSCALE_WIDGET);
-    gtk_table_set_row_spacing(GTK_TABLE(table), row, 8);
+    gwy_table_attach_adjbar(table, row, _("Correlate with:"), NULL,
+                            GTK_OBJECT(controls.chooser_op4),
+                            GWY_HSCALE_WIDGET_NO_EXPAND);
     gtk_widget_set_sensitive(controls.chooser_op4, args->multiple);
     row++;
 
     /*postprocessing*/
+    gtk_table_set_row_spacing(GTK_TABLE(table), row-1, 8);
     label = gtk_label_new(_("Postprocess:"));
     gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
-    gtk_table_attach(GTK_TABLE(table), label, 0, 4, row, row+1,
-                     GTK_EXPAND | GTK_FILL, 0, 0, 0);
+    gtk_table_attach(GTK_TABLE(table), label, 0, 2, row, row+1,
+                     GTK_FILL, 0, 0, 0);
     row++;
 
-    controls.gaussian = gtk_check_button_new_with_mnemonic
-                                           (_("Apply Ga_ussian filter of width: "));
-    gtk_table_attach(GTK_TABLE(table), controls.gaussian, 0, 3, row, row+1,
-                     GTK_EXPAND | GTK_FILL, 0, 0, 0);
+    controls.gaussian_width = gtk_adjustment_new(args->gaussian_width,
+                                                 2, 100, 1, 5, 0);
+    gwy_table_attach_adjbar(table, row,
+                            _("Apply Ga_ussian filter of width:"), NULL,
+                            controls.gaussian_width,
+                            GWY_HSCALE_CHECK | GWY_HSCALE_SQRT);
+    controls.gaussian = gwy_table_hscale_get_check(controls.gaussian_width);
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(controls.gaussian),
                                  args->gaussian);
     g_signal_connect(controls.gaussian, "toggled",
                      G_CALLBACK(gaussian_changed_cb), &controls);
-
-    controls.gaussian_width = gtk_adjustment_new(args->gaussian_width, 2, 100, 1, 5, 0);
-    spin = gtk_spin_button_new(GTK_ADJUSTMENT(controls.gaussian_width), 1, 2);
     g_signal_connect(controls.gaussian_width, "value-changed",
                      G_CALLBACK(gaussian_width_changed_cb), &controls);
-
-    gtk_table_attach(GTK_TABLE(table), spin, 3, 4, row, row+1,
-                     GTK_EXPAND | GTK_FILL, 0, 0, 0);
-
-
     row++;
 
-    controls.extend = gtk_check_button_new_with_mnemonic
-                                           (_("Extend results to borders"));
-    gtk_table_attach(GTK_TABLE(table), controls.extend, 0, 4, row, row+1,
-                     GTK_EXPAND | GTK_FILL, 0, 0, 0);
+    controls.extend
+        = gtk_check_button_new_with_label(_("Extend results to borders"));
+    gtk_table_attach(GTK_TABLE(table), controls.extend, 0, 2, row, row+1,
+                     GTK_FILL, 0, 0, 0);
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(controls.extend),
                                  args->extend);
     g_signal_connect(controls.extend, "toggled",
                      G_CALLBACK(extend_changed_cb), &controls);
     row++;
 
-    controls.correct = gtk_check_button_new_with_mnemonic
-                                           (_("Create corrected data from 2nd channel"));
-    gtk_table_attach(GTK_TABLE(table), controls.correct, 0, 4, row, row+1,
-                     GTK_EXPAND | GTK_FILL, 0, 0, 0);
+    controls.correct = gtk_check_button_new_with_label(_("Create corrected "
+                                                         "data from 2nd "
+                                                         "channel"));
+    gtk_table_attach(GTK_TABLE(table), controls.correct, 0, 2, row, row+1,
+                     GTK_FILL, 0, 0, 0);
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(controls.correct),
                                  args->correct);
     g_signal_connect(controls.correct, "toggled",
                      G_CALLBACK(correct_changed_cb), &controls);
     row++;
 
-
     gtk_widget_show_all(dialog);
 
     do {
