@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: curvature.c 18537 2016-03-28 18:11:19Z yeti-dn $
+ *  @(#) $Id: curvature.c 20064 2017-07-11 12:06:26Z yeti-dn $
  *  Copyright (C) 2009-2015 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.net.
  *
@@ -67,7 +67,6 @@ typedef struct {
     GtkWidget *set_selection;
     GtkWidget *plot_graph;
     GtkWidget *target_graph;
-    GtkWidget *target_hbox;
     GtkWidget *view;
     GtkWidget *graph;
     GtkWidget *warning;
@@ -162,12 +161,12 @@ static GwyModuleInfo module_info = {
     &module_register,
     N_("Calculates overall curvature."),
     "Yeti <yeti@gwyddion.net>",
-    "1.3",
+    "1.5",
     "David Nečas (Yeti)",
     "2009",
 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, curvature)
 
 static gboolean
 module_register(void)
@@ -395,6 +394,9 @@ curvature_calculate(GwyDataField *dfield,
                                       xreal, yreal, i1 + i, i2 + i);
     }
 
+    params[PARAM_X0] += gwy_data_field_get_xoffset(dfield);
+    params[PARAM_Y0] += gwy_data_field_get_yoffset(dfield);
+
     return ok;
 }
 
@@ -594,7 +596,7 @@ curvature_dialog(CurvatureArgs *args,
                  GwyDataField *mfield,
                  gint id)
 {
-    GtkWidget *dialog, *table, *label, *hbox, *vbox, *treeview, *button, *hbox2;
+    GtkWidget *dialog, *table, *label, *hbox, *vbox, *treeview, *button;
     GwyDataChooser *chooser;
     GtkTreeSelection *selection;
     GtkTreeViewColumn *column;
@@ -644,7 +646,7 @@ curvature_dialog(CurvatureArgs *args,
     g_object_set(controls.selection, "max-objects", 2, NULL);
     gtk_box_pack_start(GTK_BOX(vbox), controls.view, FALSE, FALSE, 4);
 
-    table = gtk_table_new(5 + (mfield ? 4 : 0), 4, FALSE);
+    table = gtk_table_new(5 + (mfield ? 4 : 0), 3, FALSE);
     gtk_table_set_row_spacings(GTK_TABLE(table), 2);
     gtk_table_set_col_spacings(GTK_TABLE(table), 6);
     gtk_box_pack_start(GTK_BOX(vbox), table, FALSE, FALSE, 0);
@@ -653,13 +655,13 @@ curvature_dialog(CurvatureArgs *args,
     label = gwy_label_new_header(_("Output Type"));
     gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
     gtk_table_attach(GTK_TABLE(table), label,
-                     0, 4, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
+                     0, 2, row, row+1, GTK_FILL, 0, 0, 0);
     row++;
 
     controls.set_selection
         = gtk_check_button_new_with_mnemonic(_("_Set selection"));
     gtk_table_attach(GTK_TABLE(table), controls.set_selection,
-                     0, 4, row, row+1, GTK_FILL, 0, 0, 0);
+                     0, 2, row, row+1, GTK_FILL, 0, 0, 0);
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(controls.set_selection),
                                  args->set_selection);
     g_signal_connect(controls.set_selection, "toggled",
@@ -669,7 +671,7 @@ curvature_dialog(CurvatureArgs *args,
     controls.plot_graph
         = gtk_check_button_new_with_mnemonic(_("_Plot graph"));
     gtk_table_attach(GTK_TABLE(table), controls.plot_graph,
-                     0, 4, row, row+1, GTK_FILL, 0, 0, 0);
+                     0, 2, row, row+1, GTK_FILL, 0, 0, 0);
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(controls.plot_graph),
                                  args->plot_graph);
     g_signal_connect(controls.plot_graph, "toggled",
@@ -677,15 +679,6 @@ curvature_dialog(CurvatureArgs *args,
     row++;
 
     gtk_table_set_row_spacing(GTK_TABLE(table), row-1, 8);
-    controls.target_hbox = hbox2 = gtk_hbox_new(FALSE, 6);
-    gtk_widget_set_sensitive(controls.target_hbox, args->plot_graph);
-    gtk_table_attach(GTK_TABLE(table), hbox2,
-                     0, 4, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
-
-    label = gtk_label_new_with_mnemonic(_("Target _graph:"));
-    gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
-    gtk_box_pack_start(GTK_BOX(hbox2), label, FALSE, FALSE, 0);
-
     controls.target_graph = gwy_data_chooser_new_graphs();
     chooser = GWY_DATA_CHOOSER(controls.target_graph);
     gwy_data_chooser_set_none(chooser, _("New graph"));
@@ -693,8 +686,11 @@ curvature_dialog(CurvatureArgs *args,
     gwy_data_chooser_set_filter(chooser, filter_target_graphs, &controls, NULL);
     gwy_data_chooser_set_active_id(chooser, &args->target_graph);
     gwy_data_chooser_get_active_id(chooser, &args->target_graph);
-    gtk_label_set_mnemonic_widget(GTK_LABEL(label), controls.target_graph);
-    gtk_box_pack_end(GTK_BOX(hbox2), controls.target_graph, FALSE, FALSE, 0);
+    gwy_table_attach_adjbar(GTK_WIDGET(table), row, _("Target _graph:"), NULL,
+                            GTK_OBJECT(controls.target_graph),
+                            GWY_HSCALE_WIDGET_NO_EXPAND);
+    gwy_table_hscale_set_sensitive(GTK_OBJECT(controls.target_graph),
+                                   args->plot_graph);
     g_signal_connect_swapped(controls.target_graph, "changed",
                              G_CALLBACK(target_graph_changed), &controls);
     row++;
@@ -726,6 +722,7 @@ curvature_dialog(CurvatureArgs *args,
     gtk_box_pack_start(GTK_BOX(hbox), vbox, TRUE, TRUE, 0);
 
     controls.graph = gwy_graph_new(controls.gmodel);
+    gwy_graph_enable_user_input(GWY_GRAPH(controls.graph), FALSE);
     gtk_widget_set_size_request(controls.graph, 320, 260);
     g_object_unref(controls.gmodel);
 
@@ -858,7 +855,8 @@ curvature_plot_graph_changed(GtkToggleButton *button,
     CurvatureArgs *args = controls->args;
 
     args->plot_graph = gtk_toggle_button_get_active(button);
-    gtk_widget_set_sensitive(controls->target_hbox, args->plot_graph);
+    gwy_table_hscale_set_sensitive(GTK_OBJECT(controls->target_graph),
+                                   args->plot_graph);
 }
 
 static void
