@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: cwt.c 18537 2016-03-28 18:11:19Z yeti-dn $
+ *  @(#) $Id: cwt.c 19948 2017-06-22 14:05:41Z yeti-dn $
  *  Copyright (C) 2003 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -65,12 +65,12 @@ static GwyModuleInfo module_info = {
     &module_register,
     N_("Two-dimensional CWT (Continuous Wavelet Transform)."),
     "Petr Klapetek <klapetek@gwyddion.net>",
-    "1.5",
+    "1.6",
     "David Nečas (Yeti) & Petr Klapetek",
     "2003",
 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, cwt)
 
 static gboolean
 module_register(void)
@@ -129,7 +129,7 @@ cwt_dialog(CWTArgs *args)
 {
     GtkWidget *dialog, *table;
     CWTControls controls;
-    gint response;
+    gint response, row;
 
     dialog = gtk_dialog_new_with_buttons(_("2D CWT"), NULL, 0,
                                          _("_Reset"), RESPONSE_RESET,
@@ -139,24 +139,27 @@ cwt_dialog(CWTArgs *args)
     gtk_dialog_set_default_response(GTK_DIALOG(dialog), GTK_RESPONSE_OK);
     gwy_help_add_to_proc_dialog(GTK_DIALOG(dialog), GWY_HELP_DEFAULT);
 
-    table = gtk_table_new(4, 4, FALSE);
+    table = gtk_table_new(2, 3, FALSE);
     gtk_table_set_row_spacings(GTK_TABLE(table), 2);
     gtk_table_set_col_spacings(GTK_TABLE(table), 6);
     gtk_container_set_border_width(GTK_CONTAINER(table), 4);
     gtk_box_pack_start(GTK_BOX(GTK_DIALOG(dialog)->vbox), table,
                        FALSE, FALSE, 4);
-
+    row = 0;
 
     controls.scale = gtk_adjustment_new(args->scale, 0.0, 1000.0, 1, 10, 0);
-    gwy_table_attach_spinbutton(table, 1, _("_Scale:"), _("pixels"),
-                                controls.scale);
+    gwy_table_attach_adjbar(table, row, _("_Scale:"), _("px"),
+                            controls.scale, GWY_HSCALE_DEFAULT);
+    row++;
 
     controls.wavelet
         = gwy_enum_combo_box_new(gwy_2d_cwt_wavelet_type_get_enum(), -1,
                                  G_CALLBACK(gwy_enum_combo_box_update_int),
                                  &args->wavelet, args->wavelet, TRUE);
-    gwy_table_attach_row(table, 3, _("_Wavelet type:"), "",
-                         controls.wavelet);
+    gwy_table_attach_adjbar(table, row, _("_Wavelet type:"), NULL,
+                            GTK_OBJECT(controls.wavelet),
+                            GWY_HSCALE_WIDGET_NO_EXPAND);
+    row++;
 
     gtk_widget_show_all(dialog);
     do {
