@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: deposit_synth.c 19071 2016-10-14 09:02:41Z yeti-dn $
+ *  @(#) $Id: deposit_synth.c 19948 2017-06-22 14:05:41Z yeti-dn $
  *  Copyright (C) 2007,2009,2010 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
@@ -169,19 +169,19 @@ static GwyModuleInfo module_info = {
     &module_register,
     N_("Generates particles using simple dynamical model"),
     "Petr Klapetek <klapetek@gwyddion.net>",
-    "1.4",
+    "1.5",
     "Petr Klapetek",
     "2010",
 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, deposit_synth)
 
 static gboolean
 module_register(void)
 {
     gwy_process_func_register("deposit_synth",
                               (GwyProcessFunc)&deposit_synth,
-                              N_("/S_ynthetic/_Particles..."),
+                              N_("/S_ynthetic/_Deposition/_Particles..."),
                               GWY_STOCK_SYNTHETIC_PARTICLES,
                               DEPOSIT_SYNTH_RUN_MODES,
                               0,
@@ -339,6 +339,7 @@ deposit_synth_dialog(DepositSynthArgs *args,
     gboolean finished;
     gint response;
     gint row, newid;
+    gdouble power10;
 
     gwy_clear(&controls, 1);
     controls.in_init = TRUE;
@@ -410,11 +411,13 @@ deposit_synth_dialog(DepositSynthArgs *args,
     gtk_notebook_append_page(GTK_NOTEBOOK(notebook),
                              gwy_dimensions_get_widget(controls.dims),
                              gtk_label_new(_("Dimensions")));
-    if (controls.dims->add)
+    if (controls.dims->add) {
         g_signal_connect_swapped(controls.dims->add, "toggled",
-                                 G_CALLBACK(deposit_synth_invalidate), &controls);
+                                 G_CALLBACK(deposit_synth_invalidate),
+                                 &controls);
+    }
 
-    table = gtk_table_new(12 + (dfield_template ? 1 : 0), 5, FALSE);
+    table = gtk_table_new(12 + (dfield_template ? 1 : 0), 3, FALSE);
     gtk_table_set_row_spacings(GTK_TABLE(table), 2);
     gtk_table_set_col_spacings(GTK_TABLE(table), 6);
     gtk_container_set_border_width(GTK_CONTAINER(table), 4);
@@ -422,10 +425,12 @@ deposit_synth_dialog(DepositSynthArgs *args,
                              gtk_label_new(_("Generator")));
     row = 0;
 
-    controls.size = gtk_adjustment_new(args->size/pow10(controls.dims->args->xypow10),
-                                        0, 100.0, 0.1, 1.0, 0);
-    spin = gwy_table_attach_hscale(table, row, _("Particle r_adius:"), controls.dims->args->xyunits,
-                                   controls.size, GWY_HSCALE_DEFAULT);
+    power10 = pow10(controls.dims->args->xypow10);
+    controls.size = gtk_adjustment_new(args->size/power10,
+                                       0, 100.0, 0.1, 1.0, 0);
+    spin = gwy_table_attach_adjbar(table, row, _("Particle r_adius:"),
+                                   controls.dims->args->xyunits,
+                                   controls.size, GWY_HSCALE_SQRT);
     gtk_spin_button_set_snap_to_ticks(GTK_SPIN_BUTTON(spin), FALSE);
     gtk_spin_button_set_digits(GTK_SPIN_BUTTON(spin), 4);
     controls.size_units = gwy_table_hscale_get_units(controls.size);
@@ -433,10 +438,11 @@ deposit_synth_dialog(DepositSynthArgs *args,
                              G_CALLBACK(size_changed), &controls);
     row++;
 
-    controls.width = gtk_adjustment_new(args->width/pow10(controls.dims->args->xypow10),
+    controls.width = gtk_adjustment_new(args->width/power10,
                                         0, 100.0, 0.1, 1.0, 0);
-    spin = gwy_table_attach_hscale(table, row, _("Distribution _width:"), controls.dims->args->xyunits,
-                                   controls.width, GWY_HSCALE_DEFAULT);
+    spin = gwy_table_attach_adjbar(table, row, _("Distribution _width:"),
+                                   controls.dims->args->xyunits,
+                                   controls.width, GWY_HSCALE_SQRT);
     gtk_spin_button_set_snap_to_ticks(GTK_SPIN_BUTTON(spin), FALSE);
     gtk_spin_button_set_digits(GTK_SPIN_BUTTON(spin), 4);
     controls.width_units = gwy_table_hscale_get_units(controls.width);
@@ -446,31 +452,25 @@ deposit_synth_dialog(DepositSynthArgs *args,
 
     controls.coverage = gtk_adjustment_new(args->coverage,
                                            0.0, 100, 0.1, 1, 0);
-    gwy_table_attach_hscale(table, row, _("Surface _coverage:"),
-                            "%",
-                            controls.coverage, GWY_HSCALE_DEFAULT);
+    gwy_table_attach_adjbar(table, row, _("Co_verage:"), "%",
+                            controls.coverage, GWY_HSCALE_LINEAR);
     g_signal_connect_swapped(controls.coverage, "value-changed",
                              G_CALLBACK(coverage_changed), &controls);
     row++;
 
-    controls.revise = gtk_adjustment_new(args->revise,
-                                           0.0, 10000, 1, 10, 0);
-    gwy_table_attach_hscale(table, row, _("_Relax steps:"),
-                            "",
-                            controls.revise, GWY_HSCALE_DEFAULT);
+    controls.revise = gtk_adjustment_new(args->revise, 0.0, 10000, 1, 10, 0);
+    gwy_table_attach_adjbar(table, row, _("_Relax steps:"), NULL,
+                            controls.revise, GWY_HSCALE_SQRT);
     g_signal_connect_swapped(controls.revise, "value-changed",
                              G_CALLBACK(revise_changed), &controls);
     row++;
 
-
-    controls.message = gtk_label_new("");
+    controls.message = gtk_label_new(NULL);
     gtk_misc_set_alignment(GTK_MISC(controls.message), 0.0, 0.5);
     gtk_table_attach(GTK_TABLE(table), controls.message,
                      0, 4, row, row+1, GTK_FILL, 0, 0, 0);
     row++;
 
-
-
     gtk_widget_show_all(dialog);
     controls.in_init = FALSE;
     /* Must be done when widgets are shown, see GtkNotebook docs */
@@ -602,7 +602,8 @@ update_controls(DepositSynthControls *controls,
     gtk_adjustment_set_value(GTK_ADJUSTMENT(controls->seed), args->seed);
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(controls->randomize),
                                  args->randomize);
-    gtk_adjustment_set_value(GTK_ADJUSTMENT(controls->size), args->size/pow10(controls->dims->args->xypow10));
+    gtk_adjustment_set_value(GTK_ADJUSTMENT(controls->size),
+                             args->size/pow10(controls->dims->args->xypow10));
     gtk_adjustment_set_value(GTK_ADJUSTMENT(controls->width),
                              args->width/pow10(controls->dims->args->xypow10));
     gtk_adjustment_set_value(GTK_ADJUSTMENT(controls->coverage),
@@ -694,14 +695,11 @@ page_switched(DepositSynthControls *controls,
         GwyDimensions *dims = controls->dims;
 
         if (controls->size_units)
-          gtk_label_set_markup(GTK_LABEL(controls->size_units),
-                             dims->xyvf->units);
+            gtk_label_set_markup(GTK_LABEL(controls->size_units),
+                                 dims->xyvf->units);
         if (controls->width_units)
-          gtk_label_set_markup(GTK_LABEL(controls->width_units),
-                             dims->xyvf->units);
-
-        //update_size_value(controls);
-        //update_width_value(controls);
+            gtk_label_set_markup(GTK_LABEL(controls->width_units),
+                                 dims->xyvf->units);
     }
 }
 
@@ -724,36 +722,38 @@ static void
 size_changed(DepositSynthControls *controls,
              GtkAdjustment *adj)
 {
-    controls->args->size = gtk_adjustment_get_value(adj)*pow10(controls->dims->args->xypow10);
-    deposit_synth_invalidate(controls);
+    gdouble power10 = pow10(controls->dims->args->xypow10);
 
+    controls->args->size = gtk_adjustment_get_value(adj)*power10;
+    deposit_synth_invalidate(controls);
 }
+
 static void
 width_changed(DepositSynthControls *controls,
              GtkAdjustment *adj)
 {
-    controls->args->width = gtk_adjustment_get_value(adj)*pow10(controls->dims->args->xypow10);
-    deposit_synth_invalidate(controls);
+    gdouble power10 = pow10(controls->dims->args->xypow10);
 
+    controls->args->width = gtk_adjustment_get_value(adj)*power10;
+    deposit_synth_invalidate(controls);
 }
+
 static void
 coverage_changed(DepositSynthControls *controls,
              GtkAdjustment *adj)
 {
     controls->args->coverage = gtk_adjustment_get_value(adj);
     deposit_synth_invalidate(controls);
-
 }
+
 static void
 revise_changed(DepositSynthControls *controls,
              GtkAdjustment *adj)
 {
     controls->args->revise = gtk_adjustment_get_value(adj);
     deposit_synth_invalidate(controls);
-
 }
 
-
 static void
 deposit_synth_invalidate(DepositSynthControls *controls)
 {
@@ -776,7 +776,6 @@ preview_gsource(gpointer user_data)
     return FALSE;
 }
 
-
 static void
 preview(DepositSynthControls *controls)
 {
