@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: diff_synth.c 19044 2016-10-08 19:10:46Z yeti-dn $
+ *  @(#) $Id: diff_synth.c 19948 2017-06-22 14:05:41Z yeti-dn $
  *  Copyright (C) 2014 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
@@ -218,14 +218,14 @@ static GwyModuleInfo module_info = {
     "2014",
 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, diff_synth)
 
 static gboolean
 module_register(void)
 {
     gwy_process_func_register("diff_synth",
                               (GwyProcessFunc)&diff_synth,
-                              N_("/S_ynthetic/_Diffusion..."),
+                              N_("/S_ynthetic/_Deposition/_Diffusion..."),
                               GWY_STOCK_SYNTHETIC_DIFFUSION,
                               DIFF_SYNTH_RUN_MODES,
                               0,
@@ -476,7 +476,7 @@ diff_synth_dialog(DiffSynthArgs *args,
                              gwy_dimensions_get_widget(controls.dims),
                              gtk_label_new(_("Dimensions")));
 
-    table = gtk_table_new(15 + (dfield_template ? 1 : 0), 4, FALSE);
+    table = gtk_table_new(15 + (dfield_template ? 1 : 0), 3, FALSE);
     /* This is used only for synt.h helpers. */
     controls.table = GTK_TABLE(table);
     gtk_table_set_row_spacings(GTK_TABLE(table), 2);
@@ -489,7 +489,7 @@ diff_synth_dialog(DiffSynthArgs *args,
     controls.coverage = gtk_adjustment_new(args->coverage,
                                            0.0, 16.0, 0.001, 1.0, 0);
     g_object_set_data(G_OBJECT(controls.coverage), "target", &args->coverage);
-    gwy_table_attach_hscale(table, row, _("Co_verage:"), NULL,
+    gwy_table_attach_adjbar(table, row, _("Co_verage:"), NULL,
                             controls.coverage, GWY_HSCALE_SQRT);
     g_signal_connect_swapped(controls.coverage, "value-changed",
                              G_CALLBACK(gwy_synth_double_changed), &controls);
@@ -497,8 +497,8 @@ diff_synth_dialog(DiffSynthArgs *args,
 
     controls.flux = gtk_adjustment_new(args->flux, -13.0, -3.0, 0.01, 1.0, 0);
     g_object_set_data(G_OBJECT(controls.flux), "target", &args->flux);
-    gwy_table_attach_hscale(table, row, _("_Flux:"), "log<sub>10</sub>",
-                            controls.flux, GWY_HSCALE_DEFAULT);
+    gwy_table_attach_adjbar(table, row, _("_Flux:"), "log<sub>10</sub>",
+                            controls.flux, GWY_HSCALE_LINEAR);
     g_signal_connect_swapped(controls.flux, "value-changed",
                              G_CALLBACK(gwy_synth_double_changed), &controls);
     row++;
@@ -509,25 +509,24 @@ diff_synth_dialog(DiffSynthArgs *args,
 
     if (dfield_template) {
         controls.height_init
-            = gtk_button_new_with_mnemonic(_("_Like Current Channel"));
+            = gtk_button_new_with_mnemonic(_("_Like Current Image"));
         g_signal_connect_swapped(controls.height_init, "clicked",
                                  G_CALLBACK(height_init_clicked), &controls);
         gtk_table_attach(GTK_TABLE(table), controls.height_init,
-                         1, 3, row, row+1, GTK_FILL, 0, 0, 0);
+                         0, 2, row, row+1, GTK_FILL, 0, 0, 0);
         row++;
     }
 
     gtk_table_set_row_spacing(GTK_TABLE(table), row-1, 8);
-
     label = gwy_label_new_header(_("Probabilities"));
-    gtk_table_attach(GTK_TABLE(table), label, 0, 3, row, row+1,
-                     GTK_EXPAND | GTK_FILL, 0, 0, 0);
+    gtk_table_attach(GTK_TABLE(table), label, 0, 2, row, row+1,
+                     GTK_FILL, 0, 0, 0);
     row++;
 
     controls.p_stick = gtk_adjustment_new(args->p_stick,
                                           0.0, 1.0, 0.0001, 0.1, 0);
     g_object_set_data(G_OBJECT(controls.p_stick), "target", &args->p_stick);
-    gwy_table_attach_hscale(table, row, _("_Sticking:"), NULL,
+    gwy_table_attach_adjbar(table, row, _("_Sticking:"), NULL,
                             controls.p_stick, GWY_HSCALE_SQRT);
     g_signal_connect_swapped(controls.p_stick, "value-changed",
                              G_CALLBACK(gwy_synth_double_changed), &controls);
@@ -536,7 +535,7 @@ diff_synth_dialog(DiffSynthArgs *args,
     controls.p_break = gtk_adjustment_new(args->p_break,
                                           0.0, 1.0, 0.0001, 0.1, 0);
     g_object_set_data(G_OBJECT(controls.p_break), "target", &args->p_break);
-    gwy_table_attach_hscale(table, row, _("_Activation:"), NULL,
+    gwy_table_attach_adjbar(table, row, _("_Activation:"), NULL,
                             controls.p_break, GWY_HSCALE_SQRT);
     g_signal_connect_swapped(controls.p_break, "value-changed",
                              G_CALLBACK(gwy_synth_double_changed), &controls);
@@ -545,14 +544,14 @@ diff_synth_dialog(DiffSynthArgs *args,
     controls.schwoebel = gtk_adjustment_new(args->schwoebel,
                                             -12.0, 0.0, 0.01, 1.0, 0);
     g_object_set_data(G_OBJECT(controls.schwoebel), "target", &args->schwoebel);
-    gwy_table_attach_hscale(table, row, _("Passing Sch_woebel:"),
+    gwy_table_attach_adjbar(table, row, _("Passing Sch_woebel:"),
                             "log<sub>10</sub>",
-                            controls.schwoebel, GWY_HSCALE_DEFAULT);
+                            controls.schwoebel, GWY_HSCALE_LINEAR);
     g_signal_connect_swapped(controls.schwoebel, "value-changed",
                              G_CALLBACK(gwy_synth_double_changed), &controls);
     row++;
 
-    table = gtk_table_new(1 + GRAPH_NFLAGS, 4, FALSE);
+    table = gtk_table_new(1 + GRAPH_NFLAGS, 3, FALSE);
     /* This is used only for synt.h helpers. */
     controls.table = GTK_TABLE(table);
     gtk_table_set_row_spacings(GTK_TABLE(table), 2);
@@ -575,7 +574,7 @@ diff_synth_dialog(DiffSynthArgs *args,
         toggle = GTK_TOGGLE_BUTTON(controls.graph_flags[i]);
         gtk_toggle_button_set_active(toggle, args->graph_flags[i]);
         gtk_table_attach(GTK_TABLE(table), controls.graph_flags[i],
-                         0, 3, row, row+1, GTK_FILL, 0, 0, 0);
+                         0, 2, row, row+1, GTK_FILL, 0, 0, 0);
         g_signal_connect(toggle, "toggled",
                          G_CALLBACK(gwy_synth_boolean_changed_silent),
                          &args->graph_flags[i]);
