@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: dimensions.h 18278 2016-02-13 16:57:55Z yeti-dn $
+ *  @(#) $Id: dimensions.h 19907 2017-06-11 18:03:15Z yeti-dn $
  *  Copyright (C) 2009 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
@@ -37,7 +37,7 @@ typedef struct {
     gchar *zunits;
     gint xypow10;
     gint zpow10;
-    gboolean replace;    /* do not create a new channel */
+    gboolean replace;    /* do not create a new image */
     gboolean add;        /* starts from the current, but may create new */
 } GwyDimensionArgs;
 
@@ -68,6 +68,9 @@ typedef struct {
     GtkWidget *zunits;
     GtkWidget *replace;
     GtkWidget *add;
+    GtkWidget *units_label;
+    GtkWidget *unit_xy_label;
+    GtkWidget *unit_z_label;
     gboolean in_update;
 } GwyDimensions;
 
@@ -78,28 +81,19 @@ gwy_dimensions_make_res(GtkTable *table,
                         const gchar *name,
                         gint value)
 {
-    GtkWidget *label, *spin;
-    GtkAdjustment *adj;
+    GtkWidget *spin;
     GtkObject *obj;
 
-    label = gtk_label_new_with_mnemonic(name);
-    gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
-    gwy_sensitivity_group_add_widget(sensgroup, label, GWY_DIMENSIONS_SENS);
-    gtk_table_attach(table, label, 0, 1, row, row+1, GTK_FILL, 0, 0, 0);
-
     obj = gtk_adjustment_new(value, 2, 32768, 1, 100, 0);
-    adj = GTK_ADJUSTMENT(obj);
-    spin = gtk_spin_button_new(adj, 0, 0);
-    gtk_label_set_mnemonic_widget(GTK_LABEL(label), spin);
+    spin = gwy_table_attach_adjbar(GTK_WIDGET(table), row, name, _("px"),
+                                   obj, GWY_HSCALE_LOG);
     gwy_sensitivity_group_add_widget(sensgroup, spin, GWY_DIMENSIONS_SENS);
-    gtk_table_attach(table, spin, 1, 2, row, row+1, GTK_FILL, 0, 0, 0);
+    gwy_sensitivity_group_add_widget(sensgroup, gwy_table_hscale_get_label(obj),
+                                     GWY_DIMENSIONS_SENS);
+    gwy_sensitivity_group_add_widget(sensgroup, gwy_table_hscale_get_units(obj),
+                                     GWY_DIMENSIONS_SENS);
 
-    label = gtk_label_new("px");
-    gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
-    gwy_sensitivity_group_add_widget(sensgroup, label, GWY_DIMENSIONS_SENS);
-    gtk_table_attach(table, label, 2, 3, row, row+1, GTK_FILL, 0, 0, 0);
-
-    return adj;
+    return GTK_ADJUSTMENT(obj);
 }
 
 static GtkAdjustment*
@@ -111,29 +105,19 @@ gwy_dimensions_make_real(GtkTable *table,
                          const gchar *units,
                          GtkWidget **unitlab)
 {
-    GtkWidget *label, *spin;
-    GtkAdjustment *adj;
+    GtkWidget *spin;
     GtkObject *obj;
 
-    label = gtk_label_new_with_mnemonic(name);
-    gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
-    gwy_sensitivity_group_add_widget(sensgroup, label, GWY_DIMENSIONS_SENS);
-    gtk_table_attach(table, label, 0, 1, row, row+1, GTK_FILL, 0, 0, 0);
-
     obj = gtk_adjustment_new(value, 0.001, 10000.0, 1, 100, 0);
-    adj = GTK_ADJUSTMENT(obj);
-    spin = gtk_spin_button_new(adj, 0, 3);
-    gtk_label_set_mnemonic_widget(GTK_LABEL(label), spin);
+    spin = gwy_table_attach_adjbar(GTK_WIDGET(table), row, name, units,
+                                   obj, GWY_HSCALE_LOG);
     gwy_sensitivity_group_add_widget(sensgroup, spin, GWY_DIMENSIONS_SENS);
-    gtk_table_attach(table, spin, 1, 2, row, row+1, GTK_FILL, 0, 0, 0);
-
-    *unitlab = gtk_label_new(units);
-    gtk_label_set_use_markup(GTK_LABEL(*unitlab), TRUE);
-    gtk_misc_set_alignment(GTK_MISC(*unitlab), 0.0, 0.5);
+    gwy_sensitivity_group_add_widget(sensgroup, gwy_table_hscale_get_label(obj),
+                                     GWY_DIMENSIONS_SENS);
+    *unitlab = gwy_table_hscale_get_units(obj);
     gwy_sensitivity_group_add_widget(sensgroup, *unitlab, GWY_DIMENSIONS_SENS);
-    gtk_table_attach(table, *unitlab, 2, 3, row, row+1, GTK_FILL, 0, 0, 0);
 
-    return adj;
+    return GTK_ADJUSTMENT(obj);
 }
 
 static GtkWidget*
@@ -143,20 +127,18 @@ gwy_dimensions_make_units(GtkTable *table,
                           const gchar *name,
                           gint pwr,
                           GwySIUnit *siunit,
-                          GtkWidget **combo)
+                          GtkWidget **combo,
+                          GtkWidget **label)
 {
-    GtkWidget *label, *changer;
-
-    label = gtk_label_new_with_mnemonic(name);
-    gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
-    gwy_sensitivity_group_add_widget(sensgroup, label, GWY_DIMENSIONS_SENS);
-    gtk_table_attach(table, label, 0, 1, row, row+1, GTK_FILL, 0, 0, 0);
+    GtkWidget *changer;
 
     *combo = gwy_combo_box_metric_unit_new(NULL, NULL,
                                            pwr - 6, pwr + 6, siunit, pwr);
-    gtk_label_set_mnemonic_widget(GTK_LABEL(label), *combo);
+    gwy_table_attach_adjbar(GTK_WIDGET(table), row, name, NULL,
+                            GTK_OBJECT(*combo), GWY_HSCALE_WIDGET_NO_EXPAND);
     gwy_sensitivity_group_add_widget(sensgroup, *combo, GWY_DIMENSIONS_SENS);
-    gtk_table_attach(table, *combo, 1, 2, row, row+1, GTK_FILL, 0, 0, 0);
+    *label = gwy_table_hscale_get_label(GTK_OBJECT(*combo));
+    gwy_sensitivity_group_add_widget(sensgroup, *label, GWY_DIMENSIONS_SENS);
 
     changer = gtk_button_new_with_label(gwy_sgettext("verb|Change"));
     gwy_sensitivity_group_add_widget(sensgroup, changer, GWY_DIMENSIONS_SENS);
@@ -444,7 +426,7 @@ gwy_dimensions_new(GwyDimensionArgs *args,
     /* Resolution */
     label = gwy_label_new_header(_("Resolution"));
     gwy_sensitivity_group_add_widget(sensgroup, label, GWY_DIMENSIONS_SENS);
-    gtk_table_attach(table, label, 0, 3, row, row+1, GTK_FILL, 0, 0, 0);
+    gtk_table_attach(table, label, 0, 2, row, row+1, GTK_FILL, 0, 0, 0);
     row++;
 
     dims->xres = gwy_dimensions_make_res(table, sensgroup, row++,
@@ -459,14 +441,14 @@ gwy_dimensions_new(GwyDimensionArgs *args,
                                  args->xres == args->yres);
     gwy_sensitivity_group_add_widget(sensgroup, dims->xyreseq,
                                      GWY_DIMENSIONS_SENS);
-    gtk_table_attach(table, dims->xyreseq, 0, 3, row, row+1, GTK_FILL, 0, 0, 0);
+    gtk_table_attach(table, dims->xyreseq, 0, 2, row, row+1, GTK_FILL, 0, 0, 0);
     gtk_table_set_row_spacing(table, row, 12);
     row++;
 
     /* Physical dimensions */
     label = gwy_label_new_header(_("Physical Dimensions"));
     gwy_sensitivity_group_add_widget(sensgroup, label, GWY_DIMENSIONS_SENS);
-    gtk_table_attach(table, label, 0, 3, row, row+1, GTK_FILL, 0, 0, 0);
+    gtk_table_attach(table, label, 0, 2, row, row+1, GTK_FILL, 0, 0, 0);
     row++;
 
     dims->xreal = gwy_dimensions_make_real(table, sensgroup, row++,
@@ -480,30 +462,35 @@ gwy_dimensions_new(GwyDimensionArgs *args,
     gtk_table_set_row_spacing(table, row-1, 12);
 
     /* Units */
-    label = gwy_label_new_header(_("Units"));
-    gwy_sensitivity_group_add_widget(sensgroup, label, GWY_DIMENSIONS_SENS);
-    gtk_table_attach(table, label, 0, 3, row, row+1, GTK_FILL, 0, 0, 0);
+    dims->units_label = gwy_label_new_header(_("Units"));
+    gwy_sensitivity_group_add_widget(sensgroup, dims->units_label,
+                                     GWY_DIMENSIONS_SENS);
+    gtk_table_attach(table, dims->units_label, 0, 2, row, row+1,
+                     GTK_FILL, 0, 0, 0);
     row++;
 
     dims->xyunits = gwy_dimensions_make_units(table, sensgroup, row++,
                                               _("_Dimension units:"),
                                               args->xypow10, dims->xysiunit,
-                                              &dims->xypow10);
+                                              &dims->xypow10,
+                                              &dims->unit_xy_label);
 
     dims->zunits = gwy_dimensions_make_units(table, sensgroup, row++,
                                              _("_Value units:"),
                                              args->zpow10, dims->zsiunit,
-                                             &dims->zpow10);
+                                             &dims->zpow10,
+                                             &dims->unit_z_label);
 
     /* Template */
     if (dims->template_) {
         gtk_table_set_row_spacing(table, row-1, 12);
 
-        label = gwy_label_new_header(_("Current Channel"));
-        gtk_table_attach(table, label, 0, 3, row, row+1, GTK_FILL, 0, 0, 0);
+        label = gwy_label_new_header(_("Current Image"));
+        gtk_table_attach(table, label, 0, 2, row, row+1, GTK_FILL, 0, 0, 0);
         row++;
 
-        button = gtk_button_new_with_mnemonic(_("_Take Dimensions from Current Channel"));
+        button = gtk_button_new_with_mnemonic(_("_Take Dimensions from "
+                                                "Current Image"));
         gwy_sensitivity_group_add_widget(sensgroup, button,
                                          GWY_DIMENSIONS_SENS);
         gtk_table_attach(table, button, 0, 3, row, row+1, GTK_FILL, 0, 0, 0);
@@ -512,19 +499,19 @@ gwy_dimensions_new(GwyDimensionArgs *args,
         row++;
 
         button = gtk_check_button_new_with_mnemonic(_("_Replace the current "
-                                                      "channel"));
+                                                      "image"));
         dims->replace = button;
         gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(button), args->replace);
-        gtk_table_attach(table, button, 0, 3, row, row+1, GTK_FILL, 0, 0, 0);
+        gtk_table_attach(table, button, 0, 2, row, row+1, GTK_FILL, 0, 0, 0);
         g_signal_connect_swapped(button, "toggled",
                                  G_CALLBACK(gwy_dimensions_replace), dims);
         row++;
 
         button = gtk_check_button_new_with_mnemonic(_("_Start from the current "
-                                                      "channel"));
+                                                      "image"));
         dims->add = button;
         gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(button), args->add);
-        gtk_table_attach(table, button, 0, 3, row, row+1, GTK_FILL, 0, 0, 0);
+        gtk_table_attach(table, button, 0, 2, row, row+1, GTK_FILL, 0, 0, 0);
         g_signal_connect_swapped(button, "toggled",
                                  G_CALLBACK(gwy_dimensions_add), dims);
         row++;
