@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: domain_synth.c 19044 2016-10-08 19:10:46Z yeti-dn $
+ *  @(#) $Id: domain_synth.c 19948 2017-06-22 14:05:41Z yeti-dn $
  *  Copyright (C) 2014 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
@@ -169,7 +169,7 @@ static GwyModuleInfo module_info = {
     "2014",
 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, domain_synth)
 
 static gboolean
 module_register(void)
@@ -429,7 +429,7 @@ domain_synth_dialog(DomainSynthArgs *args,
                              gwy_dimensions_get_widget(controls.dims),
                              gtk_label_new(_("Dimensions")));
 
-    table = gtk_table_new(12 + (dfield_template ? 1 : 0), 4, FALSE);
+    table = gtk_table_new(12 + (dfield_template ? 1 : 0), 3, FALSE);
     controls.table = GTK_TABLE(table);
     gtk_table_set_row_spacings(GTK_TABLE(table), 2);
     gtk_table_set_col_spacings(GTK_TABLE(table), 6);
@@ -439,28 +439,28 @@ domain_synth_dialog(DomainSynthArgs *args,
     row = 0;
 
     controls.preview_quantity = preview_quantity_selector_new(&controls);
-    gwy_table_attach_hscale(table, row, _("_Preview quantity:"), NULL,
+    gwy_table_attach_adjbar(table, row, _("_Preview quantity:"), NULL,
                             GTK_OBJECT(controls.preview_quantity),
-                            GWY_HSCALE_WIDGET);
+                            GWY_HSCALE_WIDGET_NO_EXPAND);
     row++;
 
     gtk_table_set_row_spacing(GTK_TABLE(table), row-1, 8);
     gtk_table_attach(GTK_TABLE(table),
                      gwy_label_new_header(_("Simulation Parameters")),
-                     0, 3, row, row+1, GTK_FILL, 0, 0, 0);
+                     0, 2, row, row+1, GTK_FILL, 0, 0, 0);
     row++;
 
     controls.niters = gtk_adjustment_new(args->niters, 1, 10000, 1, 10, 0);
     g_object_set_data(G_OBJECT(controls.niters), "target", &args->niters);
-    gwy_table_attach_hscale(table, row, _("_Number of iterations:"), NULL,
-                            GTK_OBJECT(controls.niters), GWY_HSCALE_SQRT);
+    gwy_table_attach_adjbar(table, row, _("_Number of iterations:"), NULL,
+                            GTK_OBJECT(controls.niters), GWY_HSCALE_LOG);
     g_signal_connect_swapped(controls.niters, "value-changed",
                              G_CALLBACK(gwy_synth_int_changed), &controls);
     row++;
 
     controls.T = gtk_adjustment_new(args->T, 0.001, 5.0, 0.001, 0.1, 0);
     g_object_set_data(G_OBJECT(controls.T), "target", &args->T);
-    gwy_table_attach_hscale(table, row, _("_Temperature:"), NULL,
+    gwy_table_attach_adjbar(table, row, _("_Temperature:"), NULL,
                             GTK_OBJECT(controls.T), GWY_HSCALE_SQRT);
     g_signal_connect_swapped(controls.T, "value-changed",
                              G_CALLBACK(gwy_synth_double_changed), &controls);
@@ -468,7 +468,7 @@ domain_synth_dialog(DomainSynthArgs *args,
 
     controls.B = gtk_adjustment_new(args->B, 0.001, 100.0, 0.1, 10, 0);
     g_object_set_data(G_OBJECT(controls.B), "target", &args->B);
-    gwy_table_attach_hscale(table, row, _("_Inhibitor strength:"), NULL,
+    gwy_table_attach_adjbar(table, row, _("_Inhibitor strength:"), NULL,
                             GTK_OBJECT(controls.B), GWY_HSCALE_SQRT);
     g_signal_connect_swapped(controls.B, "value-changed",
                              G_CALLBACK(gwy_synth_double_changed), &controls);
@@ -476,7 +476,7 @@ domain_synth_dialog(DomainSynthArgs *args,
 
     controls.mu = gtk_adjustment_new(args->mu, 0.001, 100.0, 0.1, 10, 0);
     g_object_set_data(G_OBJECT(controls.mu), "target", &args->mu);
-    gwy_table_attach_hscale(table, row, _("In_hibitor coupling:"), NULL,
+    gwy_table_attach_adjbar(table, row, _("In_hibitor coupling:"), NULL,
                             GTK_OBJECT(controls.mu), GWY_HSCALE_SQRT);
     g_signal_connect_swapped(controls.mu, "value-changed",
                              G_CALLBACK(gwy_synth_double_changed), &controls);
@@ -484,7 +484,7 @@ domain_synth_dialog(DomainSynthArgs *args,
 
     controls.nu = gtk_adjustment_new(args->nu, -5.0, 5.0, 0.001, 0.1, 0);
     g_object_set_data(G_OBJECT(controls.nu), "target", &args->nu);
-    gwy_table_attach_hscale(table, row, _("_Bias:"), NULL,
+    gwy_table_attach_adjbar(table, row, _("_Bias:"), NULL,
                             GTK_OBJECT(controls.nu), GWY_HSCALE_DEFAULT);
     g_signal_connect_swapped(controls.nu, "value-changed",
                              G_CALLBACK(gwy_synth_double_changed), &controls);
@@ -492,7 +492,7 @@ domain_synth_dialog(DomainSynthArgs *args,
 
     controls.dt = gtk_adjustment_new(args->dt, 0.001, 1000.0, 0.001, 1.0, 0);
     g_object_set_data(G_OBJECT(controls.dt), "target", &args->dt);
-    gwy_table_attach_hscale(table, row, _("_Monte Carlo time step:"), 
+    gwy_table_attach_adjbar(table, row, _("_Monte Carlo time step:"), 
                             "×10<sup>-3</sup>",
                             GTK_OBJECT(controls.dt), GWY_HSCALE_LOG);
     g_signal_connect_swapped(controls.dt, "value-changed",
@@ -511,11 +511,11 @@ domain_synth_dialog(DomainSynthArgs *args,
 
     if (dfield_template) {
         controls.height_init
-            = gtk_button_new_with_mnemonic(_("_Like Current Channel"));
+            = gtk_button_new_with_mnemonic(_("_Like Current Image"));
         g_signal_connect_swapped(controls.height_init, "clicked",
                                  G_CALLBACK(height_init_clicked), &controls);
         gtk_table_attach(GTK_TABLE(table), controls.height_init,
-                         1, 3, row, row+1, GTK_FILL, 0, 0, 0);
+                         0, 2, row, row+1, GTK_FILL, 0, 0, 0);
         row++;
     }
 
@@ -523,7 +523,7 @@ domain_synth_dialog(DomainSynthArgs *args,
     label = gtk_label_new(_("Output type:"));
     gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
     gtk_table_attach(GTK_TABLE(table), label,
-                     0, 3, row, row+1, GTK_FILL, 0, 0, 0);
+                     0, 2, row, row+1, GTK_FILL, 0, 0, 0);
     row++;
 
     for (i = 0; i < QUANTITY_NTYPES; i++) {
@@ -534,7 +534,7 @@ domain_synth_dialog(DomainSynthArgs *args,
         g_object_set_data(G_OBJECT(controls.quantity[i]), "value",
                           GUINT_TO_POINTER(i));
         gtk_table_attach(GTK_TABLE(table), controls.quantity[i],
-                         0, 3, row, row+1, GTK_FILL, 0, 0, 0);
+                         0, 2, row, row+1, GTK_FILL, 0, 0, 0);
         g_signal_connect(controls.quantity[i], "toggled",
                          G_CALLBACK(output_quantity_toggled), &controls);
         row++;
