@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: drift.c 19044 2016-10-08 19:10:46Z yeti-dn $
+ *  @(#) $Id: drift.c 20116 2017-07-31 10:28:57Z yeti-dn $
  *  Copyright (C) 2007,2008 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -163,7 +163,7 @@ static const DriftArgs drift_defaults = {
     FALSE,
     GWY_INTERPOLATION_BSPLINE,
     FALSE,
-    FALSE,
+    TRUE,
     GWY_APP_DATA_ID_NONE,
 };
 
@@ -179,7 +179,7 @@ static GwyModuleInfo module_info = {
     "2007",
 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, drift)
 
 static gboolean
 module_register(void)
@@ -276,7 +276,7 @@ drift_dialog(DriftArgs *args,
                  "si-unit-y", unit,
                  NULL);
 
-    table = gtk_table_new(11, 4, FALSE);
+    table = gtk_table_new(11, 3, FALSE);
     gtk_table_set_row_spacings(GTK_TABLE(table), 2);
     gtk_table_set_col_spacings(GTK_TABLE(table), 6);
     gtk_container_set_border_width(GTK_CONTAINER(table), 4);
@@ -284,8 +284,9 @@ drift_dialog(DriftArgs *args,
     row = 0;
 
     controls.range = gtk_adjustment_new(args->range, 1.0, 50.0, 1.0, 5.0, 0);
-    gwy_table_attach_hscale(table, row, _("_Search range:"), _("rows"),
-                            controls.range, GWY_HSCALE_DEFAULT);
+    gwy_table_attach_adjbar(table, row, _("_Search range:"), _("rows"),
+                            controls.range,
+                            GWY_HSCALE_LINEAR | GWY_HSCALE_SNAP);
     g_signal_connect_swapped(controls.range, "value-changed",
                              G_CALLBACK(range_changed), &controls);
     row++;
@@ -294,7 +295,7 @@ drift_dialog(DriftArgs *args,
         = gwy_enum_combo_box_new(gwy_interpolation_type_get_enum(), -1,
                                  G_CALLBACK(gwy_enum_combo_box_update_int),
                                  &args->interp, args->interp, TRUE);
-    gwy_table_attach_hscale(table, row, _("_Interpolation type:"), NULL,
+    gwy_table_attach_adjbar(table, row, _("_Interpolation type:"), NULL,
                             GTK_OBJECT(controls.interp),
                             GWY_HSCALE_WIDGET_NO_EXPAND);
     gtk_table_set_row_spacing(GTK_TABLE(table), row, 8);
@@ -305,7 +306,7 @@ drift_dialog(DriftArgs *args,
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(controls.do_correct),
                                  args->do_correct);
     gtk_table_attach(GTK_TABLE(table), controls.do_correct,
-                     0, 3, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
+                     0, 2, row, row+1, GTK_FILL, 0, 0, 0);
     g_signal_connect_swapped(controls.do_correct, "toggled",
                              G_CALLBACK(do_correct_changed), &controls);
     row++;
@@ -315,7 +316,7 @@ drift_dialog(DriftArgs *args,
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(controls.exclude_linear),
                                  args->exclude_linear);
     gtk_table_attach(GTK_TABLE(table), controls.exclude_linear,
-                     0, 3, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
+                     0, 2, row, row+1, GTK_FILL, 0, 0, 0);
     g_signal_connect_swapped(controls.exclude_linear, "toggled",
                              G_CALLBACK(exclude_linear_changed), &controls);
     row++;
@@ -325,7 +326,7 @@ drift_dialog(DriftArgs *args,
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(controls.do_graph),
                                  args->do_graph);
     gtk_table_attach(GTK_TABLE(table), controls.do_graph,
-                     0, 3, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
+                     0, 2, row, row+1, GTK_FILL, 0, 0, 0);
     g_signal_connect_swapped(controls.do_graph, "toggled",
                              G_CALLBACK(do_graph_changed), &controls);
     row++;
@@ -334,10 +335,6 @@ drift_dialog(DriftArgs *args,
     gtk_table_attach(GTK_TABLE(table), hbox2,
                      0, 4, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
 
-    label = gtk_label_new_with_mnemonic(_("Target _graph:"));
-    gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
-    gtk_box_pack_start(GTK_BOX(hbox2), label, FALSE, FALSE, 0);
-
     controls.target_graph = gwy_data_chooser_new_graphs();
     chooser = GWY_DATA_CHOOSER(controls.target_graph);
     gwy_data_chooser_set_none(chooser, _("New graph"));
@@ -345,9 +342,11 @@ drift_dialog(DriftArgs *args,
     gwy_data_chooser_set_filter(chooser, filter_target_graphs, &controls, NULL);
     gwy_data_chooser_set_active_id(chooser, &args->target_graph);
     gwy_data_chooser_get_active_id(chooser, &args->target_graph);
-    gtk_label_set_mnemonic_widget(GTK_LABEL(label), controls.target_graph);
-    gtk_widget_set_sensitive(hbox2, args->do_graph);
-    gtk_box_pack_end(GTK_BOX(hbox2), controls.target_graph, FALSE, FALSE, 0);
+    gwy_table_attach_adjbar(table, row, _("Target _graph:"), NULL,
+                            GTK_OBJECT(controls.target_graph),
+                            GWY_HSCALE_WIDGET_NO_EXPAND);
+    gwy_table_hscale_set_sensitive(GTK_OBJECT(controls.target_graph),
+                                   args->do_graph);
     g_signal_connect_swapped(controls.target_graph, "changed",
                              G_CALLBACK(target_graph_changed), &controls);
     row++;
@@ -356,7 +355,7 @@ drift_dialog(DriftArgs *args,
     label = gtk_label_new(_("Preview:"));
     gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
     gtk_table_attach(GTK_TABLE(table), label,
-                     0, 3, row, row+1, GTK_FILL, 0, 0, 0);
+                     0, 2, row, row+1, GTK_FILL, 0, 0, 0);
     row++;
 
     controls.preview_type
@@ -366,30 +365,32 @@ drift_dialog(DriftArgs *args,
                                     _("Drift _lines"), PREVIEW_MASK,
                                     NULL);
     row = gwy_radio_buttons_attach_to_table(controls.preview_type,
-                                            GTK_TABLE(table), 3, row);
+                                            GTK_TABLE(table), 2, row);
     gtk_table_set_row_spacing(GTK_TABLE(table), row-1, 8);
 
     controls.color_button = create_mask_color_button(controls.mydata, dialog,
                                                      0);
-    gwy_table_attach_hscale(table, row, _("_Mask color:"), NULL,
+    gwy_table_attach_adjbar(table, row, _("_Mask color:"), NULL,
                             GTK_OBJECT(controls.color_button),
                             GWY_HSCALE_WIDGET_NO_EXPAND);
     row++;
 
-    controls.distribute = gtk_check_button_new_with_label(_("Distribute"));
+    controls.distribute
+        = gtk_check_button_new_with_mnemonic(_("_Apply to all "
+                                               "compatible images"));
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(controls.distribute),
                                  args->distribute);
-    gtk_table_attach(GTK_TABLE(table), controls.distribute, 0, 3,
-                     row, row +1, GTK_FILL, 0, 0, 0);
+    gtk_table_attach(GTK_TABLE(table), controls.distribute,
+                     0, 2, row, row +1, GTK_FILL, 0, 0, 0);
     g_signal_connect_swapped(controls.distribute, "toggled",
                              G_CALLBACK(distribute_changed), &controls);
     row++;
 
-    controls.replace = gtk_check_button_new_with_label(_("Replace"));
+    controls.replace = gtk_check_button_new_with_label(_("Create new image"));
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(controls.replace),
-                                 args->replace);
-    gtk_table_attach(GTK_TABLE(table), controls.replace, 0, 3,
-                     row, row +1, GTK_FILL, 0, 0, 0);
+                                 !args->replace);
+    gtk_table_attach(GTK_TABLE(table), controls.replace,
+                     0, 2, row, row+1, GTK_FILL, 0, 0, 0);
     g_signal_connect_swapped(controls.replace, "toggled",
                              G_CALLBACK(replace_changed), &controls);
     row++;
@@ -660,7 +661,8 @@ do_graph_changed(DriftControls *controls,
 {
     DriftArgs *args = controls->args;
     args->do_graph = gtk_toggle_button_get_active(toggle);
-    gtk_widget_set_sensitive(controls->target_hbox, args->do_graph);
+    gwy_table_hscale_set_sensitive(GTK_OBJECT(controls->target_graph),
+                                   args->do_graph);
     update_target_graphs(controls);
     drift_invalidate(controls);
 }
@@ -693,7 +695,7 @@ static void
 replace_changed(DriftControls *controls,
                 GtkToggleButton *toggle)
 {
-    controls->args->replace = gtk_toggle_button_get_active(toggle);
+    controls->args->replace = !gtk_toggle_button_get_active(toggle);
     drift_invalidate(controls);
 }
 
