@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: dwt.c 18537 2016-03-28 18:11:19Z yeti-dn $
+ *  @(#) $Id: dwt.c 19948 2017-06-22 14:05:41Z yeti-dn $
  *  Copyright (C) 2003 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -77,7 +77,7 @@ static GwyModuleInfo module_info = {
     "2003",
 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, dwt)
 
 static gboolean
 module_register(void)
