@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: edge.c 19216 2016-11-09 10:39:06Z yeti-dn $
+ *  @(#) $Id: edge.c 19948 2017-06-22 14:05:41Z yeti-dn $
  *  Copyright (C) 2003-2007,2012 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -148,7 +148,7 @@ static GwyModuleInfo module_info = {
     "2004",
 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, edge)
 
 static gboolean
 module_register(void)
@@ -660,7 +660,7 @@ zero_crossing_dialog(ZeroCrossingArgs *args,
     controls.view = create_preview(controls.mydata, 0, PREVIEW_SIZE, FALSE);
     gtk_box_pack_start(GTK_BOX(hbox), controls.view, FALSE, FALSE, 4);
 
-    table = gtk_table_new(7, 4, FALSE);
+    table = gtk_table_new(7, 3, FALSE);
     gtk_table_set_row_spacings(GTK_TABLE(table), 2);
     gtk_table_set_col_spacings(GTK_TABLE(table), 6);
     gtk_container_set_border_width(GTK_CONTAINER(table), 4);
@@ -669,8 +669,8 @@ zero_crossing_dialog(ZeroCrossingArgs *args,
 
     adj = gtk_adjustment_new(args->gaussian_fwhm, 0.0, 20.0, 0.1, 1.0, 0);
     controls.gaussian_fwhm = adj;
-    gwy_table_attach_hscale(table, row, _("_Gaussian FWHM:"), "px", adj,
-                            GWY_HSCALE_DEFAULT);
+    gwy_table_attach_adjbar(table, row, _("_Gaussian FWHM:"), _("px"),
+                            adj, GWY_HSCALE_SQRT);
     g_signal_connect(adj, "value-changed",
                      G_CALLBACK(zero_crossing_gaussian_fwhm_changed),
                      &controls);
@@ -678,8 +678,8 @@ zero_crossing_dialog(ZeroCrossingArgs *args,
 
     adj = gtk_adjustment_new(args->threshold, 0.0, 3.0, 0.01, 0.1, 0);
     controls.threshold = adj;
-    gwy_table_attach_hscale(table, row, _("_Threshold:"), _("NRMS"), adj,
-                            GWY_HSCALE_DEFAULT);
+    gwy_table_attach_adjbar(table, row, _("_Threshold:"), _("NRMS"), adj,
+                            GWY_HSCALE_SQRT);
     g_signal_connect(adj, "value-changed",
                      G_CALLBACK(zero_crossing_threshold_changed), &controls);
     gtk_table_set_row_spacing(GTK_TABLE(table), row, 8);
@@ -688,7 +688,7 @@ zero_crossing_dialog(ZeroCrossingArgs *args,
     label = gtk_label_new(gwy_sgettext("verb|Display"));
     gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
     gtk_table_attach(GTK_TABLE(table), label,
-                     0, 3, row, row+1, GTK_FILL, 0, 0, 0);
+                     0, 2, row, row+1, GTK_FILL, 0, 0, 0);
     row++;
 
     controls.display_group
@@ -699,14 +699,14 @@ zero_crossing_dialog(ZeroCrossingArgs *args,
                                     _("Detected st_ep"), DISPLAY_SHOW,
                                     NULL);
     row = gwy_radio_buttons_attach_to_table(controls.display_group,
-                                            GTK_TABLE(table), 3, row);
+                                            GTK_TABLE(table), 2, row);
     gtk_table_set_row_spacing(GTK_TABLE(table), row-1, 8);
 
     controls.update = gtk_check_button_new_with_mnemonic(_("I_nstant updates"));
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(controls.update),
                                  args->update);
     gtk_table_attach(GTK_TABLE(table), controls.update,
-                     0, 3, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
+                     0, 2, row, row+1, GTK_FILL, 0, 0, 0);
     g_signal_connect(controls.update, "toggled",
                      G_CALLBACK(zero_crossing_update_changed), &controls);
 
