@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: entropy.c 18537 2016-03-28 18:11:19Z yeti-dn $
+ *  @(#) $Id: entropy.c 19948 2017-06-22 14:05:41Z yeti-dn $
  *  Copyright (C) 2015 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
@@ -111,12 +111,12 @@ static GwyModuleInfo module_info = {
     &module_register,
     N_("Visualizes entropy calculation for value and slope distribution."),
     "Yeti <yeti@gwyddion.net>",
-    "1.0",
+    "1.1",
     "David Nečas (Yeti)",
     "2015",
 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, entropy)
 
 static gboolean
 module_register(void)
@@ -190,7 +190,7 @@ entropy_dialog(EntropyArgs *args, GwyDataField *dfield, GwyDataField *mfield)
     gtk_box_pack_start(GTK_BOX(GTK_DIALOG(dialog)->vbox), hbox,
                        TRUE, TRUE, 0);
 
-    table = gtk_table_new(8 + 4*(!!mfield), 4, FALSE);
+    table = gtk_table_new(8 + 4*(!!mfield), 3, FALSE);
     gtk_table_set_row_spacings(GTK_TABLE(table), 2);
     gtk_table_set_col_spacings(GTK_TABLE(table), 6);
     gtk_container_set_border_width(GTK_CONTAINER(table), 4);
@@ -208,12 +208,12 @@ entropy_dialog(EntropyArgs *args, GwyDataField *dfield, GwyDataField *mfield)
                                     ENTROPY_ANGLES,
                                     NULL);
     row = gwy_radio_buttons_attach_to_table(controls.mode,
-                                            GTK_TABLE(table), 3, row);
+                                            GTK_TABLE(table), 2, row);
     if (mfield) {
         gtk_table_set_row_spacing(GTK_TABLE(table), row-1, 8);
         label = gwy_label_new_header(_("Masking Mode"));
         gtk_table_attach(GTK_TABLE(table), label,
-                        0, 3, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
+                        0, 2, row, row+1, GTK_FILL, 0, 0, 0);
         row++;
 
         controls.masking
@@ -221,7 +221,7 @@ entropy_dialog(EntropyArgs *args, GwyDataField *dfield, GwyDataField *mfield)
                                        G_CALLBACK(masking_changed), &controls,
                                        args->masking);
         row = gwy_radio_buttons_attach_to_table(controls.masking,
-                                                GTK_TABLE(table), 3, row);
+                                                GTK_TABLE(table), 2, row);
     }
     else
         controls.masking = NULL;
@@ -232,15 +232,15 @@ entropy_dialog(EntropyArgs *args, GwyDataField *dfield, GwyDataField *mfield)
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(controls.fit_plane),
                                  args->fit_plane);
     gtk_table_attach(GTK_TABLE(table), controls.fit_plane,
-                     0, 4, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
+                     0, 2, row, row+1, GTK_FILL, 0, 0, 0);
     g_signal_connect_swapped(controls.fit_plane, "toggled",
                              G_CALLBACK(fit_plane_changed), &controls);
     row++;
 
     controls.kernel_size = gtk_adjustment_new(args->kernel_size,
                                               2, 16, 1, 4, 0);
-    gwy_table_attach_hscale(table, row, _("_Plane size:"), "px",
-                            controls.kernel_size, 0);
+    gwy_table_attach_adjbar(table, row, _("_Plane size:"), _("px"),
+                            controls.kernel_size, GWY_HSCALE_LINEAR);
     g_signal_connect_swapped(controls.kernel_size, "value-changed",
                              G_CALLBACK(kernel_size_changed), &controls);
     row++;
@@ -251,7 +251,7 @@ entropy_dialog(EntropyArgs *args, GwyDataField *dfield, GwyDataField *mfield)
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(controls.zoom_in),
                                  args->zoom_in);
     gtk_table_attach(GTK_TABLE(table), controls.zoom_in,
-                     0, 4, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
+                     0, 2, row, row+1, GTK_FILL, 0, 0, 0);
     g_signal_connect_swapped(controls.zoom_in, "toggled",
                              G_CALLBACK(zoom_in_changed), &controls);
     row++;
@@ -259,22 +259,22 @@ entropy_dialog(EntropyArgs *args, GwyDataField *dfield, GwyDataField *mfield)
     label = gtk_label_new(_("Entropy:"));
     gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
     gtk_table_attach(GTK_TABLE(table), label,
-                     0, 2, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
+                     0, 1, row, row+1, GTK_FILL, 0, 0, 0);
     label = gtk_label_new("");
     gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
     gtk_table_attach(GTK_TABLE(table), label,
-                     2, 3, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
+                     1, 2, row, row+1, GTK_FILL, 0, 0, 0);
     controls.entropy = label;
     row++;
 
     label = gtk_label_new(_("Entropy deficit:"));
     gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
     gtk_table_attach(GTK_TABLE(table), label,
-                     0, 2, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
+                     0, 1, row, row+1, GTK_FILL, 0, 0, 0);
     label = gtk_label_new("");
     gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
     gtk_table_attach(GTK_TABLE(table), label,
-                     2, 3, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
+                     1, 2, row, row+1, GTK_FILL, 0, 0, 0);
     controls.entropydef = label;
     row++;
 
@@ -283,6 +283,7 @@ entropy_dialog(EntropyArgs *args, GwyDataField *dfield, GwyDataField *mfield)
     gmodel = gwy_graph_model_new();
     controls.graph = gwy_graph_new(gmodel);
     g_object_unref(gmodel);
+    gwy_graph_enable_user_input(GWY_GRAPH(controls.graph), FALSE);
     gtk_widget_set_size_request(controls.graph, 400, 320);
     gtk_box_pack_start(GTK_BOX(hbox), controls.graph, TRUE, TRUE, 0);
 
