@@ -1,6 +1,6 @@
 /*
- *  @(#) $Id: extend.c 18537 2016-03-28 18:11:19Z yeti-dn $
- *  Copyright (C) 2010-2014 David Necas (Yeti).
+ *  @(#) $Id: extend.c 19948 2017-06-22 14:05:41Z yeti-dn $
+ *  Copyright (C) 2010-2017 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -106,12 +106,12 @@ static GwyModuleInfo module_info = {
     &module_register,
     N_("Extends image by adding borders."),
     "Yeti <yeti@gwyddion.net>",
-    "1.2",
+    "1.3",
     "David Nečas (Yeti)",
     "2012",
 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, extend)
 
 static gboolean
 module_register(void)
@@ -213,33 +213,33 @@ extend_dialog(ExtendArgs *args)
     /* Borders */
     label = gwy_label_new_header(_("Borders"));
     gtk_table_attach(GTK_TABLE(table), label,
-                     0, 3, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
+                     0, 2, row, row+1, GTK_FILL, 0, 0, 0);
     row++;
 
     controls.up = gtk_adjustment_new(args->up, 0, EXTEND_MAX, 1, 10, 0);
-    gwy_table_attach_hscale(table, row, _("_Up:"), "px",
-                            controls.up, GWY_HSCALE_SQRT);
+    gwy_table_attach_adjbar(table, row, _("_Up:"), _("px"),
+                            controls.up, GWY_HSCALE_DEFAULT);
     g_signal_connect(controls.up, "value-changed",
                      G_CALLBACK(up_changed), &controls);
     row++;
 
     controls.down = gtk_adjustment_new(args->down, 0, EXTEND_MAX, 1, 10, 0);
-    gwy_table_attach_hscale(table, row, _("_Down:"), "px",
-                            controls.down, GWY_HSCALE_SQRT);
+    gwy_table_attach_adjbar(table, row, _("_Down:"), _("px"),
+                            controls.down, GWY_HSCALE_DEFAULT);
     g_signal_connect(controls.down, "value-changed",
                      G_CALLBACK(down_changed), &controls);
     row++;
 
     controls.left = gtk_adjustment_new(args->left, 0, EXTEND_MAX, 1, 10, 0);
-    gwy_table_attach_hscale(table, row, _("_Left:"), "px",
-                            controls.left, GWY_HSCALE_SQRT);
+    gwy_table_attach_adjbar(table, row, _("_Left:"), _("px"),
+                            controls.left, GWY_HSCALE_DEFAULT);
     g_signal_connect(controls.left, "value-changed",
                      G_CALLBACK(left_changed), &controls);
     row++;
 
     controls.right = gtk_adjustment_new(args->right, 0, EXTEND_MAX, 1, 10, 0);
-    gwy_table_attach_hscale(table, row, _("_Right:"), "px",
-                            controls.right, GWY_HSCALE_SQRT);
+    gwy_table_attach_adjbar(table, row, _("_Right:"), _("px"),
+                            controls.right, GWY_HSCALE_DEFAULT);
     g_signal_connect(controls.right, "value-changed",
                      G_CALLBACK(right_changed), &controls);
     row++;
@@ -249,7 +249,7 @@ extend_dialog(ExtendArgs *args)
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(controls.symmetrical),
                                  controls.is_symmetrical);
     gtk_table_attach(GTK_TABLE(table), controls.symmetrical,
-                     0, 3, row, row+1, GTK_FILL, 0, 0, 0);
+                     0, 2, row, row+1, GTK_FILL, 0, 0, 0);
     g_signal_connect(controls.symmetrical, "toggled",
                      G_CALLBACK(symmetrical_toggled), &controls);
     row++;
@@ -258,7 +258,7 @@ extend_dialog(ExtendArgs *args)
     gtk_table_set_row_spacing(GTK_TABLE(table), row-1, 8);
     label = gwy_label_new_header(_("Options"));
     gtk_table_attach(GTK_TABLE(table), label,
-                     0, 3, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
+                     0, 2, row, row+1, GTK_FILL, 0, 0, 0);
     row++;
 
     controls.exterior
@@ -272,7 +272,7 @@ extend_dialog(ExtendArgs *args)
                                   gwy_sgettext("exterior|Periodic"),
                                   GWY_EXTERIOR_PERIODIC,
                                   NULL);
-    gwy_table_attach_hscale(table, row, _("_Exterior type:"), NULL,
+    gwy_table_attach_adjbar(table, row, _("_Exterior type:"), NULL,
                             GTK_OBJECT(controls.exterior),
                             GWY_HSCALE_WIDGET_NO_EXPAND);
     gtk_table_set_row_spacing(GTK_TABLE(table), row, 8);
@@ -284,17 +284,17 @@ extend_dialog(ExtendArgs *args)
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(controls.keep_offsets),
                                  args->keep_offsets);
     gtk_table_attach(GTK_TABLE(table), controls.keep_offsets,
-                     0, 3, row, row+1, GTK_FILL, 0, 0, 0);
+                     0, 2, row, row+1, GTK_FILL, 0, 0, 0);
     g_signal_connect(controls.keep_offsets, "toggled",
                      G_CALLBACK(keep_offsets_toggled), &controls);
     row++;
 
     controls.new_channel
-        = gtk_check_button_new_with_mnemonic(_("Create new channel"));
+        = gtk_check_button_new_with_mnemonic(_("Create new image"));
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(controls.new_channel),
                                  args->new_channel);
     gtk_table_attach(GTK_TABLE(table), controls.new_channel,
-                     0, 3, row, row+1, GTK_FILL, 0, 0, 0);
+                     0, 2, row, row+1, GTK_FILL, 0, 0, 0);
     g_signal_connect(controls.new_channel, "toggled",
                      G_CALLBACK(new_channel_toggled), &controls);
     row++;
