@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: extract_path.c 18886 2016-08-26 08:26:22Z yeti-dn $
+ *  @(#) $Id: extract_path.c 19948 2017-06-22 14:05:41Z yeti-dn $
  *  Copyright (C) 2016 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
@@ -91,7 +91,7 @@ static GwyModuleInfo module_info = {
     "2016",
 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, extract_path)
 
 static gboolean
 module_register(void)
