@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: facet-level.c 18537 2016-03-28 18:11:19Z yeti-dn $
+ *  @(#) $Id: facet-level.c 19948 2017-06-22 14:05:41Z yeti-dn $
  *  Copyright (C) 2004,2008 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -70,7 +70,7 @@ static GwyModuleInfo module_info = {
     "2004",
 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, facet_level)
 
 static gboolean
 module_register(void)
@@ -206,14 +206,14 @@ level_dialog(LevelArgs *args,
 
     label = gwy_label_new_header(_("Masking Mode"));
     gtk_table_attach(GTK_TABLE(table), label,
-                     0, 3, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
+                     0, 2, row, row+1, GTK_FILL, 0, 0, 0);
     row++;
 
     controls.masking = gwy_radio_buttons_create(gwy_masking_type_get_enum(), -1,
                                                 G_CALLBACK(masking_changed),
                                                 &controls, args->masking);
     row = gwy_radio_buttons_attach_to_table(controls.masking, GTK_TABLE(table),
-                                            3, row);
+                                            2, row);
 
     gtk_widget_show_all(dialog);
     do {
