@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: facet_analysis.c 18537 2016-03-28 18:11:19Z yeti-dn $
+ *  @(#) $Id: facet_analysis.c 19948 2017-06-22 14:05:41Z yeti-dn $
  *  Copyright (C) 2003-2015 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -35,6 +35,7 @@
 #include <libprocess/filters.h>
 #include <libprocess/grains.h>
 #include <libgwydgets/gwycombobox.h>
+#include <libgwydgets/gwyradiobuttons.h>
 #include <libgwymodule/gwymodule-process.h>
 #include <app/gwymoduleutils.h>
 #include <app/gwyapp.h>
@@ -73,7 +74,7 @@ typedef struct {
     GtkObject *tolerance;
     GtkObject *kernel_size;
     GtkWidget *combine;
-    GtkWidget *combine_type;
+    GSList *combine_type;
     GtkWidget *color_button;
     GwyContainer *mydata;
     GwyContainer *fdata;
@@ -112,10 +113,9 @@ static void     update_average_angle             (FacetsControls *controls,
 static void     preview_selection_updated        (GwySelection *selection,
                                                   gint id,
                                                   FacetsControls *controls);
-static void     combine_changed                  (GtkToggleButton *toggle,
-                                                  FacetsControls *controls);
-static void     combine_type_changed             (GtkComboBox *combo,
-                                                  FacetsControls *controls);
+static void     combine_changed                  (FacetsControls *controls,
+                                                  GtkToggleButton *toggle);
+static void     combine_type_changed             (FacetsControls *controls);
 static void     gwy_data_field_mark_facets       (GwyDataField *dtheta,
                                                   GwyDataField *dphi,
                                                   gdouble theta0,
@@ -163,12 +163,12 @@ static GwyModuleInfo module_info = {
     &module_register,
     N_("Visualizes, marks and measures facet orientation."),
     "Yeti <yeti@gwyddion.net>",
-    "1.9",
+    "1.11",
     "David Nečas (Yeti) & Petr Klapetek",
     "2005",
 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, facet_analysis)
 
 static gboolean
 module_register(void)
@@ -227,7 +227,7 @@ add_angle_label(GtkWidget *table,
     GtkWidget *label;
     GtkRequisition req;
 
-    label = gtk_label_new("-188.00 deg");
+    label = gtk_label_new("-188.00");
     gtk_widget_size_request(label, &req);
 
     gtk_label_set_text(GTK_LABEL(label), name);
@@ -235,11 +235,16 @@ add_angle_label(GtkWidget *table,
     gtk_table_attach(GTK_TABLE(table), label,
                      0, 1, *row, *row+1, GTK_FILL, 0, 0, 0);
 
+    label = gtk_label_new(_("deg"));
+    gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
+    gtk_table_attach(GTK_TABLE(table), label,
+                     2, 3, *row, *row+1, GTK_FILL, 0, 0, 0);
+
     label = gtk_label_new(NULL);
     gtk_widget_set_size_request(label, req.width, -1);
     gtk_misc_set_alignment(GTK_MISC(label), 1.0, 0.5);
     gtk_table_attach(GTK_TABLE(table), label,
-                     1, 2, *row, *row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
+                     1, 2, *row, *row+1, GTK_FILL, 0, 0, 0);
     (*row)++;
 
     return label;
@@ -255,7 +260,6 @@ facets_dialog(FacetsArgs *args,
               GQuark mquark)
 {
     GtkWidget *dialog, *table, *hbox, *hbox2, *vbox, *label, *scale, *button;
-    GtkWidget *spin;
     FacetsControls controls;
     gint response;
     GwySelection *selection;
@@ -314,7 +318,7 @@ facets_dialog(FacetsArgs *args,
 
 
     /* Info table */
-    table = gtk_table_new(7, 2, FALSE);
+    table = gtk_table_new(7, 3, FALSE);
     gtk_table_set_row_spacings(GTK_TABLE(table), 2);
     gtk_table_set_col_spacings(GTK_TABLE(table), 6);
     gtk_container_set_border_width(GTK_CONTAINER(table), 4);
@@ -332,12 +336,12 @@ facets_dialog(FacetsArgs *args,
 
     button = gtk_button_new_with_mnemonic(_("_Find Maximum"));
     gtk_table_attach(GTK_TABLE(table), button,
-                     0, 2, row, row+1, GTK_FILL, 0, 0, 0);
+                     0, 3, row, row+1, GTK_FILL, 0, 0, 0);
     g_signal_connect_swapped(button, "clicked",
                              G_CALLBACK(facet_view_reset_maximum), &controls);
-    gtk_table_set_row_spacing(GTK_TABLE(table), row, 8);
     row++;
 
+    gtk_table_set_row_spacing(GTK_TABLE(table), row-1, 8);
     label = gwy_label_new_header(_("Mean Normal"));
     gtk_table_attach(GTK_TABLE(table), label,
                      0, 2, row, row+1, GTK_FILL, 0, 0, 0);
@@ -345,66 +349,45 @@ facets_dialog(FacetsArgs *args,
 
     controls.mtheta_label = add_angle_label(table, _("θ:"), &row);
     controls.mphi_label = add_angle_label(table, _("φ:"), &row);
-    gtk_table_set_row_spacing(GTK_TABLE(table), row-1, 8);
 
-    label = gtk_label_new_with_mnemonic(_("Facet plane size:"));
-    gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
-    gtk_table_attach(GTK_TABLE(table), label,
-                     0, 2, row, row+1, GTK_FILL, 0, 0, 0);
-    row++;
-
-    controls.kernel_size = gtk_adjustment_new(args->kernel_size,
-                                              0.0, MAX_PLANE_SIZE, 1.0, 1.0, 0);
-    spin = gtk_spin_button_new(GTK_ADJUSTMENT(controls.kernel_size), 0.0, 0);
-    gtk_label_set_mnemonic_widget(GTK_LABEL(label), spin);
-    gtk_table_attach(GTK_TABLE(table), spin,
-                     0, 1, row, row+1, 0, 0, 0, 0);
-    g_signal_connect(controls.kernel_size, "value-changed",
-                     G_CALLBACK(facet_view_recompute), &controls);
-    row++;
-
-    table = gtk_table_new(4 + 2*(!!mfield), 4, FALSE);
+    table = gtk_table_new(5 + 1*(!!mfield), 3, FALSE);
     gtk_table_set_row_spacings(GTK_TABLE(table), 2);
     gtk_table_set_col_spacings(GTK_TABLE(table), 6);
     gtk_container_set_border_width(GTK_CONTAINER(table), 4);
     gtk_box_pack_start(GTK_BOX(vbox), table, TRUE, TRUE, 4);
     row = 0;
 
+    controls.kernel_size = gtk_adjustment_new(args->kernel_size,
+                                              0.0, MAX_PLANE_SIZE, 1.0, 1.0, 0);
+    gwy_table_attach_adjbar(table, row, _("Facet plane size:"), _("px"),
+                            controls.kernel_size, GWY_HSCALE_LINEAR);
+    g_signal_connect(controls.kernel_size, "value-changed",
+                     G_CALLBACK(facet_view_recompute), &controls);
+    row++;
+
     controls.tolerance = gtk_adjustment_new(args->tolerance*180.0/G_PI,
                                             0.0, 15.0, 0.01, 0.1, 0);
-    scale = gwy_table_attach_hscale(table, row++, _("_Tolerance:"), _("deg"),
-                                    controls.tolerance, 0);
+    scale = gwy_table_attach_adjbar(table, row++, _("_Tolerance:"), _("deg"),
+                                    controls.tolerance, GWY_HSCALE_SQRT);
     gtk_spin_button_set_digits(GTK_SPIN_BUTTON(scale), 3);
     g_signal_connect(controls.tolerance, "value-changed",
                      G_CALLBACK(facets_tolerance_changed), &controls);
 
     if (mfield) {
         gwy_container_set_object_by_name(controls.fdata, "/1/mask", mfield);
-        controls.combine
-            = gtk_check_button_new_with_mnemonic(_("Com_bine with "
-                                                   "existing mask"));
-        gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(controls.combine),
-                                     args->combine);
-        gtk_table_attach(GTK_TABLE(table), controls.combine,
-                         0, 3, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
-        g_signal_connect(controls.combine, "toggled",
-                         G_CALLBACK(combine_changed), &controls);
-        row++;
-
-        controls.combine_type
-            = gwy_enum_combo_box_new(gwy_merge_type_get_enum(), -1,
-                                     G_CALLBACK(combine_type_changed), &controls,
-                                     args->combine_type, TRUE);
-        gwy_table_attach_hscale(table, row, _("Operation:"), NULL,
-                                GTK_OBJECT(controls.combine_type),
-                                GWY_HSCALE_WIDGET);
-        gtk_table_set_row_spacing(GTK_TABLE(table), row, 8);
+        create_mask_merge_buttons(table, row, NULL,
+                                  args->combine,
+                                  G_CALLBACK(combine_changed),
+                                  args->combine_type,
+                                  G_CALLBACK(combine_type_changed),
+                                  &controls,
+                                  &controls.combine, &controls.combine_type);
         row++;
     }
 
     controls.color_button = create_mask_color_button(controls.mydata, dialog,
                                                      0);
-    gwy_table_attach_hscale(table, row, _("_Mask color:"), NULL,
+    gwy_table_attach_adjbar(table, row, _("_Mask color:"), NULL,
                             GTK_OBJECT(controls.color_button),
                             GWY_HSCALE_WIDGET_NO_EXPAND);
     row++;
@@ -417,7 +400,7 @@ facets_dialog(FacetsArgs *args,
         gtk_label_set_line_wrap(GTK_LABEL(label), TRUE);
         gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
         gtk_table_attach(GTK_TABLE(table), label,
-                         0, 4, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
+                         0, 3, row, row+1, GTK_FILL, 0, 0, 0);
         row++;
     }
 
@@ -581,11 +564,11 @@ facet_view_selection_updated(GwySelection *selection,
     y = xy[1] - G_SQRT2/q;
     xy_to_angles(x, y, &theta, &phi);
 
-    g_snprintf(s, sizeof(s), "%.2f deg", 180.0/G_PI*theta);
+    g_snprintf(s, sizeof(s), "%.2f", 180.0/G_PI*theta);
     gtk_label_set_text(GTK_LABEL(controls->theta_label), s);
     controls->args->theta0 = theta;
 
-    g_snprintf(s, sizeof(s), "%.2f deg", 180.0/G_PI*phi);
+    g_snprintf(s, sizeof(s), "%.2f", 180.0/G_PI*phi);
     gtk_label_set_text(GTK_LABEL(controls->phi_label), s);
     controls->args->phi0 = phi;
 
@@ -614,9 +597,9 @@ update_average_angle(FacetsControls *controls,
                                                            "/0/mask"));
     calculate_average_angle(dtheta, dphi, mask, &theta, &phi);
 
-    g_snprintf(s, sizeof(s), "%.2f deg", 180.0/G_PI*theta);
+    g_snprintf(s, sizeof(s), "%.2f", 180.0/G_PI*theta);
     gtk_label_set_text(GTK_LABEL(controls->mtheta_label), s);
-    g_snprintf(s, sizeof(s), "%.2f deg", 180.0/G_PI*phi);
+    g_snprintf(s, sizeof(s), "%.2f", 180.0/G_PI*phi);
     gtk_label_set_text(GTK_LABEL(controls->mphi_label), s);
 }
 
@@ -691,21 +674,20 @@ gwy_data_field_mark_facets(GwyDataField *dtheta,
                            GwyDataField *mask)
 {
     gdouble cr, cth0, sth0, cro;
-    const gdouble *xd, *yd;
+    const gdouble *td, *fd;
     gdouble *md;
-    gint i;
+    guint i, n;
 
     cr = cos(tolerance);
     cth0 = cos(theta0);
     sth0 = sin(theta0);
 
-    xd = gwy_data_field_get_data_const(dtheta);
-    yd = gwy_data_field_get_data_const(dphi);
+    td = gwy_data_field_get_data_const(dtheta);
+    fd = gwy_data_field_get_data_const(dphi);
     md = gwy_data_field_get_data(mask);
-    for (i = gwy_data_field_get_xres(dtheta)*gwy_data_field_get_yres(dtheta);
-         i;
-         i--, xd++, yd++, md++) {
-        cro = cth0*cos(*xd) + sth0*sin(*xd)*cos(*yd - phi0);
+    n = gwy_data_field_get_xres(dtheta)*gwy_data_field_get_yres(dtheta);
+    for (i = n; i; i--, td++, fd++, md++) {
+        cro = cth0*cos(*td) + sth0*sin(*td)*cos(*fd - phi0);
         *md = (cro >= cr);
     }
 }
@@ -921,15 +903,16 @@ facets_tolerance_changed(GtkAdjustment *adj,
 }
 
 static void
-combine_changed(GtkToggleButton *toggle, FacetsControls *controls)
+combine_changed(FacetsControls *controls, GtkToggleButton *toggle)
 {
     controls->args->combine = gtk_toggle_button_get_active(toggle);
 }
 
 static void
-combine_type_changed(GtkComboBox *combo, FacetsControls *controls)
+combine_type_changed(FacetsControls *controls)
 {
-    controls->args->combine_type = gwy_enum_combo_box_get_active(combo);
+    controls->args->combine_type
+        = gwy_radio_buttons_get_current(controls->combine_type);
 }
 
 static void
