@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: fbm_synth.c 19044 2016-10-08 19:10:46Z yeti-dn $
+ *  @(#) $Id: fbm_synth.c 19948 2017-06-22 14:05:41Z yeti-dn $
  *  Copyright (C) 2014 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
@@ -161,12 +161,12 @@ static GwyModuleInfo module_info = {
     &module_register,
     N_("Generates random surfaces similar to fractional Brownian motion."),
     "Yeti <yeti@gwyddion.net>",
-    "1.0",
+    "1.1",
     "David Nečas (Yeti)",
     "2014",
 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, fbm_synth)
 
 static gboolean
 module_register(void)
@@ -362,7 +362,7 @@ fbm_synth_dialog(FBMSynthArgs *args,
         g_signal_connect_swapped(controls.dims->add, "toggled",
                                  G_CALLBACK(fbm_synth_invalidate), &controls);
 
-    table = gtk_table_new(6 + (dfield_template ? 1 : 0), 4, FALSE);
+    table = gtk_table_new(6 + (dfield_template ? 1 : 0), 3, FALSE);
     controls.table = GTK_TABLE(table);
     gtk_table_set_row_spacings(controls.table, 2);
     gtk_table_set_col_spacings(controls.table, 6);
@@ -372,28 +372,28 @@ fbm_synth_dialog(FBMSynthArgs *args,
     row = 0;
 
     controls.H = gtk_adjustment_new(args->H, -0.999, 0.999, 0.001, 0.1, 0);
-    gwy_table_attach_hscale(table, row, _("_Hurst exponent:"), NULL,
-                            controls.H, GWY_HSCALE_DEFAULT);
+    gwy_table_attach_adjbar(table, row, _("_Hurst exponent:"), NULL,
+                            controls.H, GWY_HSCALE_LINEAR);
     g_signal_connect_swapped(controls.H, "value-changed",
                              G_CALLBACK(H_changed), &controls);
     row++;
 
     controls.hom_scale = gtk_adjustment_new(args->hom_scale,
                                             2, 8192, 1, 10, 0);
-    gwy_table_attach_hscale(table, row, _("_Stationarity scale:"), "px",
+    gwy_table_attach_adjbar(table, row, _("_Stationarity scale:"), _("px"),
                             controls.hom_scale, GWY_HSCALE_SQRT);
     g_signal_connect_swapped(controls.hom_scale, "value-changed",
                              G_CALLBACK(hom_scale_changed), &controls);
     row++;
 
     controls.distribution = distribution_selector_new(&controls);
-    gwy_table_attach_hscale(table, row, _("_Distribution:"), NULL,
+    gwy_table_attach_adjbar(table, row, _("_Distribution:"), NULL,
                             GTK_OBJECT(controls.distribution),
-                            GWY_HSCALE_WIDGET);
+                            GWY_HSCALE_WIDGET_NO_EXPAND);
     row++;
 
     controls.power = gtk_adjustment_new(args->power, 2.01, 12.0, 0.01, 0.1, 0);
-    gwy_table_attach_hscale(table, row, _("Po_wer:"), NULL,
+    gwy_table_attach_adjbar(table, row, _("Po_wer:"), NULL,
                             controls.power, GWY_HSCALE_SQRT);
     gwy_table_hscale_set_sensitive(controls.power,
                                    args->distribution == FBM_DISTRIBUTION_POWER);
@@ -402,18 +402,17 @@ fbm_synth_dialog(FBMSynthArgs *args,
     row++;
 
     gtk_table_set_row_spacing(GTK_TABLE(table), row-1, 8);
-
     row = gwy_synth_attach_height(&controls, row,
                                   &controls.sigma, &args->sigma,
                                   _("_RMS:"), NULL, &controls.sigma_units);
 
     if (dfield_template) {
         controls.sigma_init
-            = gtk_button_new_with_mnemonic(_("_Like Current Channel"));
+            = gtk_button_new_with_mnemonic(_("_Like Current Image"));
         g_signal_connect_swapped(controls.sigma_init, "clicked",
                                  G_CALLBACK(sigma_init_clicked), &controls);
         gtk_table_attach(GTK_TABLE(table), controls.sigma_init,
-                         1, 3, row, row+1, GTK_FILL, 0, 0, 0);
+                         0, 2, row, row+1, GTK_FILL, 0, 0, 0);
         row++;
     }
 
