@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: fft.c 19044 2016-10-08 19:10:46Z yeti-dn $
+ *  @(#) $Id: fft.c 19948 2017-06-22 14:05:41Z yeti-dn $
  *  Copyright (C) 2003-2015 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -124,12 +124,12 @@ static GwyModuleInfo module_info = {
     &module_register,
     N_("Two-dimensional FFT (Fast Fourier Transform)."),
     "Petr Klapetek <klapetek@gwyddion.net>",
-    "2.1",
+    "2.2",
     "David Nečas (Yeti) & Petr Klapetek",
     "2003",
 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, fft)
 
 static gboolean
 module_register(void)
@@ -340,7 +340,7 @@ fft_dialog(FFTArgs *args,
     gtk_dialog_set_default_response(GTK_DIALOG(dialog), GTK_RESPONSE_OK);
     gwy_help_add_to_proc_dialog(GTK_DIALOG(dialog), GWY_HELP_DEFAULT);
 
-    table = gtk_table_new(7, 4, FALSE);
+    table = gtk_table_new(7, 3, FALSE);
     gtk_table_set_row_spacings(GTK_TABLE(table), 2);
     gtk_table_set_col_spacings(GTK_TABLE(table), 6);
     gtk_container_set_border_width(GTK_CONTAINER(table), 4);
@@ -351,7 +351,7 @@ fft_dialog(FFTArgs *args,
     controls.raw_transform
         = gtk_check_button_new_with_mnemonic(_("Ra_w transform"));
     gtk_table_attach(GTK_TABLE(table), controls.raw_transform,
-                     0, 3, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
+                     0, 2, row, row+1, GTK_FILL, 0, 0, 0);
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(controls.raw_transform),
                                  args->raw_transform);
     g_signal_connect(controls.raw_transform, "toggled",
@@ -363,15 +363,13 @@ fft_dialog(FFTArgs *args,
                                 fft_imgpart_filter, dfield, NULL);
     gwy_data_chooser_set_active_id(GWY_DATA_CHOOSER(controls.imgpart),
                                    &args->imgpart);
-    gwy_table_attach_hscale(table, row, _("I_maginary part:"), NULL,
+    gwy_table_attach_adjbar(table, row, _("I_maginary part:"), NULL,
                             GTK_OBJECT(controls.imgpart),
-                            GWY_HSCALE_WIDGET | GWY_HSCALE_CHECK);
+                            GWY_HSCALE_WIDGET_NO_EXPAND | GWY_HSCALE_CHECK);
     controls.use_imgpart
         = gwy_table_hscale_get_check(GTK_OBJECT(controls.imgpart));
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(controls.use_imgpart),
                                  args->use_imgpart);
-    gwy_table_hscale_set_sensitive(GTK_OBJECT(controls.imgpart),
-                                   args->use_imgpart);
     g_signal_connect(controls.imgpart, "changed",
                      G_CALLBACK(imgpart_changed), args);
     g_signal_connect(controls.use_imgpart, "toggled",
@@ -381,7 +379,7 @@ fft_dialog(FFTArgs *args,
     controls.inverse_transform
         = gtk_check_button_new_with_mnemonic(_("_Inverse transform"));
     gtk_table_attach(GTK_TABLE(table), controls.inverse_transform,
-                     0, 3, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
+                     0, 2, row, row+1, GTK_FILL, 0, 0, 0);
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(controls.inverse_transform),
                                  args->inverse_transform);
     g_signal_connect(controls.inverse_transform, "toggled",
@@ -392,9 +390,9 @@ fft_dialog(FFTArgs *args,
         = gwy_enum_combo_box_new(fft_outputs, G_N_ELEMENTS(fft_outputs),
                                  G_CALLBACK(gwy_enum_combo_box_update_int),
                                  &args->out, args->out, TRUE);
-    gwy_table_attach_hscale(table, row, _("Output _type:"), NULL,
+    gwy_table_attach_adjbar(table, row, _("Output _type:"), NULL,
                             GTK_OBJECT(controls.out),
-                            GWY_HSCALE_WIDGET);
+                            GWY_HSCALE_WIDGET_NO_EXPAND);
     row++;
 
     gtk_table_set_row_spacing(GTK_TABLE(table), row-1, 8);
@@ -402,16 +400,16 @@ fft_dialog(FFTArgs *args,
         = gwy_enum_combo_box_new(gwy_windowing_type_get_enum(), -1,
                                  G_CALLBACK(gwy_enum_combo_box_update_int),
                                  &args->window, args->window, TRUE);
-    gwy_table_attach_hscale(table, row, _("_Windowing type:"), NULL,
+    gwy_table_attach_adjbar(table, row, _("_Windowing type:"), NULL,
                             GTK_OBJECT(controls.window),
-                            GWY_HSCALE_WIDGET);
+                            GWY_HSCALE_WIDGET_NO_EXPAND);
     row++;
 
     controls.zeromean
         = gtk_check_button_new_with_mnemonic(_("Subtract mean _value "
                                                "beforehand"));
     gtk_table_attach(GTK_TABLE(table), controls.zeromean,
-                     0, 3, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
+                     0, 2, row, row+1, GTK_FILL, 0, 0, 0);
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(controls.zeromean),
                                  args->zeromean);
     g_signal_connect(controls.zeromean, "toggled",
@@ -421,7 +419,7 @@ fft_dialog(FFTArgs *args,
     controls.preserverms
         = gtk_check_button_new_with_mnemonic(_("_Preserve RMS"));
     gtk_table_attach(GTK_TABLE(table), controls.preserverms,
-                     0, 3, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
+                     0, 2, row, row+1, GTK_FILL, 0, 0, 0);
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(controls.preserverms),
                                  args->preserverms);
     g_signal_connect(controls.preserverms, "toggled",
