@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: fft_filter_1d.c 18537 2016-03-28 18:11:19Z yeti-dn $
+ *  @(#) $Id: fft_filter_1d.c 19948 2017-06-22 14:05:41Z yeti-dn $
  *  Copyright (C) 2004 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -30,6 +30,7 @@
 #include <libprocess/arithmetic.h>
 #include <libgwydgets/gwygraph.h>
 #include <libgwydgets/gwycombobox.h>
+#include <libgwydgets/gwystock.h>
 #include <libgwymodule/gwymodule-process.h>
 #include <app/gwymoduleutils.h>
 #include <app/gwyapp.h>
@@ -121,7 +122,7 @@ static GwyModuleInfo module_info = {
     "2004",
 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, fft_filter_1d)
 
 static gboolean
 module_register(void)
@@ -129,7 +130,7 @@ module_register(void)
     gwy_process_func_register("fft_filter_1d",
                               (GwyProcessFunc)&fftf_1d,
                               N_("/_Correct Data/1D _FFT Filtering..."),
-                              NULL,
+                              GWY_STOCK_FFT_FILTER_1D,
                               FFTF_1D_RUN_MODES,
                               GWY_MENU_FLAG_DATA,
                               N_("1D FFT Filtering"));
@@ -239,6 +240,7 @@ fftf_1d_dialog(Fftf1dArgs *args,
     controls.graph = gwy_graph_new(controls.gmodel);
     gwy_graph_set_status(GWY_GRAPH(controls.graph), GWY_GRAPH_STATUS_XSEL);
     gtk_widget_set_size_request(controls.graph, -1, PREVIEW_HALF_SIZE);
+    gwy_graph_enable_user_input(GWY_GRAPH(controls.graph), FALSE);
     gtk_box_pack_start(GTK_BOX(hbox), controls.graph, TRUE, TRUE, 4);
 
     area = GWY_GRAPH_AREA(gwy_graph_get_area(GWY_GRAPH(controls.graph)));
