@@ -1,5 +1,5 @@
 /*
- *  $Id: fft_filter_2d.c 19044 2016-10-08 19:10:46Z yeti-dn $
+ *  $Id: fft_filter_2d.c 19948 2017-06-22 14:05:41Z yeti-dn $
  *  Copyright (C) 2005 Christopher Anderson, Molecular Imaging Corp.
  *  E-mail: Chris Anderson (sidewinder.asu@gmail.com)
  *  Copyright (C) 2011 David Necas (Yeti).
@@ -162,7 +162,7 @@ static GwyModuleInfo module_info = {
     "2005",
 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, fft_filter_2d)
 
 static gboolean
 module_register(void)
@@ -454,12 +454,12 @@ run_dialog(ControlsType *controls)
 
     label = gwy_label_new_header(_("Filter Mask"));
     gtk_table_attach(GTK_TABLE(table), label, 0, 2, row, row+1,
-                     GTK_EXPAND | GTK_FILL, 0, 0, 0);
+                     GTK_FILL, 0, 0, 0);
     row++;
 
     hbox2 = gtk_hbox_new(FALSE, 0);
     gtk_table_attach(GTK_TABLE(table), hbox2, 0, 1, row, row+1,
-                     GTK_EXPAND | GTK_FILL, 0, 0, 0);
+                     GTK_FILL, 0, 0, 0);
 
     /* MODE/SHAPE Buttons */
     group = NULL;
@@ -485,7 +485,7 @@ run_dialog(ControlsType *controls)
     /* Remaining controls: */
     hbox2 = gtk_vbox_new(FALSE, 0);
     gtk_table_attach(GTK_TABLE(table), hbox2, 1, 2, row, row+3,
-                     GTK_EXPAND | GTK_FILL, 0, 4, 0);
+                     GTK_FILL, 0, 4, 0);
 
     button = gwy_stock_like_button_new(_("_Undo"), GTK_STOCK_UNDO);
     gwy_sensitivity_group_add_widget(controls->sensgroup, button,
@@ -519,7 +519,7 @@ run_dialog(ControlsType *controls)
     gtk_tooltips_set_tip(tips, button,
                          g_hash_table_lookup(hash_tips, "origin"), NULL);
     gtk_table_attach(GTK_TABLE(table), button, 0, 1, row, row+1,
-                     GTK_EXPAND | GTK_FILL, 0, 0, 0);
+                     GTK_FILL, 0, 0, 0);
     set_toggled(button, controls->snap);
     g_signal_connect(button, "clicked", G_CALLBACK(snap_cb), controls);
 
@@ -529,7 +529,7 @@ run_dialog(ControlsType *controls)
 
     label = gwy_label_new_header(_("Preview Options"));
     gtk_table_attach(GTK_TABLE(table), label, 0, 2, row, row+1,
-                     GTK_EXPAND | GTK_FILL, 0, 0, 0);
+                     GTK_FILL, 0, 0, 0);
     row++;
 
     label = gtk_label_new(_("Display:"));
@@ -540,7 +540,7 @@ run_dialog(ControlsType *controls)
 
     hbox2 = gtk_vbox_new(FALSE, 0);
     gtk_table_attach(GTK_TABLE(table), hbox2, 0, 1, row, row+1,
-                     GTK_EXPAND | GTK_FILL, 0, 0, 0);
+                     GTK_FILL, 0, 0, 0);
 
     group = NULL;
     for (i = 0; i < G_N_ELEMENTS(prev_modes); i++) {
@@ -561,7 +561,7 @@ run_dialog(ControlsType *controls)
     /* Zoom */
     hbox2 = gtk_hbox_new(FALSE, 8);
     gtk_table_attach(GTK_TABLE(table), hbox2, 0, 2, row, row+1,
-                     GTK_EXPAND | GTK_FILL, 0, 0, 0);
+                     GTK_FILL, 0, 0, 0);
     label = gtk_label_new(_("Zoom:"));
     gtk_box_pack_start(GTK_BOX(hbox2), label, FALSE, FALSE, 0);
     gwy_sensitivity_group_add_widget(controls->sensgroup, label, SENS_EDIT);
@@ -585,13 +585,13 @@ run_dialog(ControlsType *controls)
     /* Output */
     label = gwy_label_new_header(_("Output Options"));
     gtk_table_attach(GTK_TABLE(table), label, 0, 2, row, row+1,
-                     GTK_EXPAND | GTK_FILL, 0, 0, 0);
+                     GTK_FILL, 0, 0, 0);
     row++;
 
     label = gtk_label_new(_("Output type:"));
     gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
     gtk_table_attach(GTK_TABLE(table), label, 0, 2, row, row+1,
-                     GTK_EXPAND | GTK_FILL, 0, 0, 2);
+                     GTK_FILL, 0, 0, 2);
     row++;
 
     for (i = 0; i < G_N_ELEMENTS(out_modes); i++) {
@@ -601,7 +601,7 @@ run_dialog(ControlsType *controls)
         if (controls->out_mode & out_modes[i].out_mode)
             gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check), TRUE);
         gtk_table_attach(GTK_TABLE(table), check, 0, 2, row, row+1,
-                         GTK_EXPAND | GTK_FILL, 0, 0, 0);
+                         GTK_FILL, 0, 0, 0);
         g_signal_connect(check, "toggled",
                          G_CALLBACK(out_mode_changed), controls);
         row++;
