@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: fft_profile.c 18626 2016-04-22 10:15:13Z yeti-dn $
+ *  @(#) $Id: fft_profile.c 20063 2017-07-11 11:03:01Z yeti-dn $
  *  Copyright (C) 2009 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
@@ -70,7 +70,6 @@ typedef struct {
     GwyGraphModel *gmodel;
     GtkWidget *separate;
     GtkWidget *target_graph;
-    GtkWidget *target_hbox;
     GwyContainer *mydata;
 } ProfControls;
 
@@ -125,12 +124,12 @@ static GwyModuleInfo module_info = {
     N_("Reads radial sections of two-dimensional power spectrum density "
        "function."),
     "Yeti <yeti@gwyddion.net>",
-    "1.3",
+    "1.4",
     "David Nečas (Yeti)",
     "2009",
 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, fft_profile)
 
 static gboolean
 module_register(void)
@@ -171,7 +170,7 @@ prof_dialog(ProfArgs *args,
             GwyDataField *dfield,
             gint id)
 {
-    GtkWidget *hbox, *hbox2, *vbox, *label;
+    GtkWidget *hbox, *vbox;
     GwyDataChooser *chooser;
     GtkTable *table;
     GtkDialog *dialog;
@@ -253,7 +252,7 @@ prof_dialog(ProfArgs *args,
     gwy_graph_area_enable_user_input(area, FALSE);
     gtk_box_pack_start(GTK_BOX(vbox), controls.graph, TRUE, TRUE, 0);
 
-    table = GTK_TABLE(gtk_table_new(4, 4, FALSE));
+    table = GTK_TABLE(gtk_table_new(4, 3, FALSE));
     gtk_table_set_row_spacings(table, 2);
     gtk_table_set_col_spacings(table, 6);
     gtk_container_set_border_width(GTK_CONTAINER(table), 4);
@@ -263,7 +262,8 @@ prof_dialog(ProfArgs *args,
     controls.resolution = gtk_adjustment_new(controls.args->resolution,
                                              MIN_RESOLUTION, MAX_RESOLUTION,
                                              1, 10, 0);
-    gwy_table_attach_hscale(GTK_WIDGET(table), row, _("_Fix res.:"), NULL,
+    gwy_table_attach_adjbar(GTK_WIDGET(table), row,
+                            _("_Fixed resolution:"), NULL,
                             controls.resolution,
                             GWY_HSCALE_CHECK | GWY_HSCALE_SQRT);
     g_signal_connect_swapped(controls.resolution, "value-changed",
@@ -273,44 +273,28 @@ prof_dialog(ProfArgs *args,
                                  controls.args->fixres);
     g_signal_connect_swapped(controls.fixres, "toggled",
                              G_CALLBACK(prof_fixres_changed), &controls);
-    gwy_table_hscale_set_sensitive(controls.resolution, controls.args->fixres);
     row++;
 
     controls.separate = gtk_check_button_new_with_mnemonic(_("_Separate curves"));
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(controls.separate),
                                  args->separate);
     gtk_table_attach(table, controls.separate,
-                     0, 3, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
+                     0, 2, row, row+1, GTK_FILL, 0, 0, 0);
     g_signal_connect_swapped(controls.separate, "toggled",
                              G_CALLBACK(prof_separate_changed), &controls);
     row++;
 
-    hbox2 = gtk_hbox_new(FALSE, 6);
-    gtk_table_attach(table, hbox2,
-                     0, 3, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
-
-    label = gtk_label_new_with_mnemonic(_("_Interpolation type:"));
-    gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
-    gtk_box_pack_start(GTK_BOX(hbox2), label, FALSE, FALSE, 0);
-
     controls.interpolation
         = gwy_enum_combo_box_new(gwy_interpolation_type_get_enum(), -1,
                                  G_CALLBACK(prof_interpolation_changed),
                                  &controls,
                                  controls.args->interpolation, TRUE);
-    gtk_label_set_mnemonic_widget(GTK_LABEL(label), controls.interpolation);
-    gtk_box_pack_end(GTK_BOX(hbox2), controls.interpolation, FALSE, FALSE, 0);
+    gwy_table_attach_adjbar(GTK_WIDGET(table), row,
+                            _("_Interpolation type:"), NULL,
+                            GTK_OBJECT(controls.interpolation),
+                            GWY_HSCALE_WIDGET_NO_EXPAND);
     row++;
 
-    controls.target_hbox = hbox2 = gtk_hbox_new(FALSE, 6);
-    gtk_widget_set_sensitive(hbox2, !args->separate);
-    gtk_table_attach(GTK_TABLE(table), hbox2,
-                     0, 4, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
-
-    label = gtk_label_new_with_mnemonic(_("Target _graph:"));
-    gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
-    gtk_box_pack_start(GTK_BOX(hbox2), label, FALSE, FALSE, 0);
-
     controls.target_graph = gwy_data_chooser_new_graphs();
     chooser = GWY_DATA_CHOOSER(controls.target_graph);
     gwy_data_chooser_set_none(chooser, _("New graph"));
@@ -318,8 +302,10 @@ prof_dialog(ProfArgs *args,
     gwy_data_chooser_set_filter(chooser, filter_target_graphs, &controls, NULL);
     gwy_data_chooser_set_active_id(chooser, &args->target_graph);
     gwy_data_chooser_get_active_id(chooser, &args->target_graph);
-    gtk_label_set_mnemonic_widget(GTK_LABEL(label), controls.target_graph);
-    gtk_box_pack_end(GTK_BOX(hbox2), controls.target_graph, FALSE, FALSE, 0);
+    gwy_table_attach_adjbar(GTK_WIDGET(table), row,
+                            _("Target _graph:"), NULL,
+                            GTK_OBJECT(controls.target_graph),
+                            GWY_HSCALE_WIDGET_NO_EXPAND);
     g_signal_connect_swapped(controls.target_graph, "changed",
                              G_CALLBACK(target_graph_changed), &controls);
     row++;
@@ -388,7 +374,8 @@ prof_separate_changed(ProfControls *controls)
     ProfArgs *args = controls->args;
     args->separate
         = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(controls->separate));
-    gtk_widget_set_sensitive(controls->target_hbox, !args->separate);
+    gwy_table_hscale_set_sensitive(GTK_OBJECT(controls->target_graph),
+                                   !args->separate);
     update_target_graphs(controls);
 }
 
