@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: fft_synth.c 19044 2016-10-08 19:10:46Z yeti-dn $
+ *  @(#) $Id: fft_synth.c 19948 2017-06-22 14:05:41Z yeti-dn $
  *  Copyright (C) 2007,2009,2010,2013 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
@@ -178,12 +178,12 @@ static GwyModuleInfo module_info = {
     &module_register,
     N_("Generates random surfaces using spectral synthesis."),
     "Yeti <yeti@gwyddion.net>",
-    "1.5",
+    "1.6",
     "David Nečas (Yeti)",
     "2009",
 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, fft_synth)
 
 static gboolean
 module_register(void)
@@ -400,7 +400,7 @@ fft_synth_dialog(FFTSynthArgs *args,
         g_signal_connect_swapped(controls.dims->add, "toggled",
                                  G_CALLBACK(fft_synth_invalidate), &controls);
 
-    table = gtk_table_new(14 + (dfield_template ? 1 : 0), 5, FALSE);
+    table = gtk_table_new(14 + (dfield_template ? 1 : 0), 3, FALSE);
     controls.table = GTK_TABLE(table);
     gtk_table_set_row_spacings(controls.table, 2);
     gtk_table_set_col_spacings(controls.table, 6);
@@ -415,19 +415,19 @@ fft_synth_dialog(FFTSynthArgs *args,
 
     if (dfield_template) {
         controls.sigma_init
-            = gtk_button_new_with_mnemonic(_("_Like Current Channel"));
+            = gtk_button_new_with_mnemonic(_("_Like Current Image"));
         g_signal_connect_swapped(controls.sigma_init, "clicked",
                                  G_CALLBACK(sigma_init_clicked), &controls);
         gtk_table_attach(GTK_TABLE(table), controls.sigma_init,
-                         1, 3, row, row+1, GTK_FILL, 0, 0, 0);
+                         0, 2, row, row+1, GTK_FILL, 0, 0, 0);
         row++;
     }
     gtk_table_set_row_spacing(GTK_TABLE(table), row-1, 8);
 
     controls.freq_min = gtk_adjustment_new(args->freq_min,
                                            0.0, G_SQRT2*G_PI, 0.001, 0.1, 0);
-    gwy_table_attach_hscale(table, row, _("M_inimum frequency:"),
-                            "px<sup>-1</sup>",
+    gwy_table_attach_adjbar(table, row,
+                            _("M_inimum frequency:"), _("px<sup>-1</sup>"),
                             controls.freq_min, GWY_HSCALE_SQRT);
     g_signal_connect_swapped(controls.freq_min, "value-changed",
                              G_CALLBACK(freq_min_changed), &controls);
@@ -436,18 +436,18 @@ fft_synth_dialog(FFTSynthArgs *args,
     controls.freq_min_value = gtk_label_new(NULL);
     gtk_misc_set_alignment(GTK_MISC(controls.freq_min_value), 1.0, 0.5);
     gtk_table_attach(GTK_TABLE(table), controls.freq_min_value,
-                     2, 3, row, row+1, GTK_FILL, 0, 0, 0);
+                     1, 2, row, row+1, GTK_FILL, 0, 0, 0);
 
     controls.freq_min_units = gtk_label_new(NULL);
     gtk_misc_set_alignment(GTK_MISC(controls.freq_min_units), 0.0, 0.5);
     gtk_table_attach(GTK_TABLE(table), controls.freq_min_units,
-                     3, 4, row, row+1, GTK_FILL, 0, 0, 0);
+                     2, 3, row, row+1, GTK_FILL, 0, 0, 0);
     row++;
 
     controls.freq_max = gtk_adjustment_new(args->freq_max,
                                            0.0, G_SQRT2*G_PI, 0.001, 0.1, 0);
-    gwy_table_attach_hscale(table, row, _("Ma_ximum frequency:"),
-                            "px<sup>-1</sup>",
+    gwy_table_attach_adjbar(table, row,
+                            _("Ma_ximum frequency:"), _("px<sup>-1</sup>"),
                             controls.freq_max, GWY_HSCALE_SQRT);
     g_signal_connect_swapped(controls.freq_max, "value-changed",
                              G_CALLBACK(freq_max_changed), &controls);
@@ -456,12 +456,12 @@ fft_synth_dialog(FFTSynthArgs *args,
     controls.freq_max_value = gtk_label_new(NULL);
     gtk_misc_set_alignment(GTK_MISC(controls.freq_max_value), 1.0, 0.5);
     gtk_table_attach(GTK_TABLE(table), controls.freq_max_value,
-                     2, 3, row, row+1, GTK_FILL, 0, 0, 0);
+                     1, 2, row, row+1, GTK_FILL, 0, 0, 0);
 
     controls.freq_max_units = gtk_label_new(NULL);
     gtk_misc_set_alignment(GTK_MISC(controls.freq_max_units), 0.0, 0.5);
     gtk_table_attach(GTK_TABLE(table), controls.freq_max_units,
-                     3, 4, row, row+1, GTK_FILL, 0, 0, 0);
+                     2, 3, row, row+1, GTK_FILL, 0, 0, 0);
     gtk_table_set_row_spacing(GTK_TABLE(table), row, 8);
     row++;
 
@@ -470,7 +470,7 @@ fft_synth_dialog(FFTSynthArgs *args,
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(controls.gauss_enable),
                                  args->gauss_enable);
     gtk_table_attach(GTK_TABLE(table), controls.gauss_enable,
-                     0, 3, row, row+1, GTK_FILL, 0, 0, 0);
+                     0, 2, row, row+1, GTK_FILL, 0, 0, 0);
     g_signal_connect_swapped(controls.gauss_enable, "toggled",
                              G_CALLBACK(gauss_enable_changed), &controls);
     row++;
@@ -493,7 +493,7 @@ fft_synth_dialog(FFTSynthArgs *args,
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(controls.lorentz_enable),
                                  args->lorentz_enable);
     gtk_table_attach(GTK_TABLE(table), controls.lorentz_enable,
-                     0, 3, row, row+1, GTK_FILL, 0, 0, 0);
+                     0, 2, row, row+1, GTK_FILL, 0, 0, 0);
     g_signal_connect_swapped(controls.lorentz_enable, "toggled",
                              G_CALLBACK(lorentz_enable_changed), &controls);
     row++;
@@ -523,7 +523,7 @@ fft_synth_dialog(FFTSynthArgs *args,
 
     controls.power_p = gtk_adjustment_new(args->power_p,
                                           0.0, 5.0, 0.01, 0.1, 0);
-    spin = gwy_table_attach_hscale(table, row, _("Po_wer:"), NULL,
+    spin = gwy_table_attach_adjbar(table, row, _("Po_wer:"), NULL,
                                    controls.power_p, 0);
     gtk_spin_button_set_snap_to_ticks(GTK_SPIN_BUTTON(spin), FALSE);
     gtk_spin_button_set_digits(GTK_SPIN_BUTTON(spin), 3);
@@ -843,7 +843,7 @@ fft_synth_do(const FFTSynthArgs *args,
         gdouble y = (i <= yres/2 ? i : yres-i)/(0.5*yres);
         for (j = 0; j < xres; j++) {
             gdouble x = (j <= xres/2 ? j : xres-j)/(0.5*xres);
-            gdouble r = hypot(x, y);
+            gdouble r = sqrt(x*x + y*y);
 
             if (r < freq_min || r > freq_max) {
                 /* XXX: This is necessary for stability! */
