@@ -1,6 +1,6 @@
 /*
- *  @(#) $Id: fit-shape.c 19147 2016-10-31 16:30:37Z yeti-dn $
- *  Copyright (C) 2016 David Necas (Yeti).
+ *  @(#) $Id: fit-shape.c 19948 2017-06-22 14:05:41Z yeti-dn $
+ *  Copyright (C) 2016-2017 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -40,6 +40,7 @@
 #include <libprocess/gwyshapefitpreset.h>
 #include <libgwydgets/gwycombobox.h>
 #include <libgwydgets/gwyradiobuttons.h>
+#include <libgwydgets/gwystock.h>
 #include <libgwydgets/gwyinventorystore.h>
 #include <libgwymodule/gwymodule-process.h>
 #include <libgwymodule/gwymodule-xyz.h>
@@ -219,7 +220,7 @@ static void         update_correl_table       (FitShapeControls *controls,
                                                GwyNLFitter *fitter);
 static void         update_secondary_table    (FitShapeControls *controls);
 static void         fit_shape_estimate        (FitShapeControls *controls);
-static void         fit_shape_reduced_fit     (FitShapeControls *controls);
+static void         fit_shape_quick_fit       (FitShapeControls *controls);
 static void         fit_shape_full_fit        (FitShapeControls *controls);
 static void         fit_copy_correl_matrix    (FitShapeControls *controls,
                                                GwyNLFitter *fitter);
@@ -234,22 +235,15 @@ static void         fit_context_resize_params (FitShapeContext *ctx,
 static void         fit_context_free          (FitShapeContext *ctx);
 static GwyNLFitter* fit                       (GwyShapeFitPreset *preset,
                                                const FitShapeContext *ctx,
-                                               guint maxiter,
                                                gdouble *param,
                                                gdouble *rss,
                                                GwySetFractionFunc set_fraction,
                                                GwySetMessageFunc set_message,
+                                               gboolean quick_fit,
                                                gboolean geometric_fit);
-static GwyNLFitter* fit_reduced               (GwyShapeFitPreset *preset,
-                                               const FitShapeContext *ctx,
-                                               gdouble *param,
-                                               gdouble *rss);
 static void         calculate_field           (GwyShapeFitPreset *preset,
                                                const gdouble *params,
                                                GwyDataField *dfield);
-static void         reduce_data_size          (const GwyXYZ *xyzsrc,
-                                               guint nsrc,
-                                               GwySurface *dest);
 static GString*     create_fit_report         (FitShapeControls *controls);
 static void         fit_shape_load_args       (GwyContainer *container,
                                                FitShapeArgs *args);
@@ -269,12 +263,12 @@ static GwyModuleInfo module_info = {
     &module_register,
     N_("Fits predefined geometrical shapes to data."),
     "Yeti <yeti@gwyddion.net>",
-    "1.1",
+    "1.3",
     "David Nečas (Yeti)",
     "2016",
 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, fit_shape)
 
 static gboolean
 module_register(void)
@@ -282,14 +276,14 @@ module_register(void)
     gwy_process_func_register("fit_shape",
                               (GwyProcessFunc)&fit_shape,
                               N_("/_Level/_Fit Shape..."),
-                              NULL,
+                              GWY_STOCK_FIT_SHAPE,
                               FIT_SHAPE_RUN_MODES,
                               GWY_MENU_FLAG_DATA,
                               N_("Fit geometrical shapes"));
     gwy_xyz_func_register("xyz_fit_shape",
                           (GwyXYZFunc)&fit_shape_xyz,
                           N_("/_Fit Shape..."),
-                          NULL,
+                          GWY_STOCK_FIT_SHAPE,
                           FIT_SHAPE_RUN_MODES,
                           GWY_MENU_FLAG_XYZ,
                           N_("Fit geometrical shapes"));
@@ -348,6 +342,8 @@ fit_shape_dialogue(FitShapeArgs *args,
 {
     GtkWidget *dialogue, *notebook, *widget, *vbox, *hbox, *alignment,
               *hbox2, *label;
+    GtkClipboard *clipboard;
+    GdkDisplay *display;
     FitShapeControls controls;
     FitShapeContext ctx;
     GwyDataField *mydfield = NULL;
@@ -361,13 +357,11 @@ fit_shape_dialogue(FitShapeArgs *args,
     controls.ctx = &ctx;
     controls.id = id;
 
-    xyunit = gwy_data_field_get_si_unit_xy(dfield);
-    zunit = gwy_data_field_get_si_unit_z(dfield);
-    controls.same_units = gwy_si_unit_equal(xyunit, zunit);
-
     if (surface) {
         controls.pageno = GWY_PAGE_XYZS;
         controls.title = gwy_app_get_surface_title(data, id);
+        xyunit = gwy_surface_get_si_unit_xy(surface);
+        zunit = gwy_surface_get_si_unit_z(surface);
         mydfield = gwy_data_field_new(1, 1, 1.0, 1.0, FALSE);
         gwy_preview_surface_to_datafield(surface, mydfield,
                                          PREVIEW_SIZE, PREVIEW_SIZE,
@@ -377,17 +371,24 @@ fit_shape_dialogue(FitShapeArgs *args,
     else if (dfield) {
         controls.pageno = GWY_PAGE_CHANNELS;
         controls.title = gwy_app_get_data_field_title(data, id);
+        xyunit = gwy_data_field_get_si_unit_xy(dfield);
+        zunit = gwy_data_field_get_si_unit_z(dfield);
+
     }
     else {
         g_return_if_reached();
     }
 
+    controls.same_units = gwy_si_unit_equal(xyunit, zunit);
+
     controls.diff_gradient = gwy_inventory_new_item(gwy_gradients(),
                                                     GWY_GRADIENT_DEFAULT,
                                                     FIT_GRADIENT_NAME);
     gwy_resource_use(GWY_RESOURCE(controls.diff_gradient));
 
     dialogue = gtk_dialog_new_with_buttons(_("Fit Shape"), NULL, 0,
+                                           GTK_STOCK_COPY,
+                                           RESPONSE_COPY,
                                            GTK_STOCK_SAVE,
                                            RESPONSE_SAVE,
                                            gwy_sgettext("verb|_Fit"),
@@ -510,7 +511,7 @@ fit_shape_dialogue(FitShapeArgs *args,
             break;
 
             case RESPONSE_CALCULATE:
-            fit_shape_reduced_fit(&controls);
+            fit_shape_quick_fit(&controls);
             break;
 
             case RESPONSE_ESTIMATE:
@@ -524,6 +525,15 @@ fit_shape_dialogue(FitShapeArgs *args,
             g_string_free(report, TRUE);
             break;
 
+            case RESPONSE_COPY:
+            report = create_fit_report(&controls);
+            display = gtk_widget_get_display(dialogue);
+            clipboard = gtk_clipboard_get_for_display(display,
+                                                      GDK_SELECTION_CLIPBOARD);
+            gtk_clipboard_set_text(clipboard, report->str, -1);
+            g_string_free(report, TRUE);
+            break;
+
             default:
             g_assert_not_reached();
             break;
@@ -669,7 +679,7 @@ basic_tab_new(FitShapeControls *controls, GwyDataField *mfield)
 
     hbox = gtk_hbox_new(FALSE, 0);
 
-    table = gtk_table_new(8 + !!controls->same_units + 4*(!!mfield), 4, FALSE);
+    table = gtk_table_new(8 + !!controls->same_units + 4*(!!mfield), 3, FALSE);
     gtk_container_set_border_width(GTK_CONTAINER(table), 4);
     gtk_table_set_row_spacings(GTK_TABLE(table), 2);
     gtk_table_set_col_spacings(GTK_TABLE(table), 6);
@@ -677,23 +687,25 @@ basic_tab_new(FitShapeControls *controls, GwyDataField *mfield)
     row = 0;
 
     controls->function = function_menu_new(args->function, controls);
-    gwy_table_attach_hscale(table, row, _("_Function type:"), NULL,
-                            GTK_OBJECT(controls->function), GWY_HSCALE_WIDGET);
+    gwy_table_attach_adjbar(table, row, _("_Function type:"), NULL,
+                            GTK_OBJECT(controls->function),
+                            GWY_HSCALE_WIDGET_NO_EXPAND);
     row++;
 
     controls->output
         = gwy_enum_combo_box_new(outputs, G_N_ELEMENTS(outputs),
                                  G_CALLBACK(output_changed), controls,
                                  args->output, TRUE);
-    gwy_table_attach_hscale(table, row, _("Output _type:"), NULL,
-                            GTK_OBJECT(controls->output), GWY_HSCALE_WIDGET);
+    gwy_table_attach_adjbar(table, row, _("Output _type:"), NULL,
+                            GTK_OBJECT(controls->output),
+                            GWY_HSCALE_WIDGET_NO_EXPAND);
     row++;
 
     gtk_table_set_row_spacing(GTK_TABLE(table), row-1, 8);
     label = gtk_label_new(_("Preview:"));
     gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
     gtk_table_attach(GTK_TABLE(table), label,
-                     0, 3, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
+                     0, 2, row, row+1, GTK_FILL, 0, 0, 0);
     row++;
 
     controls->display
@@ -701,7 +713,7 @@ basic_tab_new(FitShapeControls *controls, GwyDataField *mfield)
                                    G_CALLBACK(display_changed),
                                    controls, args->display);
     row = gwy_radio_buttons_attach_to_table(controls->display,
-                                            GTK_TABLE(table), 3, row);
+                                            GTK_TABLE(table), 2, row);
     row++;
 
     controls->diff_colourmap
@@ -710,7 +722,7 @@ basic_tab_new(FitShapeControls *controls, GwyDataField *mfield)
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(controls->diff_colourmap),
                                  args->diff_colourmap);
     gtk_table_attach(GTK_TABLE(table), controls->diff_colourmap,
-                     0, 3, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
+                     0, 2, row, row+1, GTK_FILL, 0, 0, 0);
     g_signal_connect(controls->diff_colourmap, "toggled",
                      G_CALLBACK(diff_colourmap_changed), controls);
     row++;
@@ -721,7 +733,7 @@ basic_tab_new(FitShapeControls *controls, GwyDataField *mfield)
         gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(controls->geometric_fit),
                                      args->geometric_fit);
         gtk_table_attach(GTK_TABLE(table), controls->geometric_fit,
-                         0, 3, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
+                         0, 2, row, row+1, GTK_FILL, 0, 0, 0);
         g_signal_connect(controls->geometric_fit, "toggled",
                          G_CALLBACK(geometric_fit_changed), controls);
         row++;
@@ -742,7 +754,7 @@ basic_tab_add_masking(FitShapeControls *controls, GtkWidget *table, gint row)
     gtk_table_set_row_spacing(GTK_TABLE(table), row-1, 8);
     label = gwy_label_new_header(_("Masking Mode"));
     gtk_table_attach(GTK_TABLE(table), label,
-                     0, 3, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
+                     0, 2, row, row+1, GTK_FILL, 0, 0, 0);
     row++;
 
     controls->masking
@@ -750,7 +762,7 @@ basic_tab_add_masking(FitShapeControls *controls, GtkWidget *table, gint row)
                                    G_CALLBACK(masking_changed),
                                    controls, args->masking);
     row = gwy_radio_buttons_attach_to_table(controls->masking,
-                                            GTK_TABLE(table), 3, row);
+                                            GTK_TABLE(table), 2, row);
     row++;
 
     controls->diff_excluded
@@ -759,7 +771,7 @@ basic_tab_add_masking(FitShapeControls *controls, GtkWidget *table, gint row)
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(controls->diff_excluded),
                                  args->diff_excluded);
     gtk_table_attach(GTK_TABLE(table), controls->diff_excluded,
-                     0, 3, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
+                     0, 2, row, row+1, GTK_FILL, 0, 0, 0);
     g_signal_connect(controls->diff_excluded, "toggled",
                      G_CALLBACK(diff_excluded_changed), controls);
     row++;
@@ -1588,7 +1600,7 @@ fit_shape_estimate(FitShapeControls *controls)
 }
 
 static void
-fit_shape_reduced_fit(FitShapeControls *controls)
+fit_shape_quick_fit(FitShapeControls *controls)
 {
     const FitShapeContext *ctx = controls->ctx;
     GwyNLFitter *fitter;
@@ -1596,11 +1608,13 @@ fit_shape_reduced_fit(FitShapeControls *controls)
     guint nparams;
 
     gwy_app_wait_cursor_start(GTK_WINDOW(controls->dialogue));
-    gwy_debug("start reduced fit");
+    gwy_debug("start quick fit");
     update_all_param_values(controls);
     nparams = gwy_shape_fit_preset_get_nparams(controls->preset);
     gwy_assign(controls->alt_param, controls->param, nparams);
-    fitter = fit_reduced(controls->preset, ctx, controls->param, &rss);
+    fitter = fit(controls->preset, ctx, controls->param, &rss, NULL, NULL,
+                 TRUE, controls->args->geometric_fit);
+
     if (rss >= 0.0)
         controls->state = FIT_SHAPE_QUICK_FITTED;
     else
@@ -1634,9 +1648,9 @@ fit_shape_full_fit(FitShapeControls *controls)
     nparams = gwy_shape_fit_preset_get_nparams(controls->preset);
     update_all_param_values(controls);
     gwy_assign(controls->alt_param, controls->param, nparams);
-    fitter = fit(controls->preset, ctx, G_MAXUINT, controls->param, &rss,
+    fitter = fit(controls->preset, ctx, controls->param, &rss,
                  gwy_app_wait_set_fraction, gwy_app_wait_set_message,
-                 controls->args->geometric_fit);
+                 FALSE, controls->args->geometric_fit);
 
     if (rss >= 0.0)
         controls->state = FIT_SHAPE_FITTED;
@@ -1860,6 +1874,9 @@ update_fit_state(FitShapeControls *controls)
     gtk_dialog_set_response_sensitive(GTK_DIALOG(controls->dialogue),
                                       RESPONSE_SAVE,
                                       controls->state == FIT_SHAPE_FITTED);
+    gtk_dialog_set_response_sensitive(GTK_DIALOG(controls->dialogue),
+                                      RESPONSE_COPY,
+                                      controls->state == FIT_SHAPE_FITTED);
 }
 
 static void
@@ -1889,8 +1906,12 @@ update_fit_results(FitShapeControls *controls, GwyNLFitter *fitter)
 
     if (is_fitted) {
         nparams = gwy_shape_fit_preset_get_nparams(controls->preset);
-        for (i = 0; i < nparams; i++)
-            controls->param_err[i] = gwy_math_nlfit_get_sigma(fitter, i);
+        for (i = 0; i < nparams; i++) {
+            if (ctx->param_fixed[i])
+                controls->param_err[i] = 0.0;
+            else
+                controls->param_err[i] = gwy_math_nlfit_get_sigma(fitter, i);
+        }
     }
 
     dfield = gwy_container_get_object_by_name(controls->mydata, "/0/data");
@@ -1966,54 +1987,31 @@ fit_context_free(FitShapeContext *ctx)
 
 static GwyNLFitter*
 fit(GwyShapeFitPreset *preset, const FitShapeContext *ctx,
-    guint maxiter, gdouble *param, gdouble *rss,
+    gdouble *param, gdouble *rss,
     GwySetFractionFunc set_fraction, GwySetMessageFunc set_message,
-    gboolean geometric_fit)
+    gboolean quick_fit, gboolean geometric_fit)
 {
     GwyNLFitter *fitter;
 
     fitter = gwy_shape_fit_preset_create_fitter(preset);
     if (set_fraction || set_message)
         gwy_math_nlfit_set_callbacks(fitter, set_fraction, set_message);
-    if (maxiter != G_MAXUINT)
-        gwy_math_nlfit_set_max_iterations(fitter, maxiter);
     if (geometric_fit)
         gwy_math_nlfit_set_approx_geometric(fitter, TRUE);
 
-    gwy_shape_fit_preset_fit(preset, fitter, ctx->xyz, ctx->n,
-                             param, ctx->param_fixed, rss);
+    if (quick_fit) {
+        gwy_shape_fit_preset_quick_fit(preset, fitter, ctx->xyz, ctx->n,
+                                       param, ctx->param_fixed, rss);
+    }
+    else {
+        gwy_shape_fit_preset_fit(preset, fitter, ctx->xyz, ctx->n,
+                                 param, ctx->param_fixed, rss);
+    }
     gwy_debug("rss from nlfit %g", *rss);
 
     return fitter;
 }
 
-/* XXX XXX XXX XXX XXX This is duplicated in gwyshapefitpreset.c and it should
- * probably go to the library.  There we can do something better in the future
- * than random choice, for instance a mix of spatially uniform and random
- * choice. */
-static GwyNLFitter*
-fit_reduced(GwyShapeFitPreset *preset, const FitShapeContext *ctx,
-            gdouble *param, gdouble *rss)
-{
-    GwyNLFitter *fitter;
-    FitShapeContext ctxred;
-    guint nred = (guint)sqrt(ctx->n*(gdouble)NREDLIM);
-
-    if (nred >= ctx->n)
-        return fit(preset, ctx, 30, param, rss, NULL, NULL, FALSE);
-
-    ctxred = *ctx;
-    ctxred.n = nred;
-    ctxred.surface = gwy_surface_new_sized(nred);
-    ctxred.xyz = gwy_surface_get_data_const(ctxred.surface);
-    reduce_data_size(gwy_surface_get_data_const(ctx->surface), ctx->n,
-                     ctxred.surface);
-    fitter = fit(preset, &ctxred, 30, param, rss, NULL, NULL, FALSE);
-    g_object_unref(ctxred.surface);
-
-    return fitter;
-}
-
 static void
 calculate_field(GwyShapeFitPreset *preset, const gdouble *params,
                 GwyDataField *dfield)
@@ -2030,22 +2028,6 @@ calculate_field(GwyShapeFitPreset *preset, const gdouble *params,
     g_object_unref(surface);
 }
 
-static void
-reduce_data_size(const GwyXYZ *xyzsrc, guint nsrc, GwySurface *dest)
-{
-    GwyRandGenSet *rngset = gwy_rand_gen_set_new(1);
-    guint ndest = gwy_surface_get_npoints(dest);
-    guint *redindex = gwy_rand_gen_set_choose_shuffle(rngset, 0, nsrc, ndest);
-    GwyXYZ *xyzdest = gwy_surface_get_data(dest);
-    guint i;
-
-    for (i = 0; i < ndest; i++)
-        xyzdest[i] = xyzsrc[redindex[i]];
-
-    g_free(redindex);
-    gwy_rand_gen_set_free(rngset);
-}
-
 static GString*
 create_fit_report(FitShapeControls *controls)
 {
@@ -2250,6 +2232,8 @@ fit_shape_save_args(GwyContainer *container,
                                       args->diff_colourmap);
     gwy_container_set_boolean_by_name(container, diff_excluded_key,
                                       args->diff_excluded);
+    gwy_container_set_boolean_by_name(container, geometric_fit_key,
+                                      args->geometric_fit);
 }
 
 /* vim: set cin et ts=4 sw=4 cino=>1s,e0,n0,f0,{0,}0,^0,\:1s,=0,g1s,h0,t0,+1s,c3,(0,u0 : */
