@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: flatten_base.c 19155 2016-11-01 08:49:49Z yeti-dn $
+ *  @(#) $Id: flatten_base.c 19948 2017-06-22 14:05:41Z yeti-dn $
  *  Copyright (C) 2014 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -48,7 +48,7 @@ static GwyModuleInfo module_info = {
     "2014",
 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, flatten_base)
 
 static gboolean
 module_register(void)
