@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: fraccor.c 16388 2014-07-10 14:26:53Z yeti-dn $
+ *  @(#) $Id: fraccor.c 19948 2017-06-22 14:05:41Z yeti-dn $
  *  Copyright (C) 2004 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -23,6 +23,7 @@
 #include <libgwyddion/gwymacros.h>
 #include <libprocess/datafield.h>
 #include <libprocess/fractals.h>
+#include <libgwydgets/gwystock.h>
 #include <libgwymodule/gwymodule-process.h>
 #include <app/gwyapp.h>
 
@@ -42,7 +43,7 @@ static GwyModuleInfo module_info = {
     "2004",
 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, fraccor)
 
 static gboolean
 module_register(void)
@@ -50,7 +51,7 @@ module_register(void)
     gwy_process_func_register("fraccor",
                               (GwyProcessFunc)&fraccor,
                               N_("/_Correct Data/_Fractal Correction"),
-                              NULL,
+                              GWY_STOCK_FRACTAL_CORRECTION,
                               FRACCOR_RUN_MODES,
                               GWY_MENU_FLAG_DATA_MASK | GWY_MENU_FLAG_DATA,
                               N_("Interpolate data under mask with fractal "
