@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: fractal.c 18537 2016-03-28 18:11:19Z yeti-dn $
+ *  @(#) $Id: fractal.c 19972 2017-06-24 09:15:44Z yeti-dn $
  *  Copyright (C) 2003-2006 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -85,10 +85,6 @@ static void       fractal                 (GwyContainer *data,
                                            GwyRunType run);
 static void       fractal_dialog          (FractalArgs *args,
                                            GwyContainer *data);
-static GtkWidget* attach_value_row        (GtkWidget *table,
-                                           gint row,
-                                           const gchar *description,
-                                           const gchar *value);
 static void       interp_changed_cb       (GtkWidget *combo,
                                            FractalArgs *args);
 static void       out_changed_cb          (GtkWidget *combo,
@@ -173,12 +169,12 @@ static GwyModuleInfo module_info = {
     N_("Calculates fractal dimension using several methods "
        "(partitioning, box counting, triangulation, power spectrum)."),
     "Jindřich Bilek & Petr Klapetek <klapetek@gwyddion.net>",
-    "1.8",
+    "1.9",
     "David Nečas (Yeti) & Petr Klapetek & Jindřich Bílek",
     "2004",
 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, fractal)
 
 static gboolean
 module_register(void)
@@ -186,7 +182,7 @@ module_register(void)
     gwy_process_func_register("fractal",
                               (GwyProcessFunc)&fractal,
                               N_("/_Statistics/_Fractal Dimension..."),
-                              GWY_STOCK_FRACTAL,
+                              GWY_STOCK_FRACTAL_MEASURE,
                               FRACTAL_RUN_MODES,
                               GWY_MENU_FLAG_DATA,
                               N_("Calculate fractal dimension"));
@@ -208,7 +204,7 @@ fractal(GwyContainer *data, GwyRunType run)
 static void
 fractal_dialog(FractalArgs *args, GwyContainer *data)
 {
-    GtkWidget *dialog, *table, *hbox, *vbox, *label, *button, *hbox2;
+    GtkWidget *dialog, *table, *hbox, *vbox;
     GwyDataChooser *chooser;
     GwyGraphArea *area;
     GwySelection *selection;
@@ -225,8 +221,9 @@ fractal_dialog(FractalArgs *args, GwyContainer *data)
     /* The axes should be unitless so no unit initialisation is necessary. */
 
     dialog = gtk_dialog_new_with_buttons(_("Fractal Dimension"), NULL, 0, NULL);
-    button = gwy_stock_like_button_new(_("Reco_mpute"), GTK_STOCK_EXECUTE);
-    gtk_dialog_add_action_widget(GTK_DIALOG(dialog), button,
+    gtk_dialog_add_action_widget(GTK_DIALOG(dialog),
+                                 gwy_stock_like_button_new(_("_Update"),
+                                                           GTK_STOCK_EXECUTE),
                                  RESPONSE_CALCULATE);
     gtk_dialog_add_button(GTK_DIALOG(dialog), _("_Reset"), RESPONSE_RESET);
     gtk_dialog_add_button(GTK_DIALOG(dialog),
@@ -244,70 +241,51 @@ fractal_dialog(FractalArgs *args, GwyContainer *data)
     gtk_box_pack_start(GTK_BOX(hbox), vbox, FALSE, FALSE, 0);
 
     /* Parameters */
-    table = gtk_table_new(4, 2, FALSE);
+    table = gtk_table_new(GWY_FRACTAL_NMETHODS + 7, 3, FALSE);
     gtk_table_set_row_spacings(GTK_TABLE(table), 2);
     gtk_table_set_col_spacings(GTK_TABLE(table), 6);
     gtk_box_pack_start(GTK_BOX(vbox), table, FALSE, FALSE, 0);
     row = 0;
 
-    label = gtk_label_new_with_mnemonic(_("_Interpolation type:"));
-    gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
-    gtk_table_attach(GTK_TABLE(table), label,
-                     0, 2, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
+    controls.out = gwy_enum_combo_box_new(methods, G_N_ELEMENTS(methods),
+                                          G_CALLBACK(out_changed_cb), &controls,
+                                          args->out, TRUE);
+    gwy_table_attach_adjbar(table, row, _("_Method:"), NULL,
+                            GTK_OBJECT(controls.out),
+                            GWY_HSCALE_WIDGET_NO_EXPAND);
     row++;
 
     controls.interp
         = gwy_enum_combo_box_new(gwy_interpolation_type_get_enum(), -1,
                                  G_CALLBACK(interp_changed_cb), args,
                                  args->interp, TRUE);
-    gtk_label_set_mnemonic_widget(GTK_LABEL(label), controls.interp);
-    gtk_table_attach(GTK_TABLE(table), controls.interp,
-                     0, 2, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
-    gtk_table_set_row_spacing(GTK_TABLE(table), row, 8);
-    row++;
-
-    label = gtk_label_new_with_mnemonic(_("_Method:"));
-    gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
-    gtk_table_attach(GTK_TABLE(table), label,
-                     0, 2, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
-    row++;
-
-    controls.out = gwy_enum_combo_box_new(methods, G_N_ELEMENTS(methods),
-                                          G_CALLBACK(out_changed_cb), &controls,
-                                          args->out, TRUE);
-    gtk_label_set_mnemonic_widget(GTK_LABEL(label), controls.out);
-    gtk_table_attach(GTK_TABLE(table), controls.out,
-                     0, 2, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
+    gwy_table_attach_adjbar(table, row, _("_Interpolation type:"), NULL,
+                            GTK_OBJECT(controls.interp),
+                            GWY_HSCALE_WIDGET_NO_EXPAND);
     row++;
 
     /* Area */
-    table = gtk_table_new(3, 2, FALSE);
-    gtk_table_set_row_spacings(GTK_TABLE(table), 2);
-    gtk_table_set_col_spacings(GTK_TABLE(table), 6);
-    gtk_box_pack_start(GTK_BOX(vbox), table, FALSE, FALSE, 0);
-    row = 0;
-
-    label = gwy_label_new_header(_("Fit Area"));
-    gtk_table_attach(GTK_TABLE(table), label,
-                     0, 2, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
+    gtk_table_set_row_spacing(GTK_TABLE(table), row-1, 8);
+    gtk_table_attach(GTK_TABLE(table), gwy_label_new_header(_("Fit Area")),
+                     0, 2, row, row+1, GTK_FILL, 0, 0, 0);
     row++;
 
-    controls.from = attach_value_row(table, row, _("From:"), _("minimum"));
+    controls.from = gtk_label_new(_("minimum"));
+    gwy_table_attach_adjbar(table, row, _("From:"), NULL,
+                            GTK_OBJECT(controls.from),
+                            GWY_HSCALE_WIDGET_NO_EXPAND);
     row++;
 
-    controls.to = attach_value_row(table, row, _("To:"), _("maximum"));
+    controls.to = gtk_label_new(_("maximum"));
+    gwy_table_attach_adjbar(table, row, _("To:"), NULL,
+                            GTK_OBJECT(controls.to),
+                            GWY_HSCALE_WIDGET_NO_EXPAND);
     row++;
 
     /* Results */
-    table = gtk_table_new(GWY_FRACTAL_NMETHODS + 1, 2, FALSE);
-    gtk_table_set_row_spacings(GTK_TABLE(table), 2);
-    gtk_table_set_col_spacings(GTK_TABLE(table), 6);
-    gtk_box_pack_start(GTK_BOX(vbox), table, FALSE, FALSE, 0);
-    row = 0;
-
-    label = gwy_label_new_header(_("Result"));
-    gtk_table_attach(GTK_TABLE(table), label,
-                     0, 2, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
+    gtk_table_set_row_spacing(GTK_TABLE(table), row-1, 8);
+    gtk_table_attach(GTK_TABLE(table), gwy_label_new_header(_("Result")),
+                     0, 2, row, row+1, GTK_FILL, 0, 0, 0);
     row++;
 
     /* FIXME: This is a latinism. */
@@ -315,20 +293,16 @@ fractal_dialog(FractalArgs *args, GwyContainer *data)
     for (i = 0; i < GWY_FRACTAL_NMETHODS; i++) {
         g_string_assign(str, _(methods[i].name));
         g_string_append_c(str, ':');
-        controls.results[i] = attach_value_row(table, row, str->str, NULL);
+        controls.results[i] = gtk_label_new(NULL);
+        gwy_table_attach_adjbar(table, row, str->str, NULL,
+                                GTK_OBJECT(controls.results[i]),
+                                GWY_HSCALE_WIDGET_NO_EXPAND);
         gtk_label_set_selectable(GTK_LABEL(controls.results[i]), TRUE);
         row++;
     }
     g_string_free(str, TRUE);
     row++;
 
-    hbox2 = gtk_hbox_new(FALSE, 6);
-    gtk_box_pack_start(GTK_BOX(vbox), hbox2, FALSE, FALSE, 0);
-
-    label = gtk_label_new_with_mnemonic(_("Target _graph:"));
-    gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
-    gtk_box_pack_start(GTK_BOX(hbox2), label, FALSE, FALSE, 0);
-
     controls.target_graph = gwy_data_chooser_new_graphs();
     chooser = GWY_DATA_CHOOSER(controls.target_graph);
     gwy_data_chooser_set_none(chooser, _("New graph"));
@@ -336,8 +310,9 @@ fractal_dialog(FractalArgs *args, GwyContainer *data)
     gwy_data_chooser_set_filter(chooser, filter_target_graphs, &controls, NULL);
     gwy_data_chooser_set_active_id(chooser, &args->target_graph);
     gwy_data_chooser_get_active_id(chooser, &args->target_graph);
-    gtk_label_set_mnemonic_widget(GTK_LABEL(label), controls.target_graph);
-    gtk_box_pack_end(GTK_BOX(hbox2), controls.target_graph, FALSE, FALSE, 0);
+    gwy_table_attach_adjbar(table, row, _("Target _graph:"), NULL,
+                            GTK_OBJECT(controls.target_graph),
+                            GWY_HSCALE_WIDGET_NO_EXPAND);
     g_signal_connect_swapped(controls.target_graph, "changed",
                              G_CALLBACK(target_graph_changed), &controls);
     row++;
@@ -394,25 +369,6 @@ fractal_dialog(FractalArgs *args, GwyContainer *data)
     gtk_widget_destroy(dialog);
 }
 
-static GtkWidget*
-attach_value_row(GtkWidget *table, gint row,
-                 const gchar *description, const gchar *value)
-{
-    GtkWidget *label;
-
-    label = gtk_label_new(description);
-    gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
-    gtk_table_attach(GTK_TABLE(table), label,
-                     0, 1, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
-
-    label = gtk_label_new(value);
-    gtk_misc_set_alignment(GTK_MISC(label), 1.0, 0.5);
-    gtk_table_attach(GTK_TABLE(table), label,
-                     1, 2, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
-
-    return label;
-}
-
 static void
 interp_changed_cb(GtkWidget *combo,
                   FractalArgs *args)
