@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: gradient.c 16388 2014-07-10 14:26:53Z yeti-dn $
+ *  @(#) $Id: gradient.c 19948 2017-06-22 14:05:41Z yeti-dn $
  *  Copyright (C) 2003 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -48,7 +48,7 @@ static GwyModuleInfo module_info = {
     "2004",
 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, gradient)
 
 static gboolean
 module_register(void)
