@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: grain_cross.c 18626 2016-04-22 10:15:13Z yeti-dn $
+ *  @(#) $Id: grain_cross.c 19948 2017-06-22 14:05:41Z yeti-dn $
  *  Copyright (C) 2007 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
@@ -105,7 +105,7 @@ static GwyModuleInfo module_info = {
     "2007",
 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, grain_cross)
 
 static gboolean
 module_register(void)
@@ -233,6 +233,7 @@ grain_cross_dialog(GrainCrossArgs *args,
     gmodel = create_corr_graph(args, dfield);
     controls.graph = gwy_graph_new(gmodel);
     gtk_widget_set_size_request(controls.graph, 320, -1);
+    gwy_graph_enable_user_input(GWY_GRAPH(controls.graph), FALSE);
     g_object_unref(gmodel);
     gtk_table_attach(GTK_TABLE(table), controls.graph, 0, 1, 0, 3,
                      GTK_EXPAND | GTK_FILL, GTK_EXPAND | GTK_FILL, 0, 0);
