@@ -1,6 +1,6 @@
 /*
- *  @(#) $Id: grain_dist.c 18537 2016-03-28 18:11:19Z yeti-dn $
- *  Copyright (C) 2003-2012 David Necas (Yeti), Petr Klapetek, Sven Neumann.
+ *  @(#) $Id: grain_dist.c 20063 2017-07-11 11:03:01Z yeti-dn $
+ *  Copyright (C) 2003-2017 David Necas (Yeti), Petr Klapetek, Sven Neumann.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net, neumann@jpk.com.
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -153,7 +153,7 @@ static GwyModuleInfo module_info = {
     N_("Evaluates distribution of grains (continuous parts of mask)."),
     "Petr Klapetek <petr@klapetek.cz>, Sven Neumann <neumann@jpk.com>, "
         "Yeti <yeti@gwyddion.net>",
-    "4.2",
+    "4.3",
     "David Nečas (Yeti) & Petr Klapetek & Sven Neumann",
     "2003",
 };
@@ -165,7 +165,7 @@ static const gchar add_comment_key[] = "/module/grain_dist/add_comment";
 static const gchar selected_key[]    = "/module/grain_dist/selected";
 static const gchar expanded_key[]    = "/module/grain_dist/expanded";
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, grain_dist)
 
 static gboolean
 module_register(void)
@@ -256,6 +256,7 @@ grain_dist_dialog(GrainDistArgs *args,
     gmodel = gwy_graph_model_new();
     controls.graph = gwy_graph_new(gmodel);
     gtk_widget_set_size_request(controls.graph, 360, -1);
+    gwy_graph_enable_user_input(GWY_GRAPH(controls.graph), FALSE);
     g_object_unref(gmodel);
     gtk_box_pack_start(GTK_BOX(hbox), controls.graph, TRUE, TRUE, 4);
 
@@ -291,7 +292,7 @@ grain_dist_dialog(GrainDistArgs *args,
                              G_CALLBACK(selected_changed), &controls);
 
     /* Options */
-    table = GTK_TABLE(gtk_table_new(5, 4, FALSE));
+    table = GTK_TABLE(gtk_table_new(5, 3, FALSE));
     gtk_table_set_row_spacings(table, 2);
     gtk_table_set_col_spacings(table, 6);
     gtk_container_set_border_width(GTK_CONTAINER(table), 4);
@@ -304,12 +305,12 @@ grain_dist_dialog(GrainDistArgs *args,
                                              args->mode);
 
     gtk_table_attach(table, gwy_label_new_header(_("Options")),
-                     0, 3, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
+                     0, 2, row, row+1, GTK_FILL, 0, 0, 0);
     row++;
 
     l = controls.mode;
     gtk_table_attach(table, GTK_WIDGET(l->data),
-                     0, 4, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
+                     0, 2, row, row+1, GTK_FILL, 0, 0, 0);
     l = g_slist_next(l);
     row++;
 
@@ -319,13 +320,13 @@ grain_dist_dialog(GrainDistArgs *args,
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(controls.add_comment),
                                  args->add_comment);
     gtk_table_attach(table, controls.add_comment,
-                     0, 4, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
+                     0, 2, row, row+1, GTK_FILL, 0, 0, 0);
     g_signal_connect_swapped(controls.add_comment, "toggled",
                              G_CALLBACK(add_comment_changed), &controls);
     row++;
 
     gtk_table_attach(table, GTK_WIDGET(l->data),
-                     0, 4, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
+                     0, 2, row, row+1, GTK_FILL, 0, 0, 0);
     l = g_slist_next(l);
     gtk_table_set_row_spacing(table, row, 8);
     row++;
@@ -333,7 +334,8 @@ grain_dist_dialog(GrainDistArgs *args,
     controls.resolution = gtk_adjustment_new(args->resolution,
                                              MIN_RESOLUTION, MAX_RESOLUTION,
                                              1, 10, 0);
-    gwy_table_attach_hscale(GTK_WIDGET(table), row, _("_Fix res.:"), NULL,
+    gwy_table_attach_adjbar(GTK_WIDGET(table), row,
+                            _("_Fixed resolution:"), NULL,
                             controls.resolution, GWY_HSCALE_CHECK);
     controls.fixres = gwy_table_hscale_get_check(controls.resolution);
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(controls.fixres),
@@ -438,24 +440,16 @@ static void
 update_sensitivity(GrainDistControls *controls, GrainDistArgs *args)
 {
     GtkTreeView *treeview;
-    GtkWidget *check, *w;
 
-    check = gwy_table_hscale_get_check(controls->resolution);
     switch (args->mode) {
         case MODE_GRAPH:
         gtk_widget_set_sensitive(controls->add_comment, FALSE);
-        gtk_widget_set_sensitive(check, TRUE);
-        gtk_toggle_button_toggled(GTK_TOGGLE_BUTTON(check));
-        gtk_toggle_button_toggled(GTK_TOGGLE_BUTTON(check));
+        gwy_table_hscale_set_sensitive(controls->resolution, TRUE);
         break;
 
         case MODE_RAW:
         gtk_widget_set_sensitive(controls->add_comment, TRUE);
-        gtk_widget_set_sensitive(check, FALSE);
-        w = gwy_table_hscale_get_scale(controls->resolution);
-        gtk_widget_set_sensitive(w, FALSE);
-        w = gwy_table_hscale_get_middle_widget(controls->resolution);
-        gtk_widget_set_sensitive(w, FALSE);
+        gwy_table_hscale_set_sensitive(controls->resolution, FALSE);
         break;
 
         default:
