@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: grain_edge.c 18673 2016-05-03 13:08:36Z dn2010 $
+ *  @(#) $Id: grain_edge.c 19948 2017-06-22 14:05:41Z yeti-dn $
  *  Copyright (C) 2011 David Necas (Yeti), Petr Klapetek, Daniil Bratashov.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net, dn2010@gmail.com.
  *
@@ -27,6 +27,7 @@
 #include <libprocess/grains.h>
 #include <libprocess/stats.h>
 #include <libgwydgets/gwycombobox.h>
+#include <libgwydgets/gwyradiobuttons.h>
 #include <libgwydgets/gwystock.h>
 #include <libgwymodule/gwymodule-process.h>
 #include <app/gwymoduleutils.h>
@@ -48,7 +49,7 @@ typedef struct {
     GwyContainer *mydata;
     GtkObject *threshold_laplasian;
     GtkWidget *combine;
-    GtkWidget *combine_type;
+    GSList *combine_type;
     GtkWidget *color_button;
     GtkWidget *update;
     GEdgeArgs *args;
@@ -75,8 +76,6 @@ static void     gedge_dialog_update_values  (GEdgeControls *controls,
                                              GEdgeArgs *args);
 static void     update_changed              (GEdgeControls *controls);
 static void     gedge_invalidate            (GEdgeControls *controls);
-static void     gedge_invalidate2           (gpointer instance,
-                                             GEdgeControls *controls);
 static void     preview                     (GEdgeControls *controls,
                                              GEdgeArgs *args);
 static void     gedge_process               (GwyDataField *dfield,
@@ -99,12 +98,12 @@ static GwyModuleInfo module_info = {
     &module_register,
     N_("Marks grains by edge detection method."),
     "Daniil Bratashov <dn2010@gmail.com>",
-    "0.3",
+    "0.5",
     "David Nečas (Yeti) & Petr Klapetek & Daniil Bratashov",
     "2011",
 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, grain_edge)
 
 static gboolean
 module_register(void)
@@ -151,7 +150,7 @@ table_attach_threshold(GtkWidget *table, gint *row, const gchar *name,
                        gpointer data)
 {
     *adj = gtk_adjustment_new(value, 0.0, 100.0, 0.1, 5, 0);
-    gwy_table_attach_hscale(table, *row, name, "%", *adj, GWY_HSCALE_DEFAULT);
+    gwy_table_attach_adjbar(table, *row, name, "%", *adj, GWY_HSCALE_DEFAULT);
     g_signal_connect_swapped(*adj, "value-changed",
                              G_CALLBACK(gedge_invalidate), data);
     (*row)++;
@@ -235,7 +234,7 @@ gedge_dialog(GEdgeArgs *args,
     controls.view = create_preview(controls.mydata, 0, PREVIEW_SIZE, TRUE);
     gtk_box_pack_start(GTK_BOX(hbox), controls.view, FALSE, FALSE, 4);
 
-    table = gtk_table_new(5, 4, FALSE);
+    table = gtk_table_new(5, 3, FALSE);
     gtk_table_set_row_spacings(GTK_TABLE(table), 2);
     gtk_table_set_col_spacings(GTK_TABLE(table), 6);
     gtk_container_set_border_width(GTK_CONTAINER(table), 4);
@@ -243,7 +242,7 @@ gedge_dialog(GEdgeArgs *args,
     row = 0;
 
     gtk_table_attach(GTK_TABLE(table), gwy_label_new_header(_("Threshold")),
-                     0, 3, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
+                     0, 2, row, row+1, GTK_FILL, 0, 0, 0);
     row++;
 
     table_attach_threshold(table, &row, _("_Laplacian:"),
@@ -253,36 +252,24 @@ gedge_dialog(GEdgeArgs *args,
     gtk_table_set_row_spacing(GTK_TABLE(table), row-1, 8);
 
     gtk_table_attach(GTK_TABLE(table), gwy_label_new_header(_("Options")),
-                     0, 3, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
+                     0, 2, row, row+1, GTK_FILL, 0, 0, 0);
     row++;
 
     if (mfield) {
         gwy_container_set_object_by_name(controls.mydata, "/1/mask", mfield);
-        controls.combine
-            = gtk_check_button_new_with_mnemonic(_("Com_bine with "
-                                                   "existing mask"));
-        gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(controls.combine),
-                                     args->combine);
-        gtk_table_attach(GTK_TABLE(table), controls.combine,
-                         0, 3, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
-        g_signal_connect_swapped(controls.combine, "toggled",
-                                 G_CALLBACK(gedge_invalidate), &controls);
-        row++;
-
-        controls.combine_type
-            = gwy_enum_combo_box_new(gwy_merge_type_get_enum(), -1,
-                                     G_CALLBACK(gedge_invalidate2), &controls,
-                                     args->combine_type, TRUE);
-        gwy_table_attach_hscale(table, row, _("Operation:"), NULL,
-                                GTK_OBJECT(controls.combine_type),
-                                GWY_HSCALE_WIDGET);
-        gtk_table_set_row_spacing(GTK_TABLE(table), row, 8);
+        create_mask_merge_buttons(table, row, NULL,
+                                  args->combine,
+                                  G_CALLBACK(gedge_invalidate),
+                                  args->combine_type,
+                                  G_CALLBACK(gedge_invalidate),
+                                  &controls,
+                                  &controls.combine, &controls.combine_type);
         row++;
     }
 
     controls.color_button = create_mask_color_button(controls.mydata, dialog,
                                                      0);
-    gwy_table_attach_hscale(table, row, _("_Mask color:"), NULL,
+    gwy_table_attach_adjbar(table, row, _("_Mask color:"), NULL,
                             GTK_OBJECT(controls.color_button),
                             GWY_HSCALE_WIDGET_NO_EXPAND);
     row++;
@@ -291,7 +278,7 @@ gedge_dialog(GEdgeArgs *args,
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(controls.update),
                                  args->update);
     gtk_table_attach(GTK_TABLE(table), controls.update,
-                     0, 3, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
+                     0, 2, row, row+1, GTK_FILL, 0, 0, 0);
     g_signal_connect_swapped(controls.update, "toggled",
                              G_CALLBACK(update_changed), &controls);
 
@@ -367,13 +354,12 @@ gedge_dialog_update_controls(GEdgeControls *controls,
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(controls->update),
                                  args->update);
 
-    if (!controls->combine)
-        return;
-
-    gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(controls->combine),
-                                 args->combine);
-    gwy_enum_combo_box_set_active(GTK_COMBO_BOX(controls->combine_type),
-                                  args->combine_type);
+    if (controls->combine) {
+        gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(controls->combine),
+                                     args->combine);
+        gwy_radio_buttons_set_current(controls->combine_type,
+                                      args->combine_type);
+    }
 }
 
 static void
@@ -385,13 +371,12 @@ gedge_dialog_update_values(GEdgeControls *controls,
     args->update
         = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(controls->update));
 
-    if (!controls->combine)
-        return;
-
-    args->combine
-        = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(controls->combine));
-    args->combine_type
-        = gwy_enum_combo_box_get_active(GTK_COMBO_BOX(controls->combine_type));
+    if (controls->combine) {
+        args->combine
+            = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(controls->combine));
+        args->combine_type
+            = gwy_radio_buttons_get_current(controls->combine_type);
+    }
 }
 
 static void
@@ -404,13 +389,6 @@ gedge_invalidate(GEdgeControls *controls)
     }
 }
 
-static void
-gedge_invalidate2(G_GNUC_UNUSED gpointer instance,
-                  GEdgeControls *controls)
-{
-    gedge_invalidate(controls);
-}
-
 static void
 preview(GEdgeControls *controls,
         GEdgeArgs *args)
