@@ -1,6 +1,6 @@
 /*
- *  @(#) $Id: grain_filter.c 18537 2016-03-28 18:11:19Z yeti-dn $
- *  Copyright (C) 2014 David Necas (Yeti).
+ *  @(#) $Id: grain_filter.c 19948 2017-06-22 14:05:41Z yeti-dn $
+ *  Copyright (C) 2014-2017 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -29,6 +29,7 @@
 #include <libprocess/grains.h>
 #include <libgwydgets/gwystock.h>
 #include <libgwydgets/gwycombobox.h>
+#include <libgwydgets/gwyadjustbar.h>
 #include <libgwydgets/gwygrainvaluemenu.h>
 #include <libgwymodule/gwymodule-process.h>
 #include <app/gwymoduleutils.h>
@@ -94,12 +95,10 @@ typedef struct {
     GwySIValueFormat *vf[NQUANTITIES];
     GtkWidget *header[NQUANTITIES];
     GtkObject *lower[NQUANTITIES];
-    GtkWidget *lower_label[NQUANTITIES];
     GtkWidget *lower_scale[NQUANTITIES];
     GtkWidget *lower_entry[NQUANTITIES];
     GtkWidget *lower_units[NQUANTITIES];
     GtkObject *upper[NQUANTITIES];
-    GtkWidget *upper_label[NQUANTITIES];
     GtkWidget *upper_scale[NQUANTITIES];
     GtkWidget *upper_entry[NQUANTITIES];
     GtkWidget *upper_units[NQUANTITIES];
@@ -195,12 +194,12 @@ static GwyModuleInfo module_info = {
     N_("Filters grains by their properties, using logical expressions "
        "and thresholds."),
     "Yeti <yeti@gwyddion.net>",
-    "1.1",
+    "1.2",
     "David Nečas (Yeti)",
     "2014",
 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, grain_filter)
 
 static gboolean
 module_register(void)
@@ -362,7 +361,7 @@ gfilter_dialog(GFilterArgs *args,
     gtk_label_set_mnemonic_widget(GTK_LABEL(label), controls.color_button);
     gtk_box_pack_start(GTK_BOX(hbox2), controls.color_button, FALSE, FALSE, 0);
 
-    table = gtk_table_new(10, 4, FALSE);
+    table = gtk_table_new(10, 3, FALSE);
     gtk_table_set_row_spacings(GTK_TABLE(table), 2);
     gtk_table_set_col_spacings(GTK_TABLE(table), 6);
     gtk_container_set_border_width(GTK_CONTAINER(table), 4);
@@ -373,8 +372,8 @@ gfilter_dialog(GFilterArgs *args,
     scwin = gtk_scrolled_window_new(NULL, NULL);
     gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(scwin),
                                    GTK_POLICY_NEVER, GTK_POLICY_AUTOMATIC);
-    gtk_table_attach(GTK_TABLE(table), scwin, 0, 4, row, row+1,
-                     GTK_EXPAND | GTK_FILL, GTK_EXPAND | GTK_FILL, 0, 0);
+    gtk_table_attach(GTK_TABLE(table), scwin, 0, 3, row, row+1,
+                     GTK_FILL, GTK_EXPAND | GTK_FILL, 0, 0);
 
     controls.values = gwy_grain_value_tree_view_new(FALSE,
                                                     "name", "symbol_markup",
@@ -401,7 +400,7 @@ gfilter_dialog(GFilterArgs *args,
         g_signal_connect_swapped(controls.set_as[i], "clicked",
                                  G_CALLBACK(set_as_clicked), &controls);
     }
-    gwy_table_attach_hscale(table, row++,
+    gwy_table_attach_adjbar(table, row++,
                             _("Set selected as:"), NULL,
                             GTK_OBJECT(hbox2), GWY_HSCALE_WIDGET_NO_EXPAND);
 
@@ -416,7 +415,7 @@ gfilter_dialog(GFilterArgs *args,
                                   "(A ∧ B) ∨ C", GRAIN_LOGICAL_A_AND_B_OR_C,
                                   "(A ∨ B) ∧ C", GRAIN_LOGICAL_A_OR_B_AND_C,
                                   NULL);
-    gwy_table_attach_hscale(table, row++,
+    gwy_table_attach_adjbar(table, row++,
                             _("Keep grains satisfying:"), NULL,
                             GTK_OBJECT(controls.logical_op),
                             GWY_HSCALE_WIDGET);
@@ -427,33 +426,25 @@ gfilter_dialog(GFilterArgs *args,
         controls.header[i] = gtk_label_new(NULL);
         gtk_misc_set_alignment(GTK_MISC(controls.header[i]), 0.0, 0.5);
         gtk_table_attach(GTK_TABLE(table), controls.header[i],
-                         0, 4, row, row+1, GTK_FILL, 0, 0, 0);
+                         0, 2, row, row+1, GTK_FILL, 0, 0, 0);
         row++;
 
         /* The values are set properly later. */
-        controls.lower_label[i] = gtk_label_new(_("Lower threshold:"));
-        gtk_misc_set_alignment(GTK_MISC(controls.lower_label[i]), 0.0, 0.5);
-        gtk_table_attach(GTK_TABLE(table), controls.lower_label[i],
-                         0, 1, row, row+1, GTK_FILL, 0, 0, 0);
-
-        controls.lower[i] = gtk_adjustment_new(0.0, 0.0, 0.0,
-                                               1.0, 10.0, 0.0);
+        controls.lower[i] = gtk_adjustment_new(0.0, 0.0, 0.0, 1.0, 10.0, 0.0);
         g_object_set_data(G_OBJECT(controls.lower[i]), "id",
                           GUINT_TO_POINTER(i));
         g_signal_connect_swapped(controls.lower[i], "value-changed",
                                  G_CALLBACK(threshold_changed), &controls);
         controls.lower_scale[i]
-            = gtk_hscale_new(GTK_ADJUSTMENT(controls.lower[i]));
-        gtk_scale_set_draw_value(GTK_SCALE(controls.lower_scale[i]), FALSE);
-        gtk_widget_set_size_request(controls.lower_scale[i],
-                                    GWY_HSCALE_WIDTH, -1);
+            = gwy_adjust_bar_new(GTK_ADJUSTMENT(controls.lower[i]),
+                                 _("Lower threshold:"));
         gtk_table_attach(GTK_TABLE(table), controls.lower_scale[i],
-                         1, 2, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
+                         0, 1, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
 
         controls.lower_entry[i] = gtk_entry_new();
         gtk_entry_set_width_chars(GTK_ENTRY(controls.lower_entry[i]), 8);
         gtk_table_attach(GTK_TABLE(table), controls.lower_entry[i],
-                         2, 3, row, row+1, GTK_FILL, 0, 0, 0);
+                         1, 2, row, row+1, GTK_FILL, 0, 0, 0);
         gwy_widget_set_activate_on_unfocus(controls.lower_entry[i], TRUE);
         g_object_set_data(G_OBJECT(controls.lower_entry[i]), "id",
                           GUINT_TO_POINTER(i));
@@ -463,32 +454,24 @@ gfilter_dialog(GFilterArgs *args,
         controls.lower_units[i] = gtk_label_new(NULL);
         gtk_misc_set_alignment(GTK_MISC(controls.lower_units[i]), 0.0, 0.5);
         gtk_table_attach(GTK_TABLE(table), controls.lower_units[i],
-                         3, 4, row, row+1, GTK_FILL, 0, 0, 0);
+                         2, 3, row, row+1, GTK_FILL, 0, 0, 0);
         row++;
 
-        controls.upper_label[i] = gtk_label_new(_("Upper threshold:"));
-        gtk_misc_set_alignment(GTK_MISC(controls.upper_label[i]), 0.0, 0.5);
-        gtk_table_attach(GTK_TABLE(table), controls.upper_label[i],
-                         0, 1, row, row+1, GTK_FILL, 0, 0, 0);
-
-        controls.upper[i] = gtk_adjustment_new(0.0, 0.0, 0.0,
-                                               1.0, 10.0, 0.0);
+        controls.upper[i] = gtk_adjustment_new(0.0, 0.0, 0.0, 1.0, 10.0, 0.0);
         g_object_set_data(G_OBJECT(controls.upper[i]), "id",
                           GUINT_TO_POINTER(i | IS_UPPER));
         g_signal_connect_swapped(controls.upper[i], "value-changed",
                                  G_CALLBACK(threshold_changed), &controls);
         controls.upper_scale[i]
-            = gtk_hscale_new(GTK_ADJUSTMENT(controls.upper[i]));
-        gtk_scale_set_draw_value(GTK_SCALE(controls.upper_scale[i]), FALSE);
-        gtk_widget_set_size_request(controls.upper_scale[i],
-                                    GWY_HSCALE_WIDTH, -1);
+            = gwy_adjust_bar_new(GTK_ADJUSTMENT(controls.upper[i]),
+                                 _("Upper threshold:"));
         gtk_table_attach(GTK_TABLE(table), controls.upper_scale[i],
-                         1, 2, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
+                         0, 1, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
 
         controls.upper_entry[i] = gtk_entry_new();
         gtk_entry_set_width_chars(GTK_ENTRY(controls.upper_entry[i]), 8);
         gtk_table_attach(GTK_TABLE(table), controls.upper_entry[i],
-                         2, 3, row, row+1, GTK_FILL, 0, 0, 0);
+                         1, 2, row, row+1, GTK_FILL, 0, 0, 0);
         gwy_widget_set_activate_on_unfocus(controls.upper_entry[i], TRUE);
         g_object_set_data(G_OBJECT(controls.upper_entry[i]), "id",
                           GUINT_TO_POINTER(i | IS_UPPER));
@@ -498,7 +481,7 @@ gfilter_dialog(GFilterArgs *args,
         controls.upper_units[i] = gtk_label_new(NULL);
         gtk_misc_set_alignment(GTK_MISC(controls.upper_units[i]), 0.0, 0.5);
         gtk_table_attach(GTK_TABLE(table), controls.upper_units[i],
-                         3, 4, row, row+1, GTK_FILL, 0, 0, 0);
+                         2, 3, row, row+1, GTK_FILL, 0, 0, 0);
         row++;
     }
 
@@ -775,11 +758,9 @@ logical_op_changed(GtkComboBox *combo, GFilterControls *controls)
         if (sens) {
             gtk_widget_show(controls->set_as[i]);
             gtk_widget_show(controls->header[i]);
-            gtk_widget_show(controls->lower_label[i]);
             gtk_widget_show(controls->lower_scale[i]);
             gtk_widget_show(controls->lower_entry[i]);
             gtk_widget_show(controls->lower_units[i]);
-            gtk_widget_show(controls->upper_label[i]);
             gtk_widget_show(controls->upper_scale[i]);
             gtk_widget_show(controls->upper_entry[i]);
             gtk_widget_show(controls->upper_units[i]);
@@ -787,11 +768,9 @@ logical_op_changed(GtkComboBox *combo, GFilterControls *controls)
         else {
             gtk_widget_hide(controls->set_as[i]);
             gtk_widget_hide(controls->header[i]);
-            gtk_widget_hide(controls->lower_label[i]);
             gtk_widget_hide(controls->lower_scale[i]);
             gtk_widget_hide(controls->lower_entry[i]);
             gtk_widget_hide(controls->lower_units[i]);
-            gtk_widget_hide(controls->upper_label[i]);
             gtk_widget_hide(controls->upper_scale[i]);
             gtk_widget_hide(controls->upper_entry[i]);
             gtk_widget_hide(controls->upper_units[i]);
