@@ -1,6 +1,6 @@
 /*
- *  @(#) $Id: grain_mark.c 18537 2016-03-28 18:11:19Z yeti-dn $
- *  Copyright (C) 2004-2015 David Necas (Yeti), Petr Klapetek.
+ *  @(#) $Id: grain_mark.c 19948 2017-06-22 14:05:41Z yeti-dn $
+ *  Copyright (C) 2004-2017 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -27,7 +27,7 @@
 #include <libprocess/grains.h>
 #include <libprocess/stats.h>
 #include <libgwydgets/gwycombobox.h>
-#include <libgwydgets/gwystock.h>
+#include <libgwydgets/gwyradiobuttons.h>
 #include <libgwymodule/gwymodule-process.h>
 #include <app/gwymoduleutils.h>
 #include <app/gwyapp.h>
@@ -70,9 +70,9 @@ typedef struct {
     GwySIValueFormat *format_height;
     GtkObject *threshold_slope;
     GtkObject *threshold_lap;
-    GtkWidget *merge;
+    GSList *merge_type;
     GtkWidget *combine;
-    GtkWidget *combine_type;
+    GSList *combine_type;
     GtkWidget *color_button;
     GtkWidget *update;
     GwyContainer *mydata;
@@ -103,8 +103,6 @@ static void        mark_dialog_update_values  (MarkControls *controls,
 static void        update_threshold_value     (MarkControls *controls);
 static void        update_change_cb           (MarkControls *controls);
 static void        mark_invalidate            (MarkControls *controls);
-static void        mark_invalidate2           (gpointer whatever,
-                                               MarkControls *controls);
 static void        preview                    (MarkControls *controls,
                                                MarkArgs *args);
 static void        mask_process               (GwyDataField *dfield,
@@ -138,12 +136,12 @@ static GwyModuleInfo module_info = {
     &module_register,
     N_("Marks grains by thresholding (height, slope, curvature)."),
     "Petr Klapetek <petr@klapetek.cz>",
-    "1.18",
+    "1.20",
     "David Nečas (Yeti) & Petr Klapetek",
     "2003",
 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, grain_mark)
 
 static gboolean
 module_register(void)
@@ -192,7 +190,8 @@ table_attach_threshold(GtkWidget *table, gint *row, const gchar *name,
                        gpointer data)
 {
     *adj = gtk_adjustment_new(value, 0.0, 100.0, 0.1, 5, 0);
-    gwy_table_attach_hscale(table, *row, name, "%", *adj, GWY_HSCALE_CHECK);
+    gwy_table_attach_adjbar(table, *row, name, "%", *adj,
+                            GWY_HSCALE_CHECK | GWY_HSCALE_LINEAR);
     *check = gwy_table_hscale_get_check(*adj);
     g_signal_connect_swapped(*adj, "value-changed",
                              G_CALLBACK(mark_invalidate), data);
@@ -271,7 +270,7 @@ mark_dialog(MarkArgs *args,
     controls.view = create_preview(controls.mydata, 0, PREVIEW_SIZE, TRUE);
     gtk_box_pack_start(GTK_BOX(hbox), controls.view, FALSE, FALSE, 4);
 
-    table = gtk_table_new(10 + 2*(!!existing_mask), 4, FALSE);
+    table = gtk_table_new(10 + 1*(!!existing_mask), 3, FALSE);
     gtk_table_set_row_spacings(GTK_TABLE(table), 2);
     gtk_table_set_col_spacings(GTK_TABLE(table), 6);
     gtk_container_set_border_width(GTK_CONTAINER(table), 4);
@@ -279,7 +278,7 @@ mark_dialog(MarkArgs *args,
     row = 0;
 
     gtk_table_attach(GTK_TABLE(table), gwy_label_new_header(_("Threshold by")),
-                     0, 3, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
+                     0, 2, row, row+1, GTK_FILL, 0, 0, 0);
     row++;
 
     table_attach_threshold(table, &row, _("_Height:"),
@@ -290,7 +289,7 @@ mark_dialog(MarkArgs *args,
     controls.value_height = gtk_label_new(NULL);
     gtk_misc_set_alignment(GTK_MISC(controls.value_height), 1.0, 0.5);
     gtk_table_attach(GTK_TABLE(table), controls.value_height,
-                     2, 3, row, row+1, GTK_FILL, 0, 0, 0);
+                     1, 2, row, row+1, GTK_FILL, 0, 0, 0);
     g_signal_connect_swapped(controls.threshold_height, "value-changed",
                              G_CALLBACK(update_threshold_value), &controls);
     gwy_widget_sync_sensitivity(pivot, controls.value_height);
@@ -302,7 +301,7 @@ mark_dialog(MarkArgs *args,
     gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
     gtk_label_set_markup(GTK_LABEL(label), controls.format_height->units);
     gtk_table_attach(GTK_TABLE(table), label,
-                     3, 4, row, row+1, GTK_FILL, 0, 0, 0);
+                     2, 3, row, row+1, GTK_FILL, 0, 0, 0);
     gwy_widget_sync_sensitivity(pivot, label);
 
     gtk_table_set_row_spacing(GTK_TABLE(table), row, 8);
@@ -317,63 +316,49 @@ mark_dialog(MarkArgs *args,
                            &controls.is_lap, &controls);
     gtk_table_set_row_spacing(GTK_TABLE(table), row-1, 8);
 
-    controls.merge
-        = gwy_enum_combo_box_new(gwy_merge_type_get_enum(), -1,
-                                 G_CALLBACK(mark_invalidate2), &controls,
-                                 args->merge_type, TRUE);
-    gwy_table_attach_hscale(table, row, _("Criteria combination:"), NULL,
-                            GTK_OBJECT(controls.merge), GWY_HSCALE_WIDGET);
-    row++;
-
     controls.inverted = gtk_check_button_new_with_mnemonic(_("_Invert height"));
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(controls.inverted),
                                  args->inverted);
     gtk_table_attach(GTK_TABLE(table), controls.inverted,
-                     0, 3, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
+                     0, 2, row, row+1, GTK_FILL, 0, 0, 0);
     g_signal_connect_swapped(controls.inverted, "toggled",
                              G_CALLBACK(mark_invalidate), &controls);
     row++;
 
-    gtk_table_set_row_spacing(GTK_TABLE(table), row-1, 8);
-    gtk_table_attach(GTK_TABLE(table), gwy_label_new_header(_("Options")),
-                     0, 3, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
+    create_mask_merge_buttons(table, row, _("Criteria combination:"),
+                              TRUE, NULL,
+                              args->merge_type, G_CALLBACK(mark_invalidate),
+                              &controls, NULL, &controls.merge_type);
     row++;
 
-    if (existing_mask) {
-        controls.combine
-            = gtk_check_button_new_with_mnemonic(_("Com_bine with "
-                                                   "existing mask"));
-        gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(controls.combine),
-                                     args->combine);
-        gtk_table_attach(GTK_TABLE(table), controls.combine,
-                         0, 3, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
-        g_signal_connect_swapped(controls.combine, "toggled",
-                                 G_CALLBACK(mark_invalidate), &controls);
-        row++;
-
-        controls.combine_type
-            = gwy_enum_combo_box_new(gwy_merge_type_get_enum(), -1,
-                                     G_CALLBACK(mark_invalidate2), &controls,
-                                     args->combine_type, TRUE);
-        gwy_table_attach_hscale(table, row, _("Operation:"), NULL,
-                                GTK_OBJECT(controls.combine_type),
-                                GWY_HSCALE_WIDGET);
-        gtk_table_set_row_spacing(GTK_TABLE(table), row, 8);
-        row++;
-    }
+    gtk_table_set_row_spacing(GTK_TABLE(table), row-1, 8);
+    gtk_table_attach(GTK_TABLE(table), gwy_label_new_header(_("Options")),
+                     0, 2, row, row+1, GTK_FILL, 0, 0, 0);
+    row++;
 
     controls.color_button = create_mask_color_button(controls.mydata, dialog,
                                                      0);
-    gwy_table_attach_hscale(table, row++, _("_Mask color:"), NULL,
+    gwy_table_attach_adjbar(table, row++, _("_Mask color:"), NULL,
                             GTK_OBJECT(controls.color_button),
                             GWY_HSCALE_WIDGET_NO_EXPAND);
     row++;
 
+    if (existing_mask) {
+        create_mask_merge_buttons(table, row, NULL,
+                                  args->combine,
+                                  G_CALLBACK(mark_invalidate),
+                                  args->combine_type,
+                                  G_CALLBACK(mark_invalidate),
+                                  &controls,
+                                  &controls.combine, &controls.combine_type);
+        row++;
+    }
+
     controls.update = gtk_check_button_new_with_mnemonic(_("I_nstant updates"));
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(controls.update),
                                  args->update);
     gtk_table_attach(GTK_TABLE(table), controls.update,
-                     0, 3, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
+                     0, 2, row, row+1, GTK_FILL, 0, 0, 0);
     g_signal_connect_swapped(controls.update, "toggled",
                              G_CALLBACK(update_change_cb), &controls);
 
@@ -485,12 +470,11 @@ mark_dialog_update_controls(MarkControls *controls,
                                  args->is_lap);
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(controls->update),
                                  args->update);
-    gwy_enum_combo_box_set_active(GTK_COMBO_BOX(controls->merge),
-                                  args->merge_type);
+    gwy_radio_buttons_set_current(controls->merge_type, args->merge_type);
     if (controls->combine) {
         gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(controls->combine),
                                      args->combine);
-        gwy_enum_combo_box_set_active(GTK_COMBO_BOX(controls->combine_type),
+        gwy_radio_buttons_set_current(controls->combine_type,
                                       args->combine_type);
     }
 }
@@ -515,13 +499,12 @@ mark_dialog_update_values(MarkControls *controls,
         = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(controls->is_lap));
     args->update
         = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(controls->update));
-    args->merge_type
-        = gwy_enum_combo_box_get_active(GTK_COMBO_BOX(controls->merge));
+    args->merge_type = gwy_radio_buttons_get_current(controls->merge_type);
     if (controls->combine) {
         args->combine = gtk_toggle_button_get_active
                                        (GTK_TOGGLE_BUTTON(controls->combine));
-        args->combine_type = gwy_enum_combo_box_get_active
-                                      (GTK_COMBO_BOX(controls->combine_type));
+        args->combine_type
+            = gwy_radio_buttons_get_current(controls->combine_type);
     }
 }
 
@@ -566,12 +549,6 @@ update_change_cb(MarkControls *controls)
         mark_invalidate(controls);
 }
 
-static void
-mark_invalidate2(G_GNUC_UNUSED gpointer whatever, MarkControls *controls)
-{
-    mark_invalidate(controls);
-}
-
 static void
 preview(MarkControls *controls,
         MarkArgs *args)
