@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: grain_stat.c 18877 2016-08-24 14:48:29Z yeti-dn $
+ *  @(#) $Id: grain_stat.c 19950 2017-06-22 15:03:32Z yeti-dn $
  *  Copyright (C) 2014 David Necas (Yeti), Petr Klapetek, Sven Neumann.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net, neumann@jpk.com.
  *
@@ -59,7 +59,7 @@ static GwyModuleInfo module_info = {
     "2015",
 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, grain_stat)
 
 static gboolean
 module_register(void)
@@ -74,7 +74,7 @@ module_register(void)
     gwy_process_func_register("grain_inscribe_discs",
                               (GwyProcessFunc)&grain_inscribe_discs,
                               N_("/_Grains/Select _Inscribed Discs"),
-                              GWY_STOCK_GRAIN_EXSCRIBED_CIRCLE,
+                              GWY_STOCK_GRAIN_INSCRIBED_CIRCLE,
                               INSCRIBE_RUN_MODES,
                               GWY_MENU_FLAG_DATA | GWY_MENU_FLAG_DATA_MASK,
                               N_("Create a selection visualizing discs "
@@ -82,7 +82,7 @@ module_register(void)
     gwy_process_func_register("grain_exscribe_circles",
                               (GwyProcessFunc)&grain_exscribe_circles,
                               N_("/_Grains/Select _Circumscribed Circles"),
-                              GWY_STOCK_GRAIN_INSCRIBED_CIRCLE,
+                              GWY_STOCK_GRAIN_EXSCRIBED_CIRCLE,
                               INSCRIBE_RUN_MODES,
                               GWY_MENU_FLAG_DATA | GWY_MENU_FLAG_DATA_MASK,
                               N_("Create a selection visualizing grain "
