@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: grain_wshed.c 18537 2016-03-28 18:11:19Z yeti-dn $
+ *  @(#) $Id: grain_wshed.c 19948 2017-06-22 14:05:41Z yeti-dn $
  *  Copyright (C) 2004 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -26,6 +26,7 @@
 #include <libprocess/stats.h>
 #include <libprocess/grains.h>
 #include <libgwydgets/gwystock.h>
+#include <libgwydgets/gwydgetutils.h>
 #include <libgwymodule/gwymodule-process.h>
 #include <app/gwymoduleutils.h>
 #include <app/gwyapp.h>
@@ -100,12 +101,12 @@ static GwyModuleInfo module_info = {
     &module_register,
     N_("Marks grains by watershed algorithm."),
     "Petr Klapetek <petr@klapetek.cz>",
-    "1.17",
+    "1.18",
     "David Nečas (Yeti) & Petr Klapetek",
     "2004",
 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, grain_wshed)
 
 static gboolean
 module_register(void)
@@ -189,7 +190,7 @@ wshed_dialog(WshedArgs *args,
     controls.view = create_preview(controls.mydata, 0, PREVIEW_SIZE, TRUE);
     gtk_box_pack_start(GTK_BOX(hbox), controls.view, FALSE, FALSE, 4);
 
-    table = gtk_table_new(9, 4, FALSE);
+    table = gtk_table_new(9, 3, FALSE);
     gtk_table_set_row_spacings(GTK_TABLE(table), 2);
     gtk_table_set_col_spacings(GTK_TABLE(table), 6);
     gtk_container_set_border_width(GTK_CONTAINER(table), 4);
@@ -198,20 +199,21 @@ wshed_dialog(WshedArgs *args,
 
     label = gwy_label_new_header(_("Grain Location"));
     gtk_table_attach(GTK_TABLE(table), label,
-                     0, 2, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
+                     0, 2, row, row+1, GTK_FILL, 0, 0, 0);
     row++;
 
     controls.locate_steps = gtk_adjustment_new(args->locate_steps,
                                                1.0, 100.0, 1, 5, 0);
-    gwy_table_attach_hscale(table, row, _("_Number of steps:"), "",
-                            controls.locate_steps, 0);
+    gwy_table_attach_adjbar(table, row, _("_Number of steps:"), NULL,
+                            controls.locate_steps,
+                            GWY_HSCALE_SQRT | GWY_HSCALE_SNAP);
     g_signal_connect_swapped(controls.locate_steps, "value-changed",
                              G_CALLBACK(wshed_invalidate), &controls);
     row++;
 
     controls.locate_dropsize = gtk_adjustment_new(args->locate_dropsize,
                                                   0.01, 100.0, 0.1, 5, 0);
-    spin = gwy_table_attach_hscale(table, row, _("_Drop size:"), "%",
+    spin = gwy_table_attach_adjbar(table, row, _("_Drop size:"), "%",
                                    controls.locate_dropsize, 0);
     gtk_spin_button_set_digits(GTK_SPIN_BUTTON(spin), 2);
     g_signal_connect_swapped(controls.locate_dropsize, "value-changed",
@@ -220,28 +222,30 @@ wshed_dialog(WshedArgs *args,
     row++;
     controls.locate_thresh = gtk_adjustment_new(args->locate_thresh,
                                                 0.0, 100.0, 1, 5, 0);
-    gwy_table_attach_hscale(table, row, _("T_hreshold:"), "px<sup>2</sup>",
-                            controls.locate_thresh, 0);
+    gwy_table_attach_adjbar(table, row, _("T_hreshold:"), "px<sup>2</sup>",
+                            controls.locate_thresh,
+                            GWY_HSCALE_SQRT | GWY_HSCALE_SNAP);
     g_signal_connect_swapped(controls.locate_thresh, "value-changed",
                              G_CALLBACK(wshed_invalidate), &controls);
     gtk_table_set_row_spacing(GTK_TABLE(table), row, 8);
     row++;
 
     gtk_table_attach(GTK_TABLE(table), gwy_label_new_header(_("Segmentation")),
-                     0, 2, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
+                     0, 2, row, row+1, GTK_FILL, 0, 0, 0);
     row++;
 
     controls.wshed_steps = gtk_adjustment_new(args->wshed_steps,
                                               1.0, 1000.0, 1, 5, 0);
-    gwy_table_attach_hscale(table, row, _("Num_ber of steps:"), "",
-                            controls.wshed_steps, 0);
+    gwy_table_attach_adjbar(table, row, _("Num_ber of steps:"), NULL,
+                            controls.wshed_steps,
+                            GWY_HSCALE_SQRT | GWY_HSCALE_SNAP);
     g_signal_connect_swapped(controls.wshed_steps, "value-changed",
                              G_CALLBACK(wshed_invalidate), &controls);
     row++;
 
     controls.wshed_dropsize = gtk_adjustment_new(args->wshed_dropsize,
                                                  0.01, 100.0, 0.1, 5, 0);
-    spin = gwy_table_attach_hscale(table, row, _("Dr_op size:"), "%",
+    spin = gwy_table_attach_adjbar(table, row, _("Dr_op size:"), "%",
                                    controls.wshed_dropsize, 0);
     gtk_spin_button_set_digits(GTK_SPIN_BUTTON(spin), 2);
     g_signal_connect_swapped(controls.wshed_dropsize, "value-changed",
@@ -250,21 +254,21 @@ wshed_dialog(WshedArgs *args,
     row++;
 
     gtk_table_attach(GTK_TABLE(table), gwy_label_new_header(_("Options")),
-                     0, 2, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
+                     0, 2, row, row+1, GTK_FILL, 0, 0, 0);
     row++;
 
     controls.inverted = gtk_check_button_new_with_mnemonic(_("_Invert height"));
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(controls.inverted),
                                  args->inverted);
     gtk_table_attach(GTK_TABLE(table), controls.inverted,
-                     0, 4, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
+                     0, 2, row, row+1, GTK_FILL, 0, 0, 0);
     g_signal_connect_swapped(controls.inverted, "toggled",
                              G_CALLBACK(wshed_invalidate), &controls);
     row++;
 
     controls.color_button = create_mask_color_button(controls.mydata, dialog,
                                                      0);
-    gwy_table_attach_hscale(table, row, _("_Mask color:"), NULL,
+    gwy_table_attach_adjbar(table, row, _("_Mask color:"), NULL,
                             GTK_OBJECT(controls.color_button),
                             GWY_HSCALE_WIDGET_NO_EXPAND);
     row++;
