@@ -1,4 +1,5 @@
 /*
+ *  @(#) $Id: hough.c 19948 2017-06-22 14:05:41Z yeti-dn $
  *  Copyright (C) 2003 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -45,23 +46,24 @@ typedef struct {
 } HoughArgs;
 
 typedef struct {
+    HoughArgs *args;
     GtkWidget *output;
     GtkObject *circle_size;
     GtkWidget *circle_spin;
 } HoughControls;
 
-static gboolean    module_register            (void);
-static void        hough                      (GwyContainer *data,
-                                               GwyRunType run);
-static gboolean    hough_dialog               (HoughArgs *args);
-static void        hough_load_args            (GwyContainer *container,
-                                               HoughArgs *args);
-static void        hough_save_args            (GwyContainer *container,
-                                               HoughArgs *args);
-static void        hough_dialog_update        (HoughControls *controls,
-                                               HoughArgs *args);
-static void        type_changed_cb            (GtkComboBox *combo,
-                                               HoughControls *controls);
+static gboolean module_register    (void);
+static void     hough              (GwyContainer *data,
+                                    GwyRunType run);
+static gboolean hough_dialog       (HoughArgs *args);
+static void     hough_load_args    (GwyContainer *container,
+                                    HoughArgs *args);
+static void     hough_save_args    (GwyContainer *container,
+                                    HoughArgs *args);
+static void     hough_dialog_update(HoughControls *controls,
+                                    HoughArgs *args);
+static void     output_changed     (GtkComboBox *combo,
+                                    HoughControls *controls);
 
 static const HoughArgs hough_defaults = {
     GWY_HOUGH_OUTPUT_LINE,
@@ -73,12 +75,12 @@ static GwyModuleInfo module_info = {
     &module_register,
     N_("Hough transform."),
     "Petr Klapetek <klapetek@gwyddion.net>",
-    "1.2",
+    "1.3",
     "David Nečas (Yeti) & Petr Klapetek",
     "2006",
 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, hough)
 
 static gboolean
 module_register(void)
@@ -102,7 +104,7 @@ hough(GwyContainer *data, GwyRunType run)
     gboolean ok;
     HoughArgs args;
     gint id, newid;
-    gchar title[30];
+    gchar *title;
 
     g_return_if_fail(run & HOUGH_RUN_MODES);
     gwy_app_data_browser_get_current(GWY_APP_DATA_FIELD, &dfield,
@@ -132,21 +134,12 @@ hough(GwyContainer *data, GwyRunType run)
     gwy_data_field_filter_sobel(f1, GWY_ORIENTATION_HORIZONTAL);
     gwy_data_field_filter_sobel(f2, GWY_ORIENTATION_VERTICAL);
     if (args.output == GWY_HOUGH_OUTPUT_LINE) {
-        g_snprintf(title, sizeof(title), "Hough line");
-        gwy_data_field_hough_line(edgefield,
-                              f1,
-                              f2,
-                              result,
-                              1,
-                              FALSE);
+        title = g_strdup(_("Hough line"));
+        gwy_data_field_hough_line(edgefield, f1, f2, result, 1, FALSE);
     }
     else  {
-        g_snprintf(title, sizeof(title), "Hough circle r=%d px",
-                   args.circle_size);
-        gwy_data_field_hough_circle(edgefield,
-                                    f1,
-                                    f2,
-                                    result,
+        title = g_strdup_printf(_("Hough circle r=%d"), args.circle_size);
+        gwy_data_field_hough_circle(edgefield, f1, f2, result,
                                     args.circle_size);
     }
 
@@ -158,11 +151,11 @@ hough(GwyContainer *data, GwyRunType run)
     g_object_unref(edgefield);
     g_object_unref(f1);
     g_object_unref(f2);
+    g_free(title);
 
     gwy_app_channel_log_add_proc(data, id, newid);
 }
 
-
 static gboolean
 hough_dialog(HoughArgs *args)
 {
@@ -175,6 +168,8 @@ hough_dialog(HoughArgs *args)
     HoughControls controls;
     gint response, row;
 
+    controls.args = args;
+
     dialog = gtk_dialog_new_with_buttons(_("Hough Transform"), NULL, 0,
                                          _("_Reset"), RESPONSE_RESET,
                                          GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
@@ -183,13 +178,12 @@ hough_dialog(HoughArgs *args)
     gtk_dialog_set_default_response(GTK_DIALOG(dialog), GTK_RESPONSE_OK);
     gwy_help_add_to_proc_dialog(GTK_DIALOG(dialog), GWY_HELP_DEFAULT);
 
-    table = gtk_table_new(4, 4, FALSE);
+    table = gtk_table_new(4, 3, FALSE);
     gtk_table_set_row_spacings(GTK_TABLE(table), 2);
     gtk_table_set_col_spacings(GTK_TABLE(table), 6);
     gtk_container_set_border_width(GTK_CONTAINER(table), 4);
     gtk_box_pack_start(GTK_BOX(GTK_DIALOG(dialog)->vbox), table,
                        FALSE, FALSE, 4);
-
     row = 0;
 
     controls.output
@@ -197,20 +191,19 @@ hough_dialog(HoughArgs *args)
                                  G_CALLBACK(gwy_enum_combo_box_update_int),
                                  &args->output, args->output, TRUE);
     g_signal_connect(GTK_COMBO_BOX(controls.output), "changed",
-                     G_CALLBACK(type_changed_cb), &controls);
-    gwy_table_attach_row(table, row, _("_Transform type:"), NULL,
-                         controls.output);
-
-
-
+                     G_CALLBACK(output_changed), &controls);
+    gwy_table_attach_adjbar(table, row, _("_Transform type:"), NULL,
+                            GTK_OBJECT(controls.output),
+                            GWY_HSCALE_WIDGET_NO_EXPAND);
     row++;
 
-
-    controls.circle_size
-        = gtk_adjustment_new(args->circle_size, 1.0, 1000.0, 1, 10, 0);
-    controls.circle_spin
-        = gwy_table_attach_spinbutton(table, 1, _("_Circle size:"), _("pixels"),
-                                      controls.circle_size);
+    controls.circle_size = gtk_adjustment_new(args->circle_size,
+                                              1.0, 1000.0, 1, 10, 0);
+    controls.circle_spin = gwy_table_attach_adjbar(table, 1,
+                                                   _("_Circle size:"), _("px"),
+                                                   controls.circle_size,
+                                                   GWY_HSCALE_DEFAULT);
+    row++;
 
     hough_dialog_update(&controls, args);
 
@@ -249,24 +242,22 @@ hough_dialog(HoughArgs *args)
 }
 
 static void
-type_changed_cb(GtkComboBox *combo, HoughControls *controls)
+output_changed(GtkComboBox *combo, HoughControls *controls)
 {
-    if (gwy_enum_combo_box_get_active(combo) == GWY_HOUGH_OUTPUT_CIRCLE)
-        gtk_widget_set_sensitive(controls->circle_spin, TRUE);
-    else
-        gtk_widget_set_sensitive(controls->circle_spin, FALSE);
+    gboolean is_circ;
+
+    controls->args->output = gwy_enum_combo_box_get_active(combo);
+    is_circ = (controls->args->output == GWY_HOUGH_OUTPUT_CIRCLE);
+    gwy_table_hscale_set_sensitive(controls->circle_size, is_circ);
 }
 
 static void
-hough_dialog_update(HoughControls *controls,
-                  HoughArgs *args)
+hough_dialog_update(HoughControls *controls, HoughArgs *args)
 {
+    gwy_enum_combo_box_set_active(GTK_COMBO_BOX(controls->output),
+                                  args->output);
     gtk_adjustment_set_value(GTK_ADJUSTMENT(controls->circle_size),
                              args->circle_size);
-    if (args->output == GWY_HOUGH_OUTPUT_CIRCLE)
-        gtk_widget_set_sensitive(controls->circle_spin, TRUE);
-    else
-        gtk_widget_set_sensitive(controls->circle_spin, FALSE);
 }
 
 static const gchar output_key[]      = "/module/hough/output";
@@ -280,8 +271,7 @@ hough_sanitize_args(HoughArgs *args)
 }
 
 static void
-hough_load_args(GwyContainer *container,
-              HoughArgs *args)
+hough_load_args(GwyContainer *container, HoughArgs *args)
 {
     *args = hough_defaults;
 
@@ -292,8 +282,7 @@ hough_load_args(GwyContainer *container,
 }
 
 static void
-hough_save_args(GwyContainer *container,
-              HoughArgs *args)
+hough_save_args(GwyContainer *container, HoughArgs *args)
 {
     gwy_container_set_enum_by_name(container, output_key, args->output);
     gwy_container_set_int32_by_name(container, circle_size_key,
