@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: immerse.c 19216 2016-11-09 10:39:06Z yeti-dn $
+ *  @(#) $Id: immerse.c 19948 2017-06-22 14:05:41Z yeti-dn $
  *  Copyright (C) 2004 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -78,6 +78,7 @@ typedef struct {
     GwyContainer *mydata;
     GtkWidget *view;
     GtkWidget *pos;
+    GtkWidget *pos_units;
     GSList *sampling;
     GSList *leveling;
     GtkWidget *draw_frame;
@@ -161,12 +162,12 @@ static GwyModuleInfo module_info = {
     &module_register,
     N_("Immerse high resolution detail into overall image."),
     "Petr Klapetek <klapetek@gwyddion.net>",
-    "2.5",
+    "2.6",
     "David Nečas (Yeti) & Petr Klapetek",
     "2006",
 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, immerse)
 
 static gboolean
 module_register(void)
@@ -287,7 +288,7 @@ immerse_dialog(ImmerseArgs *args)
     gwy_data_chooser_get_active_id(GWY_DATA_CHOOSER(chooser), &args->detail);
     g_signal_connect(chooser, "changed",
                      G_CALLBACK(immerse_detail_cb), &controls);
-    gwy_table_attach_hscale(table, row, _("_Detail image:"), NULL,
+    gwy_table_attach_adjbar(table, row, _("_Detail image:"), NULL,
                             GTK_OBJECT(chooser), GWY_HSCALE_WIDGET_NO_EXPAND);
     row++;
 
@@ -298,17 +299,22 @@ immerse_dialog(ImmerseArgs *args)
                      0, 1, row, row+1, GTK_FILL, 0, 0, 0);
 
     controls.pos = gtk_label_new(NULL);
-    gtk_misc_set_alignment(GTK_MISC(controls.pos), 0.0, 0.5);
+    gtk_misc_set_alignment(GTK_MISC(controls.pos), 1.0, 0.5);
     gtk_table_attach(GTK_TABLE(table), controls.pos,
-                     1, 3, row, row+1, GTK_FILL, 0, 0, 0);
-    gtk_table_set_row_spacing(GTK_TABLE(table), row, 8);
+                     1, 2, row, row+1, GTK_FILL, 0, 0, 0);
+
+    controls.pos_units = gtk_label_new(NULL);
+    gtk_misc_set_alignment(GTK_MISC(controls.pos_units), 0.0, 0.5);
+    gtk_table_attach(GTK_TABLE(table), controls.pos_units,
+                     2, 3, row, row+1, GTK_FILL, 0, 0, 0);
     row++;
 
     /* Sampling */
+    gtk_table_set_row_spacing(GTK_TABLE(table), row-1, 8);
     label = gtk_label_new(_("Result Sampling"));
     gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
     gtk_table_attach(GTK_TABLE(table), label,
-                     0, 3, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
+                     0, 2, row, row+1, GTK_FILL, 0, 0, 0);
     row++;
 
     controls.sampling
@@ -329,7 +335,7 @@ immerse_dialog(ImmerseArgs *args)
     label = gtk_label_new(_("Detail Leveling"));
     gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
     gtk_table_attach(GTK_TABLE(table), label,
-                     0, 3, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
+                     0, 2, row, row+1, GTK_FILL, 0, 0, 0);
     row++;
 
     controls.leveling
@@ -342,13 +348,13 @@ immerse_dialog(ImmerseArgs *args)
                                     NULL);
 
     row = gwy_radio_buttons_attach_to_table(controls.leveling, GTK_TABLE(table),
-                                            4, row);
-    gtk_table_set_row_spacing(GTK_TABLE(table), row-1, 8);
+                                            2, row);
 
     /* Draw frame */
+    gtk_table_set_row_spacing(GTK_TABLE(table), row-1, 8);
     controls.draw_frame = gtk_check_button_new_with_mnemonic(_("Show _frame"));
     gtk_table_attach(GTK_TABLE(table), controls.draw_frame,
-                     0, 3, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
+                     0, 2, row, row+1, GTK_FILL, 0, 0, 0);
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(controls.draw_frame),
                                  args->draw_frame);
     g_signal_connect(controls.draw_frame, "toggled",
@@ -968,15 +974,16 @@ immerse_clamp_detail_offset(ImmerseControls *controls,
 
         controls->args->xpos = xpos;
         controls->args->ypos = ypos;
-        s = g_strdup_printf("(%.*f, %.*f) %s",
+        s = g_strdup_printf("(%.*f, %.*f)",
                             controls->vf->precision + 1,
                             xpos/controls->vf->magnitude,
                             controls->vf->precision + 1,
-                            ypos/controls->vf->magnitude,
-                            controls->vf->units);
+                            ypos/controls->vf->magnitude);
         gtk_label_set_text(GTK_LABEL(controls->pos), s);
         g_free(s);
 
+        gtk_label_set_text(GTK_LABEL(controls->pos_units), controls->vf->units);
+
         if (GTK_WIDGET_DRAWABLE(controls->view))
             gtk_widget_queue_draw(controls->view);
         return TRUE;
