@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: indent_analyze.c 19216 2016-11-09 10:39:06Z yeti-dn $
+ *  @(#) $Id: indent_analyze.c 19948 2017-06-22 14:05:41Z yeti-dn $
  *  Copyright (C) 2006 Lukas Chvatal, David Necas (Yeti), Petr Klapetek.
  *  E-mail: chvatal@physics.muni.cz, yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -104,7 +104,6 @@ typedef struct {
     gdouble plane_tol;  /* what to consider as belonging to plane/percents
                            of max-min */
     gdouble phi_tol;
-    gdouble theta_tol;    /* XXX: not implemented */
 
     gdouble plane_x;
     gdouble plane_y;
@@ -135,22 +134,20 @@ typedef struct {
 
     gint what_mark;
     gint how_mark;
-    gint plane_correct;    /* XXX: not implemented */
 
     GwyIndentorType indentor;
     gint nof_sides;
 } IndentAnalyzeArgs;
 
 typedef struct {
-    GtkWidget *w_plane_correct;
-    GtkWidget *w_how_mark;
-    GtkWidget *w_what_mark;
-    GtkWidget *w_indentor;
+    GtkWidget *how_mark;
+    GtkWidget *what_mark;
+    GtkWidget *indentor;
 
-    GtkObject *w_plane_tol;
-    GtkObject *w_nof_sides;
-    GtkObject *w_phi_tol;
-    GtkObject *w_theta_tol;
+    GtkObject *plane_tol;
+    GtkObject *nof_sides;
+    GtkObject *phi_tol;
+    GtkObject *theta_tol;
 
     GtkWidget *view;
     GwyContainer *mydata;
@@ -159,32 +156,23 @@ typedef struct {
     gboolean computed;
 
     /* labels */
-    GtkWidget *w_min_xy;
-    GtkWidget *w_max_xy;
-    GtkWidget *w_minmax;
+    GtkWidget *min_xy;
+    GtkWidget *max_xy;
+    GtkWidget *minmax;
 
-    GtkWidget *w_volume_above;
-    GtkWidget *w_volume_below;
-    GtkWidget *w_volume_dif;
+    GtkWidget *volume_dif;
 
-    GtkWidget *w_area_above;
-    GtkWidget *w_area_below;
-    GtkWidget *w_area_plane;
+    GtkWidget *volume_indent;
+    GtkWidget *surface_indent;
+    GtkWidget *area_indent;
 
-    GtkWidget *w_surface_above;
-    GtkWidget *w_surface_below;
+    GtkWidget *area_indent_exp;
+    GtkWidget *surface_indent_exp;
 
-    GtkWidget *w_volume_indent;
-    GtkWidget *w_surface_indent;
-    GtkWidget *w_area_indent;
-
-    GtkWidget *w_area_indent_exp;
-    GtkWidget *w_surface_indent_exp;
-
-    GtkWidget *w_surface_innerpileup;
-    GtkWidget *w_surface_outerpileup;
-    GtkWidget *w_area_innerpileup;
-    GtkWidget *w_area_outerpileup;
+    GtkWidget *surface_innerpileup;
+    GtkWidget *surface_outerpileup;
+    GtkWidget *area_innerpileup;
+    GtkWidget *area_outerpileup;
 
     GtkFileSelection *filesel;
 
@@ -209,9 +197,6 @@ static gboolean indent_analyze(GwyContainer *data, GwyRunType run);
 static gboolean indent_analyze_dialog(GwyContainer *data,
                                       IndentAnalyzeArgs *args);
 
-static void dialog_update(IndentAnalyzeControls *controls,
-                          IndentAnalyzeArgs *args);
-
 /*static void plane_correct_cb(GtkWidget *item, IndentAnalyzeControls *controls);*/
 static void how_mark_cb(GtkWidget *item, IndentAnalyzeControls *controls);
 static void what_mark_cb(GtkWidget *item, IndentAnalyzeControls *controls);
@@ -302,15 +287,12 @@ static GwyModuleInfo module_info = {
     (GwyModuleRegisterFunc) &module_register,
     N_("Analyses nanoindentation structure (volumes, surfaces, ...)."),
     "Lukáš Chvátal <chvatal@physics.muni.cz>",
-    "0.1.4",
+    "0.1.5",
     "Lukáš Chvátal",
     "2005",
 };
 
-/* This is the ONLY exported symbol.  The argument is the module info.
- * NO semicolon after. */
-GWY_MODULE_QUERY(module_info)
-
+GWY_MODULE_QUERY2(module_info, indent_analyze);
 
 static gboolean
 module_register(void)
@@ -340,7 +322,8 @@ indent_analyze(GwyContainer *data, GwyRunType run)
        load_args(gwy_app_settings_get(), &args);
        indent_analyze_dialog(data, &args);
        save_args(gwy_app_settings_get(), &args);
-    } else {
+    }
+    else {
        g_warning("Non-interactive mode not supported.");
     }
 
@@ -361,7 +344,6 @@ create_preview_data(IndentAnalyzeControls *controls)
     GwyDataField *dfield = NULL, *mask;
     gint oldid;
     // No zoom, zoom disorder final result
-    // gdouble zoomval;
     const GwyRGBA mask_color = { 1.0, 0.0, 0.00, 0.5 };
 
     gwy_app_data_browser_get_current(GWY_APP_DATA_FIELD, &dfield,
@@ -373,12 +355,6 @@ create_preview_data(IndentAnalyzeControls *controls)
       preview_container = gwy_container_new();
       dfield = gwy_data_field_duplicate(dfield);
 
-      // No zoom because it disorder mask on original image.
-      // zoomval = (gdouble)PREVIEW_SIZE/MAX(xres, yres);
-      // gwy_data_field_resample(dfield, xres*zoomval, yres*zoomval,
-      //                        GWY_INTERPOLATION_LINEAR);
-
-
       gwy_container_set_object_by_name(preview_container, "/0/data", dfield);
       mask = create_mask_field(dfield);
       gwy_data_field_clear(mask);
@@ -393,11 +369,19 @@ create_preview_data(IndentAnalyzeControls *controls)
       */
 
       gwy_rgba_store_to_container(gwy_rgba_copy(&mask_color),
-            preview_container, "/0/mask");
+                                  preview_container, "/0/mask");
    }
 
     return preview_container;
 }
+
+static void
+use_markup_in_label(GtkObject *pivot)
+{
+    GtkWidget *label = gwy_table_hscale_get_label(pivot);
+    gtk_label_set_use_markup(GTK_LABEL(label), TRUE);
+}
+
 /** Create table with statistical info.
  *
  * \param  controls build object
@@ -407,221 +391,163 @@ create_preview_data(IndentAnalyzeControls *controls)
 static GtkWidget*
 create_parameters_table(IndentAnalyzeControls * controls)
 {
-   IndentAnalyzeArgs * args = controls->args;
-   int row = 0;
-   GtkWidget *table = 0, *label;
-   GwyDataField *dfield;
-   GwySIValueFormat *siformat;
-   GString *siu;
+    IndentAnalyzeArgs * args = controls->args;
+    int row = 0;
+    GtkWidget *table = NULL;
+    GwyDataField *dfield;
+    GwySIValueFormat *siformat;
+    GString *siu;
 
-   /* TABLE */
-   table = gtk_table_new(8, 3, FALSE);
-   gtk_table_set_row_spacings(GTK_TABLE(table), 2);
-   gtk_table_set_col_spacings(GTK_TABLE(table), 6);
-   gtk_container_set_border_width(GTK_CONTAINER(table), 4);
+    /* TABLE */
+    table = gtk_table_new(8, 3, FALSE);
+    gtk_table_set_row_spacings(GTK_TABLE(table), 2);
+    gtk_table_set_col_spacings(GTK_TABLE(table), 6);
+    gtk_container_set_border_width(GTK_CONTAINER(table), 4);
 
-   /*
-    controls.w_plane_correct
-    = gwy_option_menu_create(plane_correct_enum,
-    G_N_ELEMENTS(plane_correct_enum),
-    "menu_plane_correct",
-    G_CALLBACK(plane_correct_cb), &controls,
-    args->plane_correct);
-    gwy_table_attach_hscale(table, row, _("Data field _leveling:"), NULL,
-    GTK_OBJECT(controls.w_plane_correct),
-    GWY_HSCALE_WIDGET);
-    row++;
-    */
+    controls->what_mark = gwy_enum_combo_box_new(what_mark_enum,
+                                                   G_N_ELEMENTS(what_mark_enum), G_CALLBACK(what_mark_cb), controls,
+                                                   args->what_mark, TRUE);
+    gwy_table_attach_adjbar(table, row++, _("Marked _areas:"), NULL,
+                            GTK_OBJECT(controls->what_mark),
+                            GWY_HSCALE_WIDGET_NO_EXPAND);
 
-   controls->w_what_mark = gwy_enum_combo_box_new(what_mark_enum,
-         G_N_ELEMENTS(what_mark_enum), G_CALLBACK(what_mark_cb), controls,
-         args->what_mark, TRUE);
-   gwy_table_attach_hscale(table, row++, _("Marked _areas:"), NULL,
-         GTK_OBJECT(controls->w_what_mark), GWY_HSCALE_WIDGET);
+    controls->indentor = gwy_enum_combo_box_new(indentor_enum,
+                                                  G_N_ELEMENTS(indentor_enum),
+                                                  G_CALLBACK(indentor_changed_cb),
+                                                  controls, args->indentor,
+                                                  TRUE);
+    gwy_table_attach_adjbar(table, row++, _("_Indentor type:"), NULL,
+                            GTK_OBJECT(controls->indentor),
+                            GWY_HSCALE_WIDGET_NO_EXPAND);
 
-   controls->w_indentor = gwy_enum_combo_box_new(indentor_enum,
-         G_N_ELEMENTS(indentor_enum), G_CALLBACK(indentor_changed_cb),
-         controls, args->indentor, TRUE);
-   gwy_table_attach_hscale(table, row++, _("_Indentor type:"), NULL,
-         GTK_OBJECT(controls->w_indentor), GWY_HSCALE_WIDGET);
+    controls->how_mark = gwy_enum_combo_box_new(how_mark_enum,
+                                                  G_N_ELEMENTS(how_mark_enum),
+                                                  G_CALLBACK(how_mark_cb),
+                                                  controls, args->how_mark,
+                                                  TRUE);
+    gwy_table_attach_adjbar(table, row++, _("_Mask creation type:"), NULL,
+                            GTK_OBJECT(controls->how_mark),
+                            GWY_HSCALE_WIDGET_NO_EXPAND);
 
-   controls->w_how_mark = gwy_enum_combo_box_new(how_mark_enum,
-         G_N_ELEMENTS(how_mark_enum), G_CALLBACK(how_mark_cb), controls,
-         args->how_mark, TRUE);
-   gwy_table_attach_hscale(table, row++, _("_Mask creation type:"), NULL,
-         GTK_OBJECT(controls->w_how_mark), GWY_HSCALE_WIDGET);
+    controls->plane_tol = gtk_adjustment_new(args->plane_tol, 0, 100, 0.1, 1,
+                                               0);
+    gwy_table_attach_adjbar(table, row++, _("Ref. plane _tolerance:"), "%",
+                            controls->plane_tol, GWY_HSCALE_SQRT);
 
-   controls->w_plane_tol = gtk_adjustment_new(args->plane_tol, 0, 100, 0.1, 1,
-                                              0);
-   gwy_table_attach_hscale(table, row++, _("Ref. plane _tolerance:"), "%",
-         controls->w_plane_tol, 0);
+    controls->phi_tol = gtk_adjustment_new(args->phi_tol, 0, 180, 0.1, 10, 0);
+    gwy_table_attach_adjbar(table, row++, _("Angle _1 tolerance:"), _("deg"),
+                            controls->phi_tol, GWY_HSCALE_SQRT);
 
-   controls->w_phi_tol = gtk_adjustment_new(args->phi_tol, 0, 180, 0.1, 10, 0);
-   gwy_table_attach_hscale(table, row++, _("Angle _1 tolerance:"), _("deg"),
-         controls->w_phi_tol, 0);
+    /* "statistical" labels */
+    dfield = GWY_DATA_FIELD(gwy_container_get_object_by_name(controls->mydata,
+                                                             "/0/data"));
+    if (!dfield) {
+        g_warning("Cannot get /0/data from controls->mydata.");
+    }
+    siformat = gwy_data_field_get_value_format_xy(dfield,
+                                                  GWY_SI_UNIT_FORMAT_PLAIN,
+                                                  NULL);
+    if (!siformat) {
+        g_warning("Cannot get siformat from /0/data");
+    }
+    siu = g_string_new(siformat->units);
 
-   /* XXX: what the hell is this for?
-    controls.w_theta_tol = gtk_adjustment_new(args->theta_tol,
-    0, 90, 0.1, 10, 0);
-    spin = gwy_table_attach_hscale(table, row, _("T_heta range:"), _("deg"),
-    controls.w_theta_tol, 0);
-    row++;
-    */
+    controls->min_xy = gtk_label_new(NULL);
+    gwy_table_attach_adjbar(table, row++, _("Indent center at"), siu->str,
+                            GTK_OBJECT(controls->min_xy),
+                            GWY_HSCALE_WIDGET_NO_EXPAND);
+    controls->max_xy = gtk_label_new(NULL);
+    gwy_table_attach_adjbar(table, row++, _("Maximum at"), siu->str,
+                            GTK_OBJECT(controls->max_xy),
+                            GWY_HSCALE_WIDGET_NO_EXPAND);
+    controls->minmax = gtk_label_new(NULL);
+    gwy_table_attach_adjbar(table, row++, _("Max-min difference"), siu->str,
+                            GTK_OBJECT(controls->minmax),
+                            GWY_HSCALE_WIDGET_NO_EXPAND);
 
-   /* "statistical" labels */
-   dfield = GWY_DATA_FIELD(gwy_container_get_object_by_name(controls->mydata,
-         "/0/data"));
-   if (!dfield) {
-      g_warning("Cannot get /0/data from controls->mydata.");
-   }
-   siformat = gwy_data_field_get_value_format_xy(dfield,
-         GWY_SI_UNIT_FORMAT_PLAIN, NULL);
-   if (!siformat) {
-      g_warning("Cannot get siformat from /0/data");
-   }
-   siu = g_string_new(siformat->units);
+    /* XXX: Wrong, must actually square the units. */
+    g_string_append(siu, "<sup>2</sup>");
 
-   controls->w_min_xy = gtk_label_new("");
-   gwy_table_attach_row(table, row++, _("Indent center at"), siu->str,
-         controls->w_min_xy);
-   controls->w_max_xy = gtk_label_new("");
-   gwy_table_attach_row(table, row++, _("Maximum at"), siu->str,
-         controls->w_max_xy);
-   controls->w_minmax = gtk_label_new("");
-   gwy_table_attach_row(table, row++, _("Max-min difference"), siu->str,
-         controls->w_minmax);
-
-   g_string_append(siu, "<sup>2</sup>");
-
-   controls->w_surface_indent_exp = gtk_label_new("");
-   gwy_table_attach_row(table, row, _("Expected A<sub>d</sub>:"), siu->str,
-         controls->w_surface_indent_exp);
-   if ( (label = gwy_table_get_child_widget(table, row, 0)) ) {
-      gtk_label_set_markup_with_mnemonic(GTK_LABEL(label),
-            gtk_label_get_text(GTK_LABEL(label)) );
-   }
-   row++;
-   controls->w_area_indent_exp = gtk_label_new("");
-   gwy_table_attach_row(table, row, _("Expected A<sub>p</sub>:"), siu->str,
-         controls->w_area_indent_exp);
-   if ( (label = gwy_table_get_child_widget(table, row, 0)) ) {
-      gtk_label_set_markup_with_mnemonic(GTK_LABEL(label),
-            gtk_label_get_text(GTK_LABEL(label)) );
-   }
-   row++;
-
-   gtk_table_attach(GTK_TABLE(table), gtk_hseparator_new(), 0, 2, row, row + 1,
-         (GtkAttachOptions) (GTK_FILL), (GtkAttachOptions) (GTK_EXPAND
-               | GTK_FILL), 0, 0);
-   row++;
-
-   /*
-    controls.w_area_above = gtk_label_new ("");
-    gtk_label_set_justify( &controls.w_area_above, GTK_JUSTIFY_RIGHT);
-    gwy_table_attach_row(table, row, _("Area above"), siu->str,controls.w_area_above);
-    row++;
-    controls.w_area_below = gtk_label_new ("");
-    gwy_table_attach_row(table, row, _("Area below"), siu->str,controls.w_area_below);
-    row++;
-    controls.w_area_plane = gtk_label_new ("");
-    gwy_table_attach_row(table, row, _("Area of plane"), siu->str,controls.w_area_plane);
+    controls->surface_indent_exp = gtk_label_new(NULL);
+    gwy_table_attach_adjbar(table, row, _("Expected A<sub>d</sub>:"), siu->str,
+                            GTK_OBJECT(controls->surface_indent_exp),
+                            GWY_HSCALE_WIDGET_NO_EXPAND);
+    use_markup_in_label(GTK_OBJECT(controls->surface_indent_exp));
     row++;
 
-    controls.w_surface_above = gtk_label_new ("");
-    gwy_table_attach_row(table, row, _("Surface above"), siu->str,controls.w_surface_above);
+    controls->area_indent_exp = gtk_label_new(NULL);
+    gwy_table_attach_adjbar(table, row, _("Expected A<sub>p</sub>:"), siu->str,
+                            GTK_OBJECT(controls->area_indent_exp),
+                            GWY_HSCALE_WIDGET_NO_EXPAND);
+    use_markup_in_label(GTK_OBJECT(controls->area_indent_exp));
     row++;
-    controls.w_surface_below = gtk_label_new ("");
-    gwy_table_attach_row(table, row, _("Surface below"), siu->str,controls.w_surface_below);
+
+    /* XXX: Wrong, must actually cube the units. */
+    g_string_assign(siu, siformat->units);
+    g_string_append(siu, "<sup>3</sup>");
+    controls->volume_dif = gtk_label_new(NULL);
+    gwy_table_attach_adjbar(table, row++, _("Volume above-below"), siu->str,
+                            GTK_OBJECT(controls->volume_dif),
+                            GWY_HSCALE_WIDGET_NO_EXPAND);
+
+    controls->volume_indent = gtk_label_new(NULL);
+    gwy_table_attach_adjbar(table, row++, _("Indent. volume"), siu->str,
+                            GTK_OBJECT(controls->volume_indent),
+                            GWY_HSCALE_WIDGET_NO_EXPAND);
+
+    /* XXX: Wrong, must actually square the units. */
+    g_string_assign(siu, siformat->units);
+    g_string_append(siu, "<sup>2</sup>");
+    controls->surface_indent = gtk_label_new(NULL);
+    gwy_table_attach_adjbar(table, row, _("Indent. A<sub>d</sub>"), siu->str,
+                            GTK_OBJECT(controls->surface_indent),
+                            GWY_HSCALE_WIDGET_NO_EXPAND);
+    use_markup_in_label(GTK_OBJECT(controls->surface_indent));
     row++;
-    */
 
-   g_string_assign(siu, siformat->units);
-   g_string_append(siu, "<sup>3</sup>");
-   /*
-    controls.w_volume_above = gtk_label_new ("");
-    gwy_table_attach_row(table, row, _("Volume above"), siu->str,controls.w_volume_above);
+    controls->area_indent = gtk_label_new(NULL);
+    gwy_table_attach_adjbar(table, row, _("Indent. A<sub>p</sub>"), siu->str,
+                            GTK_OBJECT(controls->area_indent),
+                            GWY_HSCALE_WIDGET_NO_EXPAND);
+    use_markup_in_label(GTK_OBJECT(controls->area_indent));
     row++;
-    controls.w_volume_below = gtk_label_new ("");
-    gwy_table_attach_row(table, row, _("Volume below"), siu->str,controls.w_volume_below);
+
+    controls->surface_innerpileup = gtk_label_new(NULL);
+    gwy_table_attach_adjbar(table, row,
+                            _("Inner Pile-Up A<sub>d</sub>"), siu->str,
+                            GTK_OBJECT(controls->surface_innerpileup),
+                            GWY_HSCALE_WIDGET_NO_EXPAND);
+    use_markup_in_label(GTK_OBJECT(controls->surface_innerpileup));
     row++;
-    */
-   controls->w_volume_dif = gtk_label_new("");
-   gwy_table_attach_row(table, row++, _("Volume above-below"), siu->str,
-         controls->w_volume_dif);
 
-   gtk_table_attach(GTK_TABLE(table), gtk_hseparator_new(), 0, 2, row, row + 1,
-         (GtkAttachOptions) (GTK_FILL), (GtkAttachOptions) (GTK_EXPAND
-               | GTK_FILL), 0, 0);
-   row++;
+    controls->area_innerpileup = gtk_label_new(NULL);
+    gwy_table_attach_adjbar(table, row,
+                            _("Inner Pile-Up A<sub>p</sub>"), siu->str,
+                            GTK_OBJECT(controls->area_innerpileup),
+                            GWY_HSCALE_WIDGET_NO_EXPAND);
+    use_markup_in_label(GTK_OBJECT(controls->area_innerpileup));
+    row++;
 
-   controls->w_volume_indent = gtk_label_new("");
-   gwy_table_attach_row(table, row++, _("Indent. volume"), siu->str,
-         controls->w_volume_indent);
+    controls->surface_outerpileup = gtk_label_new(NULL);
+    gwy_table_attach_adjbar(table, row,
+                            _("Outer Pile-Up A<sub>d</sub>"), siu->str,
+                            GTK_OBJECT(controls->surface_outerpileup),
+                            GWY_HSCALE_WIDGET_NO_EXPAND);
+    use_markup_in_label(GTK_OBJECT(controls->surface_outerpileup));
+    row++;
 
-   g_string_assign(siu, siformat->units);
-   g_string_append(siu, "<sup>2</sup>");
-   controls->w_surface_indent = gtk_label_new("");
-   gwy_table_attach_row(table, row, _("Indent. A<sub>d</sub>"), siu->str,
-         controls->w_surface_indent);
-   if ( (label = gwy_table_get_child_widget(table, row, 0)) ) {
-      gtk_label_set_markup_with_mnemonic(GTK_LABEL(label),
-            gtk_label_get_text(GTK_LABEL(label)) );
-   }
-   row++;
+    controls->area_outerpileup = gtk_label_new(NULL);
+    gwy_table_attach_adjbar(table, row,
+                            _("Outer Pile-Up A<sub>p</sub>"), siu->str,
+                            GTK_OBJECT(controls->area_outerpileup),
+                            GWY_HSCALE_WIDGET_NO_EXPAND);
+    use_markup_in_label(GTK_OBJECT(controls->area_outerpileup));
+    row++;
 
-   controls->w_area_indent = gtk_label_new("");
-   gwy_table_attach_row(table, row, _("Indent. A<sub>p</sub>"), siu->str,
-         controls->w_area_indent);
-   if ( (label = gwy_table_get_child_widget(table, row, 0)) ) {
-      gtk_label_set_markup_with_mnemonic(GTK_LABEL(label),
-            gtk_label_get_text(GTK_LABEL(label)) );
-   }
-   row++;
+    g_string_free(siu, TRUE);
+    gwy_si_unit_value_format_free(siformat);
 
-   gtk_table_attach(GTK_TABLE(table), gtk_hseparator_new(), 0, 2, row, row + 1,
-         (GtkAttachOptions) (GTK_FILL), (GtkAttachOptions) (GTK_EXPAND
-               | GTK_FILL), 0, 0);
-   row++;
-
-   controls->w_surface_innerpileup = gtk_label_new("");
-   gwy_table_attach_row(table, row, _("Inner Pile-Up A<sub>d</sub>"), siu->str,
-         controls->w_surface_innerpileup);
-   if ( (label = gwy_table_get_child_widget(table, row, 0)) ) {
-      gtk_label_set_markup_with_mnemonic(GTK_LABEL(label),
-            gtk_label_get_text(GTK_LABEL(label)) );
-   }
-
-   row++;
-   controls->w_area_innerpileup = gtk_label_new("");
-   gwy_table_attach_row(table, row, _("Inner Pile-Up A<sub>p</sub>"), siu->str,
-         controls->w_area_innerpileup);
-   if ( (label = gwy_table_get_child_widget(table, row, 0)) ) {
-      gtk_label_set_markup_with_mnemonic(GTK_LABEL(label),
-            gtk_label_get_text(GTK_LABEL(label)) );
-   }
-
-   row++;
-   controls->w_surface_outerpileup = gtk_label_new("");
-   gwy_table_attach_row(table, row, _("Outer Pile-Up A<sub>d</sub>"), siu->str,
-         controls->w_surface_outerpileup);
-   if ( (label = gwy_table_get_child_widget(table, row, 0)) ) {
-      gtk_label_set_markup_with_mnemonic(GTK_LABEL(label),
-            gtk_label_get_text(GTK_LABEL(label)) );
-   }
-
-   row++;
-   controls->w_area_outerpileup = gtk_label_new("");
-   gwy_table_attach_row(table, row, _("Outer Pile-Up A<sub>p</sub>"), siu->str,
-         controls->w_area_outerpileup);
-   if ( (label = gwy_table_get_child_widget(table, row, 0)) ) {
-      gtk_label_set_markup_with_mnemonic(GTK_LABEL(label),
-            gtk_label_get_text(GTK_LABEL(label)) );
-   }
-
-   g_string_free(siu, TRUE);
-   gwy_si_unit_value_format_free(siformat);
-
-   return table;
+    return table;
 }
 
 /** Create and run analyze dialog
@@ -637,7 +563,6 @@ indent_analyze_dialog(GwyContainer *data, IndentAnalyzeArgs * args)
     GtkWidget *dialog, *table, *hbox;
     IndentAnalyzeControls controls;
     gint response;
-    //gdouble zoomval;
     GtkObject *layer;
 
     controls.args = args;
@@ -669,7 +594,8 @@ indent_analyze_dialog(GwyContainer *data, IndentAnalyzeArgs * args)
     gwy_data_view_set_alpha_layer(GWY_DATA_VIEW(controls.view),
                                   GWY_PIXMAP_LAYER(layer));
     gtk_box_pack_start(GTK_BOX(hbox), controls.view, TRUE, TRUE, 4);
-    //gtk_widget_show_all(GTK_WIDGET(controls.view));
+    gwy_data_view_set_data_prefix(GWY_DATA_VIEW(controls.view), "/0/data");
+    gwy_set_data_preview_size(GWY_DATA_VIEW(controls.view), PREVIEW_SIZE);
 
     table = create_parameters_table(&controls);
     gtk_box_pack_start(GTK_BOX(hbox), table, FALSE, FALSE, 4);
@@ -843,31 +769,24 @@ set_mask_at(GwyDataField *mask, gint x, gint y, gdouble m, gint how)
 
     switch (how) {
         case GWY_HOW_MARK_NEW:
-            act_mask = im;
-            break;
+        act_mask = im;
+        break;
 
         case GWY_HOW_MARK_AND:
-            act_mask = (act_mask && im);
-            break;
+        act_mask = (act_mask && im);
+        break;
 
         case GWY_HOW_MARK_OR:
-            act_mask = (act_mask || im);
-            /*    if(act_mask){
-               FILE* fl = gwy_fopen ("setmask.txt","a");
-               gwy_fprintf(fl, "[%d %d]%d %d %lf\n", x,y,act_mask, im, (double)(act_mask || im));
-               fclose(fl);
-               }
-               gwy_data_field_area_fill(mask,10,10,20,20,(double)act_mask);
-             */
-            break;
+        act_mask = (act_mask || im);
+        break;
 
         case GWY_HOW_MARK_NOT:
-            act_mask = !im;
-            break;
+        act_mask = !im;
+        break;
 
         case GWY_HOW_MARK_XOR:
-            act_mask = !(act_mask || im);
-            break;
+        act_mask = !(act_mask || im);
+        break;
     }
     gwy_data_field_set_val(mask, x, y, (double)act_mask);
 }
@@ -891,27 +810,8 @@ level_data(IndentAnalyzeControls *c)
                                     &(args->plane_y));
     }
 
-/*
-    switch(args->plane_correct)
-    {
-        case GWY_PLANE_LEVEL:
-            while (iter--) {
-               gwy_data_field_plane_level(dfield, args->plane_c, args->plane_x, args->plane_y);
-               get_field_slope_from_border (dfield, &(args->plane_c), &(args->plane_x), &(args->plane_y));
-            }
-            break;
-
-        case GWY_PLANE_ROTATE:
-            gwy_data_field_plane_rotate(dfield,
-                                180/G_PI*atan2(args->plane_x, 1),
-                                180/G_PI*atan2(args->plane_y, 1),
-                                GWY_INTERPOLATION_LINEAR);
-            break;
-    }
-*/
 }
 
-
 typedef struct {
     gint x;
     gint y;
@@ -924,8 +824,11 @@ typedef struct {
 
 #define   FLOOD_MAX_DEPTH  1000
 
-static void indentmask_flood_fill(GwyDataField *indentmask, gint i, gint j,
-      GwyDataField *dfield, FloodFillInfo * ffi)
+/* XXX XXX XXX: This could probably just mask areas according to a condition,
+ * number grains, and keep just a selected grain.  But who knows... */
+static void
+indentmask_flood_fill(GwyDataField *indentmask, gint i, gint j,
+                      GwyDataField *dfield, FloodFillInfo * ffi)
 {
    gint test = 0;
    gdouble c_f, c_t;
@@ -986,10 +889,10 @@ static void indentmask_flood_fill(GwyDataField *indentmask, gint i, gint j,
                if (s || rr) {
                   // check if point is inside datafield
                   if (tail->x + rr >= 0 && tail->x + rr < dfield_xres
-                        && tail->y + s >= 0 && tail->y + s < dfield_yres)
-                  {
-                     gdouble val = gwy_data_field_get_val(indentmask, tail->x
-                           + rr, tail->y + s);
+                        && tail->y + s >= 0 && tail->y + s < dfield_yres) {
+                     gdouble val = gwy_data_field_get_val(indentmask,
+                                                          tail->x + rr,
+                                                          tail->y + s);
                      if (!val) {
                         head->x = tail->x + rr;
                         head->y = tail->y + s;
@@ -1001,9 +904,6 @@ static void indentmask_flood_fill(GwyDataField *indentmask, gint i, gint j,
                         gwy_data_field_set_val(indentmask, tail->x + rr,
                               tail->y + s, FLOOD_QUEUED);
                      }
-                  } else {
-                     printf("start %d %d, want to set %d %d, dimensions %d %d\n", i, j, tail->x
-                           + rr, tail->y + s, dfield_xres, dfield_yres);
                   }
                }
             }
@@ -1276,7 +1176,7 @@ indent_analyze_ok(GwyContainer *data, IndentAnalyzeControls * controls)
 {
     //GwyDataField *dfield;
     GObject *maskfield;
-    GString *mask_name = g_string_new("");
+    GString *mask_name = g_string_new(NULL);
 
     // get right ID of datafield
     g_string_printf(mask_name, "/%d/mask", controls->dfield_id);
@@ -1304,9 +1204,8 @@ compute_and_preview(IndentAnalyzeControls * controls)
     GwyDataField *maskfield = 0, *dfield;
     GwyPixmapLayer *layer;
 
-    dfield =
-        GWY_DATA_FIELD(gwy_container_get_object_by_name
-                       (controls->mydata, "/0/data"));
+    dfield = GWY_DATA_FIELD(gwy_container_get_object_by_name
+                            (controls->mydata, "/0/data"));
 
     read_data_from_controls(controls);
 
@@ -1339,80 +1238,35 @@ compute_and_preview(IndentAnalyzeControls * controls)
 
 /* =========== dialog control functions ========================= */
 
-static void
-dialog_update(G_GNUC_UNUSED IndentAnalyzeControls *controls,
-              G_GNUC_UNUSED IndentAnalyzeArgs *args)
-{
-
-    /*
-    gwy_option_menu_set_history(controls->w_plane_correct, "menu_plane_correct",
-                                args->plane_correct);
-                                */
-   /*
-    gwy_option_menu_set_history(controls->w_how_mark, "menu_how_mark",
-                                args->how_mark);
-    gwy_option_menu_set_history(controls->w_what_mark, "menu_what_mark",
-                                args->what_mark);
-                                */
-}
-
-/*
-static void
-plane_correct_cb(GtkWidget *item, IndentAnalyzeControls * controls)
-{
-    controls->args->plane_correct
-        =
-        GPOINTER_TO_UINT(g_object_get_data
-                         (G_OBJECT(item), "menu_plane_correct"));
-    dialog_update(controls, controls->args);
-}
-*/
-
 static void
 what_mark_cb(GtkWidget *item, IndentAnalyzeControls * controls)
 {
-    controls->args->what_mark
-        = gtk_combo_box_get_active(GTK_COMBO_BOX(item));
-        //= GPOINTER_TO_UINT(g_object_get_data(G_OBJECT(item), "menu_what_mark"));
-    dialog_update(controls, controls->args);
+    controls->args->what_mark = gtk_combo_box_get_active(GTK_COMBO_BOX(item));
 }
 
 static void
 how_mark_cb(GtkWidget *item, IndentAnalyzeControls * controls)
 {
-    controls->args->how_mark
-        = gtk_combo_box_get_active(GTK_COMBO_BOX(item));
-        //= GPOINTER_TO_UINT(g_object_get_data(G_OBJECT(item), "menu_how_mark"));
-    dialog_update(controls, controls->args);
+    controls->args->how_mark = gtk_combo_box_get_active(GTK_COMBO_BOX(item));
 }
 
 static void
 indentor_changed_cb(GtkWidget *item, IndentAnalyzeControls * controls)
 {
-    controls->args->indentor =
-        gtk_combo_box_get_active(GTK_COMBO_BOX(item));
-        //= GPOINTER_TO_UINT(g_object_get_data(G_OBJECT(item), "indentor-type"));
-
-
-    dialog_update(controls, controls->args);
-    printf("indentor type %d\n", controls->args->indentor);
+    controls->args->indentor = gtk_combo_box_get_active(GTK_COMBO_BOX(item));
     gtk_combo_box_get_active(GTK_COMBO_BOX(item));
 }
 
-
 static const gchar *what_mark_key = "/module/nanoindent/what_mark";
 static const gchar *how_mark_key = "/module/nanoindent/how_mark";
-static const gchar *plane_correct_key = "/module/nanoindent/plane_correct";
 static const gchar *indentor_key = "/module/nanoindent/indentor";
 
 static const gchar *plane_tol_key = "/module/nanoindent/plane_tol";
 static const gchar *phi_tol_key = "/module/nanoindent/phi_tol";
-static const gchar *theta_tol_key = "/module/nanoindent/theta_tol";
 
 static void
 sanitize_args(IndentAnalyzeArgs * args)
 {
-    args->plane_correct = MIN(args->plane_correct, GWY_PLANE_ROTATE);
     args->what_mark = MIN(args->what_mark, GWY_WHAT_MARK_FACESBORDER);
     args->how_mark = MIN(args->how_mark, GWY_HOW_MARK_XOR);
     args->indentor = MIN(args->indentor, GWY_INDENTOR_CUBECORNER);
@@ -1422,16 +1276,12 @@ sanitize_args(IndentAnalyzeArgs * args)
 static void
 load_args(GwyContainer *container, IndentAnalyzeArgs * args)
 {
-    args->plane_correct = GWY_PLANE_LEVEL;
     args->what_mark = GWY_WHAT_MARK_NOTHING;
     args->how_mark = GWY_HOW_MARK_NEW;
     args->indentor = GWY_INDENTOR_VICKERS;
     args->plane_tol = 1.0;
     args->phi_tol = 8.0;
-    args->theta_tol = 8.0;
 
-    gwy_container_gis_enum_by_name(container, plane_correct_key,
-                                   &args->plane_correct);
     gwy_container_gis_enum_by_name(container, what_mark_key,
                                    &args->what_mark);
     gwy_container_gis_enum_by_name(container, how_mark_key,
@@ -1443,18 +1293,12 @@ load_args(GwyContainer *container, IndentAnalyzeArgs * args)
                                      &args->plane_tol);
     gwy_container_gis_double_by_name(container, phi_tol_key,
                                      &args->phi_tol);
-    gwy_container_gis_double_by_name(container, theta_tol_key,
-                                     &args->theta_tol);
     sanitize_args(args);
 }
 
 static void
 save_args(GwyContainer *container, IndentAnalyzeArgs * args)
 {
-    /*
-    gwy_container_set_enum_by_name(container, plane_correct_key,
-                                   args->plane_correct);
-                                   */
     gwy_container_set_enum_by_name(container, what_mark_key, args->what_mark);
     gwy_container_set_enum_by_name(container, how_mark_key, args->how_mark);
     gwy_container_set_enum_by_name(container, indentor_key, args->indentor);
@@ -1462,7 +1306,6 @@ save_args(GwyContainer *container, IndentAnalyzeArgs * args)
     gwy_container_set_double_by_name(container, plane_tol_key, args->plane_tol);
     /*
     gwy_container_set_double_by_name(container, phi_tol_key, args->phi_tol);
-    gwy_container_set_double_by_name(container, theta_tol_key, args->theta_tol);
     */
 }
 
@@ -1471,11 +1314,9 @@ static void
 read_data_from_controls(IndentAnalyzeControls *c)
 {
     c->args->plane_tol =
-        gtk_adjustment_get_value(GTK_ADJUSTMENT(c->w_plane_tol));
+        gtk_adjustment_get_value(GTK_ADJUSTMENT(c->plane_tol));
     /*
-    c->args->phi_tol = gtk_adjustment_get_value(GTK_ADJUSTMENT(c->w_phi_tol));
-    c->args->theta_tol =
-        gtk_adjustment_get_value(GTK_ADJUSTMENT(c->w_theta_tol));
+    c->args->phi_tol = gtk_adjustment_get_value(GTK_ADJUSTMENT(c->phi_tol));
      */
 }
 
@@ -1494,56 +1335,38 @@ update_data_labels(IndentAnalyzeControls *c)
 
     g_snprintf(str, str_len, "[%d, %d]px: %lf", c->args->minx, c->args->miny,
             c->args->min_val/mag);
-    gtk_label_set_text(GTK_LABEL(c->w_min_xy), str);
+    gtk_label_set_text(GTK_LABEL(c->min_xy), str);
 
     g_snprintf(str, str_len, "[%d, %d]px: %lf", c->args->maxx, c->args->maxy,
             c->args->max_val/mag);
-    gtk_label_set_text(GTK_LABEL(c->w_max_xy), str);
+    gtk_label_set_text(GTK_LABEL(c->max_xy), str);
 
     g_snprintf(str, str_len, "%lf", (c->args->max_val - c->args->min_val)/mag);
-    gtk_label_set_text(GTK_LABEL(c->w_minmax), str);
-/*
-    sprintf (str, "%g (%.1lf %%)", c->args->area_above/mag/mag, 100.*(c->args->area_above/sxy));
-    gtk_label_set_text(c->w_area_above, str);
-    sprintf (str, "%g (%.1lf %%)", c->args->area_below/mag/mag, 100.*(c->args->area_below/sxy));
-    gtk_label_set_text(c->w_area_below, str);
-    sprintf (str, "%g (%.1lf %%)", c->args->area_plane/mag/mag, 100.*(c->args->area_plane/sxy));
-    gtk_label_set_text(c->w_area_plane, str);
-
-    sprintf (str, "%g (+%.1f %%)", c->args->surface_above/mag/mag, 100.*c->args->surface_above/c->args->area_above);
-    gtk_label_set_text(c->w_surface_above, str);
-    sprintf (str, "%g (+%.1lf %%)", c->args->surface_below/mag/mag, 100.*c->args->surface_below/c->args->surface_below);
-    gtk_label_set_text(c->w_surface_below, str);
-
-    sprintf (str, "%g", c->args->volume_above/mag/mag/mag);
-    gtk_label_set_text(c->w_volume_above, str);
-    sprintf (str, "%g", c->args->volume_below/mag/mag/mag);
-    gtk_label_set_text(c->w_volume_below, str);
-*/
+    gtk_label_set_text(GTK_LABEL(c->minmax), str);
     g_snprintf(str, str_len, "%g",
             (c->args->volume_above - c->args->volume_below)/mag/mag/mag);
-    gtk_label_set_text(GTK_LABEL(c->w_volume_dif), str);
+    gtk_label_set_text(GTK_LABEL(c->volume_dif), str);
 
     g_snprintf(str, str_len, "%g", c->args->volume_indent/mag/mag/mag);
-    gtk_label_set_text(GTK_LABEL(c->w_volume_indent), str);
+    gtk_label_set_text(GTK_LABEL(c->volume_indent), str);
     g_snprintf(str, str_len, "%g", c->args->surface_indent/mag/mag);
-    gtk_label_set_text(GTK_LABEL(c->w_surface_indent), str);
+    gtk_label_set_text(GTK_LABEL(c->surface_indent), str);
     g_snprintf(str, str_len, "%g", (c->args->area_indent)/mag/mag);
-    gtk_label_set_text(GTK_LABEL(c->w_area_indent), str);
+    gtk_label_set_text(GTK_LABEL(c->area_indent), str);
 
     g_snprintf(str, str_len, "%g", c->args->surface_indent_exp/mag/mag);
-    gtk_label_set_text(GTK_LABEL(c->w_surface_indent_exp), str);
+    gtk_label_set_text(GTK_LABEL(c->surface_indent_exp), str);
     g_snprintf(str, str_len, "%g", (c->args->area_indent_exp)/mag/mag);
-    gtk_label_set_text(GTK_LABEL(c->w_area_indent_exp), str);
+    gtk_label_set_text(GTK_LABEL(c->area_indent_exp), str);
 
     g_snprintf(str, str_len, "%g", c->args->surface_innerpileup/mag/mag);
-    gtk_label_set_text(GTK_LABEL(c->w_surface_innerpileup), str);
+    gtk_label_set_text(GTK_LABEL(c->surface_innerpileup), str);
     g_snprintf(str, str_len, "%g", (c->args->area_innerpileup)/mag/mag);
-    gtk_label_set_text(GTK_LABEL(c->w_area_innerpileup), str);
+    gtk_label_set_text(GTK_LABEL(c->area_innerpileup), str);
     g_snprintf(str, str_len, "%g", c->args->surface_outerpileup/mag/mag);
-    gtk_label_set_text(GTK_LABEL(c->w_surface_outerpileup), str);
+    gtk_label_set_text(GTK_LABEL(c->surface_outerpileup), str);
     g_snprintf(str, str_len, "%g", (c->args->area_outerpileup)/mag/mag);
-    gtk_label_set_text(GTK_LABEL(c->w_area_outerpileup), str);
+    gtk_label_set_text(GTK_LABEL(c->area_outerpileup), str);
 }
 
 static void
@@ -1597,7 +1420,7 @@ save_statistics_dialog(IndentAnalyzeControls *c,
     sxy = gwy_data_field_get_xreal(dfield) * gwy_data_field_get_yreal(dfield);
     vf = gwy_data_field_get_value_format_xy(dfield, GWY_SI_UNIT_FORMAT_PLAIN, NULL);
     /*
-    siunit = gwy_si_unit_new("");
+    siunit = gwy_si_unit_new(NULL);
     gwy_si_unit_power(gwy_data_field_get_si_unit_xy(dfield), 2, siunit);
     vf2 = gwy_si_unit_get_format(siunit, args->area_plane, NULL);
     gwy_si_unit_multiply(siunit, gwy_data_field_get_si_unit_z(dfield), siunit);
