@@ -75,12 +75,12 @@ static GwyModuleInfo module_info = {
     &module_register,
     N_("Lateral force simulator"),
     "Petr Klapetek <klapetek@gwyddion.net>",
-    "1.1",
+    "1.2",
     "David Nečas (Yeti) & Petr Klapetek",
     "2012",
 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, latsim)
 
 static gboolean
 module_register(void)
@@ -172,25 +172,23 @@ latsim_dialog(LatSimArgs *args)
 
 
     controls.mu = gtk_adjustment_new(args->mu, 0.001, 100, 0.1, 1, 0);
-    spin = gwy_table_attach_spinbutton(table, row, _("_Friction coef.:"), "",
-                                controls.mu);
+    spin = gwy_table_attach_adjbar(table, row, _("_Friction coef.:"), NULL,
+                                   controls.mu, GWY_HSCALE_LOG);
     gtk_spin_button_set_digits(GTK_SPIN_BUTTON(spin), 1);
     row++;
 
     controls.load = gtk_adjustment_new(args->load, 0.0, 1000, 1, 10, 0);
-    spin = gwy_table_attach_spinbutton(table, row, _("_Normal force:"), "nN",
-                                controls.load);
+    spin = gwy_table_attach_adjbar(table, row, _("_Normal force:"), "nN",
+                                   controls.load, GWY_HSCALE_SQRT);
     gtk_spin_button_set_digits(GTK_SPIN_BUTTON(spin), 1);
 
     row++;
     controls.adhesion = gtk_adjustment_new(args->adhesion, 0.0, 1000, 1, 10, 0);
-    spin = gwy_table_attach_spinbutton(table, row, _("_Adhesion force:"), "nN",
-                                controls.adhesion);
+    spin = gwy_table_attach_adjbar(table, row, _("_Adhesion force:"), "nN",
+                                   controls.adhesion, GWY_HSCALE_SQRT);
     gtk_spin_button_set_digits(GTK_SPIN_BUTTON(spin), 1);
     row++;
 
-
-
     gtk_widget_show_all(dialog);
     do {
         response = gtk_dialog_run(GTK_DIALOG(dialog));
