@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: level.c 19044 2016-10-08 19:10:46Z yeti-dn $
+ *  @(#) $Id: level.c 19948 2017-06-22 14:05:41Z yeti-dn $
  *  Copyright (C) 2003-2016 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -78,7 +78,7 @@ static GwyModuleInfo module_info = {
     "2003",
 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, level)
 
 static gboolean
 module_register(void)
@@ -258,7 +258,7 @@ level_dialog(LevelArgs *args,
 
     label = gwy_label_new_header(_("Masking Mode"));
     gtk_table_attach(GTK_TABLE(table), label,
-                     0, 3, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
+                     0, 3, row, row+1, GTK_FILL, 0, 0, 0);
     row++;
 
     controls.masking = gwy_radio_buttons_create(gwy_masking_type_get_enum(), -1,
