@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: level_grains.c 19089 2016-10-16 12:47:38Z yeti-dn $
+ *  @(#) $Id: level_grains.c 19948 2017-06-22 14:05:41Z yeti-dn $
  *  Copyright (C) 2011 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
@@ -89,7 +89,7 @@ static GwyModuleInfo module_info = {
     "2011",
 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, level_grains)
 
 static gboolean
 module_register(void)
