@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: linecorrect.c 19044 2016-10-08 19:10:46Z yeti-dn $
+ *  @(#) $Id: linecorrect.c 19948 2017-06-22 14:05:41Z yeti-dn $
  *  Copyright (C) 2003 David Necas (Yeti), Petr Klapetek, Luke Somers.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net, lsomers@sas.upenn.edu.
  *
@@ -35,8 +35,6 @@
 
 #define LINECORR_RUN_MODES GWY_RUN_IMMEDIATE
 
-#define GOLDEN_RATIO .6180339887498948482
-
 typedef struct {
     gdouble *a;
     gdouble *b;
@@ -58,7 +56,7 @@ static GwyModuleInfo module_info = {
     "2004",
 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, linecorrect)
 
 static gboolean
 module_register(void)
