@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: linematch.c 19044 2016-10-08 19:10:46Z yeti-dn $
+ *  @(#) $Id: linematch.c 19948 2017-06-22 14:05:41Z yeti-dn $
  *  Copyright (C) 2015 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
@@ -106,9 +106,6 @@ static void     slope_level_row_shifts  (GwyDataLine *shifts);
 static void     apply_row_shifts        (GwyDataField *dfield,
                                          GwyDataField *bg,
                                          GwyDataLine *shifts);
-static void     flip_xy                 (GwyDataField *source,
-                                         GwyDataField *dest,
-                                         gboolean minor);
 static gboolean linematch_dialog        (LineMatchArgs *args,
                                          GwyContainer *data,
                                          GwyDataField *dfield,
@@ -167,12 +164,12 @@ static GwyModuleInfo module_info = {
     &module_register,
     N_("Aligns rows by various methods."),
     "Yeti <yeti@gwyddion.net>",
-    "1.4",
+    "1.5",
     "David Nečas (Yeti)",
     "2015",
 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, linematch)
 
 static gboolean
 module_register(void)
@@ -295,11 +292,11 @@ linematch_do(GwyDataField *mask,
     mymask = mask;
     if (args->direction == GWY_ORIENTATION_VERTICAL) {
         tmpresult = gwy_data_field_new_alike(args->result, FALSE);
-        flip_xy(args->result, tmpresult, FALSE);
+        gwy_data_field_flip_xy(args->result, tmpresult, FALSE);
         GWY_SWAP(GwyDataField*, args->result, tmpresult);
         if (mask) {
             mymask = gwy_data_field_new_alike(mask, FALSE);
-            flip_xy(mask, mymask, FALSE);
+            gwy_data_field_flip_xy(mask, mymask, FALSE);
         }
     }
 
@@ -328,9 +325,9 @@ linematch_do(GwyDataField *mask,
     /* Transpose back if necessary. */
     if (args->direction == GWY_ORIENTATION_VERTICAL) {
         GWY_OBJECT_UNREF(mymask);
-        flip_xy(args->result, tmpresult, TRUE);
+        gwy_data_field_flip_xy(args->result, tmpresult, TRUE);
         GWY_SWAP(GwyDataField*, args->result, tmpresult);
-        flip_xy(args->bg, tmpresult, TRUE);
+        gwy_data_field_flip_xy(args->bg, tmpresult, TRUE);
         gwy_data_field_resample(args->bg,
                                 args->result->xres, args->result->yres,
                                 GWY_INTERPOLATION_NONE);
@@ -740,36 +737,6 @@ apply_row_shifts(GwyDataField *dfield, GwyDataField *bg,
     }
 }
 
-static void
-flip_xy(GwyDataField *source, GwyDataField *dest, gboolean minor)
-{
-    gint xres, yres, i, j;
-    gdouble *dd;
-    const gdouble *sd;
-
-    xres = gwy_data_field_get_xres(source);
-    yres = gwy_data_field_get_yres(source);
-    gwy_data_field_resample(dest, yres, xres, GWY_INTERPOLATION_NONE);
-    sd = gwy_data_field_get_data_const(source);
-    dd = gwy_data_field_get_data(dest);
-    if (minor) {
-        for (i = 0; i < xres; i++) {
-            for (j = 0; j < yres; j++) {
-                dd[i*yres + j] = sd[j*xres + (xres - 1 - i)];
-            }
-        }
-    }
-    else {
-        for (i = 0; i < xres; i++) {
-            for (j = 0; j < yres; j++) {
-                dd[i*yres + (yres - 1 - j)] = sd[j*xres + i];
-            }
-        }
-    }
-    gwy_data_field_set_xreal(dest, gwy_data_field_get_yreal(source));
-    gwy_data_field_set_yreal(dest, gwy_data_field_get_xreal(source));
-}
-
 static gboolean
 linematch_dialog(LineMatchArgs *args,
                  GwyContainer *data,
@@ -818,7 +785,7 @@ linematch_dialog(LineMatchArgs *args,
     gtk_container_add(GTK_CONTAINER(alignment), controls.dataview);
     gtk_box_pack_start(GTK_BOX(hbox), alignment, FALSE, FALSE, 4);
 
-    table = gtk_table_new(7 + LINE_LEVEL_NMETHODS + (mfield ? 4 : 0), 4, FALSE);
+    table = gtk_table_new(7 + LINE_LEVEL_NMETHODS + (mfield ? 4 : 0), 3, FALSE);
     gtk_table_set_row_spacings(GTK_TABLE(table), 2);
     gtk_table_set_col_spacings(GTK_TABLE(table), 6);
     gtk_container_set_border_width(GTK_CONTAINER(table), 4);
@@ -828,7 +795,7 @@ linematch_dialog(LineMatchArgs *args,
     label = gtk_label_new(_("Method:"));
     gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
     gtk_table_attach(GTK_TABLE(table), label,
-                     0, 3, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
+                     0, 2, row, row+1, GTK_FILL, 0, 0, 0);
     row++;
 
     controls.method_group
@@ -836,13 +803,13 @@ linematch_dialog(LineMatchArgs *args,
                                    G_CALLBACK(method_changed),
                                    &controls, args->method);
     row = gwy_radio_buttons_attach_to_table(controls.method_group,
-                                            GTK_TABLE(table), 3, row);
+                                            GTK_TABLE(table), 2, row);
 
     controls.max_degree = gtk_adjustment_new(args->max_degree,
                                              0, MAX_DEGREE, 1, 1, 0);
-    gwy_table_attach_hscale(table, row++,
-                            _("_Polynomial degree:"), NULL,
-                            controls.max_degree, 0);
+    gwy_table_attach_adjbar(table, row++, _("_Polynomial degree:"), NULL,
+                            controls.max_degree,
+                            GWY_HSCALE_LINEAR | GWY_HSCALE_SNAP);
     gwy_table_hscale_set_sensitive(GTK_OBJECT(controls.max_degree),
                                    args->method == LINE_LEVEL_POLY);
     g_signal_connect_swapped(controls.max_degree, "value-changed",
@@ -851,15 +818,16 @@ linematch_dialog(LineMatchArgs *args,
     gtk_table_set_row_spacing(GTK_TABLE(table), row-1, 8);
     label = gwy_label_new_header(_("Options"));
     gtk_table_attach(GTK_TABLE(table), label,
-                     0, 3, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
+                     0, 2, row, row+1, GTK_FILL, 0, 0, 0);
     row++;
 
     controls.direction
         = gwy_enum_combo_box_new(gwy_orientation_get_enum(), -1,
                                  G_CALLBACK(direction_changed), &controls,
                                  args->direction, TRUE);
-    gwy_table_attach_row(table, row, _("_Direction:"), NULL,
-                         controls.direction);
+    gwy_table_attach_adjbar(table, row, _("_Direction:"), NULL,
+                            GTK_OBJECT(controls.direction),
+                            GWY_HSCALE_WIDGET_NO_EXPAND);
     row++;
 
     controls.do_extract
@@ -882,11 +850,6 @@ linematch_dialog(LineMatchArgs *args,
                              G_CALLBACK(do_plot_changed), &controls);
     row++;
 
-    label = gtk_label_new_with_mnemonic(_("Target _graph:"));
-    gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
-    gtk_table_attach(GTK_TABLE(table), label,
-                     0, 1, row, row+1, GTK_FILL, 0, 0, 0);
-
     controls.target_graph = gwy_data_chooser_new_graphs();
     chooser = GWY_DATA_CHOOSER(controls.target_graph);
     gwy_data_chooser_set_none(chooser, _("New graph"));
@@ -894,9 +857,9 @@ linematch_dialog(LineMatchArgs *args,
     gwy_data_chooser_set_filter(chooser, filter_target_graphs, &controls, NULL);
     gwy_data_chooser_set_active_id(chooser, &args->target_graph);
     gwy_data_chooser_get_active_id(chooser, &args->target_graph);
-    gtk_label_set_mnemonic_widget(GTK_LABEL(label), controls.target_graph);
-    gtk_table_attach(GTK_TABLE(table), controls.target_graph,
-                     1, 3, row, row+1, GTK_FILL, 0, 0, 0);
+    gwy_table_attach_adjbar(table, row, _("Target _graph:"), NULL,
+                            GTK_OBJECT(controls.target_graph),
+                            GWY_HSCALE_WIDGET_NO_EXPAND);
     g_signal_connect_swapped(controls.target_graph, "changed",
                              G_CALLBACK(target_graph_changed), &controls);
     row++;
@@ -905,7 +868,7 @@ linematch_dialog(LineMatchArgs *args,
         gtk_table_set_row_spacing(GTK_TABLE(table), row-1, 8);
         label = gwy_label_new_header(_("Masking Mode"));
         gtk_table_attach(GTK_TABLE(table), label,
-                        0, 3, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
+                        0, 3, row, row+1, GTK_FILL, 0, 0, 0);
         row++;
 
         controls.masking_group
