@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: lno_synth.c 19044 2016-10-08 19:10:46Z yeti-dn $
+ *  @(#) $Id: lno_synth.c 20105 2017-07-29 09:24:09Z yeti-dn $
  *  Copyright (C) 2010 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
@@ -35,8 +35,6 @@
 #include "dimensions.h"
 #include "preview.h"
 
-#define GWY_SQRT6 2.449489742783178098197284074705
-
 #define LNO_SYNTH_RUN_MODES (GWY_RUN_IMMEDIATE | GWY_RUN_INTERACTIVE)
 
 #define DECLARE_LNOISE(name) \
@@ -279,7 +277,7 @@ static GwyModuleInfo module_info = {
     "2010",
 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, lno_synth)
 
 static gboolean
 module_register(void)
@@ -492,7 +490,7 @@ lno_synth_dialog(LNoSynthArgs *args,
         g_signal_connect_swapped(controls.dims->add, "toggled",
                                  G_CALLBACK(lno_synth_invalidate), &controls);
 
-    table = gtk_table_new(9 + (dfield_template ? 1 : 0), 4, FALSE);
+    table = gtk_table_new(9 + (dfield_template ? 1 : 0), 3, FALSE);
     controls.table = GTK_TABLE(table);
     gtk_table_set_row_spacings(controls.table, 2);
     gtk_table_set_col_spacings(controls.table, 6);
@@ -502,18 +500,18 @@ lno_synth_dialog(LNoSynthArgs *args,
     row = 0;
 
     gtk_table_attach(controls.table, gwy_label_new_header(_("Distribution")),
-                     0, 3, row, row+1, GTK_FILL, 0, 0, 0);
+                     0, 2, row, row+1, GTK_FILL, 0, 0, 0);
     row++;
 
     controls.distribution = distribution_selector_new(&controls);
-    gwy_table_attach_hscale(table, row, _("_Distribution:"), NULL,
+    gwy_table_attach_adjbar(table, row, _("_Distribution:"), NULL,
                             GTK_OBJECT(controls.distribution),
-                            GWY_HSCALE_WIDGET);
+                            GWY_HSCALE_WIDGET_NO_EXPAND);
     row++;
 
-    label = gtk_label_new(_("Direction:"));
+    label = gtk_label_new(_("Noise type:"));
     gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
-    gtk_table_attach(GTK_TABLE(table), label, 0, 1, row, row+1,
+    gtk_table_attach(GTK_TABLE(table), label, 0, 2, row, row+1,
                      GTK_FILL, 0, 0, 0);
     row++;
 
@@ -525,7 +523,7 @@ lno_synth_dialog(LNoSynthArgs *args,
                                     _("One-sided _negative"), LNO_DIRECTION_DOWN,
                                     NULL);
     row = gwy_radio_buttons_attach_to_table(controls.direction,
-                                            GTK_TABLE(table), 3, row);
+                                            GTK_TABLE(table), 2, row);
     gtk_table_set_row_spacing(GTK_TABLE(table), row-1, 8);
 
     row = gwy_synth_attach_height(&controls, row,
@@ -534,22 +532,23 @@ lno_synth_dialog(LNoSynthArgs *args,
 
     if (dfield_template) {
         controls.sigma_init
-            = gtk_button_new_with_mnemonic(_("_Like Current Channel"));
+            = gtk_button_new_with_mnemonic(_("_Like Current Image"));
         g_signal_connect_swapped(controls.sigma_init, "clicked",
                                  G_CALLBACK(sigma_init_clicked), &controls);
         gtk_table_attach(GTK_TABLE(table), controls.sigma_init,
-                         1, 3, row, row+1, GTK_FILL, 0, 0, 0);
+                         0, 2, row, row+1, GTK_FILL, 0, 0, 0);
         row++;
     }
 
     gtk_table_set_row_spacing(GTK_TABLE(table), row-1, 8);
     gtk_table_attach(controls.table, gwy_label_new_header(_("Noise Type")),
-                     0, 3, row, row+1, GTK_FILL, 0, 0, 0);
+                     0, 2, row, row+1, GTK_FILL, 0, 0, 0);
     row++;
 
     controls.type = noise_selector_new(&controls);
-    gwy_table_attach_hscale(table, row, _("_Noise type:"), NULL,
-                            GTK_OBJECT(controls.type), GWY_HSCALE_WIDGET);
+    gwy_table_attach_adjbar(table, row, _("_Noise type:"), NULL,
+                            GTK_OBJECT(controls.type),
+                            GWY_HSCALE_WIDGET_NO_EXPAND);
     row++;
 
     g_object_set_data(G_OBJECT(controls.table),
@@ -849,9 +848,9 @@ create_gui_steps(LNoSynthControls *controls)
                                             0.001, 100.0, 0.001, 1.0, 0);
     g_object_set_data(G_OBJECT(pcontrols->density),
                       "target", &pargs->density);
-    gwy_table_attach_hscale(GTK_WIDGET(controls->table),
-                            row, _("Densi_ty:"), NULL, pcontrols->density,
-                            GWY_HSCALE_LOG);
+    gwy_table_attach_adjbar(GTK_WIDGET(controls->table), row,
+                            _("Densi_ty:"), NULL,
+                            pcontrols->density, GWY_HSCALE_LOG);
     g_signal_connect_swapped(pcontrols->density, "value-changed",
                              G_CALLBACK(gwy_synth_double_changed), controls);
     row++;
@@ -860,9 +859,9 @@ create_gui_steps(LNoSynthControls *controls)
                                              0.0, 1.0, 0.001, 0.1, 0);
     g_object_set_data(G_OBJECT(pcontrols->lineprob),
                       "target", &pargs->lineprob);
-    gwy_table_attach_hscale(GTK_WIDGET(controls->table),
-                            row, _("_Within line:"), NULL, pcontrols->lineprob,
-                            GWY_HSCALE_DEFAULT);
+    gwy_table_attach_adjbar(GTK_WIDGET(controls->table), row,
+                            _("_Within line:"), NULL,
+                            pcontrols->lineprob, GWY_HSCALE_SQRT);
     g_signal_connect_swapped(pcontrols->lineprob, "value-changed",
                              G_CALLBACK(gwy_synth_double_changed), controls);
     row++;
@@ -874,7 +873,7 @@ create_gui_steps(LNoSynthControls *controls)
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(pcontrols->cumulative),
                                  pargs->cumulative);
     gtk_table_attach(controls->table, pcontrols->cumulative,
-                     0, 3, row, row+1, GTK_FILL, 0, 0, 0);
+                     0, 2, row, row+1, GTK_FILL, 0, 0, 0);
     g_signal_connect_swapped(pcontrols->cumulative, "toggled",
                              G_CALLBACK(gwy_synth_boolean_changed), controls);
     row++;
@@ -1038,8 +1037,9 @@ create_gui_scars(LNoSynthControls *controls)
 
     pcontrols->coverage = gtk_adjustment_new(pargs->coverage,
                                              0.0001, 10.0, 0.0001, 0.1, 0);
-    gwy_table_attach_hscale(GTK_WIDGET(controls->table), row, _("Co_verage:"),
-                            NULL, pcontrols->coverage, GWY_HSCALE_SQRT);
+    gwy_table_attach_adjbar(GTK_WIDGET(controls->table), row,
+                            _("Co_verage:"), NULL,
+                            pcontrols->coverage, GWY_HSCALE_SQRT);
     g_object_set_data(G_OBJECT(pcontrols->coverage),
                       "target", &pargs->coverage);
     g_signal_connect_swapped(pcontrols->coverage, "value-changed",
@@ -1218,9 +1218,9 @@ create_gui_ridges(LNoSynthControls *controls)
                                             0.001, 100.0, 0.001, 1.0, 0);
     g_object_set_data(G_OBJECT(pcontrols->density),
                       "target", &pargs->density);
-    gwy_table_attach_hscale(GTK_WIDGET(controls->table),
-                            row, _("Densi_ty:"), NULL, pcontrols->density,
-                            GWY_HSCALE_LOG);
+    gwy_table_attach_adjbar(GTK_WIDGET(controls->table), row,
+                            _("Densi_ty:"), NULL,
+                            pcontrols->density, GWY_HSCALE_LOG);
     g_signal_connect_swapped(pcontrols->density, "value-changed",
                              G_CALLBACK(gwy_synth_double_changed), controls);
     row++;
@@ -1229,9 +1229,9 @@ create_gui_ridges(LNoSynthControls *controls)
                                              0.0, 1.0, 0.001, 0.1, 0);
     g_object_set_data(G_OBJECT(pcontrols->lineprob),
                       "target", &pargs->lineprob);
-    gwy_table_attach_hscale(GTK_WIDGET(controls->table),
-                            row, _("_Within line:"), NULL, pcontrols->lineprob,
-                            GWY_HSCALE_DEFAULT);
+    gwy_table_attach_adjbar(GTK_WIDGET(controls->table), row,
+                            _("_Within line:"), NULL,
+                            pcontrols->lineprob, GWY_HSCALE_SQRT);
     g_signal_connect_swapped(pcontrols->lineprob, "value-changed",
                              G_CALLBACK(gwy_synth_double_changed), controls);
     row++;
@@ -1239,9 +1239,9 @@ create_gui_ridges(LNoSynthControls *controls)
     pcontrols->width = gtk_adjustment_new(pargs->width,
                                           0.0001, 1.0, 0.0001, 0.01, 0);
     g_object_set_data(G_OBJECT(pcontrols->width), "target", &pargs->width);
-    gwy_table_attach_hscale(GTK_WIDGET(controls->table),
-                            row, _("Wi_dth:"), NULL, pcontrols->width,
-                            GWY_HSCALE_SQRT);
+    gwy_table_attach_adjbar(GTK_WIDGET(controls->table), row,
+                            _("Wi_dth:"), NULL,
+                            pcontrols->width, GWY_HSCALE_SQRT);
     g_signal_connect_swapped(pcontrols->width, "value-changed",
                              G_CALLBACK(gwy_synth_double_changed), controls);
     row++;
