@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: local_contrast.c 18537 2016-03-28 18:11:19Z yeti-dn $
+ *  @(#) $Id: local_contrast.c 19948 2017-06-22 14:05:41Z yeti-dn $
  *  Copyright (C) 2003 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -76,12 +76,12 @@ static GwyModuleInfo module_info = {
     &module_register,
     N_("Maximizes local contrast."),
     "Yeti <yeti@gwyddion.net>",
-    "1.3",
+    "1.4",
     "David Nečas (Yeti) & Petr Klapetek",
     "2005",
 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, local_contrast)
 
 static gboolean
 module_register(void)
@@ -134,7 +134,7 @@ contrast_dialog(ContrastArgs *args)
     gtk_dialog_set_default_response(GTK_DIALOG(dialog), GTK_RESPONSE_OK);
     gwy_help_add_to_proc_dialog(GTK_DIALOG(dialog), GWY_HELP_DEFAULT);
 
-    table = gtk_table_new(3, 4, FALSE);
+    table = gtk_table_new(3, 3, FALSE);
     gtk_table_set_row_spacings(GTK_TABLE(table), 2);
     gtk_table_set_col_spacings(GTK_TABLE(table), 6);
     gtk_container_set_border_width(GTK_CONTAINER(table), 4);
@@ -143,16 +143,16 @@ contrast_dialog(ContrastArgs *args)
     row = 0;
 
     controls.size = gtk_adjustment_new(args->size, 1, MAX_SIZE, 1, 5, 0);
-    gwy_table_attach_hscale(table, row++, _("Kernel _size:"), "px",
-                            controls.size, 0);
+    gwy_table_attach_adjbar(table, row++, _("Kernel _size:"), _("px"),
+                            controls.size, GWY_HSCALE_LINEAR);
 
     controls.depth = gtk_adjustment_new(args->depth, 2, MAX_DEPTH, 1, 2, 0);
-    gwy_table_attach_hscale(table, row++, _("Blending _depth:"), NULL,
-                            controls.depth, 0);
+    gwy_table_attach_adjbar(table, row++, _("Blending _depth:"), NULL,
+                            controls.depth, GWY_HSCALE_LINEAR);
 
     controls.weight = gtk_adjustment_new(args->weight, 0.0, 1.0, 0.01, 0.1, 0);
-    gwy_table_attach_hscale(table, row++, _("_Weight:"), NULL,
-                            controls.weight, 0);
+    gwy_table_attach_adjbar(table, row++, _("_Weight:"), NULL,
+                            controls.weight, GWY_HSCALE_LINEAR);
 
     gtk_widget_show_all(dialog);
     do {
