@@ -1,6 +1,6 @@
 /*
- *  @(#) $Id: logistic.c 19068 2016-10-13 18:41:54Z dn2010 $
- *  Copyright (C) 2016 David Necas (Yeti), Petr Klapetek,
+ *  @(#) $Id: logistic.c 19948 2017-06-22 14:05:41Z yeti-dn $
+ *  Copyright (C) 2016-2017 David Necas (Yeti), Petr Klapetek,
  *  Daniil Bratashov.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net,
  *  dn2010@gwyddion.net
@@ -30,8 +30,8 @@
 #include <libprocess/stats.h>
 #include <libprocess/filters.h>
 #include <libgwydgets/gwystock.h>
+#include <libgwydgets/gwyradiobuttons.h>
 #include <libgwydgets/gwydgetutils.h>
-#include <libgwydgets/gwydgets.h>
 #include <libgwymodule/gwymodule-process.h>
 #include <app/gwyapp.h>
 #include <string.h>
@@ -121,12 +121,12 @@ static GwyModuleInfo module_info = {
     &module_register,
     N_("Trains logistic regression to mark grains."),
     "Daniil Bratashov <dn2010@gwyddion.net>",
-    "0.2",
+    "0.3",
     "David Nečas (Yeti) & Petr Klapetek & Daniil Bratashov",
     "2016",
 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, logistic)
 
 static gboolean
 module_register(void)
@@ -241,7 +241,7 @@ logistic_dialog(G_GNUC_UNUSED GwyContainer *data, LogisticArgs *args)
     gwy_help_add_to_proc_dialog(GTK_DIALOG(dialog), GWY_HELP_DEFAULT);
     controls.dialog = dialog;
 
-    table = gtk_table_new(9, 4, FALSE);
+    table = gtk_table_new(9, 3, FALSE);
     gtk_table_set_row_spacings(GTK_TABLE(table), 2);
     gtk_table_set_col_spacings(GTK_TABLE(table), 6);
     gtk_container_set_border_width(GTK_CONTAINER(table), 4);
@@ -257,18 +257,17 @@ logistic_dialog(G_GNUC_UNUSED GwyContainer *data, LogisticArgs *args)
                                               LOGISTIC_MODE_TRAIN,
                                               NULL);
     button = gwy_radio_buttons_find(controls.mode, LOGISTIC_MODE_TRAIN);
-    gtk_table_attach(GTK_TABLE(table), button, 0, 3, row, row+1,
+    gtk_table_attach(GTK_TABLE(table), button, 0, 2, row, row+1,
                      GTK_FILL, 0, 0, 0);
     row++;
 
     button = gwy_radio_buttons_find(controls.mode, LOGISTIC_MODE_USE);
-    gtk_table_attach(GTK_TABLE(table), button, 0, 3, row, row+1,
+    gtk_table_attach(GTK_TABLE(table), button, 0, 2, row, row+1,
                      GTK_FILL, 0, 0, 0);
     row++;
 
-    gtk_table_attach(GTK_TABLE(table),
-                     gwy_label_new_header(_("Features")),
-                     0, 3, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
+    gtk_table_attach(GTK_TABLE(table), gwy_label_new_header(_("Features")),
+                     0, 2, row, row+1, GTK_FILL, 0, 0, 0);
     row++;
 
     controls.use_gaussians
@@ -276,20 +275,18 @@ logistic_dialog(G_GNUC_UNUSED GwyContainer *data, LogisticArgs *args)
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(controls.use_gaussians),
                                  args->use_gaussians);
     gtk_table_attach(GTK_TABLE(table), controls.use_gaussians,
-                     0, 3, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
+                     0, 2, row, row+1, GTK_FILL, 0, 0, 0);
     g_signal_connect_swapped(controls.use_gaussians, "toggled",
-                             G_CALLBACK(logistic_invalidate),
-                             &controls);
+                             G_CALLBACK(logistic_invalidate), &controls);
     row++;
 
-    controls.ngaussians
-                 = gtk_adjustment_new(args->ngaussians, 1, 10, 1, 2, 0);
-    gwy_table_attach_hscale(table, row,
+    controls.ngaussians = gtk_adjustment_new(args->ngaussians, 1, 10, 1, 2, 0);
+    gwy_table_attach_adjbar(table, row,
                             _("_Number of Gaussians:"), NULL,
-                            controls.ngaussians, GWY_HSCALE_DEFAULT);
+                            controls.ngaussians,
+                            GWY_HSCALE_LINEAR | GWY_HSCALE_SNAP);
     g_signal_connect_swapped(controls.ngaussians, "value-changed",
-                             G_CALLBACK(logistic_invalidate),
-                             &controls);
+                             G_CALLBACK(logistic_invalidate), &controls);
     row++;
 
     controls.use_sobel
@@ -297,10 +294,9 @@ logistic_dialog(G_GNUC_UNUSED GwyContainer *data, LogisticArgs *args)
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(controls.use_sobel),
                                  args->use_sobel);
     gtk_table_attach(GTK_TABLE(table), controls.use_sobel,
-                     0, 3, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
+                     0, 2, row, row+1, GTK_FILL, 0, 0, 0);
     g_signal_connect_swapped(controls.use_sobel, "toggled",
-                             G_CALLBACK(logistic_invalidate),
-                             &controls);
+                             G_CALLBACK(logistic_invalidate), &controls);
     row++;
 
     controls.use_laplasian
@@ -308,10 +304,9 @@ logistic_dialog(G_GNUC_UNUSED GwyContainer *data, LogisticArgs *args)
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(controls.use_laplasian),
                                  args->use_laplasian);
     gtk_table_attach(GTK_TABLE(table), controls.use_laplasian,
-                     0, 3, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
+                     0, 2, row, row+1, GTK_FILL, 0, 0, 0);
     g_signal_connect_swapped(controls.use_laplasian, "toggled",
-                             G_CALLBACK(logistic_invalidate),
-                             &controls);
+                             G_CALLBACK(logistic_invalidate), &controls);
     row++;
 
     controls.use_hessian
@@ -319,20 +314,18 @@ logistic_dialog(G_GNUC_UNUSED GwyContainer *data, LogisticArgs *args)
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(controls.use_hessian),
                                  args->use_hessian);
     gtk_table_attach(GTK_TABLE(table), controls.use_hessian,
-                     0, 3, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
+                     0, 2, row, row+1, GTK_FILL, 0, 0, 0);
     g_signal_connect_swapped(controls.use_hessian, "toggled",
-                             G_CALLBACK(logistic_invalidate),
-                             &controls);
+                             G_CALLBACK(logistic_invalidate), &controls);
     row++;
 
     controls.lambda
              = gtk_adjustment_new(args->lambda, 0.0, 10.0, 0.1, 1.0, 0);
-    gwy_table_attach_hscale(table, row,
+    gwy_table_attach_adjbar(table, row,
                             _("_Regularization parameter:"), NULL,
                             controls.lambda, GWY_HSCALE_DEFAULT);
     g_signal_connect_swapped(controls.lambda, "value-changed",
-                             G_CALLBACK(logistic_invalidate),
-                             &controls);
+                             G_CALLBACK(logistic_invalidate), &controls);
     row++;
 
     logistic_dialog_update(&controls, args);
