@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: mark_disconn.c 19044 2016-10-08 19:10:46Z yeti-dn $
+ *  @(#) $Id: mark_disconn.c 19948 2017-06-22 14:05:41Z yeti-dn $
  *  Copyright (C) 2015 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
@@ -31,6 +31,7 @@
 #include <libprocess/linestats.h>
 #include <libgwydgets/gwyradiobuttons.h>
 #include <libgwydgets/gwycombobox.h>
+#include <libgwydgets/gwystock.h>
 #include <libgwymodule/gwymodule-process.h>
 #include <app/gwymoduleutils.h>
 #include <app/gwyapp.h>
@@ -62,7 +63,7 @@ typedef struct {
     GtkWidget *view;
     GtkWidget *color_button;
     GtkWidget *combine;
-    GtkWidget *combine_type;
+    GSList *combine_type;
 } DisconnControls;
 
 static gboolean module_register      (void);
@@ -83,10 +84,9 @@ static void     size_changed         (GtkAdjustment *adj,
                                       DisconnControls *controls);
 static void     threshold_changed    (GtkAdjustment *adj,
                                       DisconnControls *controls);
-static void     combine_changed      (GtkToggleButton *toggle,
-                                      DisconnControls *controls);
-static void     combine_type_changed (GtkComboBox *combo,
-                                      DisconnControls *controls);
+static void     combine_changed      (DisconnControls *controls,
+                                      GtkToggleButton *toggle);
+static void     combine_type_changed (DisconnControls *controls);
 static void     disconn_load_args    (GwyContainer *container,
                                       DisconnArgs *args);
 static void     disconn_save_args    (GwyContainer *container,
@@ -103,12 +103,12 @@ static GwyModuleInfo module_info = {
     &module_register,
     N_("Creates mask of values disconnected to the rest."),
     "Yeti <yeti@gwyddion.net>",
-    "1.2",
+    "1.4",
     "David Nečas (Yeti)",
     "2015",
 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, mark_disconn)
 
 static gboolean
 module_register(void)
@@ -116,7 +116,7 @@ module_register(void)
     gwy_process_func_register("mark_disconn",
                               (GwyProcessFunc)&mark_disconn,
                               N_("/_Correct Data/Mask of _Disconnected..."),
-                              NULL,
+                              GWY_STOCK_DISCONNECTED,
                               DISCONN_RUN_MODES,
                               GWY_MENU_FLAG_DATA,
                               N_("Mark data disconnected from other values"));
@@ -148,8 +148,8 @@ mark_disconn(GwyContainer *data,
                            _("Initializing..."));
         if (!disconn_do(dfield, maskfield, &args))
             GWY_OBJECT_UNREF(maskfield);
-        disconn_save_args(gwy_app_settings_get(), &args);
     }
+    disconn_save_args(gwy_app_settings_get(), &args);
 
     if (!maskfield)
         return;
@@ -239,7 +239,7 @@ disconn_dialog(DisconnArgs *args, GwyContainer *data, gint id)
     controls.view = create_preview(controls.mydata, 0, PREVIEW_SIZE, TRUE);
     gtk_box_pack_start(GTK_BOX(hbox), controls.view, FALSE, FALSE, 4);
 
-    table = gtk_table_new(8 + 2*(!!existing_mask), 4, FALSE);
+    table = gtk_table_new(8 + 2*(!!existing_mask), 3, FALSE);
     gtk_table_set_row_spacings(GTK_TABLE(table), 2);
     gtk_table_set_col_spacings(GTK_TABLE(table), 6);
     gtk_container_set_border_width(GTK_CONTAINER(table), 4);
@@ -249,27 +249,28 @@ disconn_dialog(DisconnArgs *args, GwyContainer *data, gint id)
     label = gtk_label_new(_("Defect type:"));
     gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
     gtk_table_attach(GTK_TABLE(table), label,
-                     0, 3, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
+                     0, 2, row, row+1, GTK_FILL, 0, 0, 0);
     row++;
 
     group = gwy_radio_buttons_create(types, G_N_ELEMENTS(types),
                                      G_CALLBACK(type_changed), &controls,
                                      args->type);
     controls.type = group;
-    row = gwy_radio_buttons_attach_to_table(group, GTK_TABLE(table), 3, row);
+    row = gwy_radio_buttons_attach_to_table(group, GTK_TABLE(table), 2, row);
 
     gtk_table_set_row_spacing(GTK_TABLE(table), row-1, 8);
     controls.size = gtk_adjustment_new(args->size, 1, 256, 1, 10, 0);
-    gwy_table_attach_hscale(table, row, _("Defect _radius:"), "px",
-                            controls.size, GWY_HSCALE_SQRT);
+    gwy_table_attach_adjbar(table, row, _("Defect _radius:"), _("px"),
+                            controls.size,
+                            GWY_HSCALE_SQRT | GWY_HSCALE_SNAP);
     g_signal_connect(controls.size, "value-changed",
                      G_CALLBACK(size_changed), &controls);
     row++;
 
     controls.threshold = gtk_adjustment_new(args->threshold,
                                             0.0, 1.0, 0.001, 0.1, 0);
-    spin = gwy_table_attach_hscale(table, row, _("_Threshold:"), NULL,
-                                   controls.threshold, GWY_HSCALE_SQRT);
+    spin = gwy_table_attach_adjbar(table, row, _("_Threshold:"), NULL,
+                                   controls.threshold, GWY_HSCALE_DEFAULT);
     gtk_spin_button_set_digits(GTK_SPIN_BUTTON(spin), 4);
     g_signal_connect(controls.threshold, "value-changed",
                      G_CALLBACK(threshold_changed), &controls);
@@ -278,36 +279,23 @@ disconn_dialog(DisconnArgs *args, GwyContainer *data, gint id)
     gtk_table_set_row_spacing(GTK_TABLE(table), row-1, 8);
     label = gwy_label_new_header(_("Options"));
     gtk_table_attach(GTK_TABLE(table), label,
-                     0, 3, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
+                     0, 2, row, row+1, GTK_FILL, 0, 0, 0);
     row++;
 
     if (existing_mask) {
-        controls.combine
-            = gtk_check_button_new_with_mnemonic(_("Com_bine with "
-                                                   "existing mask"));
-        gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(controls.combine),
-                                     args->combine);
-        gtk_table_attach(GTK_TABLE(table), controls.combine,
-                         0, 3, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
-        g_signal_connect(controls.combine, "toggled",
-                         G_CALLBACK(combine_changed), &controls);
-        row++;
-
-        controls.combine_type
-            = gwy_enum_combo_box_new(gwy_merge_type_get_enum(), -1,
-                                     G_CALLBACK(combine_type_changed),
-                                     &controls,
-                                     args->combine_type, TRUE);
-        gwy_table_attach_hscale(table, row, _("Operation:"), NULL,
-                                GTK_OBJECT(controls.combine_type),
-                                GWY_HSCALE_WIDGET);
-        gtk_table_set_row_spacing(GTK_TABLE(table), row, 8);
+        create_mask_merge_buttons(table, row, NULL,
+                                  args->combine,
+                                  G_CALLBACK(combine_changed),
+                                  args->combine_type,
+                                  G_CALLBACK(combine_type_changed),
+                                  &controls,
+                                  &controls.combine, &controls.combine_type);
         row++;
     }
 
     controls.color_button = create_mask_color_button(controls.mydata, dialog,
                                                      0);
-    gwy_table_attach_hscale(table, row, _("_Mask color:"), NULL,
+    gwy_table_attach_adjbar(table, row, _("_Mask color:"), NULL,
                             GTK_OBJECT(controls.color_button),
                             GWY_HSCALE_WIDGET_NO_EXPAND);
     row++;
@@ -410,15 +398,16 @@ threshold_changed(GtkAdjustment *adj, DisconnControls *controls)
 }
 
 static void
-combine_changed(GtkToggleButton *toggle, DisconnControls *controls)
+combine_changed(DisconnControls *controls, GtkToggleButton *toggle)
 {
     controls->args->combine = gtk_toggle_button_get_active(toggle);
 }
 
 static void
-combine_type_changed(GtkComboBox *combo, DisconnControls *controls)
+combine_type_changed(DisconnControls *controls)
 {
-    controls->args->combine_type = gwy_enum_combo_box_get_active(combo);
+    controls->args->combine_type
+        = gwy_radio_buttons_get_current(controls->combine_type);
 }
 
 /* Remove from mask pixels with values that do not belong to the largest
