@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: mark_with.c 18537 2016-03-28 18:11:19Z yeti-dn $
+ *  @(#) $Id: mark_with.c 19948 2017-06-22 14:05:41Z yeti-dn $
  *  Copyright (C) 2009 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
@@ -138,12 +138,12 @@ static GwyModuleInfo module_info = {
     &module_register,
     N_("Creates or modifies a mask using other channels."),
     "Yeti <yeti@gwyddion.net>",
-    "1.4",
+    "1.5",
     "David Nečas (Yeti)",
     "2009",
 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, mark_with)
 
 static gboolean
 module_register(void)
@@ -180,11 +180,12 @@ static void
 mark_dialog(MarkArgs *args,
             GQuark mquark)
 {
-    GtkWidget *dialog, *hbox, *vbox, *label, *vbox2;
+    GtkWidget *dialog, *hbox, *vbox, *label, *vbox2, *hbox2;
     GtkTable *table;
     MarkControls controls;
     GwyContainer *data;
     GwyDataField *dfield;
+    GtkSizeGroup *combosizes;
     GSList *l;
     gint response, row;
     guint i;
@@ -220,7 +221,7 @@ mark_dialog(MarkArgs *args,
     gtk_box_pack_start(GTK_BOX(hbox), vbox, FALSE, FALSE, 0);
 
     /* Controls */
-    table = GTK_TABLE(gtk_table_new(13, 4, FALSE));
+    table = GTK_TABLE(gtk_table_new(13, 3, FALSE));
     gtk_table_set_row_spacings(table, 2);
     gtk_table_set_col_spacings(table, 6);
     gtk_box_pack_start(GTK_BOX(hbox), GTK_WIDGET(table), FALSE, TRUE, 0);
@@ -240,7 +241,7 @@ mark_dialog(MarkArgs *args,
                                     _("_Subtract mask"), MASK_EDIT_REMOVE,
                                     _("_Intersect masks"), MASK_EDIT_INTERSECT,
                                     NULL);
-    row = gwy_radio_buttons_attach_to_table(controls.operation, table, 3, row);
+    row = gwy_radio_buttons_attach_to_table(controls.operation, table, 2, row);
     gtk_table_set_row_spacing(table, row-1, 8);
 
     /* Mark with */
@@ -259,11 +260,13 @@ mark_dialog(MarkArgs *args,
                                     gwy_sgettext("with|_Presentation"),
                                     MARK_WITH_SHOW,
                                     NULL);
+    combosizes = gtk_size_group_new(GTK_SIZE_GROUP_HORIZONTAL);
     for (l = controls.mark_with; l; l = g_slist_next(l)) {
         GwyDataChooser *chooser;
 
-        gtk_table_attach(table, GTK_WIDGET(l->data),
-                         0, 1, row, row+1, GTK_FILL, 0, 0, 0);
+        hbox2 = gtk_hbox_new(FALSE, 6);
+        gtk_table_attach(table, hbox2, 0, 2, row, row+1, GTK_FILL, 0, 0, 0);
+        gtk_box_pack_start(GTK_BOX(hbox2), GTK_WIDGET(l->data), FALSE, TRUE, 0);
         i = gwy_radio_button_get_value(GTK_WIDGET(l->data));
         controls.channels[i] = gwy_data_chooser_new_channels();
         chooser = GWY_DATA_CHOOSER(controls.channels[i]);
@@ -278,28 +281,29 @@ mark_dialog(MarkArgs *args,
         else
             gwy_data_chooser_set_filter(chooser, &show_attach_filter,
                                         &args->target, NULL);
-        gtk_table_attach(table, controls.channels[i],
-                         1, 3, row, row+1, GTK_FILL, 0, 0, 0);
+        gtk_box_pack_end(GTK_BOX(hbox2), controls.channels[i], FALSE, TRUE, 0);
+        gtk_size_group_add_widget(combosizes, controls.channels[i]);
         controls.has_any[i] = !!gwy_data_chooser_get_active(chooser, NULL);
-        gtk_widget_set_sensitive(GTK_WIDGET(l->data), controls.has_any[i]);
+        gtk_widget_set_sensitive(hbox2, controls.has_any[i]);
         gwy_data_chooser_get_active_id(chooser, args->source + i);
         g_signal_connect(chooser, "changed",
                          G_CALLBACK(channel_changed), &controls);
         row++;
     }
+    g_object_unref(combosizes);
     gtk_table_set_row_spacing(GTK_TABLE(table), row-1, 8);
 
     /* Range */
     label = gtk_label_new(_("Marked data range:"));
     gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
-    gtk_table_attach(table, label, 0, 1, row, row+1, GTK_FILL, 0, 0, 0);
+    gtk_table_attach(table, label, 0, 2, row, row+1, GTK_FILL, 0, 0, 0);
     row++;
 
     /* Minimum */
     controls.min = GTK_ADJUSTMENT(gtk_adjustment_new(100.0*args->min,
                                                      0.0, 100.0, 0.01, 1.0, 0));
-    gwy_table_attach_hscale(GTK_WIDGET(table), row, _("_Minimum:"), "%",
-                            GTK_OBJECT(controls.min), 0);
+    gwy_table_attach_adjbar(GTK_WIDGET(table), row, _("_Minimum:"), "%",
+                            GTK_OBJECT(controls.min), GWY_HSCALE_LINEAR);
     g_signal_connect_swapped(controls.min, "value-changed",
                              G_CALLBACK(min_changed), &controls);
     row++;
@@ -307,8 +311,8 @@ mark_dialog(MarkArgs *args,
     /* Maximum */
     controls.max = GTK_ADJUSTMENT(gtk_adjustment_new(100.0*args->max,
                                                      0.0, 100.0, 0.01, 1.0, 0));
-    gwy_table_attach_hscale(GTK_WIDGET(table), row, _("M_aximum:"), "%",
-                            GTK_OBJECT(controls.max), 0);
+    gwy_table_attach_adjbar(GTK_WIDGET(table), row, _("M_aximum:"), "%",
+                            GTK_OBJECT(controls.max), GWY_HSCALE_LINEAR);
     g_signal_connect_swapped(controls.max, "value-changed",
                              G_CALLBACK(max_changed), &controls);
     gtk_table_set_row_spacing(table, row, 8);
