@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: mask_distribute.c 18626 2016-04-22 10:15:13Z yeti-dn $
+ *  @(#) $Id: mask_distribute.c 19948 2017-06-22 14:05:41Z yeti-dn $
  *  Copyright (C) 2003-2004 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -91,7 +91,7 @@ static GwyModuleInfo module_info = {
     "2015",
 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, mask_distribute)
 
 static gboolean
 module_register(void)
@@ -165,7 +165,7 @@ mask_distrib_dialog(MaskDistribArgs *args)
 
     label = gwy_label_new_header(_("Distribute to:"));
     gtk_table_attach(GTK_TABLE(table), label,
-                     0, 1, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
+                     0, 1, row, row+1, GTK_FILL, 0, 0, 0);
     row++;
 
     controls.mode = gwy_radio_buttons_create(modes, G_N_ELEMENTS(modes),
@@ -180,7 +180,7 @@ mask_distrib_dialog(MaskDistribArgs *args)
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(controls.keep_existing),
                                  args->keep_existing);
     gtk_table_attach(GTK_TABLE(table), controls.keep_existing,
-                     0, 1, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
+                     0, 1, row, row+1, GTK_FILL, 0, 0, 0);
     g_signal_connect(controls.keep_existing, "toggled",
                      G_CALLBACK(keep_existing_changed), &controls);
     row++;
