@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: mask_morph.c 18626 2016-04-22 10:15:13Z yeti-dn $
+ *  @(#) $Id: mask_morph.c 20105 2017-07-29 09:24:09Z yeti-dn $
  *  Copyright (C) 2015 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
@@ -35,7 +35,6 @@
 #include <app/gwymoduleutils.h>
 
 #define MASKMORPH_RUN_MODES (GWY_RUN_IMMEDIATE | GWY_RUN_INTERACTIVE)
-#define MASKTHIN_RUN_MODES GWY_RUN_IMMEDIATE
 
 typedef enum {
     MASKMORPH_EROSION     = 0,
@@ -116,19 +115,19 @@ static GwyModuleInfo module_info = {
     &module_register,
     N_("Performs basic morphological operations with masks."),
     "Yeti <yeti@gwyddion.net>",
-    "1.0",
+    "1.1",
     "David Nečas (Yeti)",
     "2015",
 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, mask_morph)
 
 static gboolean
 module_register(void)
 {
     gwy_process_func_register("mask_morph",
                               (GwyProcessFunc)&mask_morph,
-                              N_("/_Mask/Morphological Operation..."),
+                              N_("/_Mask/Morpho_logical Operation..."),
                               GWY_STOCK_MASK_MORPH,
                               MASKMORPH_RUN_MODES,
                               GWY_MENU_FLAG_DATA_MASK | GWY_MENU_FLAG_DATA,
@@ -201,7 +200,7 @@ maskmorph_dialog(MaskMorphArgs *args, GwyDataField *mask)
     controls.dialog = dialog;
 
     table = gtk_table_new(MASKMORPH_NOPERATIONS + MASKMORPH_NSHAPES + 5,
-                          4, FALSE);
+                          3, FALSE);
     gtk_table_set_row_spacings(GTK_TABLE(table), 2);
     gtk_table_set_col_spacings(GTK_TABLE(table), 6);
     gtk_container_set_border_width(GTK_CONTAINER(table), 4);
@@ -210,7 +209,7 @@ maskmorph_dialog(MaskMorphArgs *args, GwyDataField *mask)
     label = gtk_label_new(_("Operation:"));
     gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
     gtk_table_attach(GTK_TABLE(table), label,
-                     0, 1, row, row+1, GTK_FILL, 0, 0, 0);
+                     0, 2, row, row+1, GTK_FILL, 0, 0, 0);
     row++;
 
     controls.mode
@@ -218,13 +217,13 @@ maskmorph_dialog(MaskMorphArgs *args, GwyDataField *mask)
                                    G_CALLBACK(mode_changed), &controls,
                                    args->mode);
     row = gwy_radio_buttons_attach_to_table(controls.mode, GTK_TABLE(table),
-                                            3, row);
+                                            2, row);
 
     gtk_table_set_row_spacing(GTK_TABLE(table), row-1, 8);
     label = gtk_label_new(_("Structuring element:"));
     gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
     gtk_table_attach(GTK_TABLE(table), label,
-                     0, 1, row, row+1, GTK_FILL, 0, 0, 0);
+                     0, 2, row, row+1, GTK_FILL, 0, 0, 0);
     row++;
 
     controls.shape
@@ -232,11 +231,11 @@ maskmorph_dialog(MaskMorphArgs *args, GwyDataField *mask)
                                    G_CALLBACK(shape_changed), &controls,
                                    args->shape);
     row = gwy_radio_buttons_attach_to_table(controls.shape, GTK_TABLE(table),
-                                            3, row);
+                                            2, row);
 
     controls.radius = gtk_adjustment_new(args->radius, 1, 1025, 1, 10, 0);
-    gwy_table_attach_hscale(table, row, _("_Radius:"), "px", controls.radius,
-                            GWY_HSCALE_SQRT);
+    gwy_table_attach_adjbar(table, row, _("_Radius:"), _("px"),
+                            controls.radius, GWY_HSCALE_SQRT);
     g_signal_connect(controls.radius, "value-changed",
                      G_CALLBACK(radius_changed), &controls);
     row++;
@@ -246,8 +245,9 @@ maskmorph_dialog(MaskMorphArgs *args, GwyDataField *mask)
                                    &args->kernel);
     gwy_data_chooser_set_filter(GWY_DATA_CHOOSER(controls.kernel),
                                 &kernel_filter, mask, NULL);
-    gwy_table_attach_hscale(table, row, _("_Mask:"), NULL,
-                            GTK_OBJECT(controls.kernel), GWY_HSCALE_WIDGET);
+    gwy_table_attach_adjbar(table, row, _("_Mask:"), NULL,
+                            GTK_OBJECT(controls.kernel),
+                            GWY_HSCALE_WIDGET_NO_EXPAND);
     has_kernel = gwy_data_chooser_get_active_id(GWY_DATA_CHOOSER(controls.kernel),
                                                 &args->kernel);
     g_signal_connect(controls.kernel, "changed",
@@ -259,7 +259,7 @@ maskmorph_dialog(MaskMorphArgs *args, GwyDataField *mask)
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(controls.crop_kernel),
                                  args->crop_kernel);
     gtk_table_attach(GTK_TABLE(table), controls.crop_kernel,
-                     0, 3, row, row+1, GTK_FILL, 0, 0, 0);
+                     0, 2, row, row+1, GTK_FILL, 0, 0, 0);
     g_signal_connect(controls.crop_kernel, "toggled",
                      G_CALLBACK(crop_kernel_changed), &controls);
 
