@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: maskcor.c 18665 2016-04-26 20:42:48Z yeti-dn $
+ *  @(#) $Id: maskcor.c 19948 2017-06-22 14:05:41Z yeti-dn $
  *  Copyright (C) 2004 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -27,6 +27,7 @@
 #include <libprocess/filters.h>
 #include <libgwydgets/gwydgetutils.h>
 #include <libgwydgets/gwycombobox.h>
+#include <libgwydgets/gwystock.h>
 #include <libgwymodule/gwymodule-process.h>
 #include <app/gwymoduleutils.h>
 #include <app/gwyapp.h>
@@ -85,12 +86,12 @@ static GwyModuleInfo module_info = {
     &module_register,
     N_("Creates mask by correlation with another data."),
     "Petr Klapetek <klapetek@gwyddion.net>",
-    "1.8",
+    "1.9",
     "David Nečas (Yeti) & Petr Klapetek",
     "2004",
 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, maskcor)
 
 static gboolean
 module_register(void)
@@ -98,7 +99,7 @@ module_register(void)
     gwy_process_func_register("maskcor",
                               (GwyProcessFunc)&maskcor,
                               N_("/M_ultidata/_Mask by Correlation..."),
-                              NULL,
+                              GWY_STOCK_CORRELATION_MASK,
                               MASKCOR_RUN_MODES,
                               GWY_MENU_FLAG_DATA,
                               N_("Create mask by correlation with another "
@@ -145,7 +146,7 @@ maskcor_dialog(MaskcorArgs *args)
     gtk_dialog_set_default_response(GTK_DIALOG(dialog), GTK_RESPONSE_OK);
     gwy_help_add_to_proc_dialog(GTK_DIALOG(dialog), GWY_HELP_DEFAULT);
 
-    table = gtk_table_new(5, 4, FALSE);
+    table = gtk_table_new(5, 3, FALSE);
     gtk_table_set_row_spacings(GTK_TABLE(table), 2);
     gtk_table_set_col_spacings(GTK_TABLE(table), 6);
     gtk_container_set_border_width(GTK_CONTAINER(table), 4);
@@ -162,8 +163,8 @@ maskcor_dialog(MaskcorArgs *args)
     gwy_data_chooser_get_active_id(GWY_DATA_CHOOSER(chooser), &args->kernel);
     g_signal_connect(chooser, "changed",
                      G_CALLBACK(maskcor_kernel_changed), &args->kernel);
-    gwy_table_attach_hscale(table, row, _("Correlation _kernel:"), NULL,
-                            GTK_OBJECT(chooser), GWY_HSCALE_WIDGET);
+    gwy_table_attach_adjbar(table, row, _("Correlation _kernel:"), NULL,
+                            GTK_OBJECT(chooser), GWY_HSCALE_WIDGET_NO_EXPAND);
     row++;
 
     /* Result */
@@ -173,19 +174,22 @@ maskcor_dialog(MaskcorArgs *args)
                                     _("Correlation maxima"), GWY_MASKCOR_MAXIMA,
                                     _("Correlation score"), GWY_MASKCOR_SCORE,
                                     NULL);
-    gwy_table_attach_row(table, row, _("Output _type:"), NULL, combo);
+    gwy_table_attach_adjbar(table, row, _("Output _type:"), NULL,
+                            GTK_OBJECT(combo), GWY_HSCALE_WIDGET_NO_EXPAND);
     row++;
 
     /* Parameters */
     method = gwy_enum_combo_box_new(gwy_correlation_type_get_enum(), -1,
                                     G_CALLBACK(gwy_enum_combo_box_update_int),
                                     &args->method, args->method, TRUE);
-    gwy_table_attach_row(table, row, _("Correlation _method:"), NULL, method);
+    gwy_table_attach_adjbar(table, row, _("Correlation _method:"), NULL,
+                            GTK_OBJECT(method), GWY_HSCALE_WIDGET_NO_EXPAND);
     row++;
 
     adj = gtk_adjustment_new(args->threshold, -1.0, 1.0, 0.01, 0.1, 0);
     controls.threshold = adj;
-    spin = gwy_table_attach_hscale(table, row, _("T_hreshold:"), NULL, adj, 0);
+    spin = gwy_table_attach_adjbar(table, row, _("T_hreshold:"), NULL,
+                                   adj, GWY_HSCALE_LINEAR);
     gtk_spin_button_set_digits(GTK_SPIN_BUTTON(spin), 3);
     gwy_table_hscale_set_sensitive(adj, args->result != GWY_MASKCOR_SCORE);
     g_signal_connect(adj, "value-changed",
