@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: mcrop.c 18960 2016-09-15 21:32:48Z yeti-dn $
+ *  @(#) $Id: mcrop.c 19948 2017-06-22 14:05:41Z yeti-dn $
  *  Copyright (C) 2010, David Necas (Yeti), Petr Klapetek, Daniil Bratashov
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net, dn2010@gmail.com
  *
@@ -64,7 +64,7 @@ static GwyModuleInfo module_info = {
     "2010",
 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, mcrop)
 
 static gboolean
 module_register(void)
@@ -168,11 +168,10 @@ static gboolean mcrop_dialog (GwyAppDataId *op1, GwyAppDataId *op2)
     g_object_set_data(G_OBJECT(chooser), "dialog", dialog);
     gwy_data_chooser_set_filter(GWY_DATA_CHOOSER(chooser),
                                 mcrop_data_filter, op1, NULL);
-    g_signal_connect(chooser, "changed",
-                     G_CALLBACK(mcrop_data_cb), op2);
+    g_signal_connect(chooser, "changed", G_CALLBACK(mcrop_data_cb), op2);
     mcrop_data_cb(GWY_DATA_CHOOSER(chooser), op2);
-    gwy_table_attach_hscale(table, 1, _("_Select second argument:"), NULL,
-                            GTK_OBJECT(chooser), GWY_HSCALE_WIDGET);
+    gwy_table_attach_adjbar(table, 0, _("_Select second argument:"), NULL,
+                            GTK_OBJECT(chooser), GWY_HSCALE_WIDGET_NO_EXPAND);
 
     gtk_widget_show_all(dialog);
 
