@@ -1,6 +1,6 @@
 /*
- *  @(#) $Id: measure_lattice.c 19044 2016-10-08 19:10:46Z yeti-dn $
- *  Copyright (C) 2015 David Necas (Yeti).
+ *  @(#) $Id: measure_lattice.c 20136 2017-08-02 11:21:20Z yeti-dn $
+ *  Copyright (C) 2015-2017 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -31,6 +31,7 @@
 #include <libprocess/correct.h>
 #include <libprocess/filters.h>
 #include <libprocess/grains.h>
+#include <libprocess/elliptic.h>
 #include <libprocess/inttrans.h>
 #include <libgwydgets/gwydataview.h>
 #include <libgwydgets/gwylayer-basic.h>
@@ -65,20 +66,12 @@ typedef enum {
     ZOOM_16 = 16
 } ZoomType;
 
-typedef struct {
-    gdouble max;
-    gdouble x;
-    gdouble y;
-    gdouble d;
-    gdouble q;
-    guint basecount;
-} MaximumInfo;
-
 typedef struct {
     ImageMode image_mode;
     SelectionMode selection_mode;
     ZoomType zoom_acf;
     ZoomType zoom_psdf;
+    gboolean fix_hacf;
     /* Cache */
     GType lattice_layer;
     GType point_layer;
@@ -98,6 +91,7 @@ typedef struct {
     GSList *zoom;
     GSList *image_mode;
     GSList *selection_mode;
+    GtkWidget *fix_hacf;
     GwySIValueFormat *vf;
     GwySIValueFormat *vfphi;
     GtkWidget *a1_x;
@@ -128,8 +122,8 @@ static void       lat_meas_copy         (LatMeasControls *controls);
 static void       lat_meas_save         (LatMeasControls *controls);
 static gchar*     format_report         (LatMeasControls *controls);
 static void       do_estimate           (LatMeasControls *controls);
+static void       refine                (LatMeasControls *controls);
 static void       init_selection        (LatMeasControls *controls);
-static gboolean   smart_init_selection  (LatMeasControls *controls);
 static void       set_selection         (LatMeasControls *controls,
                                          const gdouble *xy);
 static gboolean   get_selection         (LatMeasControls *controls,
@@ -140,18 +134,14 @@ static void       selection_mode_changed(GtkToggleButton *button,
                                          LatMeasControls *controls);
 static void       zoom_changed          (GtkRadioButton *button,
                                          LatMeasControls *controls);
+static void       fix_hacf_changed      (LatMeasControls *controls,
+                                         GtkToggleButton *toggle);
 static void       calculate_acf_full    (LatMeasControls *controls,
                                          GwyDataField *dfield);
 static void       calculate_psdf_full   (LatMeasControls *controls,
                                          GwyDataField *dfield);
 static void       calculate_zoomed_field(LatMeasControls *controls);
-static void       refine                (LatMeasControls *controls);
 static void       selection_changed     (LatMeasControls *controls);
-static void       find_maximum          (GwyDataField *dfield,
-                                         gdouble *x,
-                                         gdouble *y,
-                                         gint xwinsize,
-                                         gint ywinsize);
 static gboolean   transform_selection   (gdouble *xy);
 static void       invert_matrix         (gdouble *dest,
                                          const gdouble *src);
@@ -164,6 +154,7 @@ static void       sanitize_args         (LatMeasArgs *args);
 
 static const LatMeasArgs lat_meas_defaults = {
     IMAGE_DATA, SELECTION_LATTICE, ZOOM_1, ZOOM_1,
+    FALSE,
     /* Cache */
     0, 0, 0, 0,
 };
@@ -173,12 +164,12 @@ static GwyModuleInfo module_info = {
     &module_register,
     N_("Measures parameters of two-dimensional lattices."),
     "Yeti <yeti@gwyddion.net>",
-    "1.0",
+    "2.0",
     "David Nečas (Yeti)",
     "2015",
 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, measure_lattice)
 
 static gboolean
 module_register(void)
@@ -236,7 +227,6 @@ lat_meas_dialog(LatMeasArgs *args,
     GwyPixmapLayer *layer;
     GwyVectorLayer *vlayer;
     GwySelection *selection;
-    GwySIUnit *unitphi;
     gchar selkey[40];
 
     gwy_clear(&controls, 1);
@@ -311,7 +301,7 @@ lat_meas_dialog(LatMeasArgs *args,
 
     gtk_container_add(GTK_CONTAINER(alignment), controls.view);
 
-    table = GTK_TABLE(gtk_table_new(10, 4, FALSE));
+    table = GTK_TABLE(gtk_table_new(11, 4, FALSE));
     gtk_table_set_row_spacings(table, 2);
     gtk_table_set_col_spacings(table, 6);
     gtk_container_set_border_width(GTK_CONTAINER(table), 4);
@@ -335,7 +325,7 @@ lat_meas_dialog(LatMeasArgs *args,
 
     hbox2 = gtk_hbox_new(FALSE, 8);
     gtk_table_attach(GTK_TABLE(table), hbox2, 0, 4, row, row+1,
-                     GTK_EXPAND | GTK_FILL, 0, 0, 0);
+                     GTK_FILL, 0, 0, 0);
     label = controls.zoom_label = gtk_label_new(_("Zoom:"));
     gtk_box_pack_start(GTK_BOX(hbox2), label, FALSE, FALSE, 0);
 
@@ -352,6 +342,16 @@ lat_meas_dialog(LatMeasArgs *args,
     }
     row++;
 
+    controls.fix_hacf
+        = gtk_check_button_new_with_mnemonic(_("Interpolate _horizontal ACF"));
+    gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(controls.fix_hacf),
+                                 args->fix_hacf);
+    gtk_table_attach(table, controls.fix_hacf,
+                     0, 2, row, row+1, GTK_FILL, 0, 0, 0);
+    g_signal_connect_swapped(controls.fix_hacf, "toggled",
+                             G_CALLBACK(fix_hacf_changed), &controls);
+    row++;
+
     gtk_table_set_row_spacing(table, row-1, 8);
     label = gtk_label_new(_("Show lattice as:"));
     gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
@@ -378,16 +378,10 @@ lat_meas_dialog(LatMeasArgs *args,
                                              GWY_SI_UNIT_FORMAT_MARKUP, NULL);
     controls.vf->precision += 2;
 
-    unitphi = gwy_si_unit_new("deg");
-    controls.vfphi
-        = gwy_si_unit_get_format_with_resolution(unitphi,
-                                                 GWY_SI_UNIT_FORMAT_MARKUP,
-                                                 180.0, 0.01, NULL);
-    g_object_unref(unitphi);
+    controls.vfphi = gwy_si_unit_value_format_new(G_PI/180.0, 2, _("deg"));
 
     lattable = make_lattice_table(&controls);
-    gtk_table_attach(table, lattable,
-                     0, 4, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
+    gtk_table_attach(table, lattable, 0, 4, row, row+1, GTK_FILL, 0, 0, 0);
     row++;
 
     hbox = gtk_hbox_new(FALSE, 0);
@@ -407,9 +401,8 @@ lat_meas_dialog(LatMeasArgs *args,
         if (gwy_selection_get_object(selection, 0, controls.xy))
             set_selection(&controls, controls.xy);
     }
-    else {
+    else
         do_estimate(&controls);
-    }
 
     gwy_radio_buttons_set_current(controls.selection_mode, selection_mode);
     gwy_radio_buttons_set_current(controls.image_mode, image_mode);
@@ -646,7 +639,7 @@ format_report(LatMeasControls *controls)
                         vf->precision, h/vf->magnitude, vf->units);
         g_ptr_array_add(report, g_strdup(str->str));
 
-        phi = 180.0/G_PI*atan2(-xy[2*i + 1], xy[2*i + 0]);
+        phi = atan2(-xy[2*i + 1], xy[2*i + 0]);
         g_string_printf(str, _("Angle %d:"), i+1);
         g_ptr_array_add(report, g_strdup(str->str));
         g_string_printf(str, "%.*f %s",
@@ -660,7 +653,6 @@ format_report(LatMeasControls *controls)
     phi = atan2(-xy[3], xy[2]) - atan2(-xy[1], xy[0]);
     if (phi < 0.0)
         phi += 2.0*G_PI;
-    phi *= 180.0/G_PI;
 
     g_string_assign(str, _("Angle:"));
     g_ptr_array_add(report, g_strdup(str->str));
@@ -697,24 +689,53 @@ format_report(LatMeasControls *controls)
     return g_string_free(str, FALSE);
 }
 
+static GwyDataField*
+get_full_dfield_for_mode(LatMeasControls *controls)
+{
+    LatMeasArgs *args = controls->args;
+    GwyDataField *dfield;
+    GwyDataLine *hacf;
+    const gchar *key;
+
+    if (args->image_mode == IMAGE_PSDF)
+        key = "/3/data/full";
+    else
+        key = "/2/data/full";
+
+    dfield = GWY_DATA_FIELD(gwy_container_get_object_by_name(controls->mydata,
+                                                             key));
+
+    if (args->image_mode == IMAGE_ACF) {
+        if (args->fix_hacf)
+            key = "/2/hacf-fixed";
+        else
+            key = "/2/hacf";
+
+        hacf = GWY_DATA_LINE(gwy_container_get_object_by_name(controls->mydata,
+                                                              key));
+        gwy_data_field_set_row(dfield, hacf, gwy_data_field_get_yres(dfield)/2);
+    }
+
+    return dfield;
+}
+
 static void
 do_estimate(LatMeasControls *controls)
 {
-    if (smart_init_selection(controls)) {
-        GwyDataField *dfield;
-        gdouble dh;
+    GwyDataField *dfield;
+    gboolean ok;
 
-        refine(controls);
-        /* Check if refine() did not produce two of the same vector which can
-         * sometime happen with very skewed patterns. */
-        dfield = gwy_container_get_object_by_name(controls->mydata, "/0/data");
-        dh = hypot(gwy_data_field_get_xmeasure(dfield),
-                   gwy_data_field_get_ymeasure(dfield));
-        if (hypot(controls->xy[0] - controls->xy[2],
-                  controls->xy[1] - controls->xy[3]) > 1.8*dh)
-            return;
-    }
-    init_selection(controls);
+    dfield = get_full_dfield_for_mode(controls);
+    gwy_clear(controls->xy, 4);
+    if (controls->args->image_mode == IMAGE_PSDF)
+        ok = gwy_data_field_measure_lattice_psdf(dfield, controls->xy);
+    else
+        ok = gwy_data_field_measure_lattice_acf(dfield, controls->xy);
+
+    if (ok)
+        set_selection(controls, controls->xy);
+    else
+        init_selection(controls);
 }
 
 static void
@@ -730,207 +751,6 @@ init_selection(LatMeasControls *controls)
     set_selection(controls, controls->xy);
 }
 
-static gint
-compare_maxima(gconstpointer pa, gconstpointer pb)
-{
-    const MaximumInfo *a = (const MaximumInfo*)pa;
-    const MaximumInfo *b = (const MaximumInfo*)pb;
-
-    if (a->basecount*a->q > b->basecount*b->q)
-        return -1;
-    if (a->basecount*a->q < b->basecount*b->q)
-        return 1;
-
-    if (a->q > b->q)
-        return -1;
-    if (a->q < b->q)
-        return 1;
-
-    /* Ensure comparison stability.  This should play no role in significance
-     * sorting. */
-    if (a->y < b->y)
-        return -1;
-    if (a->y > b->y)
-        return 1;
-    if (a->x < b->x)
-        return -1;
-    if (a->x > b->x)
-        return 1;
-    return 0;
-}
-
-/* Intended for ACF (or PSDF, but that requires transformation), not the
- * original data. */
-static gboolean
-smart_init_selection(LatMeasControls *controls)
-{
-    enum { nquantities = 3 };
-    GwyGrainQuantity quantities[nquantities] = {
-        GWY_GRAIN_VALUE_MAXIMUM,
-        GWY_GRAIN_VALUE_CENTER_X,
-        GWY_GRAIN_VALUE_CENTER_Y,
-    };
-    GwyDataField *dfield, *smoothed, *mask;
-    gdouble *values[nquantities];
-    MaximumInfo *maxima;
-    gint *grains;
-    guint i, j, k, ngrains;
-    gboolean ok = FALSE;
-    gdouble dh, cphi, sphi;
-
-    dfield = gwy_container_get_object_by_name(controls->mydata, "/2/data/full");
-    smoothed = gwy_data_field_duplicate(dfield);
-    mask = gwy_data_field_new_alike(dfield, FALSE);
-
-    /* Mark local maxima. */
-    gwy_data_field_filter_gaussian(smoothed, 0.5);
-    gwy_data_field_mark_extrema(smoothed, mask, TRUE);
-    grains = g_new0(gint, dfield->xres*dfield->yres);
-    ngrains = gwy_data_field_number_grains(mask, grains);
-    GWY_OBJECT_UNREF(mask);
-
-    /* Find the position and value of each. */
-    for (i = 0; i < nquantities; i++)
-        values[i] = g_new(gdouble, ngrains+1);
-
-    gwy_data_field_grains_get_quantities(smoothed, values,
-                                         quantities, nquantities,
-                                         ngrains, grains);
-    GWY_OBJECT_UNREF(smoothed);
-
-    maxima = g_new(MaximumInfo, ngrains);
-    dh = hypot(gwy_data_field_get_xmeasure(dfield),
-               gwy_data_field_get_ymeasure(dfield));
-    for (i = 0; i < ngrains; i++) {
-        maxima[i].max = values[0][i+1];
-        maxima[i].x = values[1][i+1];
-        maxima[i].y = values[2][i+1];
-        maxima[i].d = hypot(maxima[i].x, maxima[i].y);
-        maxima[i].q = maxima[i].max/(maxima[i].d + 5.0*dh);
-        maxima[i].basecount = 0;
-    }
-    for (i = 0; i < nquantities; i++)
-        g_free(values[i]);
-
-    /* Remove the central peak, i.e. anything too close to the centre */
-    i = j = 0;
-    while (i < ngrains) {
-        gdouble d = maxima[i].d;
-        maxima[j] = maxima[i];
-        if (d >= 1.8*dh)
-            j++;
-        i++;
-    }
-    ngrains = j;
-
-    if (ngrains < 10) {
-        gwy_debug("Too few maxima (after centre removal): %d.", ngrains);
-        g_free(maxima);
-        return FALSE;
-    }
-
-    qsort(maxima, ngrains, sizeof(MaximumInfo), compare_maxima);
-#ifdef DEBUG
-    for (i = 0; i < ngrains; i++) {
-        gwy_debug("[%u] (%g, %g) %g :: %g",
-                  i, maxima[i].x, maxima[i].y, maxima[i].max, maxima[i].q);
-    }
-#endif
-
-    /* Remove anything with direction opposite to the first vector.  But we
-     * must carefully accept ortohogonal vectors.  This is just a half-plane
-     * selection though it influences the preferred vectors, of course. */
-    gwy_debug("Base-plane selector [%u] (%g, %g) %g",
-              0, maxima[0].x, maxima[0].y, maxima[0].max);
-    cphi = maxima[0].x/maxima[0].d;
-    sphi = maxima[0].y/maxima[0].d;
-    i = j = 1;
-    while (i < ngrains) {
-        gdouble x = cphi*maxima[i].x + sphi*maxima[i].y,
-                y = cphi*maxima[i].y - sphi*maxima[i].x;
-        maxima[j] = maxima[i];
-        if (x > 1e-9*dh || (x > -1e-9*dh && y > 1e-9*dh))
-            j++;
-        i++;
-    }
-    ngrains = j;
-
-    if (ngrains < 10) {
-        gwy_debug("Too few maxima (after half-plane removal): %d.", ngrains);
-        g_free(maxima);
-        return FALSE;
-    }
-
-    /* Locate the most important maxima. */
-    ngrains = MIN(ngrains, 12);
-    for (i = 0; i < ngrains; i++) {
-        for (j = i+1; j < ngrains; j++) {
-            gdouble x = maxima[i].x + maxima[j].x;
-            gdouble y = maxima[i].y + maxima[j].y;
-            for (k = 0; k < ngrains; k++) {
-                if (fabs(maxima[k].x - x) < dh && fabs(maxima[k].y - y) < dh) {
-                    maxima[i].basecount++;
-                    maxima[j].basecount++;
-                }
-            }
-        }
-    }
-    qsort(maxima, ngrains, sizeof(MaximumInfo), compare_maxima);
-#ifdef DEBUG
-    for (i = 0; i < ngrains; i++) {
-        gwy_debug("[%u] (%g, %g) %g #%u",
-                  i, maxima[i].x, maxima[i].y, maxima[i].max,
-                  maxima[i].basecount);
-    }
-#endif
-
-    if (maxima[1].basecount >= 3) {
-        gdouble xy[4];
-
-        xy[0] = maxima[0].x;
-        xy[1] = maxima[0].y;
-        dh = maxima[0].d;
-        /* Exclude maxima that appear to be collinear with the first one,
-         * otherwise take the next one with the highest basecount. */
-        for (i = 1; i < ngrains; i++) {
-            for (k = 2; k < 5; k++) {
-                if (fabs(maxima[i].x/k - xy[0]) < 0.2*dh
-                    && fabs(maxima[i].y/k - xy[1]) < 0.2*dh) {
-                    gwy_debug("Excluding #%u for collinearity (%u).", i, k);
-                    break;
-                }
-            }
-            if (k == 5) {
-                xy[2] = maxima[i].x;
-                xy[3] = maxima[i].y;
-                ok = TRUE;
-                break;
-            }
-        }
-
-        if (ok) {
-            gdouble phi;
-
-            /* Try to choose some sensible vectors among the equivalent
-             * choices. */
-            for (i = 0; i < 4; i++)
-                xy[i] = -xy[i];
-
-            phi = fmod(atan2(xy[1], xy[0]) + 4.0*G_PI - atan2(xy[3], xy[2]),
-                       2.0*G_PI);
-            if (phi > G_PI) {
-                GWY_SWAP(gdouble, xy[0], xy[2]);
-                GWY_SWAP(gdouble, xy[1], xy[3]);
-            }
-            set_selection(controls, xy);
-        }
-    }
-
-    g_free(maxima);
-
-    return ok;
-}
-
 static void
 set_selection(LatMeasControls *controls, const gdouble *xy)
 {
@@ -1060,7 +880,7 @@ image_mode_changed(G_GNUC_UNUSED GtkToggleButton *button,
         if (mode == IMAGE_ACF)
             gwy_container_set_enum_by_name(controls->mydata,
                                            "/1/base/range-type",
-                                           GWY_LAYER_BASIC_RANGE_FULL);
+                                           GWY_LAYER_BASIC_RANGE_AUTO);
         else
             gwy_container_set_enum_by_name(controls->mydata,
                                            "/1/base/range-type",
@@ -1162,23 +982,56 @@ zoom_changed(GtkRadioButton *button,
     set_selection(controls, controls->xy);
 }
 
+static void
+fix_hacf_changed(LatMeasControls *controls,
+                 GtkToggleButton *toggle)
+{
+    LatMeasArgs *args = controls->args;
+
+    args->fix_hacf = gtk_toggle_button_get_active(toggle);
+    if (args->image_mode == IMAGE_ACF)
+        calculate_zoomed_field(controls);
+}
+
 static void
 calculate_acf_full(LatMeasControls *controls,
                    GwyDataField *dfield)
 {
-    GwyDataField *acf;
+    GwyDataField *acf, *mid, *mask;
+    GwyDataLine *hacf;
     guint acfwidth, acfheight;
 
     dfield = gwy_data_field_duplicate(dfield);
     gwy_data_field_add(dfield, -gwy_data_field_get_avg(dfield));
     acf = gwy_data_field_new_alike(dfield, FALSE);
-    acfwidth = MIN(MAX(3*dfield->xres/8, 64), dfield->xres/2);
-    acfheight = MIN(MAX(3*dfield->yres/8, 64), dfield->yres/2);
+    acfwidth = dfield->xres/2;
+    acfheight = dfield->yres/2;
     gwy_data_field_area_2dacf(dfield, acf, 0, 0, dfield->xres, dfield->yres,
                               acfwidth, acfheight);
     g_object_unref(dfield);
     gwy_container_set_object_by_name(controls->mydata, "/2/data/full", acf);
     g_object_unref(acf);
+
+    /* Remember the middle row as we may replace it. */
+    acfheight = gwy_data_field_get_yres(acf);
+    acfwidth = gwy_data_field_get_xres(acf);
+    hacf = gwy_data_line_new(acfwidth, 1.0, FALSE);
+    gwy_data_field_get_row(acf, hacf, acfheight/2);
+    gwy_container_set_object_by_name(controls->mydata, "/2/hacf", hacf);
+    g_object_unref(hacf);
+
+    /* Remember interpolated middle row. */
+    mid = gwy_data_field_area_extract(acf, 0, acfheight/2-1, acfwidth, 3);
+    mask = gwy_data_field_new(acfwidth, 3, acfwidth, 3, TRUE);
+    gwy_data_field_area_fill(mask, 0, 1, acfwidth, 1, 1.0);
+    gwy_data_field_set_val(mask, acfwidth/2, 1, 0.0);
+    gwy_data_field_laplace_solve(mid, mask, -1, 1.0);
+    hacf = gwy_data_line_new(acfwidth, 1.0, FALSE);
+    gwy_data_field_get_row(mid, hacf, 1);
+    gwy_container_set_object_by_name(controls->mydata, "/2/hacf-fixed", hacf);
+    g_object_unref(hacf);
+    g_object_unref(mask);
+    g_object_unref(mid);
 }
 
 static gint
@@ -1229,29 +1082,25 @@ calculate_zoomed_field(LatMeasControls *controls)
     LatMeasArgs *args = controls->args;
     ZoomType zoom;
     GwyDataField *zoomed;
-    const gchar *key = NULL;
+    guint xres, yres, width, height;
 
-    if (args->image_mode == IMAGE_ACF) {
+    if (args->image_mode == IMAGE_ACF)
         zoom = args->zoom_acf;
-        key = "/2/data/full";
-    }
-    else if (args->image_mode == IMAGE_PSDF) {
+    else if (args->image_mode == IMAGE_PSDF)
         zoom = args->zoom_psdf;
-        key = "/3/data/full";
-    }
     else
         return;
 
-    zoomed = GWY_DATA_FIELD(gwy_container_get_object_by_name(controls->mydata,
-                                                             key));
+    zoomed = get_full_dfield_for_mode(controls);
+    xres = gwy_data_field_get_xres(zoomed);
+    yres = gwy_data_field_get_yres(zoomed);
+
     if (zoom == ZOOM_1) {
         g_object_ref(zoomed);
     }
     else {
-        guint xres = zoomed->xres;
-        guint yres = zoomed->yres;
-        guint width = (xres/zoom) | 1;
-        guint height = (yres/zoom) | 1;
+        width = (xres/zoom) | 1;
+        height = (yres/zoom) | 1;
 
         if (width < 17)
             width = MAX(width, MIN(17, xres));
@@ -1274,45 +1123,20 @@ static void
 refine(LatMeasControls *controls)
 {
     GwyDataField *dfield;
-    gint xwinsize, ywinsize;
-    const gchar *key = NULL;
     gdouble xy[4];
+    gboolean ok;
 
     if (!get_selection(controls, xy))
         return;
 
-    if (controls->args->image_mode == IMAGE_PSDF) {
-        /* For refine we need selection coordinates for the visible image
-         * which is PSDF, not the real-space lattice. */
-        transform_selection(xy);
-        key = "/3/data/full";
-    }
-    else
-        key = "/2/data/full";
-
-    dfield = GWY_DATA_FIELD(gwy_container_get_object_by_name(controls->mydata,
-                                                             key));
-    xwinsize = (gint)(0.32*MAX(fabs(xy[0]), fabs(xy[2]))
-                      /gwy_data_field_get_xmeasure(dfield) + 0.5);
-    ywinsize = (gint)(0.32*MAX(fabs(xy[1]), fabs(xy[3]))
-                      /gwy_data_field_get_ymeasure(dfield) + 0.5);
-    gwy_debug("window size: %dx%d", xwinsize, ywinsize);
-
-    xy[0] = (xy[0] - dfield->xoff)/gwy_data_field_get_xmeasure(dfield);
-    xy[1] = (xy[1] - dfield->yoff)/gwy_data_field_get_ymeasure(dfield);
-    xy[2] = (xy[2] - dfield->xoff)/gwy_data_field_get_xmeasure(dfield);
-    xy[3] = (xy[3] - dfield->yoff)/gwy_data_field_get_ymeasure(dfield);
-    find_maximum(dfield, xy + 0, xy + 1, xwinsize, ywinsize);
-    find_maximum(dfield, xy + 2, xy + 3, xwinsize, ywinsize);
-    xy[0] = (xy[0] + 0.5)*gwy_data_field_get_xmeasure(dfield) + dfield->xoff;
-    xy[1] = (xy[1] + 0.5)*gwy_data_field_get_ymeasure(dfield) + dfield->yoff;
-    xy[2] = (xy[2] + 0.5)*gwy_data_field_get_xmeasure(dfield) + dfield->xoff;
-    xy[3] = (xy[3] + 0.5)*gwy_data_field_get_ymeasure(dfield) + dfield->yoff;
-
+    dfield = get_full_dfield_for_mode(controls);
     if (controls->args->image_mode == IMAGE_PSDF)
-        transform_selection(xy);
+        ok = gwy_data_field_measure_lattice_psdf(dfield, xy);
+    else
+        ok = gwy_data_field_measure_lattice_acf(dfield, xy);
 
-    set_selection(controls, xy);
+    if (ok)
+        set_selection(controls, xy);
 }
 
 static void
@@ -1339,7 +1163,7 @@ selection_changed(LatMeasControls *controls)
 
     vf = controls->vfphi;
     phi1 = atan2(-xy[1], xy[0]);
-    g_string_printf(str, "%.*f", vf->precision, 180.0/G_PI*phi1/vf->magnitude);
+    g_string_printf(str, "%.*f", vf->precision, phi1/vf->magnitude);
     gtk_label_set_text(GTK_LABEL(controls->a1_phi), str->str);
 
     vf = controls->vf;
@@ -1355,65 +1179,18 @@ selection_changed(LatMeasControls *controls)
 
     vf = controls->vfphi;
     phi2 = atan2(-xy[3], xy[2]);
-    g_string_printf(str, "%.*f", vf->precision, 180.0/G_PI*phi2/vf->magnitude);
+    g_string_printf(str, "%.*f", vf->precision, phi2/vf->magnitude);
     gtk_label_set_text(GTK_LABEL(controls->a2_phi), str->str);
 
     phi = phi2 - phi1;
     if (phi < 0.0)
         phi += 2.0*G_PI;
-    g_string_printf(str, "%.*f", vf->precision, 180.0/G_PI*phi/vf->magnitude);
+    g_string_printf(str, "%.*f", vf->precision, phi/vf->magnitude);
     gtk_label_set_text(GTK_LABEL(controls->phi), str->str);
 
     g_string_free(str, TRUE);
 }
 
-static void
-find_maximum(GwyDataField *dfield,
-             gdouble *x, gdouble *y,
-             gint xwinsize, gint ywinsize)
-{
-    gint xj = (gint)*x, yi = (gint)*y;
-    gdouble v, max = -G_MAXDOUBLE;
-    gint mi = yi, mj = xj, i, j;
-    gint xres = dfield->xres, yres = dfield->yres;
-    const gdouble *d = dfield->data;
-    gdouble z[9];
-
-    gwy_debug("searching from: %g, %g", *x, *y);
-    for (i = -ywinsize; i <= ywinsize; i++) {
-        if (i + yi < 0 || i + yi > yres-1)
-            continue;
-        for (j = -xwinsize; j <= xwinsize; j++) {
-            if (j + xj < 0 || j + xj > xres-1)
-                continue;
-
-            v = d[(i + yi)*xres + (j + xj)];
-            if (v > max) {
-                max = v;
-                mi = i + yi;
-                mj = j + xj;
-            }
-        }
-    }
-    gwy_debug("pixel maximum at: %d, %d", *mj, *mi);
-
-    /* Don't try any sub-pixel refinement if it's on the edge. */
-    if (mi >= 1 && mi+1 <= yres-1 && mj >= 1 && mj+1 <= xres-1) {
-        for (i = -1; i <= 1; i++) {
-            for (j = -1; j <= 1; j++)
-                z[3*(i + 1) + (j + 1)] = d[(mi + i)*xres + (mj + j)];
-        }
-        gwy_math_refine_maximum(z, x, y);
-        gwy_debug("refinement by (%g, %g)", *x, *y);
-    }
-    else {
-        *x = *y = 0.0;
-    }
-
-    *x += mj;
-    *y += mi;
-}
-
 static gboolean
 transform_selection(gdouble *xy)
 {
@@ -1454,6 +1231,7 @@ matrix_det(const gdouble *m)
     return m[0]*m[3] - m[1]*m[2];
 }
 
+static const gchar fix_hacf_key[]       = "/module/measure_lattice/fix_hacf";
 static const gchar image_mode_key[]     = "/module/measure_lattice/image_mode";
 static const gchar selection_mode_key[] = "/module/measure_lattice/selection_mode";
 static const gchar zoom_acf_key[]       = "/module/measure_lattice/zoom_acf";
@@ -1464,6 +1242,7 @@ sanitize_args(LatMeasArgs *args)
 {
     args->selection_mode = MIN(args->selection_mode, SELECTION_NMODES-1);
     args->image_mode = MIN(args->image_mode, IMAGE_NMODES-1);
+    args->fix_hacf = !!args->fix_hacf;
     if (args->zoom_acf != ZOOM_1
         && args->zoom_acf != ZOOM_4
         && args->zoom_acf != ZOOM_16)
@@ -1485,6 +1264,7 @@ load_args(GwyContainer *container, LatMeasArgs *args)
                                    &args->selection_mode);
     gwy_container_gis_enum_by_name(container, zoom_acf_key, &args->zoom_acf);
     gwy_container_gis_enum_by_name(container, zoom_psdf_key, &args->zoom_psdf);
+    gwy_container_gis_boolean_by_name(container, fix_hacf_key, &args->fix_hacf);
     sanitize_args(args);
 }
 
@@ -1497,6 +1277,7 @@ save_args(GwyContainer *container, LatMeasArgs *args)
                                    args->selection_mode);
     gwy_container_set_enum_by_name(container, zoom_acf_key, args->zoom_acf);
     gwy_container_set_enum_by_name(container, zoom_psdf_key, args->zoom_psdf);
+    gwy_container_set_boolean_by_name(container, fix_hacf_key, args->fix_hacf);
 }
 
 /* vim: set cin et ts=4 sw=4 cino=>1s,e0,n0,f0,{0,}0,^0,\:1s,=0,g1s,h0,t0,+1s,c3,(0,u0 : */
