@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: merge.c 19071 2016-10-14 09:02:41Z yeti-dn $
+ *  @(#) $Id: merge.c 19948 2017-06-22 14:05:41Z yeti-dn $
  *  Copyright (C) 2004,2014-2016 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -219,7 +219,7 @@ static GwyModuleInfo module_info = {
     "2006",
 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, merge)
 
 static gboolean
 module_register(void)
@@ -282,7 +282,7 @@ merge_dialog(MergeArgs *args)
     gtk_dialog_set_default_response(GTK_DIALOG(dialog), GTK_RESPONSE_OK);
     gwy_help_add_to_proc_dialog(GTK_DIALOG(dialog), GWY_HELP_DEFAULT);
 
-    table = gtk_table_new(6, 4, FALSE);
+    table = gtk_table_new(6, 3, FALSE);
     gtk_table_set_row_spacings(GTK_TABLE(table), 2);
     gtk_table_set_col_spacings(GTK_TABLE(table), 6);
     gtk_container_set_border_width(GTK_CONTAINER(table), 4);
@@ -299,8 +299,8 @@ merge_dialog(MergeArgs *args)
     g_signal_connect_swapped(chooser, "changed",
                              G_CALLBACK(merge_data_changed), &controls);
     merge_data_changed(&controls, chooser);
-    gwy_table_attach_hscale(table, row, _("_Merge with:"), NULL,
-                            GTK_OBJECT(chooser), GWY_HSCALE_WIDGET);
+    gwy_table_attach_adjbar(table, row, _("_Merge with:"), NULL,
+                            GTK_OBJECT(chooser), GWY_HSCALE_WIDGET_NO_EXPAND);
     row++;
 
     /* Parameters */
@@ -308,15 +308,15 @@ merge_dialog(MergeArgs *args)
                                    G_CALLBACK(merge_direction_changed),
                                    &controls,
                                    args->direction, TRUE);
-    gwy_table_attach_hscale(table, row, _("_Put second operand:"), NULL,
-                            GTK_OBJECT(combo), GWY_HSCALE_WIDGET);
+    gwy_table_attach_adjbar(table, row, _("_Put second operand:"), NULL,
+                            GTK_OBJECT(combo), GWY_HSCALE_WIDGET_NO_EXPAND);
     row++;
 
     combo = gwy_enum_combo_box_new(modes, G_N_ELEMENTS(modes),
                                    G_CALLBACK(merge_mode_changed), &controls,
                                    args->mode, TRUE);
-    gwy_table_attach_hscale(table, row, _("_Align second operand:"), NULL,
-                            GTK_OBJECT(combo), GWY_HSCALE_WIDGET);
+    gwy_table_attach_adjbar(table, row, _("_Align second operand:"), NULL,
+                            GTK_OBJECT(combo), GWY_HSCALE_WIDGET_NO_EXPAND);
     row++;
 
     combo = gwy_enum_combo_box_new(boundaries, G_N_ELEMENTS(boundaries),
@@ -324,8 +324,8 @@ merge_dialog(MergeArgs *args)
                                    &controls,
                                    args->boundary, TRUE);
     controls.boundary = combo;
-    gwy_table_attach_hscale(table, row, _("_Boundary treatment:"), NULL,
-                            GTK_OBJECT(combo), GWY_HSCALE_WIDGET);
+    gwy_table_attach_adjbar(table, row, _("_Boundary treatment:"), NULL,
+                            GTK_OBJECT(combo), GWY_HSCALE_WIDGET_NO_EXPAND);
     row++;
 
     check = gtk_check_button_new_with_mnemonic(_("Crop result to _avoid "
@@ -334,7 +334,7 @@ merge_dialog(MergeArgs *args)
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check),
                                  args->crop_to_rectangle);
     gtk_table_attach(GTK_TABLE(table), check,
-                     0, 3, row, row+1, GTK_FILL, 0, 0, 0);
+                     0, 2, row, row+1, GTK_FILL, 0, 0, 0);
     g_signal_connect_swapped(check, "toggled",
                              G_CALLBACK(crop_to_rectangle_changed), &controls);
     row++;
@@ -343,7 +343,7 @@ merge_dialog(MergeArgs *args)
     controls.create_mask = check;
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check), args->create_mask);
     gtk_table_attach(GTK_TABLE(table), check,
-                     0, 3, row, row+1, GTK_FILL, 0, 0, 0);
+                     0, 2, row, row+1, GTK_FILL, 0, 0, 0);
     g_signal_connect_swapped(check, "toggled",
                              G_CALLBACK(create_mask_changed), &controls);
     row++;
