@@ -1,4 +1,4 @@
-/*  @(#) $Id: nanoindent_adjust.c 18158 2016-01-22 19:36:39Z yeti-dn $
+/*  @(#) $Id: nanoindent_adjust.c 19948 2017-06-22 14:05:41Z yeti-dn $
  *  Copyright (C) 2004 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -93,7 +93,7 @@ static GwyModuleInfo module_info = {
     "2004",
 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, nanoindent_adjust)
 
 static gboolean
 module_register(void)
@@ -226,8 +226,9 @@ nanoindent_adjust_window_construct(NanoindentAdjustArgs *args)
         = gwy_enum_combo_box_new(gwy_interpolation_type_get_enum(), -1,
                                  G_CALLBACK(interp_changed_cb), args,
                                  args->interp, TRUE);
-    gwy_table_attach_hscale(table, 5, _("_Interpolation type:"), NULL,
-                            GTK_OBJECT(controls.interp), GWY_HSCALE_WIDGET);
+    gwy_table_attach_adjbar(table, 5, _("_Interpolation type:"), NULL,
+                            GTK_OBJECT(controls.interp),
+                            GWY_HSCALE_WIDGET_NO_EXPAND);
 
 
     gtk_widget_show_all(dialog);
