@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: neural.c 19044 2016-10-08 19:10:46Z yeti-dn $
+ *  @(#) $Id: neural.c 19948 2017-06-22 14:05:41Z yeti-dn $
  *  Copyright (C) 2012 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -203,12 +203,12 @@ static GwyModuleInfo module_info = {
     &module_register,
     N_("Neural network SPM data processing"),
     "Petr Klapetek <klapetek@gwyddion.net>",
-    "2.2",
+    "2.3",
     "David Nečas (Yeti) & Petr Klapetek",
     "2012",
 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, neural)
 
 static gboolean
 module_register(void)
@@ -455,7 +455,7 @@ neural_train_dialog(NeuralTrainArgs *args)
     NeuralTrainControls controls;
     NeuralNetworkData *nndata;
     GwyContainer *mydata;
-    GtkWidget *dialog, *table, *label, *spin, *hbox, *bbox, *vbox, *notebook,
+    GtkWidget *dialog, *table, *label, *hbox, *bbox, *vbox, *notebook,
               *scroll, *button;
     GtkTreeModel *filtermodel;
     GtkTreeSelection *tselect;
@@ -497,6 +497,7 @@ neural_train_dialog(NeuralTrainArgs *args)
                  NULL);
     controls.errgraph = gwy_graph_new(controls.gmodel);
     gtk_widget_set_size_request(controls.errgraph, -1, 200);
+    gwy_graph_enable_user_input(GWY_GRAPH(controls.errgraph), FALSE);
     gtk_box_pack_start(GTK_BOX(vbox), controls.errgraph, TRUE, TRUE, 0);
 
     gcmodel = gwy_graph_curve_model_new();
@@ -508,7 +509,7 @@ neural_train_dialog(NeuralTrainArgs *args)
     gtk_box_pack_start(GTK_BOX(hbox), notebook, TRUE, TRUE, 4);
 
     /* Training */
-    table = gtk_table_new(14, 4, FALSE);
+    table = gtk_table_new(14, 3, FALSE);
     gtk_container_set_border_width(GTK_CONTAINER(table), 4);
     gtk_table_set_row_spacings(GTK_TABLE(table), 2);
     gtk_table_set_col_spacings(GTK_TABLE(table), 6);
@@ -517,8 +518,9 @@ neural_train_dialog(NeuralTrainArgs *args)
     row = 0;
 
     controls.tmodel = gwy_data_chooser_new_channels();
-    gwy_table_attach_hscale(table, row, _("_Model:"), NULL,
-                            GTK_OBJECT(controls.tmodel), GWY_HSCALE_WIDGET);
+    gwy_table_attach_adjbar(table, row, _("_Model:"), NULL,
+                            GTK_OBJECT(controls.tmodel),
+                            GWY_HSCALE_WIDGET_NO_EXPAND);
     gwy_data_chooser_set_active_id(GWY_DATA_CHOOSER(controls.tmodel),
                                    &args->tmodel);
     g_object_set_data(G_OBJECT(controls.tmodel), "id", (gpointer)"model");
@@ -527,8 +529,9 @@ neural_train_dialog(NeuralTrainArgs *args)
     row++;
 
     controls.tsignal = gwy_data_chooser_new_channels();
-    gwy_table_attach_hscale(table, row, _("_Signal:"), NULL,
-                            GTK_OBJECT(controls.tsignal), GWY_HSCALE_WIDGET);
+    gwy_table_attach_adjbar(table, row, _("_Signal:"), NULL,
+                            GTK_OBJECT(controls.tsignal),
+                            GWY_HSCALE_WIDGET_NO_EXPAND);
     gwy_data_chooser_set_active_id(GWY_DATA_CHOOSER(controls.tsignal),
                                    &args->tsignal);
     g_object_set_data(G_OBJECT(controls.tsignal), "id", (gpointer)"signal");
@@ -538,8 +541,9 @@ neural_train_dialog(NeuralTrainArgs *args)
 
     controls.trainsteps = gtk_adjustment_new(args->trainsteps,
                                              0, 10000, 1, 100, 0);
-    gwy_table_attach_hscale(table, row, _("Training ste_ps:"), NULL,
-                            GTK_OBJECT(controls.trainsteps), GWY_HSCALE_SQRT);
+    gwy_table_attach_adjbar(table, row, _("Training ste_ps:"), NULL,
+                            GTK_OBJECT(controls.trainsteps),
+                            GWY_HSCALE_SQRT | GWY_HSCALE_SNAP);
     g_signal_connect_swapped(controls.trainsteps, "value-changed",
                              G_CALLBACK(train_steps_changed), &controls);
     row++;
@@ -570,7 +574,7 @@ neural_train_dialog(NeuralTrainArgs *args)
     bbox = gtk_hbutton_box_new();
     gtk_button_box_set_layout(GTK_BUTTON_BOX(bbox), GTK_BUTTONBOX_START);
     gtk_table_attach(GTK_TABLE(table), bbox,
-                     0, 3, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
+                     0, 2, row, row+1, GTK_FILL, 0, 0, 0);
 
     controls.train = gtk_button_new_with_mnemonic(gwy_sgettext("verb|_Train"));
     gtk_container_add(GTK_CONTAINER(bbox), controls.train);
@@ -592,7 +596,7 @@ neural_train_dialog(NeuralTrainArgs *args)
     gtk_table_set_row_spacing(GTK_TABLE(table), row-1, 8);
     controls.masking_label = label = gwy_label_new_header(_("Masking Mode"));
     gtk_table_attach(GTK_TABLE(table), label,
-                     0, 3, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
+                     0, 2, row, row+1, GTK_FILL, 0, 0, 0);
     row++;
 
     group = gwy_radio_buttons_create(gwy_masking_type_get_enum(), -1,
@@ -612,29 +616,29 @@ neural_train_dialog(NeuralTrainArgs *args)
 
     label = gwy_label_new_header(_("Network"));
     gtk_table_attach(GTK_TABLE(table), label, 0, 2, row, row+1,
-                     GTK_EXPAND | GTK_FILL, 0, 0, 0);
+                     GTK_FILL, 0, 0, 0);
     row++;
 
     controls.width = gtk_adjustment_new(nndata->width, 1, 100, 1, 10, 0);
-    spin = gwy_table_attach_spinbutton(table, row, _("Window _width:"), "px",
-                                       controls.width);
-    gtk_spin_button_set_digits(GTK_SPIN_BUTTON(spin), 0);
+    gwy_table_attach_adjbar(table, row, _("Window _width:"), _("px"),
+                            controls.width,
+                            GWY_HSCALE_SQRT | GWY_HSCALE_SNAP);
     g_signal_connect_swapped(controls.width, "value-changed",
                              G_CALLBACK(width_changed), &controls);
     row++;
 
     controls.height = gtk_adjustment_new(nndata->height, 1, 100, 1, 10, 0);
-    spin = gwy_table_attach_spinbutton(table, row, _("Window h_eight:"), "px",
-                                       controls.height);
-    gtk_spin_button_set_digits(GTK_SPIN_BUTTON(spin), 0);
+    gwy_table_attach_adjbar(table, row, _("Window h_eight:"), _("px"),
+                            controls.height,
+                            GWY_HSCALE_SQRT | GWY_HSCALE_SNAP);
     g_signal_connect_swapped(controls.height, "value-changed",
                              G_CALLBACK(height_changed), &controls);
     row++;
 
     controls.nhidden = gtk_adjustment_new(nndata->nhidden, 1, 30, 1, 10, 0);
-    spin = gwy_table_attach_spinbutton(table, row, _("_Hidden nodes:"), NULL,
-                                       controls.nhidden);
-    gtk_spin_button_set_digits(GTK_SPIN_BUTTON(spin), 0);
+    gwy_table_attach_adjbar(table, row, _("_Hidden nodes:"), NULL,
+                            controls.nhidden,
+                            GWY_HSCALE_LINEAR | GWY_HSCALE_SNAP);
     g_signal_connect_swapped(controls.nhidden, "value-changed",
                              G_CALLBACK(nhidden_changed), &controls);
     row++;
@@ -647,24 +651,27 @@ neural_train_dialog(NeuralTrainArgs *args)
 
     controls.inpowerxy = gtk_adjustment_new(nndata->inpowerxy,
                                             -12, 12, 1, 10, 0);
-    spin = gwy_table_attach_spinbutton(table, row, _("Power of source _XY:"),
-                                       NULL, controls.inpowerxy);
+    gwy_table_attach_adjbar(table, row, _("Power of source _XY:"), NULL,
+                            controls.inpowerxy,
+                            GWY_HSCALE_LINEAR | GWY_HSCALE_SNAP);
     g_signal_connect_swapped(controls.inpowerxy, "value-changed",
                              G_CALLBACK(inpowerxy_changed), &controls);
     row++;
 
     controls.inpowerz = gtk_adjustment_new(nndata->inpowerz,
-                                            -12, 12, 1, 10, 0);
-    spin = gwy_table_attach_spinbutton(table, row, _("Power of source _Z:"),
-                                       NULL, controls.inpowerz);
+                                           -12, 12, 1, 10, 0);
+    gwy_table_attach_adjbar(table, row, _("Power of source _Z:"), NULL,
+                            controls.inpowerz,
+                            GWY_HSCALE_LINEAR | GWY_HSCALE_SNAP);
     g_signal_connect_swapped(controls.inpowerz, "value-changed",
                              G_CALLBACK(inpowerz_changed), &controls);
     row++;
 
     controls.outunits = gtk_entry_new();
     gtk_entry_set_text(GTK_ENTRY(controls.outunits), nndata->outunits);
-    gwy_table_attach_row(table, row, _("_Fixed units:"), NULL,
-                         controls.outunits);
+    gwy_table_attach_adjbar(table, row, _("_Fixed units:"), NULL,
+                            GTK_OBJECT(controls.outunits),
+                            GWY_HSCALE_WIDGET_NO_EXPAND);
     g_signal_connect_swapped(controls.outunits, "changed",
                              G_CALLBACK(outunits_changed), &controls);
     row++;
