@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: noise_synth.c 19044 2016-10-08 19:10:46Z yeti-dn $
+ *  @(#) $Id: noise_synth.c 20105 2017-07-29 09:24:09Z yeti-dn $
  *  Copyright (C) 2010 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
@@ -34,8 +34,6 @@
 #include "preview.h"
 #include "dimensions.h"
 
-#define GWY_SQRT6 2.449489742783178098197284074705
-
 #define NOISE_SYNTH_RUN_MODES (GWY_RUN_IMMEDIATE | GWY_RUN_INTERACTIVE)
 
 #define DECLARE_NOISE(name) \
@@ -195,12 +193,12 @@ static GwyModuleInfo module_info = {
     &module_register,
     N_("Generates uncorrelated random noise."),
     "Yeti <yeti@gwyddion.net>",
-    "1.2",
+    "1.3",
     "David Nečas (Yeti)",
     "2010",
 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, noise_synth)
 
 static gboolean
 module_register(void)
@@ -316,10 +314,10 @@ run_noninteractive(NoiseSynthArgs *args,
 
 static gboolean
 noise_synth_dialog(NoiseSynthArgs *args,
-                 GwyDimensionArgs *dimsargs,
-                 GwyContainer *data,
-                 GwyDataField *dfield_template,
-                 gint id)
+                   GwyDimensionArgs *dimsargs,
+                   GwyContainer *data,
+                   GwyDataField *dfield_template,
+                   gint id)
 {
     GtkWidget *dialog, *table, *vbox, *hbox, *notebook, *label;
     NoiseSynthControls controls;
@@ -396,7 +394,7 @@ noise_synth_dialog(NoiseSynthArgs *args,
         g_signal_connect_swapped(controls.dims->add, "toggled",
                                  G_CALLBACK(noise_synth_invalidate), &controls);
 
-    table = gtk_table_new(6 + (dfield_template ? 1 : 0), 4, FALSE);
+    table = gtk_table_new(6 + (dfield_template ? 1 : 0), 3, FALSE);
     controls.table = GTK_TABLE(table);
     gtk_table_set_row_spacings(controls.table, 2);
     gtk_table_set_col_spacings(controls.table, 6);
@@ -406,14 +404,14 @@ noise_synth_dialog(NoiseSynthArgs *args,
     row = 0;
 
     controls.distribution = distribution_selector_new(&controls);
-    gwy_table_attach_hscale(table, row, _("_Distribution:"), NULL,
+    gwy_table_attach_adjbar(table, row, _("_Distribution:"), NULL,
                             GTK_OBJECT(controls.distribution),
-                            GWY_HSCALE_WIDGET);
+                            GWY_HSCALE_WIDGET_NO_EXPAND);
     row++;
 
-    label = gtk_label_new(_("Direction:"));
+    label = gtk_label_new(_("Noise type:"));
     gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
-    gtk_table_attach(GTK_TABLE(table), label, 0, 1, row, row+1,
+    gtk_table_attach(GTK_TABLE(table), label, 0, 2, row, row+1,
                      GTK_FILL, 0, 0, 0);
     row++;
 
@@ -425,7 +423,7 @@ noise_synth_dialog(NoiseSynthArgs *args,
                                     _("One-sided _negative"), NOISE_DIRECTION_DOWN,
                                     NULL);
     row = gwy_radio_buttons_attach_to_table(controls.direction,
-                                            GTK_TABLE(table), 3, row);
+                                            GTK_TABLE(table), 2, row);
     gtk_table_set_row_spacing(GTK_TABLE(table), row-1, 8);
 
     row = gwy_synth_attach_height(&controls, row,
@@ -434,11 +432,11 @@ noise_synth_dialog(NoiseSynthArgs *args,
 
     if (dfield_template) {
         controls.sigma_init
-            = gtk_button_new_with_mnemonic(_("_Like Current Channel"));
+            = gtk_button_new_with_mnemonic(_("_Like Current Image"));
         g_signal_connect_swapped(controls.sigma_init, "clicked",
                                  G_CALLBACK(sigma_init_clicked), &controls);
         gtk_table_attach(GTK_TABLE(table), controls.sigma_init,
-                         1, 3, row, row+1, GTK_FILL, 0, 0, 0);
+                         0, 2, row, row+1, GTK_FILL, 0, 0, 0);
         row++;
     }
 
