@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: obj_synth.c 19189 2016-11-06 20:09:54Z yeti-dn $
+ *  @(#) $Id: obj_synth.c 20038 2017-07-07 10:43:16Z yeti-dn $
  *  Copyright (C) 2009-2016 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
@@ -194,10 +194,6 @@ static void       shape_selected       (GtkComboBox *combo,
 static void       sculpt_type_changed  (GtkComboBox *combo,
                                         ObjSynthControls *controls);
 static void       height_init_clicked  (ObjSynthControls *controls);
-static gint       attach_truncation    (ObjSynthControls *controls,
-                                        gint row,
-                                        GtkObject **adj,
-                                        gdouble *target);
 static void       update_coverage_value(ObjSynthControls *controls);
 static void       obj_synth_invalidate (ObjSynthControls *controls);
 static gboolean   preview_gsource      (gpointer user_data);
@@ -295,14 +291,14 @@ static GwyModuleInfo module_info = {
     "2009",
 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, obj_synth)
 
 static gboolean
 module_register(void)
 {
     gwy_process_func_register("obj_synth",
                               (GwyProcessFunc)&obj_synth,
-                              N_("/S_ynthetic/_Objects..."),
+                              N_("/S_ynthetic/_Deposition/_Objects..."),
                               GWY_STOCK_SYNTHETIC_OBJECTS,
                               OBJ_SYNTH_RUN_MODES,
                               0,
@@ -330,10 +326,11 @@ obj_synth(GwyContainer *data, GwyRunType run)
 
     rngset = gwy_rand_gen_set_new(RNG_NRNGS);
     if (run == GWY_RUN_IMMEDIATE
-        || obj_synth_dialog(&args, &dimsargs, rngset, data, dfield, id)) {
-        obj_synth_save_args(gwy_app_settings_get(), &args, &dimsargs);
+        || obj_synth_dialog(&args, &dimsargs, rngset, data, dfield, id))
         run_noninteractive(&args, &dimsargs, rngset, data, dfield, id, quark);
-    }
+
+    if (run == GWY_RUN_INTERACTIVE)
+        obj_synth_save_args(gwy_app_settings_get(), &args, &dimsargs);
 
     gwy_rand_gen_set_free(rngset);
     gwy_dimensions_free_args(&dimsargs);
@@ -500,7 +497,7 @@ obj_synth_dialog(ObjSynthArgs *args,
         g_signal_connect_swapped(controls.dims->add, "toggled",
                                  G_CALLBACK(obj_synth_invalidate), &controls);
 
-    table = gtk_table_new(19 + (dfield_template ? 1 : 0), 4, FALSE);
+    table = gtk_table_new(19 + (dfield_template ? 1 : 0), 3, FALSE);
     controls.table = GTK_TABLE(table);
     gtk_table_set_row_spacings(GTK_TABLE(table), 2);
     gtk_table_set_col_spacings(GTK_TABLE(table), 6);
@@ -510,14 +507,15 @@ obj_synth_dialog(ObjSynthArgs *args,
     row = 0;
 
     controls.type = shape_selector_new(&controls);
-    gwy_table_attach_hscale(table, row, _("_Shape:"), NULL,
-                            GTK_OBJECT(controls.type), GWY_HSCALE_WIDGET);
+    gwy_table_attach_adjbar(table, row, _("_Shape:"), NULL,
+                            GTK_OBJECT(controls.type),
+                            GWY_HSCALE_WIDGET_NO_EXPAND);
     row++;
 
     controls.coverage = gtk_adjustment_new(args->coverage,
                                            0.001, 50.0, 0.001, 1.0, 0);
     g_object_set_data(G_OBJECT(controls.coverage), "target", &args->coverage);
-    gwy_table_attach_hscale(table, row, _("Co_verage:"), NULL,
+    gwy_table_attach_adjbar(table, row, _("Co_verage:"), NULL,
                             controls.coverage, GWY_HSCALE_SQRT);
     g_signal_connect_swapped(controls.coverage, "value-changed",
                              G_CALLBACK(gwy_synth_double_changed), &controls);
@@ -526,17 +524,17 @@ obj_synth_dialog(ObjSynthArgs *args,
     controls.coverage_value = gtk_label_new(NULL);
     gtk_misc_set_alignment(GTK_MISC(controls.coverage_value), 1.0, 0.5);
     gtk_table_attach(controls.table, controls.coverage_value,
-                     2, 3, row, row+1, GTK_FILL, 0, 0, 0);
+                     1, 2, row, row+1, GTK_FILL, 0, 0, 0);
 
     controls.coverage_units = gtk_label_new(_("obj."));
     gtk_misc_set_alignment(GTK_MISC(controls.coverage_units), 0.0, 0.5);
     gtk_table_attach(GTK_TABLE(table), controls.coverage_units,
-                     3, 4, row, row+1, GTK_FILL, 0, 0, 0);
+                     2, 3, row, row+1, GTK_FILL, 0, 0, 0);
     gtk_table_set_row_spacing(GTK_TABLE(table), row, 8);
     row++;
 
     gtk_table_attach(GTK_TABLE(table), gwy_label_new_header(_("Size")),
-                     0, 3, row, row+1, GTK_FILL, 0, 0, 0);
+                     0, 2, row, row+1, GTK_FILL, 0, 0, 0);
     row++;
 
     controls.size = gtk_adjustment_new(args->size, 1.0, 1000.0, 0.1, 10.0, 0);
@@ -549,13 +547,13 @@ obj_synth_dialog(ObjSynthArgs *args,
 
     gtk_table_set_row_spacing(GTK_TABLE(table), row-1, 8);
     gtk_table_attach(controls.table, gwy_label_new_header(_("Aspect Ratio")),
-                     0, 3, row, row+1, GTK_FILL, 0, 0, 0);
+                     0, 2, row, row+1, GTK_FILL, 0, 0, 0);
     row++;
 
     controls.aspect = gtk_adjustment_new(args->aspect,
                                          0.2, 5.0, 0.01, 1.0, 0);
     g_object_set_data(G_OBJECT(controls.aspect), "target", &args->aspect);
-    gwy_table_attach_hscale(table, row, _("_Aspect ratio:"), NULL,
+    gwy_table_attach_adjbar(table, row, _("_Aspect ratio:"), NULL,
                             controls.aspect, GWY_HSCALE_LOG);
     g_signal_connect_swapped(controls.aspect, "value-changed",
                              G_CALLBACK(gwy_synth_double_changed), &controls);
@@ -567,7 +565,7 @@ obj_synth_dialog(ObjSynthArgs *args,
 
     gtk_table_set_row_spacing(GTK_TABLE(table), row-1, 8);
     gtk_table_attach(GTK_TABLE(table), gwy_label_new_header(_("Height")),
-                     0, 3, row, row+1, GTK_FILL, 0, 0, 0);
+                     0, 2, row, row+1, GTK_FILL, 0, 0, 0);
     row++;
 
     row = gwy_synth_attach_height(&controls, row,
@@ -576,11 +574,11 @@ obj_synth_dialog(ObjSynthArgs *args,
 
     if (dfield_template) {
         controls.height_init
-            = gtk_button_new_with_mnemonic(_("_Like Current Channel"));
+            = gtk_button_new_with_mnemonic(_("_Like Current Image"));
         g_signal_connect_swapped(controls.height_init, "clicked",
                                  G_CALLBACK(height_init_clicked), &controls);
         gtk_table_attach(GTK_TABLE(table), controls.height_init,
-                         1, 3, row, row+1, GTK_FILL, 0, 0, 0);
+                         0, 2, row, row+1, GTK_FILL, 0, 0, 0);
         row++;
     }
 
@@ -591,7 +589,7 @@ obj_synth_dialog(ObjSynthArgs *args,
     g_object_set_data(G_OBJECT(controls.height_bound),
                       "target", &args->height_bound);
     gtk_table_attach(GTK_TABLE(table), controls.height_bound,
-                     0, 3, row, row+1, GTK_FILL, 0, 0, 0);
+                     0, 2, row, row+1, GTK_FILL, 0, 0, 0);
     g_signal_connect_swapped(controls.height_bound, "toggled",
                              G_CALLBACK(gwy_synth_boolean_changed), &controls);
     row++;
@@ -600,7 +598,8 @@ obj_synth_dialog(ObjSynthArgs *args,
                                     &controls.height_noise,
                                     &args->height_noise);
 
-    row = attach_truncation(&controls, row, &controls.htrunc, &args->htrunc);
+    row = gwy_synth_attach_truncation(&controls, row,
+                                      &controls.htrunc, &args->htrunc);
     row = gwy_synth_attach_variance(&controls, row,
                                     &controls.htrunc_noise,
                                     &args->htrunc_noise);
@@ -609,7 +608,7 @@ obj_synth_dialog(ObjSynthArgs *args,
         = gwy_enum_combo_box_new(sculpt_types, G_N_ELEMENTS(sculpt_types),
                                  G_CALLBACK(sculpt_type_changed), &controls,
                                  args->sculpt, TRUE);
-    gwy_table_attach_hscale(table, row, _("_Feature type:"), NULL,
+    gwy_table_attach_adjbar(table, row, _("_Feature type:"), NULL,
                             GTK_OBJECT(controls.sculpt), GWY_HSCALE_WIDGET);
     row++;
 
@@ -790,31 +789,6 @@ height_init_clicked(ObjSynthControls *controls)
                              controls->zscale/mag);
 }
 
-static gint
-attach_truncation(ObjSynthControls *controls,
-                  gint row,
-                  GtkObject **adj,
-                  gdouble *target)
-{
-    GtkWidget *spin;
-
-    gtk_table_set_row_spacing(controls->table, row-1, 8);
-    *adj = gtk_adjustment_new(*target,
-                              0.001, 1.0, 0.001, 0.1, 0);
-    g_object_set_data(G_OBJECT(*adj), "target", target);
-
-    spin = gwy_table_attach_hscale(GTK_WIDGET(controls->table),
-                                   row, _("_Truncate:"), NULL, *adj,
-                                   GWY_HSCALE_DEFAULT);
-    gtk_spin_button_set_digits(GTK_SPIN_BUTTON(spin), 3);
-    g_signal_connect_swapped(*adj, "value-changed",
-                             G_CALLBACK(gwy_synth_double_changed), controls);
-
-    row++;
-
-    return row;
-}
-
 static void
 update_coverage_value(ObjSynthControls *controls)
 {
@@ -966,7 +940,7 @@ object_synth_iter(GwyDataField *surface,
             angle += gwy_rand_gen_set_gaussian(rngset, RNG_ANGLE,
                                                2*args->angle_noise);
 
-        // Use a specific distribution for htrunc.
+        /* Use a specific distribution for htrunc. */
         if (args->htrunc_noise) {
             gdouble q = exp(gwy_rand_gen_set_gaussian(rngset, RNG_HTRUNC,
                                                       args->htrunc_noise));
