@@ -1,4 +1,5 @@
 /*
+ *  @(#) $Id: otsu_threshold.c 19948 2017-06-22 14:05:41Z yeti-dn $
  *  Copyright (C) 2013 Brazilian Nanotechnology National Laboratory
  *  E-mail: Vinicius Barboza <vinicius.barboza@lnnano.cnpem.br>
  *
@@ -44,7 +45,7 @@ static GwyModuleInfo module_info = {
 };
 
 /* Module query */
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, otsu_threshold)
 
 /* Module register */
 static gboolean
@@ -52,13 +53,12 @@ module_register(void)
 {
     gwy_process_func_register("otsu-threshold",
                               (GwyProcessFunc)&otsu_threshold,
-                              N_("/_Grains/_Mark by Otsu's..."),
+                              N_("/_Grains/_Mark by Otsu's"),
                               NULL,
                               OTSU_RUN_MODES,
                               GWY_MENU_FLAG_DATA,
                               N_("Automated threshold using Otsu's method "
-                                 "on heights.")
-                             );
+                                 "on heights."));
     return TRUE;
 }
 
