@@ -1,6 +1,6 @@
 /*
- *  @(#) $Id: pat_synth.c 19044 2016-10-08 19:10:46Z yeti-dn $
- *  Copyright (C) 2010,2011 David Necas (Yeti).
+ *  @(#) $Id: pat_synth.c 19948 2017-06-22 14:05:41Z yeti-dn $
+ *  Copyright (C) 2010-2017 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -221,12 +221,12 @@ static GwyModuleInfo module_info = {
     N_("Generates surfaces representing simple patterns "
        "(steps, ridges, ...)."),
     "Yeti <yeti@gwyddion.net>",
-    "1.5",
+    "1.6",
     "David Nečas (Yeti)",
     "2010",
 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, pat_synth)
 
 static gboolean
 module_register(void)
@@ -444,7 +444,7 @@ pat_synth_dialog(PatSynthArgs *args,
         g_signal_connect_swapped(controls.dims->add, "toggled",
                                  G_CALLBACK(pat_synth_invalidate), &controls);
 
-    table = gtk_table_new(1, 4, FALSE);
+    table = gtk_table_new(1, 3, FALSE);
     controls.table_parameters = GTK_TABLE(table);
     gtk_table_set_row_spacings(controls.table_parameters, 2);
     gtk_table_set_col_spacings(controls.table_parameters, 6);
@@ -455,8 +455,9 @@ pat_synth_dialog(PatSynthArgs *args,
     row = 0;
 
     controls.type = pattern_selector_new(&controls);
-    gwy_table_attach_hscale(table, row, _("_Pattern:"), NULL,
-                            GTK_OBJECT(controls.type), GWY_HSCALE_WIDGET);
+    gwy_table_attach_adjbar(table, row, _("_Pattern:"), NULL,
+                            GTK_OBJECT(controls.type),
+                            GWY_HSCALE_WIDGET_NO_EXPAND);
     row++;
     g_object_set_data(G_OBJECT(table), "base-rows", GINT_TO_POINTER(row));
 
