@@ -78,7 +78,6 @@ static gboolean    run_pid                    (GwyDataField *dfield,
 static void        pid_values_update          (PIDControls *controls,
                                                PIDArgs *args);
 
-
 static const PIDArgs pid_defaults = {
     1,
     1,
@@ -100,7 +99,7 @@ static GwyModuleInfo module_info = {
     "2012",
 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, pid)
 
 static gboolean
 module_register(void)
@@ -191,9 +190,8 @@ static gboolean
 pid_dialog(PIDArgs *args)
 {
     GtkWidget *dialog, *table, *spin;
-    gint row = 0;
+    gint response, row = 0;
     PIDControls controls;
-    gint response;
 
     dialog = gtk_dialog_new_with_buttons(_("PID simulation"), NULL, 0,
                                          _("_Reset"), RESPONSE_RESET,
@@ -203,7 +201,7 @@ pid_dialog(PIDArgs *args)
     gtk_dialog_set_default_response(GTK_DIALOG(dialog), GTK_RESPONSE_OK);
     gwy_help_add_to_proc_dialog(GTK_DIALOG(dialog), GWY_HELP_DEFAULT);
 
-    table = gtk_table_new(4, 4, FALSE);
+    table = gtk_table_new(4, 3, FALSE);
     gtk_table_set_row_spacings(GTK_TABLE(table), 2);
     gtk_table_set_col_spacings(GTK_TABLE(table), 6);
     gtk_container_set_border_width(GTK_CONTAINER(table), 4);
@@ -211,57 +209,60 @@ pid_dialog(PIDArgs *args)
                        FALSE, FALSE, 4);
 
 
-    controls.proportional = gtk_adjustment_new(args->proportional, 0.0, 100, 0.1, 1, 0);
-    spin = gwy_table_attach_spinbutton(table, row, _("_Proportional:"), "",
-                                controls.proportional);
+    controls.proportional = gtk_adjustment_new(args->proportional,
+                                               0.0, 100, 0.1, 1, 0);
+    spin = gwy_table_attach_adjbar(table, row, _("_Proportional:"), NULL,
+                                   controls.proportional, GWY_HSCALE_SQRT);
     gtk_spin_button_set_digits(GTK_SPIN_BUTTON(spin), 1);
     row++;
 
     controls.integral = gtk_adjustment_new(args->integral, 0.0, 100, 0.1, 1, 0);
-    spin = gwy_table_attach_spinbutton(table, row, _("_Integral:"), "",
-                                controls.integral);
+    spin = gwy_table_attach_adjbar(table, row, _("_Integral:"), NULL,
+                                   controls.integral, GWY_HSCALE_SQRT);
     gtk_spin_button_set_digits(GTK_SPIN_BUTTON(spin), 1);
     row++;
 
     controls.tau = gtk_adjustment_new(args->tau, 2, 100, 1, 1, 0);
-    spin = gwy_table_attach_spinbutton(table, row, _("_Integration steps:"), "",
-                                controls.tau);
+    spin = gwy_table_attach_adjbar(table, row, _("_Integration steps:"), NULL,
+                                   controls.tau,
+                                   GWY_HSCALE_SQRT | GWY_HSCALE_SNAP);
     gtk_spin_button_set_digits(GTK_SPIN_BUTTON(spin), 0);
     row++;
 
-
-    controls.derivative = gtk_adjustment_new(args->derivative, 0.0, 100, 0.1, 1, 0);
-    spin = gwy_table_attach_spinbutton(table, row, _("_Derivative:"), "",
-                                controls.derivative);
+    controls.derivative = gtk_adjustment_new(args->derivative,
+                                             0.0, 100, 0.1, 1, 0);
+    spin = gwy_table_attach_adjbar(table, row, _("_Derivative:"), NULL,
+                                   controls.derivative, GWY_HSCALE_SQRT);
     gtk_spin_button_set_digits(GTK_SPIN_BUTTON(spin), 1);
-
     row++;
 
     controls.ratio = gtk_adjustment_new(args->ratio, 1, 1000, 1, 10, 0);
-    gwy_table_attach_spinbutton(table, row, _("PID/scan speed _ratio:"), "",
-                                controls.ratio);
+    gwy_table_attach_adjbar(table, row, _("PID/scan speed _ratio:"), NULL,
+                            controls.ratio, GWY_HSCALE_SQRT);
     gtk_spin_button_set_digits(GTK_SPIN_BUTTON(spin), 0);
     row++;
 
-/*    controls.fpower = gtk_adjustment_new(args->fpower, 1, 20, 1, 10, 0);
-    gwy_table_attach_spinbutton(table, row, _("Force power law:"), "",
-                                controls.fpower);
+    /*
+    controls.fpower = gtk_adjustment_new(args->fpower, 1, 20, 1, 10, 0);
+    gwy_table_attach_adjbar(table, row, _("Force power law:"), NULL,
+                            controls.fpower,
+                            GWY_HSCALE_LINEAR | GWY_HSCALE_SNAP);
     gtk_spin_button_set_digits(GTK_SPIN_BUTTON(spin), 0);
-    row++;*/
+    row++;
+    */
 
     controls.fstrength = gtk_adjustment_new(args->fstrength, 0, 1000, 1, 10, 0);
-    gwy_table_attach_spinbutton(table, row, _("Force strength:"), "",
-                                controls.fstrength);
+    gwy_table_attach_adjbar(table, row, _("Force strength:"), NULL,
+                            controls.fstrength, GWY_HSCALE_SQRT);
     gtk_spin_button_set_digits(GTK_SPIN_BUTTON(spin), 1);
     row++;
 
     controls.fsetpoint = gtk_adjustment_new(args->fsetpoint, 0, 1000, 1, 10, 0);
-    gwy_table_attach_spinbutton(table, row, _("Force setpoint:"), "",
-                                controls.fsetpoint);
+    gwy_table_attach_adjbar(table, row, _("Force setpoint:"), NULL,
+                            controls.fsetpoint, GWY_HSCALE_SQRT);
     gtk_spin_button_set_digits(GTK_SPIN_BUTTON(spin), 1);
     row++;
 
-
     gtk_widget_show_all(dialog);
     do {
         response = gtk_dialog_run(GTK_DIALOG(dialog));
@@ -349,7 +350,6 @@ run_pid(GwyDataField *dfield, GwyContainer *data, gint id, GwyDataField *fw, Gwy
     dfrev = gwy_data_field_get_data(frev);
     surface = gwy_data_field_get_data(dfield);
 
-
     /*primitive normalisation*/
     zpos = surface[0];
     setpoint = args->fsetpoint;
@@ -359,36 +359,41 @@ run_pid(GwyDataField *dfield, GwyContainer *data, gint id, GwyDataField *fw, Gwy
     nprev = args->tau;
 
     /*scan, forming forward and backward data and error signals*/
-    if (!gwy_app_wait_set_message(_("Scanning..."))) return 0;
+    if (!gwy_app_wait_set_message(_("Scanning..."))) {
+        gwy_app_wait_finish();
+        return FALSE;
+    }
 
-    for (trow=-2; trow<(2*yres); trow++) //start with one complete scan line that is then throwen away
-    {
+    //start with one complete scan line that is then throwen away
+    for (trow = -2; trow < 2*yres; trow++) {
         revdir = trow%2;
         row = MAX(0, trow/2);
 
-        for (tcol=0; tcol<xres; tcol++)
-        {
-            if (revdir) col = xres-tcol-1;
-            else col = tcol;
+        for (tcol=0; tcol<xres; tcol++) {
+            if (revdir)
+                col = xres-tcol-1;
+            else
+                col = tcol;
 
-            for (i=0; i<args->ratio; i++) { //here comes the ratio between scanning and feedback bandwidth
+            for (i = 0; i < args->ratio; i++) { //here comes the ratio between scanning and feedback bandwidth
                 force = strength*(surface[row*xres + col]-zpos);
                 //force = strength*pow((surface[row*xres + col]-zpos), args->fpower);
 
-                for (j=nprev; j>0; j--)
-                    previous[j]=previous[j-1];
-                previous[0] = (force-setpoint);
+                for (j = nprev; j > 0; j--)
+                    previous[j] = previous[j-1];
+                previous[0] = force - setpoint;
 
                 accumulator = 0;
-                for (j=0; j<nprev; j++) accumulator += previous[j]*(gdouble)(nprev-j)/(gdouble)nprev;
+                for (j = 0; j < nprev; j++)
+                    accumulator += previous[j]*(nprev-j)/nprev;
                 accumulator/=nprev;
 
                 zpos += (args->proportional*(force-setpoint)
                         + args->integral*accumulator
                         + args->derivative*(previous[0]-previous[1])/args->ratio)*zrange;
             }
-            if (gwy_isinf(zpos) || gwy_isnan(zpos) || gwy_isinf(force) || gwy_isnan(force))
-            {
+            if (gwy_isinf(zpos) || gwy_isnan(zpos)
+                || gwy_isinf(force) || gwy_isnan(force)) {
                 dialog = gtk_message_dialog_new(GTK_WINDOW(gwy_app_find_window_for_channel(data, id)),
                                                 GTK_DIALOG_DESTROY_WITH_PARENT,
                                                 GTK_MESSAGE_ERROR,
@@ -398,7 +403,7 @@ run_pid(GwyDataField *dfield, GwyContainer *data, gint id, GwyDataField *fw, Gwy
                 gtk_widget_destroy(dialog);
 
                 gwy_app_wait_finish();
-                return 0;
+                return FALSE;
             }
 
             if (trow >= 0) {
@@ -413,12 +418,14 @@ run_pid(GwyDataField *dfield, GwyContainer *data, gint id, GwyDataField *fw, Gwy
             }
 
         }
-        if (!gwy_app_wait_set_fraction((gdouble)row/(gdouble)yres))
-            return 0;
+        if (!gwy_app_wait_set_fraction((gdouble)row/(gdouble)yres)) {
+            gwy_app_wait_finish();
+            return FALSE;
+        }
     }
     gwy_app_wait_finish();
 
-    return 1;
+    return TRUE;
 }
 
 static void
@@ -463,7 +470,6 @@ pid_sanitize_args(PIDArgs *args)
     args->fpower = CLAMP(args->fpower, 1, 20);
     args->fstrength = CLAMP(args->fstrength, 0.0, 1000.0);
     args->fsetpoint = CLAMP(args->fsetpoint, 0.0, 1000.0);
-
 }
 
 static void
@@ -480,7 +486,6 @@ pid_load_args(GwyContainer *container,
     gwy_container_gis_int32_by_name(container, fpower_key, &args->fpower);
     gwy_container_gis_double_by_name(container, fstrength_key, &args->fstrength);
     gwy_container_gis_double_by_name(container, fsetpoint_key, &args->fsetpoint);
-
     pid_sanitize_args(args);
 }
 
@@ -496,7 +501,6 @@ pid_save_args(GwyContainer *container,
     gwy_container_set_int32_by_name(container, fpower_key, args->fpower);
     gwy_container_set_double_by_name(container, fstrength_key, args->fstrength);
     gwy_container_gis_double_by_name(container, fsetpoint_key, &args->fsetpoint);
-
 }
 
 /* vim: set cin et ts=4 sw=4 cino=>1s,e0,n0,f0,{0,}0,^0,\:1s,=0,g1s,h0,t0,+1s,c3,(0,u0 : */
