@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: polydistort.c 19044 2016-10-08 19:10:46Z yeti-dn $
+ *  @(#) $Id: polydistort.c 19948 2017-06-22 14:05:41Z yeti-dn $
  *  Copyright (C) 2007,2008 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -138,7 +138,7 @@ static GwyModuleInfo module_info = {
     "2007",
 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, polydistort)
 
 static gboolean
 module_register(void)
@@ -190,7 +190,7 @@ distort_dialog(DistortArgs *args,
                GwyDataField *sfield,
                gint id)
 {
-    GtkWidget *dialog, *table, *hbox, *label;
+    GtkWidget *dialog, *table, *hbox, *label, *align;
     DistortControls controls;
     gint response;
     GSList *l;
@@ -221,6 +221,9 @@ distort_dialog(DistortArgs *args,
     gtk_box_pack_start(GTK_BOX(GTK_DIALOG(dialog)->vbox), hbox,
                        FALSE, FALSE, 4);
 
+    align = gtk_alignment_new(0.0, 0.0, 0.0, 0.0);
+    gtk_box_pack_start(GTK_BOX(hbox), align, FALSE, FALSE, 4);
+
     controls.mydata = gwy_container_new();
     gwy_container_set_object_by_name(controls.mydata, "/0/data", dfield);
     gwy_app_sync_data_items(data, controls.mydata, id, 0, FALSE,
@@ -231,9 +234,9 @@ distort_dialog(DistortArgs *args,
                             0);
     controls.view = create_preview(controls.mydata, 0, PREVIEW_SIZE, FALSE);
     g_object_unref(controls.mydata);
-    gtk_box_pack_start(GTK_BOX(hbox), controls.view, FALSE, FALSE, 4);
+    gtk_container_add(GTK_CONTAINER(align), controls.view);
 
-    table = gtk_table_new(7, 4, FALSE);
+    table = gtk_table_new(7, 3, FALSE);
     gtk_table_set_row_spacings(GTK_TABLE(table), 2);
     gtk_table_set_col_spacings(GTK_TABLE(table), 6);
     gtk_container_set_border_width(GTK_CONTAINER(table), 4);
@@ -244,7 +247,7 @@ distort_dialog(DistortArgs *args,
         = gwy_enum_combo_box_new(gwy_interpolation_type_get_enum(), -1,
                                  G_CALLBACK(interp_changed), &controls,
                                  args->interp, TRUE);
-    gwy_table_attach_hscale(table, row, _("_Interpolation type:"), NULL,
+    gwy_table_attach_adjbar(table, row, _("_Interpolation type:"), NULL,
                             GTK_OBJECT(controls.interp),
                             GWY_HSCALE_WIDGET_NO_EXPAND);
     row++;
@@ -260,7 +263,7 @@ distort_dialog(DistortArgs *args,
                                   gwy_sgettext("exterior|Periodic"),
                                   GWY_EXTERIOR_PERIODIC,
                                   NULL);
-    gwy_table_attach_hscale(table, row, _("_Exterior type:"), NULL,
+    gwy_table_attach_adjbar(table, row, _("_Exterior type:"), NULL,
                             GTK_OBJECT(controls.exterior),
                             GWY_HSCALE_WIDGET_NO_EXPAND);
     gtk_table_set_row_spacing(GTK_TABLE(table), row, 8);
@@ -268,7 +271,7 @@ distort_dialog(DistortArgs *args,
 
     hbox = gtk_hbox_new(FALSE, 6);
     gtk_table_attach(GTK_TABLE(table), hbox,
-                     0, 4, row, row+1, GTK_FILL, 0, 0, 0);
+                     0, 2, row, row+1, GTK_FILL, 0, 0, 0);
     gtk_table_set_row_spacing(GTK_TABLE(table), row, 8);
     row++;
 
@@ -295,13 +298,13 @@ distort_dialog(DistortArgs *args,
                              G_CALLBACK(g_free), controls.xcoeff);
     gtk_table_attach(GTK_TABLE(table),
                      coeff_table_new(controls.xcoeff, (gpointer)"x", &controls),
-                     0, 4, row, row+1, GTK_FILL, 0, 0, 0);
+                     0, 3, row, row+1, GTK_FILL, 0, 0, 0);
     gtk_table_set_row_spacing(GTK_TABLE(table), row, 8);
     row++;
 
     gtk_table_attach(GTK_TABLE(table),
                      gwy_label_new_header(_("Y Coefficients")),
-                     0, 3, row, row+1, GTK_FILL, 0, 0, 0);
+                     0, 2, row, row+1, GTK_FILL, 0, 0, 0);
     row++;
 
     controls.ycoeff = g_new0(GtkWidget*, NCOEFF);
@@ -309,7 +312,7 @@ distort_dialog(DistortArgs *args,
                              G_CALLBACK(g_free), controls.ycoeff);
     gtk_table_attach(GTK_TABLE(table),
                      coeff_table_new(controls.ycoeff, (gpointer)"y", &controls),
-                     0, 4, row, row+1, GTK_FILL, 0, 0, 0);
+                     0, 3, row, row+1, GTK_FILL, 0, 0, 0);
     gtk_table_set_row_spacing(GTK_TABLE(table), row, 8);
     row++;
 
@@ -317,7 +320,7 @@ distort_dialog(DistortArgs *args,
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(controls.update),
                                  args->update);
     gtk_table_attach(GTK_TABLE(table), controls.update,
-                     0, 3, row, row+1, GTK_FILL, 0, 0, 0);
+                     0, 2, row, row+1, GTK_FILL, 0, 0, 0);
     g_signal_connect(controls.update, "toggled",
                      G_CALLBACK(update_changed), &controls);
     row++;
