@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: polylevel.c 18537 2016-03-28 18:11:19Z yeti-dn $
+ *  @(#) $Id: polylevel.c 19976 2017-06-24 10:47:58Z yeti-dn $
  *  Copyright (C) 2004,2008 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -142,12 +142,12 @@ static GwyModuleInfo module_info = {
     &module_register,
     N_("Subtracts polynomial background."),
     "Yeti <yeti@gwyddion.net>",
-    "3.2",
+    "3.3",
     "David Nečas (Yeti) & Petr Klapetek",
     "2004",
 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, polylevel)
 
 static gboolean
 module_register(void)
@@ -155,7 +155,7 @@ module_register(void)
     gwy_process_func_register("polylevel",
                               (GwyProcessFunc)&poly_level,
                               N_("/_Level/_Polynomial Background..."),
-                              GWY_STOCK_POLYNOM,
+                              GWY_STOCK_POLYNOM_LEVEL,
                               POLYLEVEL_RUN_MODES,
                               GWY_MENU_FLAG_DATA,
                               N_("Remove polynomial background"));
@@ -412,15 +412,15 @@ poly_level_dialog(PolyLevelArgs *args,
     label = gtk_label_new(_("Leveled data"));
     gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
     gtk_table_attach(GTK_TABLE(table), label, 0, 1, row, row+1,
-                     GTK_EXPAND | GTK_FILL, GTK_EXPAND | GTK_FILL, 0, 0);
+                     GTK_FILL, GTK_FILL, 0, 0);
 
     label = gtk_label_new(_("Background"));
     gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
     gtk_table_attach(GTK_TABLE(table), label, 1, 2, row, row+1,
-                     GTK_EXPAND | GTK_FILL, GTK_EXPAND | GTK_FILL, 0, 0);
+                     GTK_FILL, GTK_FILL, 0, 0);
     row++;
 
-    table = gtk_table_new(7 + (mfield ? 4 : 0), 4, FALSE);
+    table = gtk_table_new(7 + (mfield ? 4 : 0), 3, FALSE);
     gtk_table_set_row_spacings(GTK_TABLE(table), 2);
     gtk_table_set_col_spacings(GTK_TABLE(table), 6);
     gtk_container_set_border_width(GTK_CONTAINER(table), 4);
@@ -433,29 +433,31 @@ poly_level_dialog(PolyLevelArgs *args,
                                    &controls,
                                    args->independent);
     gtk_table_attach(GTK_TABLE(table), GTK_WIDGET(controls.type_group->data),
-                     0, 4, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
+                     0, 2, row, row+1, GTK_FILL, 0, 0, 0);
     row++;
 
     controls.col_degree = gtk_adjustment_new(args->col_degree,
                                              0, MAX_DEGREE, 1, 1, 0);
-    gwy_table_attach_hscale(table, row++,
+    gwy_table_attach_adjbar(table, row++,
                             _("_Horizontal polynom degree:"), NULL,
-                            controls.col_degree, 0);
+                            controls.col_degree,
+                            GWY_HSCALE_LINEAR | GWY_HSCALE_SNAP);
     g_signal_connect(controls.col_degree, "value-changed",
                      G_CALLBACK(poly_level_degree_changed), &controls);
 
     controls.row_degree = gtk_adjustment_new(args->row_degree,
                                              0, MAX_DEGREE, 1, 1, 0);
-    gwy_table_attach_hscale(table, row++,
+    gwy_table_attach_adjbar(table, row++,
                             _("_Vertical polynom degree:"), NULL,
-                            controls.row_degree, 0);
+                            controls.row_degree,
+                            GWY_HSCALE_LINEAR | GWY_HSCALE_SNAP);
     g_signal_connect(controls.row_degree, "value-changed",
                      G_CALLBACK(poly_level_degree_changed), &controls);
 
     controls.same_degree
         = gtk_check_button_new_with_mnemonic(_("_Same degrees"));
     gtk_table_attach(GTK_TABLE(table), controls.same_degree,
-                     0, 4, row, row+1, GTK_FILL, 0, 0, 0);
+                     0, 2, row, row+1, GTK_FILL, 0, 0, 0);
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(controls.same_degree),
                                  args->same_degree);
     g_signal_connect(controls.same_degree, "toggled",
@@ -465,14 +467,15 @@ poly_level_dialog(PolyLevelArgs *args,
 
     gtk_table_attach(GTK_TABLE(table),
                      GTK_WIDGET(controls.type_group->next->data),
-                     0, 4, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
+                     0, 2, row, row+1, GTK_FILL, 0, 0, 0);
     row++;
 
     controls.max_degree = gtk_adjustment_new(args->max_degree,
                                              0, MAX_DEGREE, 1, 1, 0);
-    gwy_table_attach_hscale(table, row,
+    gwy_table_attach_adjbar(table, row,
                             _("_Maximum polynom degree:"), NULL,
-                            controls.max_degree, 0);
+                            controls.max_degree,
+                            GWY_HSCALE_LINEAR | GWY_HSCALE_SNAP);
     g_signal_connect(controls.max_degree, "value-changed",
                      G_CALLBACK(poly_level_max_degree_changed), &controls);
     gtk_table_set_row_spacing(GTK_TABLE(table), row, 8);
@@ -481,7 +484,7 @@ poly_level_dialog(PolyLevelArgs *args,
     controls.do_extract
         = gtk_check_button_new_with_mnemonic(_("E_xtract background"));
     gtk_table_attach(GTK_TABLE(table), controls.do_extract,
-                     0, 4, row, row+1, GTK_FILL, 0, 0, 0);
+                     0, 2, row, row+1, GTK_FILL, 0, 0, 0);
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(controls.do_extract),
                                  args->do_extract);
     gtk_table_set_row_spacing(GTK_TABLE(table), row, 8);
@@ -490,7 +493,7 @@ poly_level_dialog(PolyLevelArgs *args,
     if (mfield) {
         label = gwy_label_new_header(_("Masking Mode"));
         gtk_table_attach(GTK_TABLE(table), label,
-                        0, 3, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
+                        0, 2, row, row+1, GTK_FILL, 0, 0, 0);
         row++;
 
         controls.masking_group
@@ -498,7 +501,7 @@ poly_level_dialog(PolyLevelArgs *args,
                                        G_CALLBACK(poly_level_masking_changed),
                                        &controls, args->masking);
         row = gwy_radio_buttons_attach_to_table(controls.masking_group,
-                                                GTK_TABLE(table), 3, row);
+                                                GTK_TABLE(table), 2, row);
     }
     else
         controls.masking_group = NULL;
