@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: presentationops.c 17087 2015-05-02 10:38:25Z yeti-dn $
+ *  @(#) $Id: presentationops.c 19948 2017-06-22 14:05:41Z yeti-dn $
  *  Copyright (C) 2003-2004 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -60,7 +60,7 @@ static GwyModuleInfo module_info = {
     "2004",
 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, presentationops)
 
 static gboolean
 module_register(void)
@@ -78,7 +78,7 @@ module_register(void)
                               NULL,
                               PRESENTATIONOPS_RUN_MODES,
                               GWY_MENU_FLAG_DATA_SHOW | GWY_MENU_FLAG_DATA,
-                              N_("Extract presentation to a new channel"));
+                              N_("Extract presentation to a new image"));
     gwy_process_func_register("presentation_attach",
                               (GwyProcessFunc)&presentation_attach,
                               N_("/_Presentation/_Attach Presentation..."),
@@ -230,7 +230,7 @@ presentation_attach(GwyContainer *data,
     label = gtk_label_new_with_mnemonic(_("_Data to attach:"));
     gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
     gtk_table_attach(GTK_TABLE(table), label, 0, 1, row, row+1,
-                     GTK_EXPAND | GTK_FILL, 0, 0, 0);
+                     GTK_FILL, 0, 0, 0);
 
     chooser = gwy_data_chooser_new_channels();
     gwy_data_chooser_set_filter(GWY_DATA_CHOOSER(chooser),
@@ -238,7 +238,7 @@ presentation_attach(GwyContainer *data,
     gwy_data_chooser_set_active_id(GWY_DATA_CHOOSER(chooser),
                                    &attach_source_id);
     gtk_table_attach(GTK_TABLE(table), chooser, 1, 2, row, row+1,
-                     GTK_EXPAND | GTK_FILL, 0, 0, 0);
+                     GTK_FILL, 0, 0, 0);
     gtk_label_set_mnemonic_widget(GTK_LABEL(label), chooser);
     gtk_table_set_row_spacing(GTK_TABLE(table), row, 8);
     row++;
