@@ -1,6 +1,6 @@
 /*
- *  @(#) $Id: preview.h 18537 2016-03-28 18:11:19Z yeti-dn $
- *  Copyright (C) 2015 David Necas (Yeti).
+ *  @(#) $Id: preview.h 19887 2017-06-09 18:26:57Z yeti-dn $
+ *  Copyright (C) 2015-2017 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -27,7 +27,10 @@
 #include <libgwydgets/gwydataview.h>
 #include <libgwydgets/gwylayer-basic.h>
 #include <libgwydgets/gwylayer-mask.h>
+#include <libgwydgets/gwystock.h>
+#include <libgwydgets/gwyradiobuttons.h>
 #include <libgwydgets/gwydgetutils.h>
+#include <app/menu.h>
 #include <app/gwymoduleutils.h>
 #include <app/data-browser.h>
 
@@ -50,6 +53,7 @@ enum {
     RESPONSE_CALCULATE = 7,
     RESPONSE_LOAD      = 8,
     RESPONSE_SAVE      = 9,
+    RESPONSE_COPY      = 10,
 };
 
 G_GNUC_UNUSED
@@ -215,6 +219,90 @@ create_mask_field(GwyDataField *dfield)
     return dfield;
 }
 
+static void
+mask_merge_enabled_changed(GtkToggleButton *toggle, GtkWidget *widget)
+{
+    gtk_widget_set_sensitive(widget, gtk_toggle_button_get_active(toggle));
+}
+
+/* Pass NULL @pcheck if you do not want a checkbox.
+ * XXX: Cannot work with both hscale and adjbar.  Must use with adjbar. */
+G_GNUC_UNUSED
+static void
+create_mask_merge_buttons(GtkWidget *table, gint row, const gchar *name,
+                          gboolean enabled, GCallback enabled_callback,
+                          GwyMergeType merge, GCallback merge_type_callback,
+                          gpointer user_data,
+                          GtkWidget **pcheck, GSList **ptype)
+{
+    GtkTooltips *tips;
+    GSList *group, *l;
+    GtkWidget *hbox, *button, *label;
+    GQuark quark = g_quark_from_string("gwy-radiobuttons-key");
+    gint value;
+
+    if (!name)
+        name = _("Combine with existing mask:");
+
+    tips = gwy_app_get_tooltips();
+
+    button = gtk_radio_button_new(NULL);
+    g_object_set_qdata(G_OBJECT(button), quark,
+                       GINT_TO_POINTER(GWY_MERGE_INTERSECTION));
+    gtk_container_add(GTK_CONTAINER(button),
+                      gtk_image_new_from_stock(GWY_STOCK_MASK_INTERSECT,
+                                               GTK_ICON_SIZE_BUTTON));
+    gtk_tooltips_set_tip(tips, button, _("Intersection"), NULL);
+
+    button = gtk_radio_button_new_from_widget(GTK_RADIO_BUTTON(button));
+    g_object_set_qdata(G_OBJECT(button), quark,
+                       GINT_TO_POINTER(GWY_MERGE_UNION));
+    gtk_container_add(GTK_CONTAINER(button),
+                      gtk_image_new_from_stock(GWY_STOCK_MASK_ADD,
+                                               GTK_ICON_SIZE_BUTTON));
+    gtk_tooltips_set_tip(tips, button, _("Union"), NULL);
+
+    group = *ptype = gtk_radio_button_get_group(GTK_RADIO_BUTTON(button));
+    hbox = gtk_hbox_new(FALSE, 0);
+    gtk_table_attach(GTK_TABLE(table), hbox,
+                     1, 2, row, row+1, GTK_FILL, 0, 0, 0);
+
+    for (l = group; l; l = g_slist_next(l)) {
+        button = (GtkWidget*)l->data;
+        gtk_toggle_button_set_mode(GTK_TOGGLE_BUTTON(button), FALSE);
+        gtk_box_pack_end(GTK_BOX(hbox), button, FALSE, FALSE, 0);
+
+        value = GPOINTER_TO_INT(g_object_get_qdata(G_OBJECT(button), quark));
+        if (value == merge)
+            gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(button), TRUE);
+    }
+
+    if (merge_type_callback) {
+        for (l = group; l; l = g_slist_next(l)) {
+            g_signal_connect_swapped(l->data, "clicked",
+                                     merge_type_callback, user_data);
+        }
+    }
+
+    if (pcheck) {
+        label = *pcheck = gtk_check_button_new_with_mnemonic(name);
+        gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(label), enabled);
+        gtk_widget_set_sensitive(hbox, enabled);
+        g_signal_connect(label, "toggled",
+                         G_CALLBACK(mask_merge_enabled_changed), hbox);
+        if (enabled_callback) {
+            g_signal_connect_swapped(*pcheck, "toggled",
+                                     enabled_callback, user_data);
+        }
+    }
+    else {
+        label = gtk_label_new(name);
+        gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
+    }
+    gtk_table_attach(GTK_TABLE(table), label,
+                     0, 1, row, row+1, GTK_FILL, 0, 0, 0);
+}
+
 #endif
 
 /* vim: set cin et ts=4 sw=4 cino=>1s,e0,n0,f0,{0,}0,^0,\:1s,=0,g1s,h0,t0,+1s,c3,(0,u0 : */
