@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: psdf_logphi.c 18626 2016-04-22 10:15:13Z yeti-dn $
+ *  @(#) $Id: psdf_logphi.c 19948 2017-06-22 14:05:41Z yeti-dn $
  *  Copyright (C) 2015 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
@@ -76,12 +76,12 @@ static GwyModuleInfo module_info = {
     N_("Two-dimensional FFT (Fast Fourier Transform) transformed to "
        "coordinates (log-frequency, angle)."),
     "Yeti <yeti@gwyddion.net>",
-    "1.0",
+    "1.1",
     "David Nečas (Yeti)",
     "2015",
 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, psdf_logphi)
 
 static gboolean
 module_register(void)
@@ -253,7 +253,7 @@ psdflp_dialog(PSDFLPArgs *args)
     gtk_dialog_set_default_response(GTK_DIALOG(dialog), GTK_RESPONSE_OK);
     gwy_help_add_to_proc_dialog(GTK_DIALOG(dialog), GWY_HELP_DEFAULT);
 
-    table = gtk_table_new(2, 4, FALSE);
+    table = gtk_table_new(2, 2, FALSE);
     gtk_table_set_row_spacings(GTK_TABLE(table), 2);
     gtk_table_set_col_spacings(GTK_TABLE(table), 6);
     gtk_container_set_border_width(GTK_CONTAINER(table), 4);
@@ -265,14 +265,15 @@ psdflp_dialog(PSDFLPArgs *args)
         = gwy_enum_combo_box_new(gwy_windowing_type_get_enum(), -1,
                                  G_CALLBACK(gwy_enum_combo_box_update_int),
                                  &args->window, args->window, TRUE);
-    gwy_table_attach_row(table, row, _("_Windowing type:"), NULL,
-                         controls.window);
+    gwy_table_attach_adjbar(table, row, _("_Windowing type:"), NULL,
+                            GTK_OBJECT(controls.window),
+                            GWY_HSCALE_WIDGET_NO_EXPAND);
     g_signal_connect_swapped(controls.window, "changed",
                              G_CALLBACK(windowing_changed), &controls);
     row++;
 
     controls.sigma = gtk_adjustment_new(args->sigma, 0.0, 40.0, 0.01, 1.0, 0);
-    gwy_table_attach_hscale(table, row, _("Gaussian _smoothing:"), "px",
+    gwy_table_attach_adjbar(table, row, _("Gaussian _smoothing:"), _("px"),
                             controls.sigma, GWY_HSCALE_SQRT);
     g_signal_connect_swapped(controls.sigma, "value-changed",
                              G_CALLBACK(sigma_changed), &controls);
