@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: rank.c 18665 2016-04-26 20:42:48Z yeti-dn $
+ *  @(#) $Id: rank.c 19948 2017-06-22 14:05:41Z yeti-dn $
  *  Copyright (C) 2014-2015 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
@@ -91,12 +91,12 @@ static GwyModuleInfo module_info = {
     &module_register,
     N_("Enhances local contrast using a rank transform."),
     "Yeti <yeti@gwyddion.net>",
-    "2.1",
+    "2.2",
     "David Nečas (Yeti) & Petr Klapetek",
     "2014",
 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, rank)
 
 static gboolean
 module_register(void)
@@ -162,7 +162,7 @@ rank_dialog(RankArgs *args)
     gtk_dialog_set_default_response(GTK_DIALOG(dialog), GTK_RESPONSE_OK);
     gwy_help_add_to_proc_dialog(GTK_DIALOG(dialog), GWY_HELP_DEFAULT);
 
-    table = gtk_table_new(2 + G_N_ELEMENTS(types), 4, FALSE);
+    table = gtk_table_new(2 + G_N_ELEMENTS(types), 3, FALSE);
     gtk_table_set_row_spacings(GTK_TABLE(table), 2);
     gtk_table_set_col_spacings(GTK_TABLE(table), 6);
     gtk_container_set_border_width(GTK_CONTAINER(table), 4);
@@ -172,7 +172,7 @@ rank_dialog(RankArgs *args)
 
     label = gtk_label_new(_("Filter type:"));
     gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
-    gtk_table_attach(GTK_TABLE(table), label, 0, 3, row, row+1,
+    gtk_table_attach(GTK_TABLE(table), label, 0, 2, row, row+1,
                      GTK_FILL, 0, 0, 0);
     row++;
 
@@ -181,12 +181,12 @@ rank_dialog(RankArgs *args)
                                              &controls,
                                              args->type);
     row = gwy_radio_buttons_attach_to_table(controls.type, GTK_TABLE(table),
-                                            3, row);
+                                            2, row);
 
     gtk_table_set_row_spacing(GTK_TABLE(table), row-1, 8);
     controls.size = gtk_adjustment_new(args->size, 1, MAX_SIZE, 1, 10, 0);
-    gwy_table_attach_hscale(table, row++, _("Kernel _size:"), "px",
-                            controls.size, 0);
+    gwy_table_attach_adjbar(table, row++, _("Kernel _size:"), _("px"),
+                            controls.size, GWY_HSCALE_DEFAULT);
     g_signal_connect_swapped(controls.size, "value-changed",
                              G_CALLBACK(size_changed), &controls);
 
