@@ -1,6 +1,6 @@
 /*
- *  @(#) $Id: rotate.c 18945 2016-09-11 10:39:11Z yeti-dn $
- *  Copyright (C) 2003-2016 David Necas (Yeti), Petr Klapetek.
+ *  @(#) $Id: rotate.c 19948 2017-06-22 14:05:41Z yeti-dn $
+ *  Copyright (C) 2003-2017 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -95,12 +95,12 @@ static GwyModuleInfo module_info = {
     &module_register,
     N_("Rotates data by arbitrary angle."),
     "Yeti <yeti@gwyddion.net>",
-    "2.0",
+    "2.2",
     "David Nečas (Yeti) & Petr Klapetek",
     "2003",
 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, rotate)
 
 static gboolean
 module_register(void)
@@ -252,7 +252,7 @@ rotate_dialog(RotateArgs *args,
     gtk_box_pack_start(GTK_BOX(GTK_DIALOG(dialog)->vbox), hbox,
                        FALSE, FALSE, 4);
 
-    table = gtk_table_new(8, 4, FALSE);
+    table = gtk_table_new(8, 3, FALSE);
     gtk_table_set_row_spacings(GTK_TABLE(table), 2);
     gtk_table_set_col_spacings(GTK_TABLE(table), 6);
     gtk_container_set_border_width(GTK_CONTAINER(table), 4);
@@ -261,8 +261,8 @@ rotate_dialog(RotateArgs *args,
 
     controls.angle = gtk_adjustment_new(args->angle*180.0/G_PI,
                                         -360, 360, 0.01, 5, 0);
-    gwy_table_attach_hscale(table, row, _("Rotate by _angle:"), _("deg"),
-                            controls.angle, 0);
+    gwy_table_attach_adjbar(table, row, _("Rotate by _angle:"), _("deg"),
+                            controls.angle, GWY_HSCALE_LINEAR);
     g_signal_connect(controls.angle, "value-changed",
                      G_CALLBACK(angle_changed), &controls);
     row++;
@@ -271,7 +271,7 @@ rotate_dialog(RotateArgs *args,
         = gwy_enum_combo_box_new(gwy_interpolation_type_get_enum(), -1,
                                  G_CALLBACK(interp_changed), &controls,
                                  args->interp, TRUE);
-    gwy_table_attach_hscale(table, row, _("_Interpolation type:"), NULL,
+    gwy_table_attach_adjbar(table, row, _("_Interpolation type:"), NULL,
                             GTK_OBJECT(controls.interp),
                             GWY_HSCALE_WIDGET_NO_EXPAND);
     row++;
@@ -281,7 +281,7 @@ rotate_dialog(RotateArgs *args,
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(controls.show_grid),
                                  args->show_grid);
     gtk_table_attach(GTK_TABLE(table), controls.show_grid,
-                     0, 4, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
+                     0, 2, row, row+1, GTK_FILL, 0, 0, 0);
     g_signal_connect(controls.show_grid, "toggled",
                      G_CALLBACK(show_grid_changed), &controls);
     row++;
@@ -291,7 +291,7 @@ rotate_dialog(RotateArgs *args,
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(controls.create_mask),
                                  args->create_mask);
     gtk_table_attach(GTK_TABLE(table), controls.create_mask,
-                     0, 4, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
+                     0, 2, row, row+1, GTK_FILL, 0, 0, 0);
     g_signal_connect(controls.create_mask, "toggled",
                      G_CALLBACK(create_mask_changed), &controls);
     row++;
@@ -300,7 +300,7 @@ rotate_dialog(RotateArgs *args,
     label = gtk_label_new(_("Result size:"));
     gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
     gtk_table_attach(GTK_TABLE(table), label,
-                     0, 4, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
+                     0, 2, row, row+1, GTK_FILL, 0, 0, 0);
     row++;
 
     controls.resize
@@ -314,13 +314,13 @@ rotate_dialog(RotateArgs *args,
                                     GWY_ROTATE_RESIZE_CUT,
                                     NULL);
     row = gwy_radio_buttons_attach_to_table(controls.resize,
-                                            GTK_TABLE(table), 4, row);
+                                            GTK_TABLE(table), 2, row);
 
     controls.data = create_preview_data(data);
     controls.data_view = create_preview(controls.data, 0, PREVIEW_SIZE, FALSE);
     g_object_unref(controls.data);
     controls.selection = create_vector_layer(GWY_DATA_VIEW(controls.data_view),
-                                             0, "Lattice", TRUE);
+                                             0, "Lattice", FALSE);
     gwy_selection_set_max_objects(controls.selection, 1);
     gtk_box_pack_start(GTK_BOX(hbox), controls.data_view, FALSE, FALSE, 8);
 
