@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: scars.c 18966 2016-09-18 10:56:19Z yeti-dn $
+ *  @(#) $Id: scars.c 19948 2017-06-22 14:05:41Z yeti-dn $
  *  Copyright (C) 2003-2016 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -24,6 +24,7 @@
 #include <libgwyddion/gwymacros.h>
 #include <libgwyddion/gwymath.h>
 #include <libprocess/arithmetic.h>
+#include <libprocess/grains.h>
 #include <libprocess/correct.h>
 #include <libgwydgets/gwystock.h>
 #include <libgwydgets/gwyradiobuttons.h>
@@ -51,6 +52,8 @@ typedef struct {
     gint min_len;
     gint max_width;
     gboolean update;
+    gboolean combine;
+    GwyMergeType combine_type;
 } ScarsArgs;
 
 typedef struct {
@@ -64,6 +67,8 @@ typedef struct {
     GtkObject *max_width;
     GtkWidget *color_button;
     GtkWidget *update;
+    GtkWidget *combine;
+    GSList *combine_type;
     GwyContainer *mydata;
     gboolean computed;
     gboolean in_init;
@@ -77,10 +82,12 @@ static void     scars_mark                         (GwyContainer *data,
 static void     run_noninteractive                 (ScarsArgs *args,
                                                     GwyContainer *data,
                                                     GwyDataField *dfield,
+                                                    GwyDataField *existing_mask,
                                                     GQuark mquark);
 static void     scars_mark_dialog                  (ScarsArgs *args,
                                                     GwyContainer *data,
                                                     GwyDataField *dfield,
+                                                    GwyDataField *existing_mask,
                                                     gint id,
                                                     GQuark mquark);
 static void     scars_mark_dialog_update_controls  (ScarsControls *controls,
@@ -105,6 +112,8 @@ static const ScarsArgs scars_defaults = {
     16,
     4,
     TRUE,
+    FALSE,
+    GWY_MERGE_UNION,
 };
 
 static GwyModuleInfo module_info = {
@@ -112,12 +121,12 @@ static GwyModuleInfo module_info = {
     &module_register,
     N_("Marks and/or removes scars (horizontal linear artifacts)."),
     "Yeti <yeti@gwyddion.net>",
-    "1.13",
+    "1.15",
     "David Nečas (Yeti) & Petr Klapetek",
     "2004",
 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, scars)
 
 static gboolean
 module_register(void)
@@ -125,7 +134,7 @@ module_register(void)
     gwy_process_func_register("scars_mark",
                               (GwyProcessFunc)&scars_mark,
                               N_("/_Correct Data/M_ark Scars..."),
-                              GWY_STOCK_SCARS,
+                              GWY_STOCK_MARK_SCARS,
                               SCARS_MARK_RUN_MODES,
                               GWY_MENU_FLAG_DATA,
                               N_("Mark horizontal scars (strokes)"));
@@ -231,7 +240,7 @@ static void
 scars_mark(GwyContainer *data, GwyRunType run)
 {
     ScarsArgs args;
-    GwyDataField *dfield;
+    GwyDataField *dfield, *mask;
     GQuark mquark;
     gint id;
 
@@ -239,24 +248,26 @@ scars_mark(GwyContainer *data, GwyRunType run)
     scars_mark_load_args(gwy_app_settings_get(), &args);
     gwy_app_data_browser_get_current(GWY_APP_DATA_FIELD, &dfield,
                                      GWY_APP_MASK_FIELD_KEY, &mquark,
+                                     GWY_APP_MASK_FIELD, &mask,
                                      GWY_APP_DATA_FIELD_ID, &id,
                                      0);
     g_return_if_fail(dfield && mquark);
 
     if (run == GWY_RUN_IMMEDIATE) {
-        run_noninteractive(&args, data, dfield, mquark);
+        run_noninteractive(&args, data, dfield, mask, mquark);
         gwy_app_channel_log_add(data, id, id, "proc::scars_remove",
                                 "settings-name", "scars",
                                 NULL);
     }
     else
-        scars_mark_dialog(&args, data, dfield, id, mquark);
+        scars_mark_dialog(&args, data, dfield, mask, id, mquark);
 }
 
 static void
 run_noninteractive(ScarsArgs *args,
                    GwyContainer *data,
                    GwyDataField *dfield,
+                   GwyDataField *existing_mask,
                    GQuark mquark)
 {
     GwyDataField *mfield;
@@ -264,6 +275,12 @@ run_noninteractive(ScarsArgs *args,
     gwy_app_undo_qcheckpointv(data, 1, &mquark);
     mfield = create_mask_field(dfield);
     mark_scars(dfield, mfield, args);
+    if (existing_mask && args->combine) {
+        if (args->combine_type == GWY_MERGE_UNION)
+            gwy_data_field_grains_add(mfield, existing_mask);
+        else if (args->combine_type == GWY_MERGE_INTERSECTION)
+            gwy_data_field_grains_intersect(mfield, existing_mask);
+    }
     gwy_container_set_object(data, mquark, mfield);
     g_object_unref(mfield);
 }
@@ -272,6 +289,7 @@ static void
 scars_mark_dialog(ScarsArgs *args,
                   GwyContainer *data,
                   GwyDataField *dfield,
+                  GwyDataField *existing_mask,
                   gint id,
                   GQuark mquark)
 {
@@ -288,6 +306,7 @@ scars_mark_dialog(ScarsArgs *args,
     gboolean temp;
     gint row;
 
+    gwy_clear(&controls, 1);
     controls.in_init = TRUE;
     controls.args = args;
     dialog = gtk_dialog_new_with_buttons(_("Mark Scars"), NULL, 0, NULL);
@@ -310,6 +329,9 @@ scars_mark_dialog(ScarsArgs *args,
 
     controls.mydata = gwy_container_new();
     gwy_container_set_object_by_name(controls.mydata, "/0/data", dfield);
+    if (existing_mask)
+        gwy_container_set_object_by_name(controls.mydata, "/1/mask",
+                                         existing_mask);
     gwy_app_sync_data_items(data, controls.mydata, id, 0, FALSE,
                             GWY_DATA_ITEM_PALETTE,
                             GWY_DATA_ITEM_MASK_COLOR,
@@ -319,7 +341,7 @@ scars_mark_dialog(ScarsArgs *args,
     controls.view = create_preview(controls.mydata, 0, PREVIEW_SIZE, TRUE);
     gtk_box_pack_start(GTK_BOX(hbox), controls.view, FALSE, FALSE, 4);
 
-    table = gtk_table_new(11, 4, FALSE);
+    table = gtk_table_new(11 + 1*(!!existing_mask), 3, FALSE);
     gtk_table_set_row_spacings(GTK_TABLE(table), 2);
     gtk_table_set_col_spacings(GTK_TABLE(table), 6);
     gtk_container_set_border_width(GTK_CONTAINER(table), 4);
@@ -328,30 +350,32 @@ scars_mark_dialog(ScarsArgs *args,
 
     controls.max_width = gtk_adjustment_new(args->max_width,
                                             1.0, 16.0, 1, 3, 0);
-    gwy_table_attach_hscale(table, row++, _("Maximum _width:"), "px",
-                            controls.max_width, 0);
+    gwy_table_attach_adjbar(table, row++, _("Maximum _width:"), _("px"),
+                            controls.max_width,
+                            GWY_HSCALE_LINEAR | GWY_HSCALE_SNAP);
     g_signal_connect_swapped(controls.max_width, "value-changed",
                              G_CALLBACK(scars_invalidate), &controls);
 
     controls.min_len = gtk_adjustment_new(args->min_len,
                                           1.0, MAX_LENGTH, 1, 10, 0);
-    gwy_table_attach_hscale(table, row++, _("Minimum _length:"), "px",
-                            controls.min_len, GWY_HSCALE_SQRT);
+    gwy_table_attach_adjbar(table, row++, _("Minimum _length:"), _("px"),
+                            controls.min_len,
+                            GWY_HSCALE_DEFAULT | GWY_HSCALE_SNAP);
     g_signal_connect_swapped(controls.min_len, "value-changed",
                              G_CALLBACK(scars_invalidate), &controls);
 
     controls.threshold_high = gtk_adjustment_new(args->threshold_high,
                                                  0.0, 2.0, 0.01, 0.1, 0);
-    gwy_table_attach_hscale(table, row++, _("_Hard threshold:"),
-                            _("RMS"), controls.threshold_high, 0);
+    gwy_table_attach_adjbar(table, row++, _("_Hard threshold:"), _("RMS"),
+                            controls.threshold_high, GWY_HSCALE_LINEAR);
     g_signal_connect(controls.threshold_high, "value-changed",
                      G_CALLBACK(scars_mark_dialog_update_thresholds),
                      &controls);
 
     controls.threshold_low = gtk_adjustment_new(args->threshold_low,
                                                 0.0, 2.0, 0.01, 0.1, 0);
-    gwy_table_attach_hscale(table, row, _("_Soft threshold:"), _("RMS"),
-                            controls.threshold_low, 0);
+    gwy_table_attach_adjbar(table, row, _("_Soft threshold:"), _("RMS"),
+                            controls.threshold_low, GWY_HSCALE_LINEAR);
     g_signal_connect(controls.threshold_low, "value-changed",
                      G_CALLBACK(scars_mark_dialog_update_thresholds),
                      &controls);
@@ -361,7 +385,7 @@ scars_mark_dialog(ScarsArgs *args,
     label = gtk_label_new(_("Scars type:"));
     gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
     gtk_table_attach(GTK_TABLE(table), label,
-                     0, 4, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
+                     0, 2, row, row+1, GTK_FILL, 0, 0, 0);
     row++;
 
     group = gwy_radio_buttons_create(types, G_N_ELEMENTS(types),
@@ -369,7 +393,7 @@ scars_mark_dialog(ScarsArgs *args,
     controls.type = group;
     while (group) {
         gtk_table_attach(GTK_TABLE(table), GTK_WIDGET(group->data),
-                         0, 4, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
+                         0, 2, row, row+1, GTK_FILL, 0, 0, 0);
         g_signal_connect_swapped(group->data, "toggled",
                                  G_CALLBACK(scars_invalidate), &controls);
         group = g_slist_next(group);
@@ -378,16 +402,27 @@ scars_mark_dialog(ScarsArgs *args,
 
     controls.color_button = create_mask_color_button(controls.mydata, dialog,
                                                      0);
-    gwy_table_attach_hscale(table, row, _("_Mask color:"), NULL,
+    gwy_table_attach_adjbar(table, row, _("_Mask color:"), NULL,
                             GTK_OBJECT(controls.color_button),
                             GWY_HSCALE_WIDGET_NO_EXPAND);
     row++;
 
+    if (existing_mask) {
+        create_mask_merge_buttons(table, row, NULL,
+                                  args->combine,
+                                  G_CALLBACK(scars_invalidate),
+                                  args->combine_type,
+                                  G_CALLBACK(scars_invalidate),
+                                  &controls,
+                                  &controls.combine, &controls.combine_type);
+        row++;
+    }
+
     controls.update = gtk_check_button_new_with_mnemonic(_("I_nstant updates"));
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(controls.update),
                                  args->update);
     gtk_table_attach(GTK_TABLE(table), controls.update,
-                     0, 3, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
+                     0, 2, row, row+1, GTK_FILL, 0, 0, 0);
     g_signal_connect_swapped(controls.update, "toggled",
                              G_CALLBACK(update_change_cb), &controls);
     row++;
@@ -455,7 +490,7 @@ scars_mark_dialog(ScarsArgs *args,
     }
     else {
         g_object_unref(controls.mydata);
-        run_noninteractive(args, data, dfield, mquark);
+        run_noninteractive(args, data, dfield, existing_mask, mquark);
     }
 
     gwy_app_channel_log_add(data, id, id, "proc::scars_remove",
@@ -508,6 +543,12 @@ scars_mark_dialog_update_controls(ScarsControls *controls,
     gtk_adjustment_set_value(GTK_ADJUSTMENT(controls->max_width),
                              args->max_width);
     gwy_radio_buttons_set_current(controls->type, args->type);
+    if (controls->combine) {
+        gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(controls->combine),
+                                     args->combine);
+        gwy_radio_buttons_set_current(controls->combine_type,
+                                      args->combine_type);
+    }
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(controls->update),
                                  args->update);
 }
@@ -523,6 +564,12 @@ scars_mark_dialog_update_values(ScarsControls *controls,
     args->min_len = gwy_adjustment_get_int(controls->min_len);
     args->max_width = gwy_adjustment_get_int(controls->max_width);
     args->type = gwy_radio_buttons_get_current(controls->type);
+    if (controls->combine) {
+        args->combine
+            = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(controls->combine));
+        args->combine_type
+            = gwy_radio_buttons_get_current(controls->combine_type);
+    }
     args->update
         = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(controls->update));
 }
@@ -557,7 +604,7 @@ static void
 preview(ScarsControls *controls,
         ScarsArgs *args)
 {
-    GwyDataField *mask, *dfield;
+    GwyDataField *mask, *dfield, *existing_mask = NULL;
 
     dfield = GWY_DATA_FIELD(gwy_container_get_object_by_name(controls->mydata,
                                                              "/0/data"));
@@ -570,6 +617,15 @@ preview(ScarsControls *controls,
     }
     gwy_data_field_copy(dfield, mask, FALSE);
     mark_scars(dfield, mask, args);
+
+    gwy_container_gis_object_by_name(controls->mydata, "/1/mask",
+                                     &existing_mask);
+    if (existing_mask && args->combine) {
+        if (args->combine_type == GWY_MERGE_UNION)
+            gwy_data_field_grains_add(mask, existing_mask);
+        else if (args->combine_type == GWY_MERGE_INTERSECTION)
+            gwy_data_field_grains_intersect(mask, existing_mask);
+    }
     gwy_data_field_data_changed(mask);
 
     controls->computed = TRUE;
