@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: semsim.c 18537 2016-03-28 18:11:19Z yeti-dn $
+ *  @(#) $Id: semsim.c 19948 2017-06-22 14:05:41Z yeti-dn $
  *  Copyright (C) 2014 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
@@ -117,12 +117,12 @@ static GwyModuleInfo module_info = {
     &module_register,
     N_("Simple SEM image simulation from topography."),
     "Yeti <yeti@gwyddion.net>",
-    "1.0",
+    "1.1",
     "David Nečas (Yeti)",
     "2014",
 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, semsim)
 
 static gboolean
 module_register(void)
@@ -215,7 +215,7 @@ semsim_dialog(SEMsimArgs *args, GwyDataField *dfield)
     gtk_dialog_set_default_response(GTK_DIALOG(dialog), GTK_RESPONSE_OK);
     gwy_help_add_to_proc_dialog(GTK_DIALOG(dialog), GWY_HELP_DEFAULT);
 
-    table = gtk_table_new(6, 4, FALSE);
+    table = gtk_table_new(6, 3, FALSE);
     gtk_table_set_row_spacings(GTK_TABLE(table), 2);
     gtk_table_set_col_spacings(GTK_TABLE(table), 6);
     gtk_container_set_border_width(GTK_CONTAINER(table), 4);
@@ -224,8 +224,8 @@ semsim_dialog(SEMsimArgs *args, GwyDataField *dfield)
     row = 0;
 
     controls.sigma = gtk_adjustment_new(args->sigma, 0.5, MAX_SIZE, 0.1, 10, 0);
-    gwy_table_attach_hscale(table, row++, _("_Integration radius:"), "px",
-                            controls.sigma, GWY_HSCALE_SQRT);
+    gwy_table_attach_adjbar(table, row++, _("_Integration radius:"), _("px"),
+                            controls.sigma, GWY_HSCALE_DEFAULT);
     g_signal_connect_swapped(controls.sigma, "value-changed",
                              G_CALLBACK(sigma_changed), &controls);
     row++;
@@ -233,7 +233,7 @@ semsim_dialog(SEMsimArgs *args, GwyDataField *dfield)
     controls.value_sigma = gtk_label_new(NULL);
     gtk_misc_set_alignment(GTK_MISC(controls.value_sigma), 1.0, 0.5);
     gtk_table_attach(GTK_TABLE(table), controls.value_sigma,
-                     2, 3, row, row+1, GTK_FILL, 0, 0, 0);
+                     1, 2, row, row+1, GTK_FILL, 0, 0, 0);
 
     controls.format_sigma
         = gwy_data_field_get_value_format_xy(dfield,
@@ -243,13 +243,13 @@ semsim_dialog(SEMsimArgs *args, GwyDataField *dfield)
     gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
     gtk_label_set_markup(GTK_LABEL(label), controls.format_sigma->units);
     gtk_table_attach(GTK_TABLE(table), label,
-                     3, 4, row, row+1, GTK_FILL, 0, 0, 0);
+                     2, 3, row, row+1, GTK_FILL, 0, 0, 0);
     row++;
 
     label = gtk_label_new(_("Method:"));
     gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
     gtk_table_attach(GTK_TABLE(table), label,
-                     0, 1, row, row+1, GTK_FILL, 0, 0, 0);
+                     0, 2, row, row+1, GTK_FILL, 0, 0, 0);
     row++;
 
     controls.method
@@ -261,11 +261,11 @@ semsim_dialog(SEMsimArgs *args, GwyDataField *dfield)
                                     SEMSIM_METHOD_MONTECARLO,
                                     NULL);
     row = gwy_radio_buttons_attach_to_table(controls.method, GTK_TABLE(table),
-                                            3, row);
+                                            2, row);
 
     controls.quality = gtk_adjustment_new(args->quality, 1.0, 7.0, 0.1, 1.0, 0);
-    gwy_table_attach_hscale(table, row++, _("_Quality:"), NULL,
-                            controls.quality, GWY_HSCALE_SQRT);
+    gwy_table_attach_adjbar(table, row++, _("_Quality:"), NULL,
+                            controls.quality, GWY_HSCALE_DEFAULT);
     g_signal_connect_swapped(controls.quality, "value-changed",
                              G_CALLBACK(quality_changed), &controls);
     row++;
