@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: shade.c 18537 2016-03-28 18:11:19Z yeti-dn $
+ *  @(#) $Id: shade.c 19948 2017-06-22 14:05:41Z yeti-dn $
  *  Copyright (C) 2003 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -53,31 +53,33 @@ typedef struct {
     gboolean in_update;
 } ShadeControls;
 
-static gboolean    module_register              (void);
-static void        shade                        (GwyContainer *data,
-                                                 GwyRunType run);
-static gboolean    shade_dialog                 (ShadeArgs *args,
-                                                 GwyContainer *data,
-                                                 GwyDataField *dfield,
-                                                 gint id);
-static void        shade_changed_cb             (GtkWidget *shader,
-                                                 ShadeControls *controls);
-static void        theta_changed_cb             (GtkObject *adj,
-                                                 ShadeControls *controls);
-static void        phi_changed_cb               (GtkObject *adj,
-                                                 ShadeControls *controls);
-static void        mix_changed_cb               (ShadeControls *controls);
-static void        shade_dialog_update          (ShadeControls *controls,
-                                                 ShadeArgs *args);
-static void        shade_mix_with_plane         (GwyDataField *shaded,
-                                                 GwyDataField *plane,
-                                                 gdouble mixpercent);
-static void        load_args                    (GwyContainer *container,
-                                                 ShadeArgs *args);
-static void        save_args                    (GwyContainer *container,
-                                                 ShadeArgs *args);
-static void        sanitize_args                (ShadeArgs *args);
-
+static gboolean module_register     (void);
+static void     shade               (GwyContainer *data,
+                                     GwyRunType run);
+static gboolean shade_dialog        (ShadeArgs *args,
+                                     GwyContainer *data,
+                                     GwyDataField *dfield,
+                                     gint id);
+static void     shade_changed       (GtkWidget *shader,
+                                     ShadeControls *controls);
+static void     theta_changed       (GtkAdjustment *adj,
+                                     ShadeControls *controls);
+static void     phi_changed         (GtkAdjustment *adj,
+                                     ShadeControls *controls);
+static void     mix_changed         (GtkAdjustment *adj,
+                                     ShadeControls *controls);
+static void     do_mix_changed      (GtkToggleButton *toggle,
+                                     ShadeControls *controls);
+static void     shade_dialog_update (ShadeControls *controls,
+                                     ShadeArgs *args);
+static void     shade_mix_with_plane(GwyDataField *shaded,
+                                     GwyDataField *plane,
+                                     gdouble mixpercent);
+static void     load_args           (GwyContainer *container,
+                                     ShadeArgs *args);
+static void     save_args           (GwyContainer *container,
+                                     ShadeArgs *args);
+static void     sanitize_args       (ShadeArgs *args);
 
 static const ShadeArgs shade_defaults = {
     0,
@@ -91,12 +93,12 @@ static GwyModuleInfo module_info = {
     &module_register,
     N_("Creates a shaded presentation of data."),
     "Petr Klapetek <klapetek@gwyddion.net>",
-    "2.5",
+    "2.6",
     "David Nečas (Yeti) & Petr Klapetek",
     "2003",
 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, shade)
 
 static gboolean
 module_register(void)
@@ -142,7 +144,7 @@ shade(GwyContainer *data, GwyRunType run)
     gwy_app_undo_qcheckpointv(data, 1, &squark);
     if (!shadefield) {
         shadefield = gwy_data_field_new_alike(dfield, FALSE);
-        siunit = gwy_si_unit_new("");
+        siunit = gwy_si_unit_new(NULL);
         gwy_data_field_set_si_unit_z(shadefield, siunit);
         g_object_unref(siunit);
         gwy_container_set_object(data, squark, shadefield);
@@ -195,7 +197,7 @@ shade_dialog(ShadeArgs *args,
              GwyDataField *dfield,
              gint id)
 {
-    GtkWidget *dialog, *hbox, *table;
+    GtkWidget *dialog, *hbox, *table, *align;
     const guchar *pal;
     ShadeControls controls;
     gint response, row;
@@ -212,63 +214,61 @@ shade_dialog(ShadeArgs *args,
     gtk_dialog_set_default_response(GTK_DIALOG(dialog), GTK_RESPONSE_OK);
     gwy_help_add_to_proc_dialog(GTK_DIALOG(dialog), GWY_HELP_DEFAULT);
 
-    hbox = gtk_hbox_new(FALSE, 8);
+    align = gtk_alignment_new(0.5, 0.5, 1.0, 1.0);
+    gtk_alignment_set_padding(GTK_ALIGNMENT(align), 4, 4, 4, 4);
+    gtk_box_pack_start(GTK_BOX(GTK_DIALOG(dialog)->vbox),
+                       align, FALSE, FALSE, 0);
+
+    controls.data_view = create_preview(controls.data, 0, PREVIEW_SIZE, FALSE);
+    gtk_container_add(GTK_CONTAINER(align), controls.data_view);
+    g_object_unref(controls.data);
+
+    hbox = gtk_hbox_new(FALSE, 12);
     gtk_container_set_border_width(GTK_CONTAINER(hbox), 4);
     gtk_box_pack_start(GTK_BOX(GTK_DIALOG(dialog)->vbox), hbox, TRUE, TRUE, 4);
 
-    table = gtk_table_new(3, 3, FALSE);
-    gtk_box_pack_start(GTK_BOX(hbox), table, TRUE, TRUE, 0);
-    row = 0;
-
     pal = NULL;
     gwy_container_gis_string_by_name(controls.data, "/0/base/palette", &pal);
     controls.shader = gwy_shader_new(pal);
     gwy_shader_set_angle(GWY_SHADER(controls.shader), args->theta, args->phi);
-    gtk_widget_set_size_request(controls.shader, 72, 72);
+    gtk_widget_set_size_request(controls.shader, 80, 80);
     g_signal_connect(controls.shader, "angle_changed",
-                     G_CALLBACK(shade_changed_cb), &controls);
-    gtk_table_attach(GTK_TABLE(table), controls.shader, 0, 3, row, row+1,
-                     GTK_EXPAND | GTK_FILL, GTK_EXPAND | GTK_FILL, 2, 2);
-    gtk_table_set_row_spacing(GTK_TABLE(table), row, 8);
-    row++;
+                     G_CALLBACK(shade_changed), &controls);
+    gtk_box_pack_start(GTK_BOX(hbox), controls.shader, FALSE, TRUE, 0);
+
+    table = gtk_table_new(3, 3, FALSE);
+    gtk_box_pack_start(GTK_BOX(hbox), table, TRUE, TRUE, 0);
+    row = 0;
 
     controls.theta = gtk_adjustment_new(args->theta*180.0/G_PI,
                                         0.0, 90.0, 1.0, 15.0, 0.0);
-    gwy_table_attach_hscale(table, row, _("θ:"), _("deg"),
-                            controls.theta, GWY_HSCALE_DEFAULT);
+    gwy_table_attach_adjbar(table, row, _("θ:"), _("deg"),
+                            controls.theta, GWY_HSCALE_LINEAR);
     g_signal_connect(controls.theta, "value-changed",
-                     G_CALLBACK(theta_changed_cb), &controls);
+                     G_CALLBACK(theta_changed), &controls);
     row++;
 
     controls.phi = gtk_adjustment_new(args->phi*180.0/G_PI,
                                       0.0, 360.0, 1.0, 30.0, 0.0);
-    gwy_table_attach_hscale(table, row, _("φ:"), _("deg"),
-                            controls.phi, GWY_HSCALE_DEFAULT);
+    gwy_table_attach_adjbar(table, row, _("φ:"), _("deg"),
+                            controls.phi, GWY_HSCALE_LINEAR);
     g_signal_connect(controls.phi, "value-changed",
-                     G_CALLBACK(phi_changed_cb), &controls);
+                     G_CALLBACK(phi_changed), &controls);
     row++;
 
     controls.mix = gtk_adjustment_new(args->mix, 0.0, 100.0, 1, 5, 0);
+    gwy_table_attach_adjbar(table, row, _("_Mix:"), "%",
+                            controls.mix, GWY_HSCALE_LINEAR | GWY_HSCALE_CHECK);
+    g_signal_connect(controls.mix, "value-changed",
+                     G_CALLBACK(mix_changed), &controls);
 
-    gwy_table_attach_hscale(table, row, _("_Mix:"), "%",
-                            controls.mix, GWY_HSCALE_CHECK);
-
-    controls.do_mix = g_object_get_data(G_OBJECT(controls.mix), "check");
-
-    gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(controls.do_mix),
-                                 !args->do_mix);
+    controls.do_mix = gwy_table_hscale_get_check(controls.mix);
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(controls.do_mix),
                                  args->do_mix);
-    g_signal_connect_swapped(controls.mix, "value-changed",
-                             G_CALLBACK(mix_changed_cb), &controls);
-
-    g_signal_connect_swapped(controls.do_mix, "toggled",
-                             G_CALLBACK(mix_changed_cb), &controls);
+    g_signal_connect(controls.do_mix, "toggled",
+                     G_CALLBACK(do_mix_changed), &controls);
 
     row++;
-    controls.data_view = create_preview(controls.data, 0, PREVIEW_SIZE, FALSE);
-    g_object_unref(controls.data);
-    gtk_box_pack_start(GTK_BOX(hbox), controls.data_view, FALSE, FALSE, 8);
 
     controls.in_update = FALSE;
     shade_dialog_update(&controls, args);
@@ -290,8 +290,6 @@ shade_dialog(ShadeArgs *args,
             case RESPONSE_RESET:
             *args = shade_defaults;
             gtk_adjustment_set_value(GTK_ADJUSTMENT(controls.mix), args->mix);
-            gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(controls.do_mix),
-                                         !args->do_mix);
             gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(controls.do_mix),
                                          args->do_mix);
             gwy_shader_set_angle(GWY_SHADER(controls.shader),
@@ -310,16 +308,14 @@ shade_dialog(ShadeArgs *args,
 }
 
 static void
-shade_changed_cb(GtkWidget *shader,
-                 ShadeControls *controls)
+shade_changed(GtkWidget *shader, ShadeControls *controls)
 {
-    ShadeArgs *args;
+    ShadeArgs *args = controls->args;
 
     if (controls->in_update)
         return;
 
     controls->in_update = TRUE;
-    args = controls->args;
     args->theta = gwy_shader_get_theta(GWY_SHADER(shader));
     args->phi = gwy_shader_get_phi(GWY_SHADER(shader));
     gtk_adjustment_set_value(GTK_ADJUSTMENT(controls->theta),
@@ -331,16 +327,14 @@ shade_changed_cb(GtkWidget *shader,
 }
 
 static void
-theta_changed_cb(GtkObject *adj,
-                 ShadeControls *controls)
+theta_changed(GtkAdjustment *adj, ShadeControls *controls)
 {
-    ShadeArgs *args;
+    ShadeArgs *args = controls->args;
 
     if (controls->in_update)
         return;
 
     controls->in_update = TRUE;
-    args = controls->args;
     args->theta = gtk_adjustment_get_value(GTK_ADJUSTMENT(adj))/180.0*G_PI;
     gwy_shader_set_theta(GWY_SHADER(controls->shader), args->theta);
     shade_dialog_update(controls, args);
@@ -348,43 +342,50 @@ theta_changed_cb(GtkObject *adj,
 }
 
 static void
-phi_changed_cb(GtkObject *adj,
-               ShadeControls *controls)
+phi_changed(GtkAdjustment *adj, ShadeControls *controls)
 {
-    ShadeArgs *args;
+    ShadeArgs *args = controls->args;
 
     if (controls->in_update)
         return;
 
     controls->in_update = TRUE;
-    args = controls->args;
-    args->phi = gtk_adjustment_get_value(GTK_ADJUSTMENT(adj))/180.0*G_PI;
+    args->phi = gtk_adjustment_get_value(adj)/180.0*G_PI;
     gwy_shader_set_phi(GWY_SHADER(controls->shader), args->phi);
     shade_dialog_update(controls, args);
     controls->in_update = FALSE;
 }
 
 static void
-mix_changed_cb(ShadeControls *controls)
+mix_changed(GtkAdjustment *adj, ShadeControls *controls)
 {
-    ShadeArgs *args;
+    ShadeArgs *args = controls->args;
 
     if (controls->in_update)
         return;
 
     controls->in_update = TRUE;
-    args = controls->args;
-    args->mix = gtk_adjustment_get_value(GTK_ADJUSTMENT(controls->mix));
-    args->do_mix = gtk_toggle_button_get_active(
-                                         GTK_TOGGLE_BUTTON(controls->do_mix));
+    args->mix = gtk_adjustment_get_value(adj);
     shade_dialog_update(controls, args);
     controls->in_update = FALSE;
 }
 
+static void
+do_mix_changed(GtkToggleButton *toggle, ShadeControls *controls)
+{
+    ShadeArgs *args = controls->args;
+
+    if (controls->in_update)
+        return;
+
+    controls->in_update = TRUE;
+    args->do_mix = gtk_toggle_button_get_active(toggle);
+    shade_dialog_update(controls, args);
+    controls->in_update = FALSE;
+}
 
 static void
-shade_dialog_update(ShadeControls *controls,
-                    ShadeArgs *args)
+shade_dialog_update(ShadeControls *controls, ShadeArgs *args)
 {
     GwyDataField *dfield, *shader;
 
@@ -394,9 +395,8 @@ shade_dialog_update(ShadeControls *controls,
                                                              "/0/data"));
     gwy_data_field_shade(dfield, shader, args->theta, args->phi);
 
-    if (args->do_mix) {
+    if (args->do_mix)
         shade_mix_with_plane(shader, dfield, args->mix);
-    }
 
     gwy_data_field_data_changed(shader);
 }
@@ -410,7 +410,7 @@ shade_mix_with_plane(GwyDataField *shaded,
     gdouble plane_min, plane_max, shade_min, shade_max;
     gdouble plane_range, shade_range;
 
-    mixpercent /= 100;
+    mixpercent /= 100.0;
 
     gwy_data_field_get_min_max(plane, &plane_min, &plane_max);
     gwy_data_field_get_min_max(shaded, &shade_min, &shade_max);
@@ -424,7 +424,6 @@ shade_mix_with_plane(GwyDataField *shaded,
     gwy_data_field_sum_fields(shaded, shaded, mix);
 
     g_object_unref(mix);
-
 }
 
 static const gchar theta_key[]  = "/module/shade/theta";
