@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: slope_dist.c 18626 2016-04-22 10:15:13Z yeti-dn $
+ *  @(#) $Id: slope_dist.c 19948 2017-06-22 14:05:41Z yeti-dn $
  *  Copyright (C) 2004 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -72,7 +72,6 @@ typedef struct {
     GtkWidget *update;
     GtkObject *kernel_size;
     GtkWidget *target_graph;
-    GtkWidget *target_hbox;
     GSList *masking;
 
     GwyDataField *dfield;
@@ -161,12 +160,12 @@ static GwyModuleInfo module_info = {
     N_("Calculates one- or two-dimensional distribution of slopes "
        "or graph of their angular distribution."),
     "Yeti <yeti@gwyddion.net>",
-    "2.2",
+    "2.3",
     "David Nečas (Yeti) & Petr Klapetek",
     "2004",
 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, slope_dist)
 
 static gboolean
 module_register(void)
@@ -255,7 +254,7 @@ slope_dialog(SlopeArgs *args, gboolean same_units,
         { N_("_Inclination (θ) graph"),        SLOPE_DIST_GRAPH_THETA,    },
         { N_("Inclination (gra_dient) graph"), SLOPE_DIST_GRAPH_GRADIENT, },
     };
-    GtkWidget *dialog, *table, *label, *hbox, *hbox2, *vbox, *button;
+    GtkWidget *dialog, *table, *label, *hbox, *vbox, *button;
     GwyDataChooser *chooser;
     GwyGraphModel *gmodel;
     SlopeControls controls;
@@ -308,12 +307,13 @@ slope_dialog(SlopeArgs *args, gboolean same_units,
     set_graph_model_units(gmodel, dfield, args->output_type);
     controls.graph = gwy_graph_new(gmodel);
     gtk_widget_set_size_request(controls.graph, PREVIEW_SIZE, -1);
+    gwy_graph_enable_user_input(GWY_GRAPH(controls.graph), FALSE);
     g_object_unref(gmodel);
     gtk_box_pack_start(GTK_BOX(vbox), controls.graph, TRUE, TRUE, 0);
     if (args->output_type == SLOPE_DIST_2D_DIST)
         gtk_widget_set_no_show_all(controls.graph, TRUE);
 
-    table = gtk_table_new(11 + (mfield ? 4 : 0), 4, FALSE);
+    table = gtk_table_new(11 + (mfield ? 4 : 0), 3, FALSE);
     gtk_table_set_row_spacings(GTK_TABLE(table), 2);
     gtk_table_set_col_spacings(GTK_TABLE(table), 6);
     gtk_container_set_border_width(GTK_CONTAINER(table), 4);
@@ -323,7 +323,7 @@ slope_dialog(SlopeArgs *args, gboolean same_units,
     label = gtk_label_new(_("Output type:"));
     gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
     gtk_table_attach(GTK_TABLE(table), label,
-                     0, 4, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
+                     0, 2, row, row+1, GTK_FILL, 0, 0, 0);
     row++;
 
     controls.output_type
@@ -332,7 +332,7 @@ slope_dialog(SlopeArgs *args, gboolean same_units,
                                    &controls,
                                    args->output_type);
     row = gwy_radio_buttons_attach_to_table(controls.output_type,
-                                            GTK_TABLE(table), 4, row);
+                                            GTK_TABLE(table), 2, row);
     if (!same_units) {
         GtkWidget *radio;
 
@@ -342,14 +342,6 @@ slope_dialog(SlopeArgs *args, gboolean same_units,
     }
 
     gtk_table_set_row_spacing(GTK_TABLE(table), row-1, 8);
-    controls.target_hbox = hbox2 = gtk_hbox_new(FALSE, 6);
-    gtk_table_attach(GTK_TABLE(table), hbox2,
-                     0, 4, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
-
-    label = gtk_label_new_with_mnemonic(_("Target _graph:"));
-    gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
-    gtk_box_pack_start(GTK_BOX(hbox2), label, FALSE, FALSE, 0);
-
     controls.target_graph = gwy_data_chooser_new_graphs();
     chooser = GWY_DATA_CHOOSER(controls.target_graph);
     gwy_data_chooser_set_none(chooser, _("New graph"));
@@ -357,8 +349,8 @@ slope_dialog(SlopeArgs *args, gboolean same_units,
     gwy_data_chooser_set_filter(chooser, filter_target_graphs, &controls, NULL);
     gwy_data_chooser_set_active_id(chooser, &args->target_graph);
     gwy_data_chooser_get_active_id(chooser, &args->target_graph);
-    gtk_label_set_mnemonic_widget(GTK_LABEL(label), controls.target_graph);
-    gtk_box_pack_end(GTK_BOX(hbox2), controls.target_graph, FALSE, FALSE, 0);
+    gwy_table_attach_adjbar(table, row, _("Target _graph:"), NULL,
+                            GTK_OBJECT(chooser), GWY_HSCALE_WIDGET_NO_EXPAND);
     g_signal_connect_swapped(controls.target_graph, "changed",
                              G_CALLBACK(target_graph_changed), &controls);
     row++;
@@ -366,11 +358,11 @@ slope_dialog(SlopeArgs *args, gboolean same_units,
     gtk_table_set_row_spacing(GTK_TABLE(table), row-1, 8);
     label = gwy_label_new_header(_("Options"));
     gtk_table_attach(GTK_TABLE(table), label,
-                     0, 3, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
+                     0, 2, row, row+1, GTK_FILL, 0, 0, 0);
     row++;
 
     controls.size = gtk_adjustment_new(args->size, 10, MAX_OUT_SIZE, 1, 10, 0);
-    gwy_table_attach_hscale(table, row, _("Output _size:"), "px",
+    gwy_table_attach_adjbar(table, row, _("Output _size:"), _("px"),
                             controls.size, GWY_HSCALE_SQRT);
     g_signal_connect_swapped(controls.size, "value-changed",
                              G_CALLBACK(size_changed), &controls);
@@ -381,7 +373,7 @@ slope_dialog(SlopeArgs *args, gboolean same_units,
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(controls.logscale),
                                  args->logscale);
     gtk_table_attach(GTK_TABLE(table), controls.logscale,
-                     0, 4, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
+                     0, 2, row, row+1, GTK_FILL, 0, 0, 0);
     g_signal_connect_swapped(controls.logscale, "toggled",
                              G_CALLBACK(logscale_changed), &controls);
     row++;
@@ -391,15 +383,16 @@ slope_dialog(SlopeArgs *args, gboolean same_units,
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(controls.fit_plane),
                                  args->fit_plane);
     gtk_table_attach(GTK_TABLE(table), controls.fit_plane,
-                     0, 4, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
+                     0, 2, row, row+1, GTK_FILL, 0, 0, 0);
     g_signal_connect_swapped(controls.fit_plane, "toggled",
                              G_CALLBACK(fit_plane_changed), &controls);
     row++;
 
     controls.kernel_size = gtk_adjustment_new(args->kernel_size,
                                               2, 16, 1, 4, 0);
-    gwy_table_attach_hscale(table, row, _("_Plane size:"), "px",
-                            controls.kernel_size, 0);
+    gwy_table_attach_adjbar(table, row, _("_Plane size:"), _("px"),
+                            controls.kernel_size,
+                            GWY_HSCALE_LINEAR | GWY_HSCALE_SNAP);
     g_signal_connect_swapped(controls.kernel_size, "value-changed",
                              G_CALLBACK(kernel_size_changed), &controls);
     row++;
@@ -408,7 +401,7 @@ slope_dialog(SlopeArgs *args, gboolean same_units,
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(controls.update),
                                  args->update);
     gtk_table_attach(GTK_TABLE(table), controls.update,
-                     0, 3, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
+                     0, 2, row, row+1, GTK_FILL, 0, 0, 0);
     g_signal_connect_swapped(controls.update, "toggled",
                              G_CALLBACK(update_changed), &controls);
     row++;
@@ -417,7 +410,7 @@ slope_dialog(SlopeArgs *args, gboolean same_units,
         gtk_table_set_row_spacing(GTK_TABLE(table), row-1, 8);
         label = gwy_label_new_header(_("Masking Mode"));
         gtk_table_attach(GTK_TABLE(table), label,
-                        0, 3, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
+                        0, 2, row, row+1, GTK_FILL, 0, 0, 0);
         row++;
 
         controls.masking
@@ -425,7 +418,7 @@ slope_dialog(SlopeArgs *args, gboolean same_units,
                                        G_CALLBACK(masking_changed), &controls,
                                        args->masking);
         row = gwy_radio_buttons_attach_to_table(controls.masking,
-                                                GTK_TABLE(table), 3, row);
+                                                GTK_TABLE(table), 2, row);
     }
     else
         controls.masking = NULL;
@@ -531,7 +524,8 @@ output_type_changed(GtkToggleButton *button, SlopeControls *controls)
     otype = gwy_radio_buttons_get_current(controls->output_type);
     controls->args->output_type = otype;
     gtk_widget_set_sensitive(controls->logscale, otype == SLOPE_DIST_2D_DIST);
-    gtk_widget_set_sensitive(controls->target_hbox, otype != SLOPE_DIST_2D_DIST);
+    gwy_table_hscale_set_sensitive(GTK_OBJECT(controls->target_graph),
+                                   otype != SLOPE_DIST_2D_DIST);
     if (otype == SLOPE_DIST_2D_DIST) {
         gtk_widget_set_no_show_all(controls->graph, TRUE);
         gtk_widget_set_no_show_all(controls->view, FALSE);
