@@ -1,6 +1,6 @@
 /*
- *  @(#) $Id: sphere-revolve.c 19044 2016-10-08 19:10:46Z yeti-dn $
- *  Copyright (C) 2004 David Necas (Yeti), Petr Klapetek.
+ *  @(#) $Id: sphere-revolve.c 20013 2017-07-03 12:01:55Z yeti-dn $
+ *  Copyright (C) 2004-2017 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -20,12 +20,13 @@
  */
 
 #include "config.h"
-#include <libgwyddion/gwymacros.h>
 #include <string.h>
 #include <gtk/gtk.h>
+#include <libgwyddion/gwymacros.h>
 #include <libgwyddion/gwymath.h>
 #include <libprocess/stats.h>
 #include <libprocess/arithmetic.h>
+#include <libprocess/filters.h>
 #include <libgwydgets/gwydgetutils.h>
 #include <libgwydgets/gwyradiobuttons.h>
 #include <libgwymodule/gwymodule-process.h>
@@ -38,16 +39,16 @@ typedef enum {
     SPHREV_HORIZONTAL = 1,
     SPHREV_VERTICAL,
     SPHREV_BOTH
-} Sphrev1DDirection;
+} SphrevDirection;
 
 typedef struct {
-    Sphrev1DDirection direction;
     gdouble size;
     gboolean do_extract;
+    SphrevDirection direction;  /* only in 1D */
     /* interface only */
     GwySIValueFormat *valform;
     gdouble pixelsize;
-} Sphrev1DArgs;
+} SphrevArgs;
 
 typedef struct {
     GSList *direction;
@@ -55,38 +56,51 @@ typedef struct {
     GtkObject *size;
     GtkWidget *do_extract;
     gboolean in_update;
-} Sphrev1DControls;
+} SphrevControls;
 
-static gboolean      module_register           (void);
-static void          sphrev                    (GwyContainer *data,
-                                                GwyRunType run);
-static GwyDataField* sphrev_horizontal         (Sphrev1DArgs *args,
-                                                GwyDataField *dfield);
-static GwyDataField* sphrev_vertical           (Sphrev1DArgs *args,
-                                                GwyDataField *dfield);
-static GwyDataLine*  sphrev_make_sphere        (gdouble radius,
-                                                gint maxres);
-static gboolean      sphrev_dialog             (Sphrev1DArgs *args);
-static void          direction_changed_cb      (GtkWidget *radio,
-                                                Sphrev1DArgs *args);
-static void          radius_changed_cb         (GtkAdjustment *adj,
-                                                Sphrev1DArgs *args);
-static void          size_changed_cb           (GtkAdjustment *adj,
-                                                Sphrev1DArgs *args);
-static void          do_extract_changed_cb     (GtkWidget *check,
-                                                Sphrev1DArgs *args);
-static void          sphrev_dialog_update      (Sphrev1DControls *controls,
-                                                Sphrev1DArgs *args);
-static void          sphrev_sanitize_args      (Sphrev1DArgs *args);
-static void          sphrev_load_args          (GwyContainer *container,
-                                                Sphrev1DArgs *args);
-static void          sphrev_save_args          (GwyContainer *container,
-                                                Sphrev1DArgs *args);
+static gboolean      module_register     (void);
+static void          arcrev              (GwyContainer *data,
+                                          GwyRunType run);
+static void          sphrev              (GwyContainer *data,
+                                          GwyRunType run);
+static gboolean      sphrev_dialog       (SphrevArgs *args,
+                                          gboolean is_2d);
+static void          direction_changed   (GtkWidget *radio,
+                                          SphrevArgs *args);
+static void          radius_changed      (GtkAdjustment *adj,
+                                          SphrevArgs *args);
+static void          size_changed        (GtkAdjustment *adj,
+                                          SphrevArgs *args);
+static void          do_extract_changed  (GtkWidget *check,
+                                          SphrevArgs *args);
+static void          sphrev_dialog_update(SphrevControls *controls,
+                                          SphrevArgs *args);
+static GwyDataField* arcrev_horizontal   (SphrevArgs *args,
+                                          GwyDataField *dfield);
+static GwyDataField* arcrev_vertical     (SphrevArgs *args,
+                                          GwyDataField *dfield);
+static GwyDataLine*  arcrev_make_arc     (gdouble radius,
+                                          gint maxres);
+static GwyDataField* sphrev_make_sphere  (gdouble radius,
+                                          gint maxres);
+static GwyDataField* sphrev_2d           (SphrevArgs *args,
+                                          GwyDataField *dfield,
+                                          GwySetMessageFunc set_message,
+                                          GwySetFractionFunc set_fraction);
+static void          sphrev_sanitize_args(SphrevArgs *args);
+static void          arcrev_load_args    (GwyContainer *container,
+                                          SphrevArgs *args);
+static void          arcrev_save_args    (GwyContainer *container,
+                                          SphrevArgs *args);
+static void          sphrev_load_args    (GwyContainer *container,
+                                          SphrevArgs *args);
+static void          sphrev_save_args    (GwyContainer *container,
+                                          SphrevArgs *args);
 
-static const Sphrev1DArgs sphrev_defaults = {
-    SPHREV_HORIZONTAL,
+static const SphrevArgs sphrev_defaults = {
     20,
     FALSE,
+    SPHREV_HORIZONTAL,
     NULL,
     0,
 };
@@ -96,34 +110,40 @@ static GwyModuleInfo module_info = {
     &module_register,
     N_("Subtracts background by arc or sphere revolution."),
     "Yeti <yeti@gwyddion.net>",
-    "1.6",
+    "2.0",
     "David Nečas (Yeti) & Petr Klapetek",
     "2004",
 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, sphere_revolve)
 
 static gboolean
 module_register(void)
 {
-    /* The name mismatch is intentional, there should be a sphere_revolve
-     * function too */
     gwy_process_func_register("arc_revolve",
-                              (GwyProcessFunc)&sphrev,
+                              (GwyProcessFunc)&arcrev,
                               N_("/_Level/Revolve _Arc..."),
                               NULL,
                               SPHREV_RUN_MODES,
                               GWY_MENU_FLAG_DATA,
                               N_("Level data by arc revolution"));
+    gwy_process_func_register("sphere_revolve",
+                              (GwyProcessFunc)&sphrev,
+                              N_("/_Level/Revolve _Sphere..."),
+                              NULL,
+                              SPHREV_RUN_MODES,
+                              GWY_MENU_FLAG_DATA,
+                              N_("Level data by sphere revolution"));
 
     return TRUE;
 }
 
 static void
-sphrev(GwyContainer *data, GwyRunType run)
+arcrev(GwyContainer *data, GwyRunType run)
 {
     GwyDataField *dfield, *background = NULL;
-    Sphrev1DArgs args;
+    GwyContainer *settings;
+    SphrevArgs args;
     gint oldid, newid;
     GQuark dquark;
     gdouble xr, yr;
@@ -136,7 +156,8 @@ sphrev(GwyContainer *data, GwyRunType run)
                                      0);
     g_return_if_fail(dfield && dquark);
 
-    sphrev_load_args(gwy_app_settings_get(), &args);
+    settings = gwy_app_settings_get();
+    arcrev_load_args(settings, &args);
 
     /* FIXME: this is bogus for non-square pixels anyway */
     xr = gwy_data_field_get_xreal(dfield)/gwy_data_field_get_xres(dfield);
@@ -150,8 +171,8 @@ sphrev(GwyContainer *data, GwyRunType run)
               args.valform->units);
 
     if (run == GWY_RUN_INTERACTIVE) {
-        ok = sphrev_dialog(&args);
-        sphrev_save_args(gwy_app_settings_get(), &args);
+        ok = sphrev_dialog(&args, FALSE);
+        arcrev_save_args(settings, &args);
     }
 
     gwy_si_unit_value_format_free(args.valform);
@@ -161,18 +182,18 @@ sphrev(GwyContainer *data, GwyRunType run)
     gwy_app_undo_qcheckpointv(data, 1, &dquark);
     switch (args.direction) {
         case SPHREV_HORIZONTAL:
-        background = sphrev_horizontal(&args, dfield);
+        background = arcrev_horizontal(&args, dfield);
         break;
 
         case SPHREV_VERTICAL:
-        background = sphrev_vertical(&args, dfield);
+        background = arcrev_vertical(&args, dfield);
         break;
 
         case SPHREV_BOTH: {
             GwyDataField *tmp;
 
-            background = sphrev_horizontal(&args, dfield);
-            tmp = sphrev_vertical(&args, dfield);
+            background = arcrev_horizontal(&args, dfield);
+            tmp = arcrev_vertical(&args, dfield);
             gwy_data_field_sum_fields(background, background, tmp);
             g_object_unref(tmp);
             gwy_data_field_multiply(background, 0.5);
@@ -201,20 +222,98 @@ sphrev(GwyContainer *data, GwyRunType run)
     gwy_app_channel_log_add(data, oldid, newid, NULL, NULL);
 }
 
+static void
+sphrev(GwyContainer *data, GwyRunType run)
+{
+    GwyDataField *dfield, *background = NULL;
+    GtkWindow *window;
+    GwyContainer *settings;
+    SphrevArgs args;
+    gint oldid, newid;
+    GQuark dquark;
+    gdouble xr, yr;
+    gboolean ok = TRUE;
+
+    g_return_if_fail(run & SPHREV_RUN_MODES);
+    gwy_app_data_browser_get_current(GWY_APP_DATA_FIELD, &dfield,
+                                     GWY_APP_DATA_FIELD_KEY, &dquark,
+                                     GWY_APP_DATA_FIELD_ID, &oldid,
+                                     0);
+    g_return_if_fail(dfield && dquark);
+
+    settings = gwy_app_settings_get();
+    sphrev_load_args(settings, &args);
+
+    /* FIXME: this is bogus for non-square pixels anyway */
+    xr = gwy_data_field_get_xreal(dfield)/gwy_data_field_get_xres(dfield);
+    yr = gwy_data_field_get_yreal(dfield)/gwy_data_field_get_yres(dfield);
+    args.pixelsize = hypot(xr, yr);
+    args.valform
+        = gwy_data_field_get_value_format_xy(dfield,
+                                             GWY_SI_UNIT_FORMAT_VFMARKUP, NULL);
+    gwy_debug("pixelsize = %g, vf = (%g, %d, %s)",
+              args.pixelsize, args.valform->magnitude, args.valform->precision,
+              args.valform->units);
+
+    if (run == GWY_RUN_INTERACTIVE) {
+        ok = sphrev_dialog(&args, TRUE);
+        sphrev_save_args(settings, &args);
+    }
+
+    gwy_si_unit_value_format_free(args.valform);
+    if (!ok)
+        return;
+
+    window = gwy_app_find_window_for_channel(data, oldid);
+    if (window) {
+        gwy_app_wait_start(window, _("Initializing..."));
+        background = sphrev_2d(&args, dfield,
+                               gwy_app_wait_set_message,
+                               gwy_app_wait_set_fraction);
+        gwy_app_wait_finish();
+        if (!background)
+            return;
+    }
+    else
+        background = sphrev_2d(&args, dfield, NULL, NULL);
+
+    gwy_app_undo_qcheckpointv(data, 1, &dquark);
+    gwy_data_field_subtract_fields(dfield, dfield, background);
+    gwy_data_field_data_changed(dfield);
+    gwy_app_channel_log_add_proc(data, oldid, oldid);
+
+    if (!args.do_extract) {
+        g_object_unref(background);
+        return;
+    }
+
+    newid = gwy_app_data_browser_add_data_field(background, data, TRUE);
+    g_object_unref(background);
+    gwy_app_sync_data_items(data, data, oldid, newid, FALSE,
+                            GWY_DATA_ITEM_GRADIENT,
+                            0);
+    gwy_app_set_data_field_title(data, newid, _("Background"));
+    gwy_app_channel_log_add(data, oldid, newid, NULL, NULL);
+}
+
 static gboolean
-sphrev_dialog(Sphrev1DArgs *args)
+sphrev_dialog(SphrevArgs *args, gboolean is_2d)
 {
     const GwyEnum directions[] = {
         { N_("_Horizontal direction"), SPHREV_HORIZONTAL, },
         { N_("_Vertical direction"),   SPHREV_VERTICAL,   },
         { N_("_Both directions"),      SPHREV_BOTH,   },
     };
-    GtkWidget *dialog, *table, *spin;
-    Sphrev1DControls controls;
+    GtkWidget *dialog, *table, *spin, *label;
+    SphrevControls controls;
     gint response, row;
+    const gchar *title;
     gdouble q;
 
-    dialog = gtk_dialog_new_with_buttons(_("Revolve Arc"), NULL, 0,
+    gwy_clear(&controls, 1);
+
+    title = is_2d ? _("Revolve Sphere") : _("Revolve Arc");
+    dialog = gtk_dialog_new_with_buttons(title, NULL, 0,
                                          _("_Reset"), RESPONSE_RESET,
                                          GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
                                          GTK_STOCK_OK, GTK_RESPONSE_OK,
@@ -222,7 +321,7 @@ sphrev_dialog(Sphrev1DArgs *args)
     gtk_dialog_set_default_response(GTK_DIALOG(dialog), GTK_RESPONSE_OK);
     gwy_help_add_to_proc_dialog(GTK_DIALOG(dialog), GWY_HELP_DEFAULT);
 
-    table = gtk_table_new(5, 4, FALSE);
+    table = gtk_table_new(3 + 4*(!is_2d), 3, FALSE);
     gtk_table_set_row_spacings(GTK_TABLE(table), 2);
     gtk_table_set_col_spacings(GTK_TABLE(table), 6);
     gtk_container_set_border_width(GTK_CONTAINER(table), 4);
@@ -233,40 +332,49 @@ sphrev_dialog(Sphrev1DArgs *args)
 
     q = args->pixelsize/args->valform->magnitude;
     gwy_debug("q = %f", q);
-    controls.radius = gtk_adjustment_new(q*args->size, q, 16384*q, q, 10*q, 0);
-    spin = gwy_table_attach_hscale(table, row, _("Real _radius:"),
+    controls.radius = gtk_adjustment_new(q*args->size, q, 1024*q, q, 10*q, 0);
+    spin = gwy_table_attach_adjbar(table, row, _("Real _radius:"),
                                    args->valform->units, controls.radius,
                                    GWY_HSCALE_SQRT);
     gtk_spin_button_set_digits(GTK_SPIN_BUTTON(spin), args->valform->precision);
     g_object_set_data(G_OBJECT(controls.radius), "controls", &controls);
     g_signal_connect(controls.radius, "value-changed",
-                     G_CALLBACK(radius_changed_cb), args);
+                     G_CALLBACK(radius_changed), args);
     row++;
 
-    controls.size = gtk_adjustment_new(args->size, 1, 16384, 1, 10, 0);
-    gwy_table_attach_hscale(table, row, _("_Pixel radius:"), "px",
-                            controls.size, GWY_HSCALE_SQRT);
+    controls.size = gtk_adjustment_new(args->size, 1, 1024, 1, 10, 0);
+    gwy_table_attach_adjbar(table, row, _("_Pixel radius:"), _("px"),
+                            controls.size, GWY_HSCALE_SQRT | GWY_HSCALE_SNAP);
     g_object_set_data(G_OBJECT(controls.size), "controls", &controls);
     g_signal_connect(controls.size, "value-changed",
-                     G_CALLBACK(size_changed_cb), args);
+                     G_CALLBACK(size_changed), args);
     row++;
 
-    controls.direction
-        = gwy_radio_buttons_create(directions, G_N_ELEMENTS(directions),
-                                   G_CALLBACK(direction_changed_cb), args,
-                                   args->direction);
-    row = gwy_radio_buttons_attach_to_table(controls.direction,
-                                            GTK_TABLE(table), 4, row);
+    if (!is_2d) {
+        gtk_table_set_row_spacing(GTK_TABLE(table), row-1, 8);
+        label = gtk_label_new(_("Direction:"));
+        gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
+        gtk_table_attach(GTK_TABLE(table), label,
+                         0, 2, row, row+1, GTK_FILL, 0, 0, 0);
+        row++;
 
-    row += 3;
+        controls.direction
+            = gwy_radio_buttons_create(directions, G_N_ELEMENTS(directions),
+                                       G_CALLBACK(direction_changed), args,
+                                       args->direction);
+        row = gwy_radio_buttons_attach_to_table(controls.direction,
+                                                GTK_TABLE(table), 2, row);
+    }
+
+    gtk_table_set_row_spacing(GTK_TABLE(table), row-1, 8);
     controls.do_extract
         = gtk_check_button_new_with_mnemonic(_("E_xtract background"));
     gtk_table_attach(GTK_TABLE(table), controls.do_extract,
-                     0, 4, row, row+1, GTK_FILL, 0, 0, 0);
+                     0, 2, row, row+1, GTK_FILL, 0, 0, 0);
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(controls.do_extract),
                                  args->do_extract);
     g_signal_connect(controls.do_extract, "toggled",
-                     G_CALLBACK(do_extract_changed_cb), args);
+                     G_CALLBACK(do_extract_changed), args);
     row++;
 
     controls.in_update = FALSE;
@@ -304,8 +412,7 @@ sphrev_dialog(Sphrev1DArgs *args)
 }
 
 static void
-direction_changed_cb(GtkWidget *radio,
-                     Sphrev1DArgs *args)
+direction_changed(GtkWidget *radio, SphrevArgs *args)
 {
     if (!gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(radio)))
         return;
@@ -314,10 +421,9 @@ direction_changed_cb(GtkWidget *radio,
 }
 
 static void
-radius_changed_cb(GtkAdjustment *adj,
-                  Sphrev1DArgs *args)
+radius_changed(GtkAdjustment *adj, SphrevArgs *args)
 {
-    Sphrev1DControls *controls;
+    SphrevControls *controls;
 
     controls = g_object_get_data(G_OBJECT(adj), "controls");
     if (controls->in_update)
@@ -331,10 +437,9 @@ radius_changed_cb(GtkAdjustment *adj,
 }
 
 static void
-size_changed_cb(GtkAdjustment *adj,
-                Sphrev1DArgs *args)
+size_changed(GtkAdjustment *adj, SphrevArgs *args)
 {
-    Sphrev1DControls *controls;
+    SphrevControls *controls;
 
     controls = g_object_get_data(G_OBJECT(adj), "controls");
     if (controls->in_update)
@@ -347,21 +452,20 @@ size_changed_cb(GtkAdjustment *adj,
 }
 
 static void
-do_extract_changed_cb(GtkWidget *check,
-                      Sphrev1DArgs *args)
+do_extract_changed(GtkWidget *check, SphrevArgs *args)
 {
     args->do_extract = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(check));
 }
 
 static void
-sphrev_dialog_update(Sphrev1DControls *controls,
-                     Sphrev1DArgs *args)
+sphrev_dialog_update(SphrevControls *controls, SphrevArgs *args)
 {
     gtk_adjustment_set_value(GTK_ADJUSTMENT(controls->radius),
                              args->size
                              * args->pixelsize/args->valform->magnitude);
     gtk_adjustment_set_value(GTK_ADJUSTMENT(controls->size), args->size);
-    gwy_radio_buttons_set_current(controls->direction, args->direction);
+    if (controls->direction)
+        gwy_radio_buttons_set_current(controls->direction, args->direction);
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(controls->do_extract),
                                  args->do_extract);
 }
@@ -369,7 +473,7 @@ sphrev_dialog_update(Sphrev1DControls *controls,
 /* An efficient summing algorithm.  Although I'm author of this code, don't
  * ask me how it works... */
 static void
-moving_sums(gint res, gdouble *row, gdouble *buffer, gint size)
+moving_sums(gint res, const gdouble *row, gdouble *buffer, gint size)
 {
     gdouble *sum, *sum2;
     gint i, ls2, rs2;
@@ -427,27 +531,27 @@ moving_sums(gint res, gdouble *row, gdouble *buffer, gint size)
 }
 
 static GwyDataField*
-sphrev_horizontal(Sphrev1DArgs *args,
-                  GwyDataField *dfield)
+arcrev_horizontal(SphrevArgs *args, GwyDataField *dfield)
 {
     GwyDataField *rfield;
     GwyDataLine *sphere;
-    gdouble *data, *rdata, *sphdata, *sum, *sum2, *weight, *tmp;
+    gdouble *rdata, *sphdata, *sum, *sum2, *weight, *tmp;
+    const gdouble *data;
     gdouble q;
     gint i, j, k, size, xres, yres;
 
-    data = gwy_data_field_get_data(dfield);
+    data = gwy_data_field_get_data_const(dfield);
     rfield = gwy_data_field_duplicate(dfield);
     xres = gwy_data_field_get_xres(rfield);
     yres = gwy_data_field_get_yres(rfield);
     rdata = gwy_data_field_get_data(rfield);
 
     q = gwy_data_field_get_rms(dfield)/sqrt(2.0/3.0 - G_PI/16.0);
-    sphere = sphrev_make_sphere(args->size, gwy_data_field_get_xres(dfield));
+    sphere = arcrev_make_arc(args->size, gwy_data_field_get_xres(dfield));
 
     /* Scale-freeing.
      * Data is normalized to have the same RMS as if it was composed from
-     * spheres of radius args->radius.  Actually we normalize the sphere
+     * arcs of radius args->radius.  Actually we normalize the sphere
      * instead, but the effect is the same.  */
     gwy_data_line_multiply(sphere, -q);
     sphdata = gwy_data_line_get_data(sphere);
@@ -465,8 +569,8 @@ sphrev_horizontal(Sphrev1DArgs *args,
     gwy_assign(weight, sum, xres);
 
     for (i = 0; i < yres; i++) {
+        const gdouble *drow = data + i*xres;
         gdouble *rrow = rdata + i*xres;
-        gdouble *drow = data + i*xres;
 
         /* Kill data that stick down too much */
         moving_sums(xres, data + i*xres, sum, size);
@@ -489,8 +593,9 @@ sphrev_horizontal(Sphrev1DArgs *args,
             to = MIN(j+size, xres-1) - j;
             min = G_MAXDOUBLE;
             for (k = from; k <= to; k++) {
-                if (-(sphdata[size+k] - row[k]) < min)
-                    min = -(sphdata[size+k] - row[k]);
+                gdouble d = -sphdata[size+k] + row[k];
+                if (d < min)
+                    min = d;
             }
             rrow[j] = min;
         }
@@ -503,93 +608,29 @@ sphrev_horizontal(Sphrev1DArgs *args,
 }
 
 static GwyDataField*
-sphrev_vertical(Sphrev1DArgs *args,
-                GwyDataField *dfield)
+arcrev_vertical(SphrevArgs *args, GwyDataField *dfield)
 {
-    GwyDataField *rfield;
-    GwyDataLine *sphere;
-    gdouble *data, *rdata, *sphdata, *sum, *sum2, *weight, *tmp;
-    gdouble q;
-    gint i, j, k, size, xres, yres;
+    GwyDataField *result, *flipped;
 
-    data = gwy_data_field_get_data(dfield);
-    rfield = gwy_data_field_duplicate(dfield);
-    xres = gwy_data_field_get_xres(rfield);
-    yres = gwy_data_field_get_yres(rfield);
-    rdata = gwy_data_field_get_data(rfield);
+    flipped = gwy_data_field_new_alike(dfield, FALSE);
+    gwy_data_field_flip_xy(dfield, flipped, FALSE);
+    result = arcrev_horizontal(args, flipped);
+    gwy_data_field_flip_xy(result, flipped, FALSE);
+    g_object_unref(result);
 
-    q = gwy_data_field_get_rms(dfield)/sqrt(2.0/3.0 - G_PI/16.0);
-    sphere = sphrev_make_sphere(args->size, gwy_data_field_get_yres(dfield));
-
-    /* Scale-freeing.
-     * Data is normalized to have the same RMS as if it was composed from
-     * spheres of radius args->radius.  Actually we normalize the sphere
-     * instead, but the effect is the same.  */
-    gwy_data_line_multiply(sphere, -q);
-    sphdata = gwy_data_line_get_data(sphere);
-    size = gwy_data_line_get_res(sphere)/2;
-
-    sum = g_new(gdouble, 4*yres);
-    sum2 = sum + yres;
-    weight = sum + 2*yres;
-    tmp = sum + 3*yres;
-
-    /* Weights for RMS filter.  The xresl-proof way is to sum 1's. */
-    for (j = 0; j < yres; j++)
-        weight[j] = 1.0;
-    moving_sums(yres, weight, sum, size);
-    gwy_assign(weight, sum, yres);
-
-    for (i = 0; i < xres; i++) {
-        gdouble *rcol = rdata + i;
-        gdouble *dcol = data + i;
-
-        /* Kill data that stick down too much */
-        for (j = 0; j < yres; j++)
-            tmp[j] = dcol[j*xres];
-        moving_sums(yres, tmp, sum, size);
-        for (j = 0; j < yres; j++) {
-            /* transform to avg - 2.5*rms */
-            sum[j] = sum[j]/weight[j];
-            sum2[j] = 2.5*sqrt(sum2[j]/weight[j] - sum[j]*sum[j]);
-            sum[j] -= sum2[j];
-        }
-        for (j = 0; j < yres; j++)
-            tmp[j] = MAX(dcol[j*xres], sum[j]);
-
-        /* Find the touching point */
-        for (j = 0; j < yres; j++) {
-            gdouble *col = tmp + j;
-            gint from, to;
-            gdouble min;
-
-            from = MAX(0, j-size) - j;
-            to = MIN(j+size, yres-1) - j;
-            min = G_MAXDOUBLE;
-            for (k = from; k <= to; k++) {
-                if (-(sphdata[size+k] - col[k]) < min)
-                    min = -(sphdata[size+k] - col[k]);
-            }
-            rcol[j*xres] = min;
-        }
-    }
-
-    g_free(sum);
-    g_object_unref(sphere);
-
-    return rfield;
+    return flipped;
 }
 
 static GwyDataLine*
-sphrev_make_sphere(gdouble radius, gint maxres)
+arcrev_make_arc(gdouble radius, gint maxres)
 {
-    GwyDataLine *dline;
+    GwyDataLine *arc;
     gdouble *data;
     gint i, size;
 
     size = GWY_ROUND(MIN(radius, maxres));
-    dline = gwy_data_line_new(2*size+1, 1.0, FALSE);
-    data = gwy_data_line_get_data(dline);
+    arc = gwy_data_line_new(2*size+1, 1.0, FALSE);
+    data = gwy_data_line_get_data(arc);
 
     if (radius/8 > maxres) {
         /* Pathological case: very flat sphere */
@@ -611,41 +652,203 @@ sphrev_make_sphere(gdouble radius, gint maxres)
         }
     }
 
-    return dline;
+    return arc;
 }
 
-static const gchar radius_key[]     = "/module/arc_revolve/radius";
-static const gchar direction_key[]  = "/module/arc_revolve/direction";
-static const gchar do_extract_key[] = "/module/arc_revolve/do_extract";
+static GwyDataField*
+sphrev_2d(SphrevArgs *args, GwyDataField *dfield,
+          GwySetMessageFunc set_message, GwySetFractionFunc set_fraction)
+{
+    GwyDataField *meanfield, *rmsfield, *rfield, *sphere;
+    gdouble *rdata, *sphdata, *tmp;
+    gint i, j, ii, jj, sres, size, xres, yres, sc;
+    gdouble q;
+    gboolean ok = FALSE;
+
+    rfield = gwy_data_field_duplicate(dfield);
+    xres = gwy_data_field_get_xres(rfield);
+    yres = gwy_data_field_get_yres(rfield);
+    rdata = gwy_data_field_get_data(rfield);
+
+    q = gwy_data_field_get_rms(dfield)/sqrt(5.0/6.0);
+    sphere = sphrev_make_sphere(args->size, gwy_data_field_get_xres(dfield));
+
+    /* Scale-freeing.
+     * Data is normalized to have the same RMS as if it was composed from
+     * spheres of radius args->radius.  Actually we normalize the sphere
+     * instead, but the effect is the same.  */
+    gwy_data_field_multiply(sphere, -q);
+    sphdata = gwy_data_field_get_data(sphere);
+    sres = gwy_data_field_get_xres(sphere);
+    size = sres/2;
+    sc = size*sres + size;
+
+    meanfield = gwy_data_field_duplicate(dfield);
+    rmsfield = gwy_data_field_duplicate(dfield);
+    /* XXX: 1D apparently uses size/2 here.  Not sure why, mimic it. */
+    gwy_data_field_filter_mean(meanfield, size/2);
+    gwy_data_field_filter_rms(rmsfield, size/2);
+
+    /* Transform mean value data to avg - 2.5*rms for outlier cut-off.
+     * Allows using rmsfield as a scratch buffer for the trimmed data. */
+    gwy_data_field_multiply(rmsfield, 2.5);
+    gwy_data_field_subtract_fields(meanfield, meanfield, rmsfield);
+
+    gwy_data_field_max_of_fields(rmsfield, meanfield, dfield);
+
+    if (set_message && !set_message(_("Revolving sphere...")))
+        goto finish;
+
+    tmp = gwy_data_field_get_data(rmsfield);
+
+    for (i = 0; i < yres; i++) {
+        gint ifrom, ito;
+
+        ifrom = MAX(0, i-size) - i;
+        ito = MIN(i+size, yres-1) - i;
+        for (j = 0; j < xres; j++) {
+            gint jfrom, jto;
+            gdouble min;
+
+            jfrom = MAX(0, j-size) - j;
+            jto = MIN(j+size, xres-1) - j;
+
+            /* Find the touching point */
+            min = G_MAXDOUBLE;
+            for (ii = ifrom; ii <= ito; ii++) {
+                const gdouble *srow = sphdata + (sc + ii*sres + jfrom);
+                const gdouble *drow = tmp + ((i + ii)*xres + j + jfrom);
+
+                for (jj = jto+1 - jfrom; jj; jj--, srow++, drow++) {
+                    gdouble s = *srow, d = *drow;
+
+                    if (s >= -q) {
+                        d -= s;
+                        if (d < min)
+                            min = d;
+                    }
+                }
+            }
+            rdata[i*xres + j] = min;
+        }
+        if (set_fraction && !set_fraction((i + 1.0)/yres))
+            goto finish;
+    }
+
+    ok = TRUE;
+
+finish:
+    g_object_unref(rmsfield);
+    g_object_unref(meanfield);
+    g_object_unref(sphere);
+
+    if (!ok)
+        GWY_OBJECT_UNREF(rfield);
+
+    return rfield;
+}
+
+static GwyDataField*
+sphrev_make_sphere(gdouble radius, gint maxres)
+{
+    GwyDataField *sphere;
+    gdouble *data;
+    gint i, j, size, res, sc;
+
+    size = GWY_ROUND(MIN(radius, maxres));
+    res = 2*size + 1;
+    sphere = gwy_data_field_new(res, res, 1.0, 1.0, FALSE);
+    data = gwy_data_field_get_data(sphere);
+    sc = size*res + size;
+
+    if (radius/8 > maxres) {
+        /* Pathological case: very flat sphere */
+        for (i = 0; i <= size; i++) {
+            gdouble u = i/radius;
+
+            for (j = 0; j <= size; j++) {
+                gdouble v = j/radius;
+                gdouble r2 = u*u + v*v;
+                gdouble z = r2/2.0*(1.0 + r2/4.0*(1 + r2/2.0));
+
+                data[sc - res*i - j] = data[sc - res*i + j] = z;
+                data[sc + res*i - j] = data[sc + res*i + j] = z;
+            }
+        }
+    }
+    else {
+        /* Normal sphere */
+        for (i = 0; i <= size; i++) {
+            gdouble u = i/radius;
+
+            for (j = 0; j <= size; j++) {
+                gdouble v = j/radius;
+                gdouble r2 = u*u + v*v;
+                gdouble z = r2 > 1.0 ? 2.0 : 1.0 - sqrt(1.0 - r2);
+
+                data[sc - res*i - j] = data[sc - res*i + j] = z;
+                data[sc + res*i - j] = data[sc + res*i + j] = z;
+            }
+        }
+    }
+
+    return sphere;
+}
+
+static const gchar arc_radius_key[]     = "/module/arc_revolve/radius";
+static const gchar arc_direction_key[]  = "/module/arc_revolve/direction";
+static const gchar arc_do_extract_key[] = "/module/arc_revolve/do_extract";
+
+static const gchar sph_radius_key[]     = "/module/sphere_revolve/radius";
+static const gchar sph_do_extract_key[] = "/module/sphere_revolve/do_extract";
 
 static void
-sphrev_sanitize_args(Sphrev1DArgs *args)
+sphrev_sanitize_args(SphrevArgs *args)
 {
-    args->size = CLAMP(args->size, 1, 16384);
+    args->size = CLAMP(args->size, 1, 1024);
     args->direction = CLAMP(args->direction, SPHREV_HORIZONTAL, SPHREV_BOTH);
     args->do_extract = !!args->do_extract;
 }
 
 static void
-sphrev_load_args(GwyContainer *container,
-                 Sphrev1DArgs *args)
+arcrev_load_args(GwyContainer *container, SphrevArgs *args)
 {
     *args = sphrev_defaults;
 
-    gwy_container_gis_double_by_name(container, radius_key, &args->size);
-    gwy_container_gis_enum_by_name(container, direction_key, &args->direction);
-    gwy_container_gis_boolean_by_name(container, do_extract_key,
+    gwy_container_gis_double_by_name(container, arc_radius_key, &args->size);
+    gwy_container_gis_enum_by_name(container, arc_direction_key,
+                                   &args->direction);
+    gwy_container_gis_boolean_by_name(container, arc_do_extract_key,
                                       &args->do_extract);
     sphrev_sanitize_args(args);
 }
 
 static void
-sphrev_save_args(GwyContainer *container,
-                 Sphrev1DArgs *args)
+arcrev_save_args(GwyContainer *container, SphrevArgs *args)
 {
-    gwy_container_set_double_by_name(container, radius_key, args->size);
-    gwy_container_set_enum_by_name(container, direction_key, args->direction);
-    gwy_container_set_boolean_by_name(container, do_extract_key,
+    gwy_container_set_double_by_name(container, arc_radius_key, args->size);
+    gwy_container_set_enum_by_name(container, arc_direction_key,
+                                   args->direction);
+    gwy_container_set_boolean_by_name(container, arc_do_extract_key,
+                                      args->do_extract);
+}
+
+static void
+sphrev_load_args(GwyContainer *container, SphrevArgs *args)
+{
+    *args = sphrev_defaults;
+
+    gwy_container_gis_double_by_name(container, sph_radius_key, &args->size);
+    gwy_container_gis_boolean_by_name(container, sph_do_extract_key,
+                                      &args->do_extract);
+    sphrev_sanitize_args(args);
+}
+
+static void
+sphrev_save_args(GwyContainer *container, SphrevArgs *args)
+{
+    gwy_container_set_double_by_name(container, sph_radius_key, args->size);
+    gwy_container_set_boolean_by_name(container, sph_do_extract_key,
                                       args->do_extract);
 }
 
