@@ -1,6 +1,6 @@
 /*
- *  @(#) $Id: straighten_path.c 19044 2016-10-08 19:10:46Z yeti-dn $
- *  Copyright (C) 2016 David Necas (Yeti).
+ *  @(#) $Id: straighten_path.c 19948 2017-06-22 14:05:41Z yeti-dn $
+ *  Copyright (C) 2016-2017 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -125,12 +125,12 @@ static GwyModuleInfo module_info = {
     &module_register,
     N_("Extracts a straightened part of image along a curve."),
     "Yeti <yeti@gwyddion.net>",
-    "1.0",
+    "1.1",
     "David Nečas (Yeti)",
     "2016",
 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, straighten_path)
 
 static gboolean
 module_register(void)
@@ -230,7 +230,7 @@ straighten_dialogue(StraightenArgs *args,
                             GWY_DATA_ITEM_MASK_COLOR,
                             0);
 
-    table = GTK_TABLE(gtk_table_new(6, 4, FALSE));
+    table = GTK_TABLE(gtk_table_new(6, 3, FALSE));
     gtk_table_set_row_spacings(table, 2);
     gtk_table_set_col_spacings(table, 6);
     gtk_container_set_border_width(GTK_CONTAINER(table), 4);
@@ -238,13 +238,12 @@ straighten_dialogue(StraightenArgs *args,
     row = 0;
 
     scwin = create_coord_list(&controls);
-    gtk_table_attach(table, scwin, 0, 4, row, row+1,
-                     GTK_EXPAND | GTK_FILL, GTK_EXPAND | GTK_FILL, 0, 0);
+    gtk_table_attach(table, scwin, 0, 3, row, row+1,
+                     GTK_FILL, GTK_EXPAND | GTK_FILL, 0, 0);
     row++;
 
     hbox2 = gtk_hbox_new(TRUE, 0);
-    gtk_table_attach(table, hbox2, 0, 4, row, row+1,
-                     GTK_EXPAND | GTK_FILL, 0, 0, 0);
+    gtk_table_attach(table, hbox2, 0, 3, row, row+1, GTK_FILL, 0, 0, 0);
 
     button = gtk_button_new_with_mnemonic(_("_Reset"));
     gtk_box_pack_start(GTK_BOX(hbox2), button, TRUE, TRUE, 0);
@@ -267,24 +266,26 @@ straighten_dialogue(StraightenArgs *args,
         = gwy_enum_combo_box_new(gwy_interpolation_type_get_enum(), -1,
                                  G_CALLBACK(interpolation_changed), &controls,
                                  args->interp, TRUE);
-    gwy_table_attach_hscale(GTK_WIDGET(table), row,
+    gwy_table_attach_adjbar(GTK_WIDGET(table), row,
                             _("_Interpolation type:"), NULL,
-                            GTK_OBJECT(controls.interp), GWY_HSCALE_WIDGET);
+                            GTK_OBJECT(controls.interp),
+                            GWY_HSCALE_WIDGET_NO_EXPAND);
     row++;
 
     args->thickness = MIN(args->thickness, maxthickness);
     controls.thickness = gtk_adjustment_new(args->thickness, 3.0, maxthickness,
                                             1.0, 10.0, 0.0);
-    gwy_table_attach_hscale(GTK_WIDGET(table), row, _("_Thickness:"), "px",
-                            controls.thickness, GWY_HSCALE_SQRT);
+    gwy_table_attach_adjbar(GTK_WIDGET(table), row, _("_Thickness:"), _("px"),
+                            controls.thickness,
+                            GWY_HSCALE_SQRT | GWY_HSCALE_SNAP);
     g_signal_connect_swapped(controls.thickness, "value-changed",
                              G_CALLBACK(thickness_changed), &controls);
     row++;
 
     controls.slackness = gtk_adjustment_new(args->slackness, 0.0, G_SQRT2,
                                             0.001, 0.1, 0.0);
-    gwy_table_attach_hscale(GTK_WIDGET(table), row, _("_Slackness:"), NULL,
-                            controls.slackness, GWY_HSCALE_DEFAULT);
+    gwy_table_attach_adjbar(GTK_WIDGET(table), row, _("_Slackness:"), NULL,
+                            controls.slackness, GWY_HSCALE_LINEAR);
     g_signal_connect_swapped(controls.slackness, "value-changed",
                              G_CALLBACK(slackness_changed), &controls);
     row++;
@@ -293,7 +294,7 @@ straighten_dialogue(StraightenArgs *args,
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(controls.closed),
                                  args->closed);
     gtk_table_attach(table, controls.closed,
-                     0, 4, row, row+1, GTK_FILL, 0, 0, 0);
+                     0, 2, row, row+1, GTK_FILL, 0, 0, 0);
     g_signal_connect_swapped(controls.closed, "toggled",
                              G_CALLBACK(closed_changed), &controls);
     row++;
