@@ -71,7 +71,7 @@ static void         supres_data_cb        (GwyDataChooser *chooser,
 static void         supres_maybe_preview  (SupresControls *controls);
 static const gchar* supres_check          (SupresArgs *args);
 static void         supres_do             (SupresArgs *args);
-static GwyDataField*       make_superresolution  (GwyDataField *result, 
+static GwyDataField*       make_superresolution  (GwyDataField *result,
                                            GPtrArray *fields,
                                            SupresArgs *args);
 
@@ -88,7 +88,7 @@ static GwyModuleInfo module_info = {
     "2004",
 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, superresolution)
 
 static gboolean
 module_register(void)
@@ -156,7 +156,7 @@ supres_dialog(SupresArgs *args)
     label = gtk_label_new(_("Operands:"));
     gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
     gtk_table_attach(GTK_TABLE(table), label, 0, 2, row, row+1,
-                     GTK_EXPAND | GTK_FILL, 0, 0, 0);
+                     GTK_FILL, 0, 0, 0);
     row++;
 
     for (i = 0; i < NARGS; i++) {
@@ -165,7 +165,7 @@ supres_dialog(SupresArgs *args)
         gwy_strkill(args->name[i], "_");
         gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
         gtk_table_attach(GTK_TABLE(table), label, 0, 1, row, row+1,
-                         GTK_EXPAND | GTK_FILL, 0, 0, 0);
+                         GTK_FILL, 0, 0, 0);
 
         chooser = gwy_data_chooser_new_channels();
         gwy_data_chooser_set_active_id(GWY_DATA_CHOOSER(chooser),
@@ -174,23 +174,23 @@ supres_dialog(SupresArgs *args)
                          G_CALLBACK(supres_data_cb), &controls);
         g_object_set_data(G_OBJECT(chooser), "index", GUINT_TO_POINTER(i));
         gtk_table_attach(GTK_TABLE(table), chooser, 1, 2, row, row+1,
-                         GTK_EXPAND | GTK_FILL, 0, 0, 0);
+                         GTK_FILL, 0, 0, 0);
         gtk_label_set_mnemonic_widget(GTK_LABEL(label), chooser);
         controls.data[i] = chooser;
 
         row++;
     }
-    gtk_table_set_row_spacing(GTK_TABLE(table), row-1, 8);
 
-    controls.result = label = gtk_label_new("");
+    gtk_table_set_row_spacing(GTK_TABLE(table), row-1, 8);
+    controls.result = label = gtk_label_new(NULL);
     gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
     gtk_table_attach(GTK_TABLE(table), label, 0, 2, row, row+1,
-                     GTK_EXPAND | GTK_FILL, 0, 0, 0);
+                     GTK_FILL, 0, 0, 0);
 
 
     args->err = SUPRES_OK;
     supres_data_cb(controls.data[0], &controls);
-    
+
 
     gtk_widget_show_all(dialog);
     do {
@@ -231,7 +231,6 @@ supres_data_cb(GwyDataChooser *chooser,
         supres_maybe_preview(controls);
 }
 
-
 static void
 supres_maybe_preview(SupresControls *controls)
 {
@@ -375,9 +374,9 @@ typedef struct {
 } SDataPoint;
 
 static gdouble
-get_mean_correlation(GwyDataField *dfield, 
-                     GwyDataField *last, 
-                     gdouble *xmean, 
+get_mean_correlation(GwyDataField *dfield,
+                     GwyDataField *last,
+                     gdouble *xmean,
                      gdouble *ymean,
                      SupresArgs *args
                      )
@@ -393,17 +392,17 @@ get_mean_correlation(GwyDataField *dfield,
 
     newxres = gwy_data_field_get_xres(dfield)/2;
     newyres = gwy_data_field_get_yres(dfield)/2;
-    sm_dfield = gwy_data_field_new_resampled(dfield, 
+    sm_dfield = gwy_data_field_new_resampled(dfield,
                                              newxres,
                                              newyres,
                                              GWY_INTERPOLATION_LINEAR);
-    sm_last = gwy_data_field_new_resampled(last, 
+    sm_last = gwy_data_field_new_resampled(last,
                                              newxres,
                                              newyres,
                                              GWY_INTERPOLATION_LINEAR);
 
-    dfield_kernel = gwy_data_field_area_extract(sm_dfield, 
-                                                newxres/2 - newxres/6, 
+    dfield_kernel = gwy_data_field_area_extract(sm_dfield,
+                                                newxres/2 - newxres/6,
                                                 newyres/2 - newyres/6,
                                                 newxres/3,
                                                 newyres/3);
@@ -442,7 +441,7 @@ get_mean_correlation(GwyDataField *dfield,
                                      -1,
                                      TRUE));
 
-    
+
     *xmean -= newxres/2 - 1;
     *ymean -= newyres/2 - 1;
     g_object_unref(score);
@@ -472,7 +471,7 @@ make_superresolution(GwyDataField *result, GPtrArray *fields, SupresArgs *args)
 
     values = g_array_new(FALSE, FALSE, sizeof(SDataPoint));
     locals = g_array_new(FALSE, FALSE, sizeof(int));
-    
+
     last = GWY_DATA_FIELD(g_ptr_array_index(fields, fields->len - 1));
     xres = gwy_data_field_get_xres(last);
     yres = gwy_data_field_get_yres(last);
@@ -490,13 +489,13 @@ make_superresolution(GwyDataField *result, GPtrArray *fields, SupresArgs *args)
     for (m=0; m<(fields->len - 1); m++)
     {
         dfield = GWY_DATA_FIELD(g_ptr_array_index(fields, m));
-        
+
         /*compute overall correlation for downsampled data center to save time*/
 /*        if (get_mean_correlation(dfield, last, &xmean, &ymean, args) < mean_threshold)
             continue;
 TODO: use this when the rest works well.
             */
-        
+
         /*compute detailed correlation of each point*/
         /*compute crosscorelation */
         data = gwy_app_data_browser_get(args->objects[0].datano);
@@ -528,18 +527,18 @@ TODO: use this when the rest works well.
         scdata = gwy_data_field_get_data(score);
         for (col=5; col<(xres-5); col++) {
             for (row=5; row<(yres-5); row++) {
-               
-                if (scdata[row*xres + col] > local_threshold) 
-                { 
+
+                if (scdata[row*xres + col] > local_threshold)
+                {
                     sdp.xval = col + gwy_data_field_rtoi(dfieldx, xdata[row*xres + col]);
                     sdp.yval = row + gwy_data_field_rtoj(dfieldy, ydata[row*xres + col]);
                     sdp.score = scdata[row*xres + col];
                     sdp.zval = gwy_data_field_get_val(dfield, col, row);
-                    g_array_append_val(values, sdp); 
+                    g_array_append_val(values, sdp);
                 }
             }
         }
-        
+
 
     }
 
@@ -573,8 +572,8 @@ TODO: use this when the rest works well.
             }
             /*compute weighted average TODO in future recalculate also points from grid*/
             if (((col%2) || (row%2)) && locals->len){
-               
-                /*add last image data*/ 
+
+                /*add last image data*/
                 distance = 1.41421356;
                 rdist = 4.0/(distance*distance + 1e-18);
                 weight = rdist;
@@ -584,7 +583,7 @@ TODO: use this when the rest works well.
                 for (m=0; m<locals->len; m++)
                 {
                     pdp = &g_array_index(values, SDataPoint, g_array_index(locals, int, m));
-                    distance = sqrt((2*(pdp->xval) - col)*(2*(pdp->xval) - col) 
+                    distance = sqrt((2*(pdp->xval) - col)*(2*(pdp->xval) - col)
                                  + (2*(pdp->yval) - row)*(2*(pdp->yval) - row));
                     rdist = 1.0/(distance*distance + 1e-18);
                     weight += rdist;
@@ -593,8 +592,8 @@ TODO: use this when the rest works well.
                 gwy_data_field_set_val(result, col, row, sum/weight);
 
             }
-            
-        } 
+
+        }
     }
     gwy_app_wait_finish();
 
