@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: synth.h 17224 2015-07-31 12:00:52Z yeti-dn $
+ *  @(#) $Id: synth.h 20046 2017-07-08 18:15:12Z yeti-dn $
  *  Copyright (C) 2009,2010 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
@@ -276,8 +276,8 @@ gwy_synth_attach_lateral(GWY_SYNTH_CONTROLS *controls,
 
     g_object_set_data(G_OBJECT(adj), "target", target);
 
-    spin = gwy_table_attach_hscale(GTK_WIDGET(controls->table),
-                                   row, name, "px", adj, hscale_style);
+    spin = gwy_table_attach_adjbar(GTK_WIDGET(controls->table),
+                                   row, name, _("px"), adj, hscale_style);
     if (pspin)
         *pspin = spin;
     row++;
@@ -285,13 +285,13 @@ gwy_synth_attach_lateral(GWY_SYNTH_CONTROLS *controls,
     *pvalue = gtk_label_new(NULL);
     gtk_misc_set_alignment(GTK_MISC(*pvalue), 1.0, 0.5);
     gtk_table_attach(controls->table, *pvalue,
-                     2, 3, row, row+1, GTK_FILL, 0, 0, 0);
+                     1, 2, row, row+1, GTK_FILL, 0, 0, 0);
     g_object_set_data(G_OBJECT(adj), "value-label", *pvalue);
 
     *punits = gtk_label_new(NULL);
     gtk_misc_set_alignment(GTK_MISC(*punits), 0.0, 0.5);
     gtk_table_attach(controls->table, *punits,
-                     3, 4, row, row+1, GTK_FILL, 0, 0, 0);
+                     2, 3, row, row+1, GTK_FILL, 0, 0, 0);
     row++;
 
     g_signal_connect_swapped(adj, "value-changed",
@@ -317,7 +317,7 @@ gwy_synth_attach_height(GWY_SYNTH_CONTROLS *controls,
     *adj = gtk_adjustment_new(*target, 0.0001, 10000.0, 0.1, 10.0, 0);
     g_object_set_data(G_OBJECT(*adj), "target", target);
 
-    spin = gwy_table_attach_hscale(GTK_WIDGET(controls->table),
+    spin = gwy_table_attach_adjbar(GTK_WIDGET(controls->table),
                                    row, name, "", *adj, GWY_HSCALE_LOG);
     gtk_spin_button_set_digits(GTK_SPIN_BUTTON(spin), 4);
     gtk_spin_button_set_snap_to_ticks(GTK_SPIN_BUTTON(spin), FALSE);
@@ -339,17 +339,18 @@ gwy_synth_attach_roundness(GWY_SYNTH_CONTROLS *controls,
                            GtkObject **adj,
                            gdouble *target)
 {
-    gtk_table_set_row_spacing(controls->table, row-1, 8);
+    if (row > 0)
+        gtk_table_set_row_spacing(controls->table, row-1, 8);
     gtk_table_attach(controls->table, gwy_label_new_header(_("Roundness")),
-                     0, 3, row, row+1, GTK_FILL, 0, 0, 0);
+                     0, 2, row, row+1, GTK_FILL, 0, 0, 0);
     row++;
 
     *adj = gtk_adjustment_new(*target, 0.0, 1.0, 0.001, 0.1, 0);
     g_object_set_data(G_OBJECT(*adj), "target", target);
 
-    gwy_table_attach_hscale(GTK_WIDGET(controls->table),
+    gwy_table_attach_adjbar(GTK_WIDGET(controls->table),
                             row, _("Roundn_ess:"), NULL, *adj,
-                            GWY_HSCALE_DEFAULT);
+                            GWY_HSCALE_LINEAR);
     g_signal_connect_swapped(*adj, "value-changed",
                              G_CALLBACK(gwy_synth_double_changed), controls);
 
@@ -374,9 +375,9 @@ gwy_synth_attach_angle(GWY_SYNTH_CONTROLS *controls,
                               1.0, 10.0, 0);
     g_object_set_data(G_OBJECT(*adj), "target", target);
 
-    spin = gwy_table_attach_hscale(GTK_WIDGET(controls->table),
-                                   row, name, "deg", *adj,
-                                   GWY_HSCALE_DEFAULT);
+    spin = gwy_table_attach_adjbar(GTK_WIDGET(controls->table),
+                                   row, name, _("deg"), *adj,
+                                   GWY_HSCALE_LINEAR);
     gtk_spin_button_set_digits(GTK_SPIN_BUTTON(spin), 1);
     g_signal_connect_swapped(*adj, "value-changed",
                              G_CALLBACK(gwy_synth_angle_changed), controls);
@@ -395,18 +396,19 @@ gwy_synth_attach_orientation(GWY_SYNTH_CONTROLS *controls,
 {
     GtkWidget *spin;
 
-    gtk_table_set_row_spacing(controls->table, row-1, 8);
+    if (row > 0)
+        gtk_table_set_row_spacing(controls->table, row-1, 8);
     gtk_table_attach(controls->table, gwy_label_new_header(_("Orientation")),
-                     0, 3, row, row+1, GTK_FILL, 0, 0, 0);
+                     0, 2, row, row+1, GTK_FILL, 0, 0, 0);
     row++;
 
     *adj = gtk_adjustment_new(*target * 180.0/G_PI,
                               -180.0, 180.0, 1.0, 10.0, 0);
     g_object_set_data(G_OBJECT(*adj), "target", target);
 
-    spin = gwy_table_attach_hscale(GTK_WIDGET(controls->table),
-                                   row, _("Orien_tation:"), "deg", *adj,
-                                   GWY_HSCALE_DEFAULT);
+    spin = gwy_table_attach_adjbar(GTK_WIDGET(controls->table),
+                                   row, _("Orien_tation:"), _("deg"), *adj,
+                                   GWY_HSCALE_LINEAR);
     gtk_spin_button_set_digits(GTK_SPIN_BUTTON(spin), 1);
     g_signal_connect_swapped(*adj, "value-changed",
                              G_CALLBACK(gwy_synth_angle_changed), controls);
@@ -416,6 +418,32 @@ gwy_synth_attach_orientation(GWY_SYNTH_CONTROLS *controls,
     return row;
 }
 
+G_GNUC_UNUSED
+static gint
+gwy_synth_attach_truncation(GWY_SYNTH_CONTROLS *controls,
+                            gint row,
+                            GtkObject **adj,
+                            gdouble *target)
+{
+    GtkWidget *spin;
+
+    if (row > 0)
+        gtk_table_set_row_spacing(controls->table, row-1, 8);
+    *adj = gtk_adjustment_new(*target, 0.001, 1.0, 0.001, 0.1, 0);
+    g_object_set_data(G_OBJECT(*adj), "target", target);
+
+    spin = gwy_table_attach_adjbar(GTK_WIDGET(controls->table),
+                                   row, _("_Truncate:"), NULL, *adj,
+                                   GWY_HSCALE_SQRT);
+    gtk_spin_button_set_digits(GTK_SPIN_BUTTON(spin), 3);
+    g_signal_connect_swapped(*adj, "value-changed",
+                             G_CALLBACK(gwy_synth_double_changed), controls);
+
+    row++;
+
+    return row;
+}
+
 G_GNUC_UNUSED
 static gint
 gwy_synth_attach_variance(GWY_SYNTH_CONTROLS *controls,
@@ -428,7 +456,7 @@ gwy_synth_attach_variance(GWY_SYNTH_CONTROLS *controls,
     *adj = gtk_adjustment_new(*target, 0.0, 1.0, 0.01, 0.1, 0);
     g_object_set_data(G_OBJECT(*adj), "target", target);
 
-    spin = gwy_table_attach_hscale(GTK_WIDGET(controls->table),
+    spin = gwy_table_attach_adjbar(GTK_WIDGET(controls->table),
                                    row, _("Variance:"), NULL, *adj,
                                    GWY_HSCALE_SQRT);
     gtk_spin_button_set_snap_to_ticks(GTK_SPIN_BUTTON(spin), FALSE);
@@ -452,15 +480,16 @@ gwy_synth_attach_deformation(GWY_SYNTH_CONTROLS  *controls,
                              GtkWidget **pvalue_tau,
                              GtkWidget **punits_tau)
 {
-    gtk_table_set_row_spacing(controls->table, row-1, 8);
+    if (row > 0)
+        gtk_table_set_row_spacing(controls->table, row-1, 8);
     gtk_table_attach(controls->table, gwy_label_new_header(_("Deformation")),
-                     0, 3, row, row+1, GTK_FILL, 0, 0, 0);
+                     0, 2, row, row+1, GTK_FILL, 0, 0, 0);
     row++;
 
     *adj_sigma = gtk_adjustment_new(*target_sigma, 0.0, 100.0, 0.01, 1.0, 0);
     g_object_set_data(G_OBJECT(*adj_sigma), "target", target_sigma);
 
-    gwy_table_attach_hscale(GTK_WIDGET(controls->table),
+    gwy_table_attach_adjbar(GTK_WIDGET(controls->table),
                             row, _("_Amplitude:"), NULL, *adj_sigma,
                             GWY_HSCALE_SQRT);
     row++;
@@ -468,21 +497,21 @@ gwy_synth_attach_deformation(GWY_SYNTH_CONTROLS  *controls,
     *adj_tau = gtk_adjustment_new(*target_tau, 0.1, 1000.0, 0.01, 1.0, 0);
     g_object_set_data(G_OBJECT(*adj_tau), "target", target_tau);
 
-    gwy_table_attach_hscale(GTK_WIDGET(controls->table),
-                            row, _("_Lateral scale:"), "px", *adj_tau,
+    gwy_table_attach_adjbar(GTK_WIDGET(controls->table),
+                            row, _("_Lateral scale:"), _("px"), *adj_tau,
                             GWY_HSCALE_LOG);
     row++;
 
     *pvalue_tau = gtk_label_new(NULL);
     gtk_misc_set_alignment(GTK_MISC(*pvalue_tau), 1.0, 0.5);
     gtk_table_attach(controls->table, *pvalue_tau,
-                     2, 3, row, row+1, GTK_FILL, 0, 0, 0);
+                     1, 2, row, row+1, GTK_FILL, 0, 0, 0);
     g_object_set_data(G_OBJECT(*adj_tau), "value-label", *pvalue_tau);
 
     *punits_tau = gtk_label_new(NULL);
     gtk_misc_set_alignment(GTK_MISC(*punits_tau), 0.0, 0.5);
     gtk_table_attach(controls->table, *punits_tau,
-                     3, 4, row, row+1, GTK_FILL, 0, 0, 0);
+                     2, 3, row, row+1, GTK_FILL, 0, 0, 0);
     row++;
 
     g_signal_connect_swapped(*adj_sigma, "value-changed",
