@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: threshold.c 18739 2016-07-20 10:06:44Z yeti-dn $
+ *  @(#) $Id: threshold.c 19948 2017-06-22 14:05:41Z yeti-dn $
  *  Copyright (C) 2010 David Necas (Yeti)
  *  E-mail: yeti@gwyddion.net
  *
@@ -117,12 +117,12 @@ static GwyModuleInfo module_info = {
     &module_register,
     N_("Limit the data range using a lower/upper threshold."),
     "Yeti <yeti@gwyddion.net>",
-    "1.4",
+    "1.5",
     "David Nečas (Yeti)",
     "2010",
 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, threshold)
 
 static gboolean
 module_register(void)
@@ -203,19 +203,14 @@ threshold_entry_attach(ThresholdControls *controls,
                        gdouble value,
                        const gchar *name)
 {
-    GtkWidget *label, *entry;
+    GtkWidget *entry;
 
-    label = gtk_label_new_with_mnemonic(name);
-    gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
-    gtk_table_attach(table, label, 0, 1, row, row+1, GTK_FILL, 0, 0, 0);
     entry = gtk_entry_new();
     gwy_widget_set_activate_on_unfocus(entry, TRUE);
     threshold_format_value(controls, GTK_ENTRY(entry), value);
-    gtk_table_attach(table, entry, 1, 3, row, row+1, GTK_FILL, 0, 0, 0);
-    label = gtk_label_new(controls->format->units);
-    gtk_label_set_use_markup(GTK_LABEL(label), TRUE);
-    gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
-    gtk_table_attach(table, label, 3, 4, row, row+1, GTK_FILL, 0, 0, 0);
+    gwy_table_attach_adjbar(GTK_WIDGET(table), row,
+                            name, controls->format->units,
+                            GTK_OBJECT(entry), GWY_HSCALE_WIDGET_NO_EXPAND);
 
     return entry;
 }
@@ -269,7 +264,7 @@ threshold_dialog(ThresholdArgs *args,
     controls.view = create_preview(controls.mydata, 0, PREVIEW_SIZE, FALSE);
     gtk_box_pack_start(GTK_BOX(hbox), controls.view, FALSE, FALSE, 4);
 
-    table = GTK_TABLE(gtk_table_new(5, 4, FALSE));
+    table = GTK_TABLE(gtk_table_new(5, 3, FALSE));
     gtk_table_set_row_spacings(table, 2);
     gtk_table_set_col_spacings(table, 6);
     gtk_container_set_border_width(GTK_CONTAINER(table), 4);
@@ -287,7 +282,7 @@ threshold_dialog(ThresholdArgs *args,
                                               NULL);
 
     button = gwy_radio_buttons_find(controls.mode, THRESHOLD_RANGE_USER);
-    gtk_table_attach(table, button, 0, 3, row, row+1, GTK_FILL, 0, 0, 0);
+    gtk_table_attach(table, button, 0, 2, row, row+1, GTK_FILL, 0, 0, 0);
     row++;
 
     controls.lower = threshold_entry_attach(&controls, table, row, args->lower,
@@ -303,7 +298,7 @@ threshold_dialog(ThresholdArgs *args,
     row++;
 
     button = gtk_button_new_with_mnemonic(_("Set to _Full Range"));
-    gtk_table_attach(table, button, 0, 3, row, row+1, GTK_FILL, 0, 0, 0);
+    gtk_table_attach(table, button, 0, 2, row, row+1, GTK_FILL, 0, 0, 0);
     g_signal_connect_swapped(button, "clicked",
                              G_CALLBACK(threshold_set_to_full_range),
                              &controls);
@@ -311,7 +306,7 @@ threshold_dialog(ThresholdArgs *args,
 
     gtk_table_set_row_spacing(GTK_TABLE(table), row-1, 8);
     button = gwy_radio_buttons_find(controls.mode, THRESHOLD_RANGE_DISPLAY);
-    gtk_table_attach(table, button, 0, 3, row, row+1, GTK_FILL, 0, 0, 0);
+    gtk_table_attach(table, button, 0, 2, row, row+1, GTK_FILL, 0, 0, 0);
     row++;
 
     /* TRANSLATORS: This is a range: 123 to 456. */
@@ -323,23 +318,23 @@ threshold_dialog(ThresholdArgs *args,
     label = gtk_label_new(s);
     g_free(s);
     gtk_misc_set_alignment(GTK_MISC(label), 1.0, 0.5);
-    gtk_table_attach(table, label, 1, 3, row, row+1, GTK_FILL, 0, 0, 0);
+    gtk_table_attach(table, label, 0, 2, row, row+1, GTK_FILL, 0, 0, 0);
 
     label = gtk_label_new(controls.format->units);
     gtk_label_set_use_markup(GTK_LABEL(label), TRUE);
     gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
-    gtk_table_attach(table, label, 3, 4, row, row+1, GTK_FILL, 0, 0, 0);
+    gtk_table_attach(table, label, 2, 3, row, row+1, GTK_FILL, 0, 0, 0);
     row++;
 
     gtk_table_set_row_spacing(GTK_TABLE(table), row-1, 8);
     button = gwy_radio_buttons_find(controls.mode, THRESHOLD_RANGE_OUTLIERS);
-    gtk_table_attach(table, button, 0, 3, row, row+1, GTK_FILL, 0, 0, 0);
+    gtk_table_attach(table, button, 0, 2, row, row+1, GTK_FILL, 0, 0, 0);
     row++;
 
     controls.sigma = gtk_adjustment_new(args->sigma, 1.0, 12.0, 0.01, 1.0, 0);
-    gwy_table_attach_hscale(GTK_WIDGET(table), row,
+    gwy_table_attach_adjbar(GTK_WIDGET(table), row,
                             _("F_arther than:"), _("RMS"),
-                            controls.sigma, GWY_HSCALE_SQRT);
+                            controls.sigma, GWY_HSCALE_DEFAULT);
     g_signal_connect_swapped(controls.sigma, "value-changed",
                              G_CALLBACK(sigma_changed), &controls);
 
