@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: tilt.c 18537 2016-03-28 18:11:19Z yeti-dn $
+ *  @(#) $Id: tilt.c 19948 2017-06-22 14:05:41Z yeti-dn $
  *  Copyright (C) 2008 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
@@ -75,12 +75,12 @@ static GwyModuleInfo module_info = {
     &module_register,
     N_("Tilts image by specified amount."),
     "Yeti <yeti@gwyddion.net>",
-    "1.1",
+    "1.2",
     "David Nečas (Yeti)",
     "2008",
 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, tilt)
 
 static gboolean
 module_register(void)
@@ -178,21 +178,21 @@ tilt_dialog(TiltArgs *args,
     /* Slopes */
     label = gwy_label_new_header(_("Slopes"));
     gtk_table_attach(GTK_TABLE(table), label,
-                     0, 3, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
+                     0, 2, row, row+1, GTK_FILL, 0, 0, 0);
     row++;
 
-    controls.dx = gtk_adjustment_new(args->dx, -100, 100, 1e-4, 1e-2, 0);
-    spin = gwy_table_attach_hscale(table, row, _("_X:"), unitstr,
-                                   controls.dx, GWY_HSCALE_NO_SCALE);
+    controls.dx = gtk_adjustment_new(args->dx, -100.0, 100.0, 1e-4, 1e-2, 0);
+    spin = gwy_table_attach_adjbar(table, row, _("_X:"), unitstr,
+                                   controls.dx, GWY_HSCALE_DEFAULT);
     gwy_widget_set_activate_on_unfocus(spin, TRUE);
     gtk_spin_button_set_digits(GTK_SPIN_BUTTON(spin), 6);
     g_signal_connect(controls.dx, "value-changed",
                      G_CALLBACK(tilt_dx_changed), &controls);
     row++;
 
-    controls.dy = gtk_adjustment_new(args->dy, -100, 100, 1e-4, 1e-2, 0);
-    spin = gwy_table_attach_hscale(table, row, _("_Y:"), unitstr,
-                                   controls.dy, GWY_HSCALE_NO_SCALE);
+    controls.dy = gtk_adjustment_new(args->dy, -100.0, 100.0, 1e-4, 1e-2, 0);
+    spin = gwy_table_attach_adjbar(table, row, _("_Y:"), unitstr,
+                                   controls.dy, GWY_HSCALE_DEFAULT);
     gwy_widget_set_activate_on_unfocus(spin, TRUE);
     gtk_spin_button_set_digits(GTK_SPIN_BUTTON(spin), 6);
     g_signal_connect(controls.dy, "value-changed",
@@ -203,13 +203,13 @@ tilt_dialog(TiltArgs *args,
     /* Angles (adjustment values will be calculated later) */
     label = gwy_label_new_header(_("Angles"));
     gtk_table_attach(GTK_TABLE(table), label,
-                     0, 3, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
+                     0, 2, row, row+1, GTK_FILL, 0, 0, 0);
     row++;
 
     if (units_equal) {
-        controls.theta = gtk_adjustment_new(0, 0, 89.6, 1e-2, 1.0, 0);
-        spin = gwy_table_attach_hscale(table, row, _("θ:"), _("deg"),
-                                       controls.theta, GWY_HSCALE_NO_SCALE);
+        controls.theta = gtk_adjustment_new(0.0, 0.0, 89.6, 1e-2, 1.0, 0);
+        spin = gwy_table_attach_adjbar(table, row, _("θ:"), _("deg"),
+                                       controls.theta, GWY_HSCALE_DEFAULT);
         gwy_widget_set_activate_on_unfocus(spin, TRUE);
         gtk_spin_button_set_digits(GTK_SPIN_BUTTON(spin), 4);
         g_signal_connect_swapped(controls.theta, "value-changed",
@@ -219,9 +219,9 @@ tilt_dialog(TiltArgs *args,
     else
         controls.theta = gtk_adjustment_new(0, 0, 90.0, 1e-2, 1.0, 0);
 
-    controls.phi = gtk_adjustment_new(0, -180, 180, 1e-2, 1.0, 0);
-    spin = gwy_table_attach_hscale(table, row, _("φ:"), _("deg"),
-                                   controls.phi, GWY_HSCALE_NO_SCALE);
+    controls.phi = gtk_adjustment_new(0.0, -180.0, 180.0, 1e-2, 1.0, 0);
+    spin = gwy_table_attach_adjbar(table, row, _("φ:"), _("deg"),
+                                   controls.phi, GWY_HSCALE_LINEAR);
     gwy_widget_set_activate_on_unfocus(spin, TRUE);
     gtk_spin_button_set_digits(GTK_SPIN_BUTTON(spin), 4);
     g_signal_connect_swapped(controls.phi, "value-changed",
