@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: tip_blind.c 18537 2016-03-28 18:11:19Z yeti-dn $
+ *  @(#) $Id: tip_blind.c 19948 2017-06-22 14:05:41Z yeti-dn $
  *  Copyright (C) 2004 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -80,7 +80,6 @@ typedef struct {
     GtkWidget *data;
     GtkWidget *type;
     GtkObject *threshold;
-    GtkWidget *threshold_spin;
     GtkWidget *threshold_unit;
     GtkWidget *boundaries;
     GwyDataField *tip;
@@ -182,7 +181,7 @@ static GwyModuleInfo module_info = {
     "2004",
 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, tip_blind)
 
 static gboolean
 module_register(void)
@@ -292,6 +291,7 @@ tip_blind_dialog(TipBlindArgs *args)
     gmodel = gwy_graph_model_new();
     controls.graph = gwy_graph_new(gmodel);
     g_object_unref(gmodel);
+    gwy_graph_enable_user_input(GWY_GRAPH(controls.graph), FALSE);
     gwy_axis_set_visible(gwy_graph_get_axis(GWY_GRAPH(controls.graph),
                                             GTK_POS_LEFT),
                          FALSE);
@@ -304,7 +304,7 @@ tip_blind_dialog(TipBlindArgs *args)
                            G_CALLBACK(gtk_widget_hide), NULL);
     gtk_box_pack_start(GTK_BOX(vbox), controls.graph, TRUE, TRUE, 0);
 
-    table = gtk_table_new(13, 4, FALSE);
+    table = gtk_table_new(13, 3, FALSE);
     gtk_table_set_row_spacings(GTK_TABLE(table), 2);
     gtk_table_set_col_spacings(GTK_TABLE(table), 6);
     gtk_container_set_border_width(GTK_CONTAINER(table), 4);
@@ -318,26 +318,29 @@ tip_blind_dialog(TipBlindArgs *args)
                                    &args->source);
     g_signal_connect(controls.data, "changed",
                      G_CALLBACK(data_changed), &args->source);
-    gwy_table_attach_hscale(table, row, _("Related _data:"), NULL,
-                            GTK_OBJECT(controls.data), GWY_HSCALE_WIDGET);
+    gwy_table_attach_adjbar(table, row, _("Related _data:"), NULL,
+                            GTK_OBJECT(controls.data),
+                            GWY_HSCALE_WIDGET_NO_EXPAND);
     gtk_table_set_row_spacing(GTK_TABLE(table), row, 8);
     row++;
 
     label = gtk_label_new(_("Estimated Tip Size"));
     gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
     gtk_table_attach(GTK_TABLE(table), label,
-                     0, 4, row, row+1, GTK_FILL, 0, 0, 0);
+                     0, 2, row, row+1, GTK_FILL, 0, 0, 0);
     row++;
 
     controls.xres = gtk_adjustment_new(args->xres, MIN_RES, MAX_RES, 1, 10, 0);
-    gwy_table_attach_hscale(table, row, _("_Width:"), "px", controls.xres, 0);
+    gwy_table_attach_adjbar(table, row, _("_Width:"), _("px"),
+                            controls.xres, GWY_HSCALE_LINEAR | GWY_HSCALE_SNAP);
     g_object_set_data(G_OBJECT(controls.xres), "controls", &controls);
     g_signal_connect(controls.xres, "value-changed",
                      G_CALLBACK(width_changed), &controls);
     row++;
 
     controls.yres = gtk_adjustment_new(args->yres, MIN_RES, MAX_RES, 1, 10, 0);
-    gwy_table_attach_hscale(table, row, _("_Height:"), "px", controls.yres, 0);
+    gwy_table_attach_adjbar(table, row, _("_Height:"), _("px"),
+                            controls.yres, GWY_HSCALE_LINEAR | GWY_HSCALE_SNAP);
     g_object_set_data(G_OBJECT(controls.yres), "controls", &controls);
     g_signal_connect(controls.yres, "value-changed",
                      G_CALLBACK(height_changed), &controls);
@@ -346,7 +349,7 @@ tip_blind_dialog(TipBlindArgs *args)
     controls.same_resolution
         = gtk_check_button_new_with_mnemonic(_("_Same resolution"));
     gtk_table_attach(GTK_TABLE(table), controls.same_resolution,
-                     0, 4, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
+                     0, 2, row, row+1, GTK_FILL, 0, 0, 0);
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(controls.same_resolution),
                                  args->same_resolution);
     g_signal_connect(controls.same_resolution, "toggled",
@@ -355,57 +358,50 @@ tip_blind_dialog(TipBlindArgs *args)
     row++;
 
     gtk_table_attach(GTK_TABLE(table), gwy_label_new_header(_("Options")),
-                     0, 4, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
+                     0, 2, row, row+1, GTK_FILL, 0, 0, 0);
     row++;
 
-    controls.threshold = gtk_adjustment_new(1.0, 0.01, 1000.0, 0.01, 1.0, 0.0);
-    controls.threshold_spin
-        = gtk_spin_button_new(GTK_ADJUSTMENT(controls.threshold), 0.1, 2);
-    gtk_table_attach(GTK_TABLE(table), controls.threshold_spin,
-                     2, 3, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
-    label = gtk_label_new_with_mnemonic(_("Noise suppression t_hreshold:"));
-    gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
-    gtk_label_set_mnemonic_widget(GTK_LABEL(label), controls.threshold_spin);
-    gtk_table_attach(GTK_TABLE(table), label,
-                     0, 2, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
     unit = gwy_data_field_get_si_unit_z(dfield);
     controls.threshold_unit
         = gwy_combo_box_metric_unit_new(G_CALLBACK(thresh_changed),
                                         &controls,
                                         -12, -3, unit, -9);
     gtk_table_attach(GTK_TABLE(table), controls.threshold_unit,
-                     3, 4, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
+                     2, 3, row, row+1, GTK_FILL, 0, 0, 0);
+    /* Do this last to get correct initial sensitivity. */
+    controls.threshold = gtk_adjustment_new(1.0, 0.01, 1000.0, 0.01, 1.0, 0.0);
+    g_object_set_data(G_OBJECT(controls.threshold), "units",
+                      controls.threshold_unit);
+    gwy_table_attach_adjbar(table, row,
+                            _("Noise suppression t_hreshold:"), NULL,
+                            controls.threshold, GWY_HSCALE_LOG);
     g_signal_connect(controls.threshold, "value-changed",
                      G_CALLBACK(thresh_changed), &controls);
     sci_entry_set_value(GTK_ADJUSTMENT(controls.threshold),
-                        GTK_COMBO_BOX(controls.threshold_unit),
-                        args->thresh);
+                        GTK_COMBO_BOX(controls.threshold_unit), args->thresh);
     row++;
 
-    controls.boundaries
-                    = gtk_check_button_new_with_mnemonic(_("Use _boundaries"));
+    controls.boundaries = gtk_check_button_new_with_mnemonic(_("Use "
+                                                               "_boundaries"));
     gtk_table_attach(GTK_TABLE(table), controls.boundaries,
-                     0, 4, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
+                     0, 2, row, row+1, GTK_FILL, 0, 0, 0);
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(controls.boundaries),
-                                                 args->use_boundaries);
+                                 args->use_boundaries);
     g_signal_connect(controls.boundaries, "toggled",
                      G_CALLBACK(bound_changed), args);
-    gtk_table_set_row_spacing(GTK_TABLE(table), row, 8);
     row++;
 
+    gtk_table_set_row_spacing(GTK_TABLE(table), row-1, 8);
     gtk_table_attach(GTK_TABLE(table), gwy_label_new_header(_("Stripes")),
-                     0, 4, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
+                     0, 2, row, row+1, GTK_FILL, 0, 0, 0);
     row++;
 
     controls.nstripes = gtk_adjustment_new(args->nstripes,
                                            MIN_STRIPES, MAX_STRIPES, 1, 10, 0);
-    gwy_table_attach_hscale(table, row, _("_Split to stripes:"), NULL,
-                            controls.nstripes, GWY_HSCALE_CHECK);
+    gwy_table_attach_adjbar(table, row, _("_Split to stripes:"), NULL,
+                            controls.nstripes,
+                            GWY_HSCALE_CHECK | GWY_HSCALE_LINEAR | GWY_HSCALE_SNAP);
     controls.split_to_stripes = gwy_table_hscale_get_check(controls.nstripes);
-    gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(controls.split_to_stripes),
-                                 !args->split_to_stripes);
-    gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(controls.split_to_stripes),
-                                 args->split_to_stripes);
     g_signal_connect(controls.split_to_stripes, "toggled",
                      G_CALLBACK(split_to_stripes_changed), &controls);
     g_signal_connect(controls.nstripes, "value-changed",
@@ -413,8 +409,9 @@ tip_blind_dialog(TipBlindArgs *args)
     row++;
 
     controls.stripeno = gtk_adjustment_new(1, 1, args->nstripes, 1, 10, 0);
-    gwy_table_attach_hscale(table, row, _("_Preview stripe:"), NULL,
-                            controls.stripeno, GWY_HSCALE_DEFAULT);
+    gwy_table_attach_adjbar(table, row, _("_Preview stripe:"), NULL,
+                            controls.stripeno,
+                            GWY_HSCALE_LINEAR | GWY_HSCALE_SNAP);
     g_signal_connect(controls.stripeno, "value-changed",
                      G_CALLBACK(stripeno_changed), &controls);
     row++;
@@ -424,7 +421,7 @@ tip_blind_dialog(TipBlindArgs *args)
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(controls.plot_size_graph),
                                  args->plot_size_graph);
     gtk_table_attach(GTK_TABLE(table), controls.plot_size_graph,
-                     0, 4, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
+                     0, 2, row, row+1, GTK_FILL, 0, 0, 0);
     g_signal_connect(controls.plot_size_graph, "toggled",
                      G_CALLBACK(plot_size_graph_changed), &controls);
     row++;
@@ -434,7 +431,7 @@ tip_blind_dialog(TipBlindArgs *args)
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(controls.create_images),
                                  args->create_images);
     gtk_table_attach(GTK_TABLE(table), controls.create_images,
-                     0, 4, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
+                     0, 2, row, row+1, GTK_FILL, 0, 0, 0);
     g_signal_connect(controls.create_images, "toggled",
                      G_CALLBACK(create_images_changed), &controls);
     row++;
