@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: tip_model.c 19080 2016-10-14 13:59:02Z yeti-dn $
+ *  @(#) $Id: tip_model.c 19948 2017-06-22 14:05:41Z yeti-dn $
  *  Copyright (C) 2004-2016 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -53,9 +53,7 @@ typedef struct {
     GtkWidget *view;
     GtkWidget *type;
     GtkObject *radius;
-    GtkWidget *radius_spin;
     GtkWidget *radius_unit;
-    GtkWidget *radius_label;
     GtkObject *angle;
     GtkObject *theta;
     GtkObject *nsides;
@@ -69,38 +67,38 @@ typedef struct {
     gboolean tipdone;
 } TipModelControls;
 
-static gboolean    module_register                 (void);
-static void        tip_model                       (GwyContainer *data,
-                                                    GwyRunType run);
-static void        tip_model_dialog                (TipModelArgs *args);
-static void        tip_model_dialog_update_controls(TipModelControls *controls,
-                                                    TipModelArgs *args);
-static void        tip_model_dialog_update_values  (TipModelControls *controls,
-                                                    TipModelArgs *args);
-static void        preview                         (TipModelControls *controls,
-                                                    TipModelArgs *args);
-static void        tip_model_do                    (TipModelArgs *args,
-                                                    TipModelControls *controls);
-static void        tip_process                     (TipModelArgs *args,
-                                                    TipModelControls *controls);
-static void        tip_model_load_args             (GwyContainer *container,
-                                                    TipModelArgs *args);
-static void        tip_model_save_args             (GwyContainer *container,
-                                                    TipModelArgs *args);
-static void        tip_model_sanitize_args         (TipModelArgs *args);
-static void        sci_entry_set_value             (GtkAdjustment *adj,
-                                                    GtkComboBox *metric,
-                                                    gdouble val);
-static void        tip_type_cb                     (GtkWidget *combo,
-                                                    TipModelControls *controls);
-static GtkWidget*  create_preset_menu              (GCallback callback,
-                                                    gpointer cbdata,
-                                                    gint current);
-static void        tip_update                      (TipModelControls *controls,
-                                                    TipModelArgs *args);
-static void        radius_changed_cb               (gpointer object,
-                                                    TipModelControls *controls);
-static void        tip_model_dialog_abandon        (TipModelControls *controls);
+static gboolean   module_register                 (void);
+static void       tip_model                       (GwyContainer *data,
+                                                   GwyRunType run);
+static void       tip_model_dialog                (TipModelArgs *args);
+static void       tip_model_dialog_update_controls(TipModelControls *controls,
+                                                   TipModelArgs *args);
+static void       tip_model_dialog_update_values  (TipModelControls *controls,
+                                                   TipModelArgs *args);
+static void       preview                         (TipModelControls *controls,
+                                                   TipModelArgs *args);
+static void       tip_model_do                    (TipModelArgs *args,
+                                                   TipModelControls *controls);
+static void       tip_process                     (TipModelArgs *args,
+                                                   TipModelControls *controls);
+static void       tip_model_load_args             (GwyContainer *container,
+                                                   TipModelArgs *args);
+static void       tip_model_save_args             (GwyContainer *container,
+                                                   TipModelArgs *args);
+static void       tip_model_sanitize_args         (TipModelArgs *args);
+static void       sci_entry_set_value             (GtkAdjustment *adj,
+                                                   GtkComboBox *metric,
+                                                   gdouble val);
+static void       tip_type_changed                (GtkWidget *combo,
+                                                   TipModelControls *controls);
+static GtkWidget* create_preset_menu              (GCallback callback,
+                                                   gpointer cbdata,
+                                                   gint current);
+static void       tip_update                      (TipModelControls *controls,
+                                                   TipModelArgs *args);
+static void       radius_changed                  (gpointer object,
+                                                   TipModelControls *controls);
+static void       tip_model_dialog_abandon        (TipModelControls *controls);
 
 
 static const TipModelArgs tip_model_defaults = {
@@ -113,12 +111,12 @@ static GwyModuleInfo module_info = {
     &module_register,
     N_("Models SPM tip."),
     "Petr Klapetek <klapetek@gwyddion.net>",
-    "2.0",
+    "2.1",
     "David Nečas (Yeti) & Petr Klapetek",
     "2004",
 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, tip_model)
 
 static gboolean
 module_register(void)
@@ -212,69 +210,67 @@ tip_model_dialog(TipModelArgs *args)
     /* set up tip model controls */
     gtk_box_pack_start(GTK_BOX(hbox), controls.view, FALSE, FALSE, 4);
 
-    table = gtk_table_new(7, 4, FALSE);
+    table = gtk_table_new(7, 3, FALSE);
     gtk_table_set_row_spacings(GTK_TABLE(table), 2);
     gtk_table_set_col_spacings(GTK_TABLE(table), 6);
     gtk_container_set_border_width(GTK_CONTAINER(table), 4);
     gtk_box_pack_start(GTK_BOX(hbox), table, TRUE, TRUE, 4);
     row = 0;
 
-    controls.type = create_preset_menu(G_CALLBACK(tip_type_cb),
+    controls.type = create_preset_menu(G_CALLBACK(tip_type_changed),
                                        &controls, args->type);
-    gwy_table_attach_hscale(table, row, _("Tip _type:"), NULL,
-                            GTK_OBJECT(controls.type), GWY_HSCALE_WIDGET);
+    gwy_table_attach_adjbar(table, row, _("Tip _type:"), NULL,
+                            GTK_OBJECT(controls.type),
+                            GWY_HSCALE_WIDGET_NO_EXPAND);
     row++;
 
     controls.nsides = gtk_adjustment_new(args->nsides, 3, 24, 1, 5, 0);
-    gwy_table_attach_hscale(table, row, _("_Number of sides:"), NULL,
-                            controls.nsides, 0);
+    gwy_table_attach_adjbar(table, row, _("_Number of sides:"), NULL,
+                            controls.nsides,
+                            GWY_HSCALE_LINEAR | GWY_HSCALE_SNAP);
     row++;
 
     controls.angle = gtk_adjustment_new(args->angle, 0.1, 89.9, 0.1, 1, 0);
-    spin = gwy_table_attach_hscale(table, row, _("Tip _slope:"), _("deg"),
-                                   controls.angle, 0);
+    spin = gwy_table_attach_adjbar(table, row, _("Tip _slope:"), _("deg"),
+                                   controls.angle, GWY_HSCALE_LINEAR);
     gtk_spin_button_set_digits(GTK_SPIN_BUTTON(spin), 2);
     row++;
 
     controls.theta = gtk_adjustment_new(args->theta, 0, 360, 0.1, 1, 0);
-    spin = gwy_table_attach_hscale(table, row, _("Tip _rotation:"), _("deg"),
-                                   controls.theta, 0);
+    spin = gwy_table_attach_adjbar(table, row, _("Tip _rotation:"), _("deg"),
+                                   controls.theta, GWY_HSCALE_LINEAR);
     gtk_spin_button_set_digits(GTK_SPIN_BUTTON(spin), 2);
     row++;
 
-    controls.radius = gtk_adjustment_new(1.0, 0.01, 1000.0, 0.01, 1.0, 0.0);
-    controls.radius_spin = gtk_spin_button_new(GTK_ADJUSTMENT(controls.radius),
-                                               0.1, 2);
-    gtk_table_attach(GTK_TABLE(table), controls.radius_spin,
-                     2, 3, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
-    controls.radius_label = gtk_label_new_with_mnemonic(_("Tip _apex radius:"));
-    gtk_misc_set_alignment(GTK_MISC(controls.radius_label), 0.0, 0.5);
-    gtk_label_set_mnemonic_widget(GTK_LABEL(controls.radius_label),
-                                  controls.radius_spin);
-    gtk_table_attach(GTK_TABLE(table), controls.radius_label,
-                     0, 1, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
     unit = gwy_data_field_get_si_unit_xy(dfield);
     controls.radius_unit
-        = gwy_combo_box_metric_unit_new(G_CALLBACK(radius_changed_cb),
+        = gwy_combo_box_metric_unit_new(G_CALLBACK(radius_changed),
                                         &controls,
                                         -12, -3, unit, -9);
     gtk_table_attach(GTK_TABLE(table), controls.radius_unit,
-                     3, 4, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
+                     2, 3, row, row+1, GTK_FILL, 0, 0, 0);
+    /* Do this last to get correct initial sensitivity. */
+    controls.radius = gtk_adjustment_new(1.0, 0.01, 1000.0, 0.01, 1.0, 0.0);
+    g_object_set_data(G_OBJECT(controls.radius), "units", controls.radius_unit);
+    gwy_table_attach_adjbar(table, row, _("Tip _apex radius:"), NULL,
+                            controls.radius, GWY_HSCALE_LOG);
     g_signal_connect(controls.radius, "value-changed",
-                     G_CALLBACK(radius_changed_cb), &controls);
+                     G_CALLBACK(radius_changed), &controls);
+    sci_entry_set_value(GTK_ADJUSTMENT(controls.radius),
+                        GTK_COMBO_BOX(controls.radius_unit), args->radius);
     row++;
 
     controls.anisotropy = gtk_adjustment_new(args->anisotropy,
                                              0.1, 10.0, 0.001, 1.0, 0);
-    spin = gwy_table_attach_hscale(table, row, _("Tip _anisotropy:"), NULL,
-                                   controls.anisotropy, 0);
+    gwy_table_attach_adjbar(table, row, _("Tip _anisotropy:"), NULL,
+                            controls.anisotropy, GWY_HSCALE_SQRT);
     row++;
 
     gtk_table_set_row_spacing(GTK_TABLE(table), row-1, 8);
     controls.labsize = gtk_label_new(NULL);
     gtk_misc_set_alignment(GTK_MISC(controls.labsize), 0.0, 0.5);
     gtk_table_attach(GTK_TABLE(table), controls.labsize,
-                     0, 3, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
+                     0, 2, row, row+1, GTK_FILL, 0, 0, 0);
     row++;
 
     controls.tipdone = FALSE;
@@ -347,15 +343,15 @@ sci_entry_set_value(GtkAdjustment *adj,
     mag = 3*(gint)floor(log10(val)/3.0);
     mag = CLAMP(mag, -12, -3);
     g_signal_handlers_block_matched(metric, G_SIGNAL_MATCH_FUNC,
-                                    0, 0, 0, radius_changed_cb, 0);
+                                    0, 0, 0, radius_changed, 0);
     gwy_enum_combo_box_set_active(GTK_COMBO_BOX(metric), mag);
     g_signal_handlers_unblock_matched(metric, G_SIGNAL_MATCH_FUNC,
-                                      0, 0, 0, radius_changed_cb, 0);
+                                      0, 0, 0, radius_changed, 0);
     gtk_adjustment_set_value(adj, val/pow10(mag));
 }
 
 static void
-tip_type_cb(GtkWidget *combo, TipModelControls *controls)
+tip_type_changed(GtkWidget *combo, TipModelControls *controls)
 {
     controls->args->type = gwy_enum_combo_box_get_active(GTK_COMBO_BOX(combo));
     tip_model_dialog_update_controls(controls, controls->args);
@@ -435,9 +431,7 @@ tip_model_dialog_update_controls(TipModelControls *controls,
     gwy_table_hscale_set_sensitive(controls->theta, rotation_sens);
     gwy_table_hscale_set_sensitive(controls->nsides, nsides_sens);
     gwy_table_hscale_set_sensitive(controls->anisotropy, anisotropy_sens);
-    gtk_widget_set_sensitive(controls->radius_spin, radius_sens);
-    gtk_widget_set_sensitive(controls->radius_unit, radius_sens);
-    gtk_widget_set_sensitive(controls->radius_label, radius_sens);
+    gwy_table_hscale_set_sensitive(controls->radius, radius_sens);
 }
 
 static void
@@ -570,8 +564,7 @@ tip_process(TipModelArgs *args,
 }
 
 static void
-radius_changed_cb(G_GNUC_UNUSED gpointer object,
-                  TipModelControls *controls)
+radius_changed(G_GNUC_UNUSED gpointer object, TipModelControls *controls)
 {
     gint p10;
     gdouble val;
