@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: volumize.c 19044 2016-10-08 19:10:46Z yeti-dn $
+ *  @(#) $Id: volumize.c 19948 2017-06-22 14:05:41Z yeti-dn $
  *  Copyright (C) 2015-2016 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -46,14 +46,14 @@ static GwyModuleInfo module_info = {
     "2013",
 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, volumize)
 
 static gboolean
 module_register(void)
 {
     gwy_process_func_register("volumize",
                               (GwyProcessFunc)&volumize,
-                              N_("/_Basic Operations/Volumize..."),
+                              N_("/_Basic Operations/Volumize"),
                               GWY_STOCK_VOLUMIZE,
                               VOLUMIZE_RUN_MODES,
                               GWY_MENU_FLAG_DATA,
