@@ -1,6 +1,6 @@
 /*
  *  @(#) $Id: volumize_layers.c 14879 2013-04-15 21:04:16Z yeti-dn $
- *  Copyright (C) 2015-2016 David Necas (Yeti), Petr Klapetek.
+ *  Copyright (C) 2015-2017 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -85,12 +85,12 @@ static GwyModuleInfo module_info = {
     &module_register,
     N_("Converts all datafields to 3D volume data."),
     "Petr Klapetek <klapetek@gwyddion.net>",
-    "2.0",
+    "2.1",
     "David Nečas (Yeti) & Petr Klapetek",
     "2013",
 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, volumize_layers)
 
 static gboolean
 module_register(void)
@@ -237,29 +237,28 @@ volumize_layers_dialog(VolumizeLayersArgs *args,
     args->zres = zres;
 
     controls.xres = gtk_adjustment_new(args->xres, 1.0, 1000.0, 1, 10, 0);
-    gwy_table_attach_hscale(table, row, _("_X resolution:"), "pixels",
-                            controls.xres, GWY_HSCALE_SQRT);
+    gwy_table_attach_adjbar(table, row, _("_X resolution:"), _("px"),
+                            controls.xres, GWY_HSCALE_DEFAULT);
     row++;
 
     controls.yres = gtk_adjustment_new(args->yres, 1.0, 1000.0, 1, 10, 0);
-    gwy_table_attach_hscale(table, row, _("_Y resolution:"), "pixels",
-                            controls.yres, GWY_HSCALE_SQRT);
+    gwy_table_attach_adjbar(table, row, _("_Y resolution:"), _("px"),
+                            controls.yres, GWY_HSCALE_DEFAULT);
     row++;
 
     controls.zres = gtk_adjustment_new(args->zres, 1.0, 1000.0, 1, 10, 0);
-    gwy_table_attach_hscale(table, row, _("_Z resolution:"), "pixels",
-                            controls.zres, GWY_HSCALE_SQRT);
+    gwy_table_attach_adjbar(table, row, _("_Z resolution:"), _("px"),
+                            controls.zres, GWY_HSCALE_DEFAULT);
     row++;
 
     controls.zreal = gtk_adjustment_new(args->zreal,
                                         0.01, 10000.0, 0.01, 1.0, 0);
-    gwy_table_attach_hscale(table, row, _("Z _range:"), args->zunit,
-                            controls.zreal, GWY_HSCALE_SQRT);
+    gwy_table_attach_adjbar(table, row, _("Z _range:"), args->zunit,
+                            controls.zreal, GWY_HSCALE_DEFAULT);
 
     zunitbutton = gtk_button_new_with_label(gwy_sgettext("verb|Change"));
     gtk_table_attach(GTK_TABLE(table), zunitbutton,
-                     4, 5, row, row+2,
-                     GTK_EXPAND | GTK_FILL | GTK_SHRINK, 0, 0, 0);
+                     3, 4, row, row+2, GTK_FILL | GTK_SHRINK, 0, 0, 0);
     g_signal_connect_swapped(zunitbutton, "clicked",
                              G_CALLBACK(change_zunits), &controls);
     row++;
