@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: wave_synth.c 19044 2016-10-08 19:10:46Z yeti-dn $
+ *  @(#) $Id: wave_synth.c 20058 2017-07-10 11:22:20Z yeti-dn $
  *  Copyright (C) 2014 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
@@ -69,6 +69,7 @@ typedef struct {
     gdouble y;
     gdouble z;
     gdouble k;
+    gdouble decay;
 } GwyWaveSource;
 
 typedef struct _WaveSynthArgs WaveSynthArgs;
@@ -90,6 +91,8 @@ struct _WaveSynthArgs {
     gdouble amplitude_noise;
     gdouble k;
     gdouble k_noise;
+    gdouble decay;
+    gdouble decay_noise;
     /* Dynamic state */
     gfloat *wave_table;
 };
@@ -120,6 +123,8 @@ struct _WaveSynthControls {
     GtkObject *k;
     GtkWidget *k_units;
     GtkObject *k_noise;
+    GtkObject *decay;
+    GtkObject *decay_noise;
     GwyContainer *mydata;
     GwyDataField *surface;
     gdouble pxsize;
@@ -158,9 +163,11 @@ static void       amplitude_init_clicked (WaveSynthControls *controls);
 static void       wave_synth_invalidate  (WaveSynthControls *controls);
 static gboolean   preview_gsource        (gpointer user_data);
 static void       preview                (WaveSynthControls *controls);
-static void       wave_synth_do          (const WaveSynthArgs *args,
+static gboolean   wave_synth_do          (const WaveSynthArgs *args,
                                           const GwyDimensionArgs *dimsargs,
-                                          GwyDataField *dfield);
+                                          GwyDataField *dfield,
+                                          GwySetMessageFunc set_message,
+                                          GwySetFractionFunc set_fraction);
 static void       precalculate_wave_table(gfloat *tab,
                                           guint n,
                                           WaveTypeType type);
@@ -198,7 +205,8 @@ static const WaveSynthArgs wave_synth_defaults = {
     0.0, 0.3,
     0.0, 0.3,
     1.0, 0.0,
-    80.0, 0.02,
+    30.0, 0.02,
+    -5.0, 0.0,
     /* Dynamic state */
     NULL,
 };
@@ -210,12 +218,12 @@ static GwyModuleInfo module_info = {
     &module_register,
     N_("Generates various kinds of waves."),
     "Yeti <yeti@gwyddion.net>",
-    "1.1",
+    "1.2",
     "David Nečas (Yeti)",
     "2014",
 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, wave_synth)
 
 static gboolean
 module_register(void)
@@ -264,46 +272,57 @@ run_noninteractive(WaveSynthArgs *args,
                    gint oldid,
                    GQuark quark)
 {
+    GwyDataField *newfield;
     GwySIUnit *siunit;
     gboolean replace = dimsargs->replace && dfield;
     gboolean add = dimsargs->add && dfield;
     gint newid;
+    gboolean ok;
 
     if (args->randomize)
         args->seed = g_random_int() & 0x7fffffff;
 
-    if (replace) {
-        /* Always take a reference so that we can always unref. */
-        g_object_ref(dfield);
-
-        gwy_app_undo_qcheckpointv(data, 1, &quark);
-        if (!add)
-            gwy_data_field_clear(dfield);
-
-        gwy_app_channel_log_add_proc(data, oldid, oldid);
+    if (add || replace) {
+        if (add)
+            newfield = gwy_data_field_duplicate(dfield);
+        else
+            newfield = gwy_data_field_new_alike(dfield, TRUE);
     }
     else {
-        if (add)
-            dfield = gwy_data_field_duplicate(dfield);
-        else {
-            gdouble mag = pow10(dimsargs->xypow10) * dimsargs->measure;
-            dfield = gwy_data_field_new(dimsargs->xres, dimsargs->yres,
-                                        mag*dimsargs->xres, mag*dimsargs->yres,
-                                        TRUE);
+        gdouble mag = pow10(dimsargs->xypow10) * dimsargs->measure;
+        newfield = gwy_data_field_new(dimsargs->xres, dimsargs->yres,
+                                      mag*dimsargs->xres, mag*dimsargs->yres,
+                                      TRUE);
 
-            siunit = gwy_data_field_get_si_unit_xy(dfield);
-            gwy_si_unit_set_from_string(siunit, dimsargs->xyunits);
+        siunit = gwy_data_field_get_si_unit_xy(newfield);
+        gwy_si_unit_set_from_string(siunit, dimsargs->xyunits);
 
-            siunit = gwy_data_field_get_si_unit_z(dfield);
-            gwy_si_unit_set_from_string(siunit, dimsargs->zunits);
-        }
+        siunit = gwy_data_field_get_si_unit_z(newfield);
+        gwy_si_unit_set_from_string(siunit, dimsargs->zunits);
     }
 
-    wave_synth_do(args, dimsargs, dfield);
+    gwy_app_wait_start(gwy_app_find_window_for_channel(data, oldid),
+                       _("Initializing..."));
+    ok = wave_synth_do(args, dimsargs, newfield,
+                       gwy_app_wait_set_message, gwy_app_wait_set_fraction);
+    gwy_app_wait_finish();
 
-    if (!replace) {
+    if (!ok) {
+        g_object_unref(newfield);
+        return;
+    }
+
+    if (replace) {
+        gwy_app_undo_qcheckpointv(data, 1, &quark);
+        gwy_container_set_object(data, gwy_app_get_data_key_for_id(oldid),
+                                 newfield);
+        gwy_app_channel_log_add_proc(data, oldid, oldid);
+        g_object_unref(newfield);
+        newid = oldid;
+    }
+    else {
         if (data) {
-            newid = gwy_app_data_browser_add_data_field(dfield, data, TRUE);
+            newid = gwy_app_data_browser_add_data_field(newfield, data, TRUE);
             if (oldid != -1)
                 gwy_app_sync_data_items(data, data, oldid, newid, FALSE,
                                         GWY_DATA_ITEM_GRADIENT,
@@ -313,7 +332,7 @@ run_noninteractive(WaveSynthArgs *args,
             newid = 0;
             data = gwy_container_new();
             gwy_container_set_object(data, gwy_app_get_data_key_for_id(newid),
-                                     dfield);
+                                     newfield);
             gwy_app_data_browser_add(data);
             gwy_app_data_browser_reset_visibility(data,
                                                   GWY_VISIBILITY_RESET_SHOW_ALL);
@@ -322,8 +341,8 @@ run_noninteractive(WaveSynthArgs *args,
 
         gwy_app_set_data_field_title(data, newid, _("Generated"));
         gwy_app_channel_log_add_proc(data, add ? oldid : -1, newid);
+        g_object_unref(newfield);
     }
-    g_object_unref(dfield);
 }
 
 static gboolean
@@ -333,7 +352,7 @@ wave_synth_dialog(WaveSynthArgs *args,
                   GwyDataField *dfield_template,
                   gint id)
 {
-    GtkWidget *dialog, *table, *vbox, *hbox, *notebook;
+    GtkWidget *dialog, *table, *vbox, *hbox, *notebook, *spin;
     WaveSynthControls controls;
     GwyDataField *dfield;
     gboolean finished;
@@ -409,7 +428,7 @@ wave_synth_dialog(WaveSynthArgs *args,
         g_signal_connect_swapped(controls.dims->add, "toggled",
                                  G_CALLBACK(wave_synth_invalidate), &controls);
 
-    table = gtk_table_new(16, 4, FALSE);
+    table = gtk_table_new(18, 4, FALSE);
     controls.table = GTK_TABLE(table);
     gtk_table_set_row_spacings(controls.table, 2);
     gtk_table_set_col_spacings(controls.table, 6);
@@ -419,14 +438,14 @@ wave_synth_dialog(WaveSynthArgs *args,
     row = 0;
 
     controls.quantity = quantity_selector_new(&controls);
-    gwy_table_attach_hscale(table, row, _("_Quantity:"), NULL,
+    gwy_table_attach_adjbar(table, row, _("_Quantity:"), NULL,
                             GTK_OBJECT(controls.quantity),
-                            GWY_HSCALE_WIDGET);
+                            GWY_HSCALE_WIDGET_NO_EXPAND);
     row++;
 
     controls.nwaves = gtk_adjustment_new(args->nwaves, 1, 1000, 1, 10, 0);
     g_object_set_data(G_OBJECT(controls.nwaves), "target", &args->nwaves);
-    gwy_table_attach_hscale(table, row, _("_Number of waves:"), NULL,
+    gwy_table_attach_adjbar(table, row, _("_Number of waves:"), NULL,
                             GTK_OBJECT(controls.nwaves), GWY_HSCALE_SQRT);
     g_signal_connect_swapped(controls.nwaves, "value-changed",
                              G_CALLBACK(gwy_synth_int_changed), &controls);
@@ -434,13 +453,13 @@ wave_synth_dialog(WaveSynthArgs *args,
 
     gtk_table_set_row_spacing(GTK_TABLE(table), row-1, 8);
     gtk_table_attach(GTK_TABLE(table), gwy_label_new_header(_("Amplitude")),
-                     0, 3, row, row+1, GTK_FILL, 0, 0, 0);
+                     0, 2, row, row+1, GTK_FILL, 0, 0, 0);
     row++;
 
     controls.type = type_selector_new(&controls);
-    gwy_table_attach_hscale(table, row, _("_Wave form:"), NULL,
+    gwy_table_attach_adjbar(table, row, _("_Wave form:"), NULL,
                             GTK_OBJECT(controls.type),
-                            GWY_HSCALE_WIDGET);
+                            GWY_HSCALE_WIDGET_NO_EXPAND);
     row++;
 
     row = gwy_synth_attach_height(&controls, row,
@@ -450,11 +469,11 @@ wave_synth_dialog(WaveSynthArgs *args,
 
     if (dfield_template) {
         controls.amplitude_init
-            = gtk_button_new_with_mnemonic(_("_Like Current Channel"));
+            = gtk_button_new_with_mnemonic(_("_Like Current Image"));
         g_signal_connect_swapped(controls.amplitude_init, "clicked",
                                  G_CALLBACK(amplitude_init_clicked), &controls);
         gtk_table_attach(GTK_TABLE(table), controls.amplitude_init,
-                         1, 3, row, row+1, GTK_FILL, 0, 0, 0);
+                         0, 2, row, row+1, GTK_FILL, 0, 0, 0);
         row++;
     }
 
@@ -462,14 +481,26 @@ wave_synth_dialog(WaveSynthArgs *args,
                                     &controls.amplitude_noise,
                                     &args->amplitude_noise);
 
+    gtk_table_set_row_spacing(GTK_TABLE(table), row-1, 8);
+    controls.decay = gtk_adjustment_new(args->decay, -5.0, 0.0, 0.001, 1, 0);
+    g_object_set_data(G_OBJECT(controls.decay), "target", &args->decay);
+    gwy_table_attach_adjbar(table, row, _("_Decay:"), "log<sub>10</sub>",
+                            GTK_OBJECT(controls.decay), GWY_HSCALE_LINEAR);
+    g_signal_connect_swapped(controls.decay, "value-changed",
+                             G_CALLBACK(gwy_synth_double_changed), &controls);
+    row++;
+
+    row = gwy_synth_attach_variance(&controls, row,
+                                    &controls.decay_noise, &args->decay_noise);
+
     gtk_table_set_row_spacing(GTK_TABLE(table), row-1, 8);
     gtk_table_attach(GTK_TABLE(table), gwy_label_new_header(_("Frequency")),
-                     0, 3, row, row+1, GTK_FILL, 0, 0, 0);
+                     0, 2, row, row+1, GTK_FILL, 0, 0, 0);
     row++;
 
     controls.k = gtk_adjustment_new(args->k, 0.01, 1000.0, 0.01, 10, 0);
     g_object_set_data(G_OBJECT(controls.k), "target", &args->k);
-    gwy_table_attach_hscale(table, row, _("_Spatial frequency:"), NULL,
+    gwy_table_attach_adjbar(table, row, _("_Spatial frequency:"), NULL,
                             GTK_OBJECT(controls.k), GWY_HSCALE_SQRT);
     g_signal_connect_swapped(controls.k, "value-changed",
                              G_CALLBACK(gwy_synth_double_changed), &controls);
@@ -480,30 +511,34 @@ wave_synth_dialog(WaveSynthArgs *args,
 
     gtk_table_set_row_spacing(GTK_TABLE(table), row-1, 8);
     gtk_table_attach(GTK_TABLE(table), gwy_label_new_header(_("Position")),
-                     0, 3, row, row+1, GTK_FILL, 0, 0, 0);
+                     0, 2, row, row+1, GTK_FILL, 0, 0, 0);
     row++;
 
     controls.x = gtk_adjustment_new(args->x, -1000.0, 1000.0, 0.01, 1, 0);
     g_object_set_data(G_OBJECT(controls.x), "target", &args->x);
-    gwy_table_attach_hscale(table, row, _("_X center:"), NULL,
-                            GTK_OBJECT(controls.x), GWY_HSCALE_DEFAULT);
+    gwy_table_attach_adjbar(table, row, _("_X center:"), NULL,
+                            GTK_OBJECT(controls.x), GWY_HSCALE_SQRT);
     g_signal_connect_swapped(controls.x, "value-changed",
                              G_CALLBACK(gwy_synth_double_changed), &controls);
     row++;
 
     row = gwy_synth_attach_variance(&controls, row,
                                     &controls.x_noise, &args->x_noise);
+    spin = gwy_table_hscale_get_middle_widget(controls.x_noise);
+    gtk_spin_button_set_digits(GTK_SPIN_BUTTON(spin), 4);
 
     controls.y = gtk_adjustment_new(args->y, -1000.0, 1000.0, 0.01, 1, 0);
     g_object_set_data(G_OBJECT(controls.y), "target", &args->y);
-    gwy_table_attach_hscale(table, row, _("_Y center:"), NULL,
-                            GTK_OBJECT(controls.y), GWY_HSCALE_DEFAULT);
+    gwy_table_attach_adjbar(table, row, _("_Y center:"), NULL,
+                            GTK_OBJECT(controls.y), GWY_HSCALE_SQRT);
     g_signal_connect_swapped(controls.y, "value-changed",
                              G_CALLBACK(gwy_synth_double_changed), &controls);
     row++;
 
     row = gwy_synth_attach_variance(&controls, row,
                                     &controls.y_noise, &args->y_noise);
+    spin = gwy_table_hscale_get_middle_widget(controls.y_noise);
+    gtk_spin_button_set_digits(GTK_SPIN_BUTTON(spin), 4);
 
     gtk_widget_show_all(dialog);
     controls.in_init = FALSE;
@@ -694,6 +729,7 @@ preview(WaveSynthControls *controls)
 {
     WaveSynthArgs *args = controls->args;
     GwyDataField *dfield;
+    gboolean ok;
 
     dfield = GWY_DATA_FIELD(gwy_container_get_object_by_name(controls->mydata,
                                                              "/0/data"));
@@ -702,7 +738,24 @@ preview(WaveSynthControls *controls)
     else
         gwy_data_field_clear(dfield);
 
-    wave_synth_do(args, controls->dims->args, dfield);
+    if (args->update) {
+        wave_synth_do(args, controls->dims->args, dfield, NULL, NULL);
+        gwy_data_field_data_changed(dfield);
+        return;
+    }
+
+    gwy_app_wait_start(GTK_WINDOW(controls->dialog), _("Initializing..."));
+    ok = wave_synth_do(args, controls->dims->args, dfield,
+                       gwy_app_wait_set_message, gwy_app_wait_set_fraction);
+    gwy_app_wait_finish();
+
+    if (!ok) {
+        if (controls->dims->args->add && controls->surface)
+            gwy_data_field_copy(controls->surface, dfield, FALSE);
+        else
+            gwy_data_field_clear(dfield);
+    }
+    gwy_data_field_data_changed(dfield);
 }
 
 static inline void
@@ -720,10 +773,12 @@ approx_wave_c(const gfloat *tab, gdouble x)
     return tab[xi];
 }
 
-static void
+static gboolean
 wave_synth_do(const WaveSynthArgs *args,
               const GwyDimensionArgs *dimsargs,
-              GwyDataField *dfield)
+              GwyDataField *dfield,
+              GwySetMessageFunc set_message,
+              GwySetFractionFunc set_fraction)
 {
     GwyRandGenSet *rngset;
     GwyWaveSource *sources;
@@ -732,6 +787,7 @@ wave_synth_do(const WaveSynthArgs *args,
     gdouble *d;
     const gfloat *tab;
     gdouble q;
+    gboolean ok = FALSE;
 
     sources = g_new(GwyWaveSource, args->nwaves);
     rngset = gwy_rand_gen_set_new(1);
@@ -739,7 +795,10 @@ wave_synth_do(const WaveSynthArgs *args,
     randomize_sources(rngset, sources, args, dimsargs, xres, yres);
     gwy_rand_gen_set_free(rngset);
 
-    d = dfield->data;
+    if (set_message && !set_message(_("Rendering surface...")))
+        goto finish;
+
+    d = gwy_data_field_get_data(dfield);
     tab = args->wave_table;
     if (args->quantity == WAVE_QUANTITY_DISPLACEMENT) {
         q = 2.0/sqrt(nwaves);
@@ -750,11 +809,14 @@ wave_synth_do(const WaveSynthArgs *args,
 
                 for (k = nwaves; k; k--, source++) {
                     gdouble x = j - source->x, y = i - source->y;
-                    gdouble r = sqrt(x*x + y*y);
-                    z += source->z * approx_wave_c(tab, source->k*r);
+                    gdouble kr = source->k * sqrt(x*x + y*y);
+                    gdouble dec = exp(-kr*source->decay);
+                    z += dec*source->z * approx_wave_c(tab, kr);
                 }
                 *(d++) += q*z;
             }
+            if (set_fraction && !set_fraction((i + 1.0)/yres))
+                goto finish;
         }
     }
     else if (args->quantity == WAVE_QUANTITY_AMPLITUDE) {
@@ -766,14 +828,17 @@ wave_synth_do(const WaveSynthArgs *args,
 
                 for (k = nwaves; k; k--, source++) {
                     gdouble x = j - source->x, y = i - source->y;
-                    gdouble r = sqrt(x*x + y*y);
+                    gdouble kr = source->k * sqrt(x*x + y*y);
+                    gdouble dec = exp(-kr*source->decay);
                     gfloat c, s;
-                    approx_wave_sc(tab, source->k*r, &s, &c);
-                    zs += source->z*s;
-                    zc += source->z*c;
+                    approx_wave_sc(tab, kr, &s, &c);
+                    zs += dec*source->z*s;
+                    zc += dec*source->z*c;
                 }
                 *(d++) += q*sqrt(zc*zc + zs*zs);
             }
+            if (set_fraction && !set_fraction((i + 1.0)/yres))
+                goto finish;
         }
     }
     else if (args->quantity == WAVE_QUANTITY_PHASE) {
@@ -785,24 +850,29 @@ wave_synth_do(const WaveSynthArgs *args,
 
                 for (k = nwaves; k; k--, source++) {
                     gdouble x = j - source->x, y = i - source->y;
-                    gdouble r = sqrt(x*x + y*y);
+                    gdouble kr = source->k * sqrt(x*x + y*y);
+                    gdouble dec = exp(-kr*source->decay);
                     gfloat c, s;
-                    approx_wave_sc(tab, source->k*r, &s, &c);
-                    zs += source->z*s;
-                    zc += source->z*c;
+                    approx_wave_sc(tab, kr, &s, &c);
+                    zs += dec*source->z*s;
+                    zc += dec*source->z*c;
                 }
                 *(d++) += q*atan2(zs, zc);
             }
+            if (set_fraction && !set_fraction((i + 1.0)/yres))
+                goto finish;
         }
     }
     else {
         g_assert_not_reached();
     }
 
+    ok = TRUE;
+
+finish:
     g_free(sources);
 
-    gwy_data_field_invalidate(dfield);
-    gwy_data_field_data_changed(dfield);
+    return ok;
 }
 
 static void
@@ -911,24 +981,31 @@ randomize_sources(GwyRandGenSet *rngset,
         sources[i].z = (args->amplitude * pow10(dimsargs->zpow10)
                         * exp(rng_gaussian(rngset, 0,
                                            4.0*args->amplitude_noise)));
+        /* Phase is already scaled so this is measured in wavelengths as it
+         * should. */
+        sources[i].decay = exp(G_LN10*(args->decay
+                                       + rng_gaussian(rngset, 0,
+                                              4.0*args->decay_noise)));
     }
 }
 
 static const gchar active_page_key[]     = "/module/wave_synth/active_page";
-static const gchar update_key[]          = "/module/wave_synth/update";
+static const gchar amplitude_key[]       = "/module/wave_synth/amplitude";
+static const gchar amplitude_noise_key[] = "/module/wave_synth/amplitude_noise";
+static const gchar decay_key[]           = "/module/wave_synth/decay";
+static const gchar decay_noise_key[]     = "/module/wave_synth/decay_noise";
+static const gchar k_key[]               = "/module/wave_synth/k";
+static const gchar k_noise_key[]         = "/module/wave_synth/k_noise";
+static const gchar nwaves_key[]          = "/module/wave_synth/nwaves";
+static const gchar quantity_key[]        = "/module/wave_synth/quantity";
 static const gchar randomize_key[]       = "/module/wave_synth/randomize";
 static const gchar seed_key[]            = "/module/wave_synth/seed";
 static const gchar type_key[]            = "/module/wave_synth/type";
-static const gchar quantity_key[]        = "/module/wave_synth/quantity";
-static const gchar nwaves_key[]          = "/module/wave_synth/nwaves";
+static const gchar update_key[]          = "/module/wave_synth/update";
 static const gchar x_key[]               = "/module/wave_synth/x";
 static const gchar x_noise_key[]         = "/module/wave_synth/x_noise";
 static const gchar y_key[]               = "/module/wave_synth/y";
 static const gchar y_noise_key[]         = "/module/wave_synth/y_noise";
-static const gchar amplitude_key[]       = "/module/wave_synth/amplitude";
-static const gchar amplitude_noise_key[] = "/module/wave_synth/amplitude_noise";
-static const gchar k_key[]               = "/module/wave_synth/k";
-static const gchar k_noise_key[]         = "/module/wave_synth/k_noise";
 
 static void
 wave_synth_sanitize_args(WaveSynthArgs *args)
@@ -949,6 +1026,8 @@ wave_synth_sanitize_args(WaveSynthArgs *args)
     args->amplitude_noise = CLAMP(args->amplitude_noise, 0.0, 1.0);
     args->k = CLAMP(args->k, 0.01, 1000.0);
     args->k_noise = CLAMP(args->k_noise, 0.0, 1.0);
+    args->decay = CLAMP(args->decay, -5.0, 0.0);
+    args->decay_noise = CLAMP(args->decay_noise, 0.0, 1.0);
 }
 
 static void
@@ -977,6 +1056,9 @@ wave_synth_load_args(GwyContainer *container,
                                      &args->amplitude_noise);
     gwy_container_gis_double_by_name(container, k_key, &args->k);
     gwy_container_gis_double_by_name(container, k_noise_key, &args->k_noise);
+    gwy_container_gis_double_by_name(container, decay_key, &args->decay);
+    gwy_container_gis_double_by_name(container, decay_noise_key,
+                                     &args->decay_noise);
     wave_synth_sanitize_args(args);
 
     args->wave_table = g_new(gfloat, 2*APPROX_WAVE_SIZE);
@@ -1012,6 +1094,9 @@ wave_synth_save_args(GwyContainer *container,
                                      args->amplitude_noise);
     gwy_container_set_double_by_name(container, k_key, args->k);
     gwy_container_set_double_by_name(container, k_noise_key, args->k_noise);
+    gwy_container_set_double_by_name(container, decay_key, args->decay);
+    gwy_container_set_double_by_name(container, decay_noise_key,
+                                     args->decay_noise);
 
     gwy_dimensions_save_args(dimsargs, container, prefix);
 }
