@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: wpour_mark.c 18537 2016-03-28 18:11:19Z yeti-dn $
+ *  @(#) $Id: wpour_mark.c 19948 2017-06-22 14:05:41Z yeti-dn $
  *  Copyright (C) 2014 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
@@ -188,12 +188,12 @@ static GwyModuleInfo module_info = {
     &module_register,
     N_("Segments image using watershed with pre- and postprocessing."),
     "Yeti <yeti@gwyddion.net>",
-    "1.0",
+    "1.1",
     "David Nečas (Yeti)",
     "2014",
 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, wpour_mark)
 
 static gboolean
 module_register(void)
@@ -302,7 +302,7 @@ wpour_dialog(WPourArgs *args,
     controls.mlayer = gwy_data_view_get_alpha_layer(GWY_DATA_VIEW(controls.view));
     gtk_box_pack_start(GTK_BOX(hbox), controls.view, FALSE, FALSE, 4);
 
-    table = gtk_table_new(10, 4, FALSE);
+    table = gtk_table_new(10, 3, FALSE);
     gtk_table_set_row_spacings(GTK_TABLE(table), 2);
     gtk_table_set_col_spacings(GTK_TABLE(table), 6);
     gtk_container_set_border_width(GTK_CONTAINER(table), 4);
@@ -310,14 +310,14 @@ wpour_dialog(WPourArgs *args,
     row = 0;
 
     gtk_table_attach(GTK_TABLE(table), gwy_label_new_header(_("Preprocessing")),
-                     0, 3, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
+                     0, 2, row, row+1, GTK_FILL, 0, 0, 0);
     row++;
 
     gtkobj = gtk_adjustment_new(args->blur_fwhm, 0.0, 20.0, 0.01, 0.1, 0);
     controls.blur_fwhm = GTK_ADJUSTMENT(gtkobj);
     g_object_set_data(G_OBJECT(gtkobj), "target", &args->blur_fwhm);
-    gwy_table_attach_hscale(table, row,
-                            _("Gaussian _smoothing:"), "px", gtkobj,
+    gwy_table_attach_adjbar(table, row,
+                            _("Gaussian _smoothing:"), _("px"), gtkobj,
                             GWY_HSCALE_SQRT);
     g_signal_connect_swapped(gtkobj, "value-changed",
                              G_CALLBACK(wpour_update_double), &controls);
@@ -346,27 +346,27 @@ wpour_dialog(WPourArgs *args,
     gtk_table_set_row_spacing(GTK_TABLE(table), row-1, 8);
 
     gtk_table_attach(GTK_TABLE(table), gwy_label_new_header(_("Postprocessing")),
-                     0, 3, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
+                     0, 2, row, row+1, GTK_FILL, 0, 0, 0);
     row++;
 
     gtk_table_set_row_spacing(GTK_TABLE(table), row-1, 8);
 
     gtk_table_attach(GTK_TABLE(table), gwy_label_new_header(_("Options")),
-                     0, 3, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
+                     0, 2, row, row+1, GTK_FILL, 0, 0, 0);
     row++;
 
     controls.inverted = gtk_check_button_new_with_mnemonic(_("_Invert height"));
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(controls.inverted),
                                  args->inverted);
     gtk_table_attach(GTK_TABLE(table), controls.inverted,
-                     0, 3, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
+                     0, 2, row, row+1, GTK_FILL, 0, 0, 0);
     g_signal_connect_swapped(controls.inverted, "toggled",
                              G_CALLBACK(inverted_changed), &controls);
     row++;
 
     controls.color_button = create_mask_color_button(controls.mydata, dialog,
                                                      0);
-    gwy_table_attach_hscale(table, row, _("_Mask color:"), NULL,
+    gwy_table_attach_adjbar(table, row, _("_Mask color:"), NULL,
                             GTK_OBJECT(controls.color_button),
                             GWY_HSCALE_WIDGET_NO_EXPAND);
     row++;
@@ -379,9 +379,9 @@ wpour_dialog(WPourArgs *args,
                                   _("Preprocessed image"),
                                   IMAGE_PREVIEW_PREPROC,
                                   NULL);
-    gwy_table_attach_hscale(table, row++, _("_Image preview:"), NULL,
+    gwy_table_attach_adjbar(table, row++, _("_Image preview:"), NULL,
                             GTK_OBJECT(controls.image_preview),
-                            GWY_HSCALE_WIDGET);
+                            GWY_HSCALE_WIDGET_NO_EXPAND);
 
     controls.mask_preview
         = gwy_enum_combo_box_newl(G_CALLBACK(mask_preview_changed), &controls,
@@ -393,9 +393,9 @@ wpour_dialog(WPourArgs *args,
                                   _("Postprocessed"),
                                   MASK_PREVIEW_POSTPROCESSED,
                                   NULL);
-    gwy_table_attach_hscale(table, row++, _("_Mask preview:"), NULL,
+    gwy_table_attach_adjbar(table, row++, _("_Mask preview:"), NULL,
                             GTK_OBJECT(controls.mask_preview),
-                            GWY_HSCALE_WIDGET);
+                            GWY_HSCALE_WIDGET_NO_EXPAND);
 
     controls.update
         = gwy_enum_combo_box_newl(G_CALLBACK(update_changed), &controls,
@@ -407,9 +407,9 @@ wpour_dialog(WPourArgs *args,
                                   _("Preprocess and mark"),
                                   UPDATE_MARK,
                                   NULL);
-    gwy_table_attach_hscale(table, row++, _("Instant:"), NULL,
+    gwy_table_attach_adjbar(table, row++, _("Instant:"), NULL,
                             GTK_OBJECT(controls.update),
-                            GWY_HSCALE_WIDGET);
+                            GWY_HSCALE_WIDGET_NO_EXPAND);
     row++;
 
     controls.in_init = FALSE;
@@ -538,7 +538,7 @@ table_attach_threshold(GtkWidget *table, gint *row, const gchar *name,
 
     adj = gtk_adjustment_new(*value, 0.0, 100.0, 0.01, 1.0, 0);
     g_object_set_data(G_OBJECT(adj), "target", value);
-    gwy_table_attach_hscale(table, *row, name, "%", adj, GWY_HSCALE_DEFAULT);
+    gwy_table_attach_adjbar(table, *row, name, "%", adj, GWY_HSCALE_DEFAULT);
     g_signal_connect_swapped(adj, "value-changed",
                              G_CALLBACK(wpour_update_double), controls);
     (*row)++;
