@@ -30,6 +30,7 @@
 #include <libgwymodule/gwymodule-process.h>
 #include <libgwydgets/gwydgetutils.h>
 #include <libgwydgets/gwycombobox.h>
+#include <libgwydgets/gwystock.h>
 #include <app/gwymoduleutils.h>
 #include <app/gwyapp.h>
 
@@ -61,7 +62,7 @@ static GwyModuleInfo module_info = {
     "2012",
 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, xydenoise)
 
 static gboolean
 module_register(void)
@@ -69,7 +70,7 @@ module_register(void)
     gwy_process_func_register("xydenoise",
                               (GwyProcessFunc)&xydenoise,
                               N_("/M_ultidata/_XY denoise..."),
-                              NULL,
+                              GWY_STOCK_XY_DENOISE,
                               XYDENOISE_RUN_MODES,
                               GWY_MENU_FLAG_DATA,
                               N_("Denoises horizontal/vertical measurement."));
@@ -106,7 +107,7 @@ xydenoise_dialog(XYdenoiseArgs *args)
     gtk_dialog_set_default_response(GTK_DIALOG(dialog), GTK_RESPONSE_OK);
     gwy_help_add_to_proc_dialog(GTK_DIALOG(dialog), GWY_HELP_DEFAULT);
 
-    table = gtk_table_new(9, 4, FALSE);
+    table = gtk_table_new(1, 3, FALSE);
     gtk_table_set_row_spacings(GTK_TABLE(table), 2);
     gtk_table_set_col_spacings(GTK_TABLE(table), 6);
     gtk_container_set_border_width(GTK_CONTAINER(table), 4);
@@ -121,8 +122,8 @@ xydenoise_dialog(XYdenoiseArgs *args)
     g_signal_connect(chooser, "changed",
                      G_CALLBACK(xydenoise_data_cb), &args->op2);
     xydenoise_data_cb(GWY_DATA_CHOOSER(chooser), &args->op2);
-    gwy_table_attach_hscale(table, row, _("Second direction:"), NULL,
-                            GTK_OBJECT(chooser), GWY_HSCALE_WIDGET);
+    gwy_table_attach_adjbar(table, row, _("Second direction:"), NULL,
+                            GTK_OBJECT(chooser), GWY_HSCALE_WIDGET_NO_EXPAND);
     gtk_table_set_row_spacing(GTK_TABLE(table), row, 8);
     row++;
 
