@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: xyzize.c 18951 2016-09-12 08:35:17Z yeti-dn $
+ *  @(#) $Id: xyzize.c 19948 2017-06-22 14:05:41Z yeti-dn $
  *  Copyright (C) 2016 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
@@ -45,7 +45,7 @@ static GwyModuleInfo module_info = {
     "2016",
 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, xyzize)
 
 static gboolean
 module_register(void)
