@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: gwy.c 19289 2016-11-18 10:30:23Z yeti-dn $
+ *  @(#) $Id: gwy.c 19573 2017-04-04 09:40:08Z yeti-dn $
  *  Copyright (C) 2012-2016 David Necas (Yeti), Petr Klapetek, Jozef Vesely.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net, vesely@gjh.sk.
  *
@@ -20,7 +20,7 @@
  */
 
 #include "config.h"
-#include <pygtk-2.0/pygobject.h>
+#include <pygobject.h>
 #include <app/gwyapp.h>
 #include "wrap_calls.h"
 #include "pygwy.h"
@@ -72,7 +72,8 @@ load_modules(void)
 }
 
 /* FIXME: It would be better to just fix the flags using RTLD_NOLOAD because
- * the libraries are surely loaded. */
+ * the libraries are surely loaded.  But that is not possible using the
+ * GModule API.  */
 static gboolean
 reload_libraries(void)
 {
@@ -83,12 +84,20 @@ reload_libraries(void)
         "libgwyddion2", "libgwyprocess2", "libgwydraw2", "libgwydgets2",
         "libgwymodule2", "libgwyapp2",
     };
+#ifdef __APPLE__
+    /* Darwin has soname_spec='$libname$release$major$shared_ext' */
+    static const gchar *soname_format = "%s.0.%s";
+#else
+    /* ELF systems generally have
+     * soname_spec='$libname$release$shared_ext$major' */
+    static const gchar *soname_format = "%s.%s.0";
+#endif
     guint i;
 
     for (i = 0; i < G_N_ELEMENTS(gwyddion_libs); i++) {
-        gchar *filename = g_strconcat(gwyddion_libs[i],
-                                      ".", GWY_SHARED_LIBRARY_EXTENSION, ".0",
-                                      NULL);
+        gchar *filename = g_strdup_printf(soname_format,
+                                          gwyddion_libs[i],
+                                          GWY_SHARED_LIBRARY_EXTENSION);
         GModule *modhandle = g_module_open(filename, G_MODULE_BIND_LAZY);
         if (!modhandle) {
             gchar *excstr = g_strdup_printf("Cannot dlopen() %s.", filename);
