@@ -1,6 +1,6 @@
 /*
- *  @(#) $Id: pygwy.c 19265 2016-11-15 12:22:37Z yeti-dn $
- *  Copyright (C) 2004-2016 David Necas (Yeti), Petr Klapetek.
+ *  @(#) $Id: pygwy.c 20181 2017-08-07 09:26:23Z yeti-dn $
+ *  Copyright (C) 2004-2017 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -28,11 +28,12 @@
 #include "config.h"
 
 /* include this first, before NO_IMPORT_PYGOBJECT is defined */
-#include <pygtk-2.0/pygobject.h>
-#include <app/gwyapp.h>
+#include <pygobject.h>
 #include "wrap_calls.h"
 #include <stdarg.h>
 #include <glib/gstdio.h>
+#include <Python.h>
+
 #include "pygwy.h"
 
 #include "pygwywrap.c"
@@ -63,6 +64,15 @@ typedef struct {
     PyObject *code;
     time_t m_time;
     PygwyModuleType type;
+
+    /* Used only during registration and may become dangling pointers
+     * afterwards. */
+    const gchar *desc;
+    const gchar *menu_path;
+    const gchar *icon;
+    GwyMenuSensFlags sens;
+    GwyRunType run;
+
     /* Used dynamically during execution */
     PyObject *module;
     PyObject *dict;
@@ -89,6 +99,7 @@ static gint             pygwy_file_detect_run         (const GwyFileDetectInfo *
                                                        gboolean only_name,
                                                        const gchar *name);
 static void             pygwy_register_modules        (void);
+static gchar**          find_module_candidates        (gchar **module_dir_name);
 static void             free_module_info              (PygwyModuleInfo *info);
 static gboolean         update_module_code            (PygwyModuleInfo *info);
 static PygwyModuleInfo* pygwy_find_module             (const gchar* name);
@@ -119,7 +130,7 @@ static GwyModuleInfo module_info = {
     &module_register,
     N_("Pygwy, the Gwyddion Python wrapper."),
     "Jan Hořák <xhorak@gmail.com>, Yeti <yeti@gwyddion.net>",
-    "2.0",
+    "2.3",
     "Jan Hořák & David Nečas (Yeti)",
     "2007"
 };
@@ -172,6 +183,7 @@ check_pygtk_availability(void)
         return FALSE;
     }
 
+    gwy_debug("python path %s", pythondir);
     filename = g_build_filename(pythondir, "Lib", "site-packages", "gtk-2.0",
                                 "gobject", "__init__.py", NULL);
     if (!g_file_test(filename, G_FILE_TEST_IS_REGULAR)) {
@@ -236,7 +248,7 @@ pygwy_initialize(void)
         init_pygobject();
 
         gwy_debug("Init module gwy");
-        m = Py_InitModule("gwy", (PyMethodDef*) pygwy_functions);
+        m = Py_InitModule("gwy", (PyMethodDef*)pygwy_functions);
         gwy_debug("Get dict");
         pygwy_dict = PyModule_GetDict(m);
 
@@ -302,16 +314,20 @@ pygwy_finalize_stderr_redirect(PyObject *d)
 }
 
 static void
-pygwy_add_sys_path(PyObject *dir, gchar *path)
+pygwy_add_sys_path(PyObject *dir, const gchar *path)
 {
-    gchar *sys_path_append;
+    static const gchar sys_path_append_template[] =
+        "import sys\n"
+        "if '%s' not in sys.path:\n"
+        "    sys.path.append('%s')\n"
+        "\n";
 
     if (g_file_test(path, G_FILE_TEST_IS_DIR)) {
-        sys_path_append = g_strdup_printf("import sys\n"
-                                          "sys.path.append('%s')\n",
-                                          path);
-        pygwy_run_string(sys_path_append, Py_file_input, dir, dir);
-        g_free(sys_path_append);
+        gchar *p = gwy_strreplace(path, "'", "\\'", (gsize)-1);
+        gchar *command = g_strdup_printf(sys_path_append_template, p, p);
+        g_free(p);
+        pygwy_run_string(command, Py_file_input, dir, dir);
+        g_free(command);
     }
     else {
         g_warning("Cannot add non-existent path '%s'.", path);
@@ -385,31 +401,49 @@ err_PYTHON(GError **error)
 }
 
 static const gchar*
-pygwy_read_val_from_dict(PyObject *dict, char *v, const gchar *f)
+pygwy_read_str_from_dict(PyObject *dict, char *v, const gchar *filename,
+                         gboolean required)
 {
-    const char *ret;
     PyObject *py_str;
+    const char *ret;
 
     if ((py_str = PyDict_GetItemString(dict, v))) {
         if (PyArg_Parse(py_str, "s", &ret)) {
-            gwy_debug("Read value '%s' from '%s': %s", v, f, ret);
+            gwy_debug("Read value '%s' from '%s': %s", v, filename, ret);
             return ret;
         }
     }
-    g_warning("Value '%s' not found in '%s'.", v, f);
+    if (required) {
+        g_warning("Value '%s' not found in '%s'.", v, filename);
+    }
     return NULL;
 }
 
+static gboolean
+pygwy_read_flags_from_dict(PyObject *dict, char *v, const gchar *filename,
+                           guint *ret)
+{
+    PyObject *py_flags;
+
+    if ((py_flags = PyDict_GetItemString(dict, v))) {
+        if (PyArg_Parse(py_flags, "I", ret)) {
+            gwy_debug("Read value '%s' from '%s': %u", v, filename, *ret);
+            return TRUE;
+        }
+    }
+    return FALSE;
+}
+
 /* Contract: It must either return NULL or PygwyModuleInfo that is correct
  * for given module type with all required fields filled. */
 static PygwyModuleInfo*
-pygwy_get_module_info(const gchar *fullpath, const gchar *filename,
-                      const gchar **desc, const gchar **menu_path)
+pygwy_get_module_info(const gchar *fullpath, const gchar *filename)
 {
     PygwyModuleInfo *info = NULL;
     gchar *suffix;
     const gchar *type_str;
     PyObject *module = NULL, *d, *module_dict;
+    gboolean type_is_dataprocess;
 
     info = g_new0(PygwyModuleInfo, 1);
     info->fullpath = g_strdup(fullpath);
@@ -436,7 +470,8 @@ pygwy_get_module_info(const gchar *fullpath, const gchar *filename,
 
     /* Get parameters from dict */
     module_dict = PyModule_GetDict(module);
-    type_str = pygwy_read_val_from_dict(module_dict, "plugin_type", fullpath);
+    type_str = pygwy_read_str_from_dict(module_dict, "plugin_type", fullpath,
+                                        TRUE);
     gwy_debug("read values: %s %p", type_str, type_str);
     if (!type_str) {
         g_warning("Undefined module type, cannot load.");
@@ -448,27 +483,62 @@ pygwy_get_module_info(const gchar *fullpath, const gchar *filename,
         g_warning("Unrecognised module type %s, cannot load.", type_str);
         goto fail;
     }
+    type_is_dataprocess = (info->type == PYGWY_PROCESS
+                           || info->type == PYGWY_GRAPH
+                           || info->type == PYGWY_VOLUME
+                           || info->type == PYGWY_XYZ);
 
     /* plugin_desc is required for file modules (as the file type) */
-    *desc = pygwy_read_val_from_dict(module_dict, "plugin_desc", fullpath);
-    if (info->type == PYGWY_FILE && !*desc) {
+    info->desc = pygwy_read_str_from_dict(module_dict, "plugin_desc", fullpath,
+                                          TRUE);
+    if (info->type == PYGWY_FILE && !info->desc) {
         info->type = PYGWY_UNDEFINED;
         goto fail;
     }
-    else if (!*desc)
-        *desc = N_("Function written in Python");  /* Not very descriptive. */
+    else if (!info->desc) {
+        /* Not very descriptive... */
+        info->desc = N_("Function written in Python");
+    }
+    gwy_debug("desc: %s", info->desc);
 
-    /* menu path is required for all something-processing  modules */
-    if (info->type == PYGWY_PROCESS || info->type == PYGWY_GRAPH
-        || info->type == PYGWY_VOLUME || info->type == PYGWY_XYZ) {
-        *menu_path = pygwy_read_val_from_dict(module_dict, "plugin_menu",
-                                              fullpath);
-        if (!*menu_path) {
+    /* menu path is required for all something-processing modules */
+    if (type_is_dataprocess) {
+        info->menu_path = pygwy_read_str_from_dict(module_dict, "plugin_menu",
+                                                   fullpath, TRUE);
+        if (!info->menu_path) {
             info->type = PYGWY_UNDEFINED;
             goto fail;
         }
+        gwy_debug("menu_path: %s", info->menu_path);
+    }
+
+    /* icon is optional for something-processing modules */
+    if (type_is_dataprocess) {
+        info->icon = pygwy_read_str_from_dict(module_dict, "plugin_icon",
+                                              fullpath, FALSE);
+        gwy_debug("icon: %s", info->icon);
+    }
+
+    /* run mode and sensitivity are optional for something-processing modules */
+    if (type_is_dataprocess) {
+        if (info->type == PYGWY_PROCESS)
+            info->sens = GWY_MENU_FLAG_DATA;
+        else if (info->type == PYGWY_GRAPH)
+            info->sens = GWY_MENU_FLAG_GRAPH;
+        else if (info->type == PYGWY_VOLUME)
+            info->sens = GWY_MENU_FLAG_VOLUME;
+        else if (info->type == PYGWY_XYZ)
+            info->sens = GWY_MENU_FLAG_XYZ;
+
+        pygwy_read_flags_from_dict(module_dict, "plugin_sens", fullpath,
+                                   &info->sens);
+        gwy_debug("sens: 0x%04x", info->sens);
+
+        info->run = (GWY_RUN_INTERACTIVE | GWY_RUN_IMMEDIATE);
+        pygwy_read_flags_from_dict(module_dict, "plugin_run", fullpath,
+                                   &info->run);
+        gwy_debug("run: 0x%04x", info->run);
     }
-    gwy_debug("read values: %s %s", *desc, *menu_path);
 
 fail:
     if (info->type == PYGWY_UNDEFINED) {
@@ -497,57 +567,28 @@ free_module_info(PygwyModuleInfo *info)
 static void
 pygwy_register_modules(void)
 {
-    GDir *module_dir;
     gchar *fullpath, *module_dir_name;
-    const gchar *desc, *menu_path, *filename;
     PygwyModuleInfo *info;
-    GError *err = NULL;
     gboolean ok;
+    gchar **candidates;
+    guint i;
 
-    module_dir_name = g_build_filename(gwy_get_user_dir(),
-                                       pygwy_module_dir_name,
-                                       NULL);
-    gwy_debug("Module path: %s", module_dir_name);
-
-    module_dir = g_dir_open(module_dir_name, 0, &err);
-    if (module_dir == NULL && err) {
-        if (err->code == G_FILE_ERROR_NOENT) {
-            /* directory not found/does not exist */
-            if (g_mkdir(module_dir_name, 0700)) {
-                g_warning("Cannot create pygwy module directory %s",
-                          module_dir_name);
-            }
-            else {
-                gwy_debug("Pygwy directory created: %s", module_dir_name);
-            }
-        }
-        else {
-            g_warning("Cannot open pygwy directory: %s, reason: %s",
-                      module_dir_name, err->message);
-        }
+    candidates = find_module_candidates(&module_dir_name);
+    if (!candidates) {
         g_free(module_dir_name);
-        /* Whether the directory has been created or not, there is no reason
-           to continue by reading scripts as long as no script is available */
         return;
     }
 
-    /* Initialize python iterpret and init gwy module */
+    /* Initialize the python interpret and init gwy module.  Only do it here
+     * if we find any potential python modules.  Otherwise postpone the cost
+     * to pygwy console invocation, if if ever comes. */
     pygwy_initialize();
-    while ((filename = g_dir_read_name(module_dir))) {
-        if (!g_str_has_suffix(filename, ".py")
-            && !g_str_has_suffix(filename, ".PY")
-            && !g_str_has_suffix(filename, ".Py")) {
-            gwy_debug("Skipping file with wrong extension: %s", filename);
-            continue;
-        }
-
+    for (i = 0; candidates[i]; i++) {
         /* Read content of module file */
-        fullpath = g_build_filename(module_dir_name, filename, NULL);
+        fullpath = g_build_filename(module_dir_name, candidates[i], NULL);
 
         /* get module's metadata */
-        desc = NULL;
-        menu_path = NULL;
-        info = pygwy_get_module_info(fullpath, filename, &desc, &menu_path);
+        info = pygwy_get_module_info(fullpath, candidates[i]);
         g_free(fullpath);
         if (!info)
             continue;
@@ -556,15 +597,12 @@ pygwy_register_modules(void)
         if (info->type == PYGWY_PROCESS) {
             gwy_debug("Registering proc func.");
             ok = gwy_process_func_register(info->name, pygwy_procvolxyz_run,
-                                           menu_path,
-                                           NULL,
-                                           GWY_RUN_INTERACTIVE | GWY_RUN_IMMEDIATE,
-                                           GWY_MENU_FLAG_DATA, desc);
+                                           info->menu_path, info->icon,
+                                           info->run, info->sens, info->desc);
         }
         else if (info->type == PYGWY_FILE) {
             gwy_debug("Registering file func.");
-            ok = gwy_file_func_register(info->name,
-                                        desc,
+            ok = gwy_file_func_register(info->name, info->desc,
                                         pygwy_file_detect_run,
                                         pygwy_file_load_run,
                                         NULL,
@@ -572,32 +610,22 @@ pygwy_register_modules(void)
         }
         else if (info->type == PYGWY_GRAPH) {
             gwy_debug("Registering graph func.");
-            ok = gwy_graph_func_register(info->name,
-                                         pygwy_graph_run,
-                                         menu_path,
-                                         GWY_STOCK_GRAPH_FUNCTION,
-                                         GWY_MENU_FLAG_GRAPH,
-                                         desc);
+            ok = gwy_graph_func_register(info->name, pygwy_graph_run,
+                                         info->menu_path, info->icon,
+                                         info->sens, info->desc);
         }
         else if (info->type == PYGWY_VOLUME) {
             gwy_debug("Registering volume func.");
-            ok = gwy_volume_func_register(info->name,
-                                          pygwy_procvolxyz_run,
-                                          menu_path,
-                                          NULL,
-                                          GWY_RUN_IMMEDIATE,
-                                          GWY_MENU_FLAG_VOLUME,
-                                          desc);
+            ok = gwy_volume_func_register(info->name, pygwy_procvolxyz_run,
+                                          info->menu_path, info->icon,
+                                          info->run, info->sens, info->desc);
         }
         else if (info->type == PYGWY_XYZ) {
             gwy_debug("Registering xyz func.");
             ok = gwy_volume_func_register(info->name,
                                           pygwy_procvolxyz_run,
-                                          menu_path,
-                                          NULL,
-                                          GWY_RUN_IMMEDIATE,
-                                          GWY_MENU_FLAG_XYZ,
-                                          desc);
+                                          info->menu_path, info->icon,
+                                          info->run, info->sens, info->desc);
         }
         else {
             g_assert_not_reached();
@@ -608,8 +636,65 @@ pygwy_register_modules(void)
         else
             free_module_info(info);
     }
-    g_dir_close(module_dir);
     g_free(module_dir_name);
+    g_strfreev(candidates);
+}
+
+static gchar**
+find_module_candidates(gchar **module_dir_name)
+{
+    GDir *module_dir;
+    const gchar *filename, *dot;
+    GPtrArray *candidates = NULL;
+    GError *err = NULL;
+
+    *module_dir_name = g_build_filename(gwy_get_user_dir(),
+                                        pygwy_module_dir_name,
+                                        NULL);
+    gwy_debug("Module path: %s", *module_dir_name);
+
+    module_dir = g_dir_open(*module_dir_name, 0, &err);
+    if (module_dir == NULL && err) {
+        if (err->code == G_FILE_ERROR_NOENT) {
+            /* directory not found/does not exist */
+            if (g_mkdir(*module_dir_name, 0700)) {
+                g_warning("Cannot create pygwy module directory %s",
+                          *module_dir_name);
+            }
+            else {
+                gwy_debug("Pygwy directory created: %s", *module_dir_name);
+            }
+        }
+        else {
+            g_warning("Cannot open pygwy directory: %s, reason: %s",
+                      *module_dir_name, err->message);
+        }
+        /* Whether the directory has been created or not, there is no reason
+           to continue by reading scripts as long as no script is available */
+        return NULL;
+    }
+
+    while ((filename = g_dir_read_name(module_dir))) {
+        if (!(dot = strrchr(filename, '.'))) {
+            gwy_debug("Skipping file with no extension: %s", filename);
+            continue;
+        }
+        if (g_ascii_strcasecmp(dot+1, "py") != 0) {
+            gwy_debug("Skipping file with wrong extension: %s", filename);
+            continue;
+        }
+
+        if (!candidates)
+            candidates = g_ptr_array_new();
+        g_ptr_array_add(candidates, g_strdup(filename));
+    }
+    g_dir_close(module_dir);
+
+    if (!candidates)
+        return NULL;
+
+    g_ptr_array_add(candidates, NULL);
+    return (gchar**)g_ptr_array_free(candidates, FALSE);
 }
 
 /* (Re)load module code.  The function succeeds if, after finishing, we have
