@@ -1,5 +1,5 @@
 /*
- *  $Id: wrap_calls.c 19279 2016-11-16 16:52:15Z yeti-dn $
+ *  $Id: wrap_calls.c 20180 2017-08-07 09:18:25Z yeti-dn $
  *  Copyright (C) 2008 Jan Horak, 2015-2016 David Necas (Yeti)
  *  E-mail: xhorak@gmail.com, yeti@gwyddion.net.
  *
@@ -47,6 +47,42 @@ create_int_array(const gint *data, guint len, gboolean free_data)
    return ret;
 }
 
+static void
+free_string_array(GwyStringArray *array)
+{
+    gsize i, n = array->len;
+    gchar *s;
+
+    for (i = 0; i < n; i++) {
+        s = g_array_index(array, gchar*, i);
+        if (!s)
+            break;
+        g_free(s);
+    }
+    g_array_free(array, TRUE);
+}
+
+static GwyStringArray*
+create_string_array(const gchar **data, guint len, gboolean free_data)
+{
+   GArray *ret = g_array_new(FALSE, FALSE, sizeof(gchar*));
+   g_array_append_vals(ret, data, len);
+   if (free_data)
+      g_free((gpointer)data);
+   return ret;
+}
+
+static GwyConstStringArray*
+create_const_string_array(const gchar *const *data, guint len,
+                          gboolean free_data)
+{
+   GArray *ret = g_array_new(FALSE, FALSE, sizeof(gchar*));
+   g_array_append_vals(ret, data, len);
+   if (free_data)
+      g_free((gpointer)data);
+   return ret;
+}
+
 gdouble
 gwy_math_median_pygwy(GwyDoubleArray *array)
 {
@@ -71,8 +107,8 @@ gwy_math_curvature_pygwy(GwyDoubleArray *coeffs, gint *dimen,
 }
 
 GwyArrayFuncStatus
-gwy_math_refine_maximum_pygwy (GwyDoubleArray *z,
-                               gdouble *x, gdouble *y, gboolean *refined)
+gwy_math_refine_maximum_pygwy(GwyDoubleArray *z,
+                              gdouble *x, gdouble *y, gboolean *refined)
 {
     gboolean ok = (z->len == 9);
     if (ok)
@@ -81,6 +117,28 @@ gwy_math_refine_maximum_pygwy (GwyDoubleArray *z,
     return ok;
 }
 
+GwyArrayFuncStatus
+gwy_math_refine_maximum_2d_pygwy(GwyDoubleArray *z,
+                                 gdouble *x, gdouble *y, gboolean *refined)
+{
+    gboolean ok = (z->len == 9);
+    if (ok)
+        *refined = gwy_math_refine_maximum_2d((gdouble*)z->data, x, y);
+    g_array_free(z, TRUE);
+    return ok;
+}
+
+GwyArrayFuncStatus
+gwy_math_refine_maximum_1d_pygwy(GwyDoubleArray *y,
+                                 gdouble *x, gboolean *refined)
+{
+    gboolean ok = (y->len == 3);
+    if (ok)
+        *refined = gwy_math_refine_maximum_1d((gdouble*)y->data, x);
+    g_array_free(y, TRUE);
+    return ok;
+}
+
 GwyArrayFuncStatus
 gwy_math_is_in_polygon_pygwy(gdouble x, gdouble y, GwyDoubleArray *poly,
                              gboolean *is_inside)
@@ -155,6 +213,131 @@ gwy_fft_window_pygwy(GwyDoubleArray *data, GwyWindowingType windowing)
     return data;
 }
 
+GwyDoubleArray*
+gwy_interpolation_resolve_coeffs_1d_pygwy(GwyDoubleArray *data,
+                                          GwyInterpolationType interpolation)
+{
+    gwy_interpolation_resolve_coeffs_1d(data->len, (gdouble*)data->data,
+                                        interpolation);
+    /* This is the same as freeing data and returning a new array. */
+    return data;
+}
+
+GwyDoubleArray*
+gwy_interpolation_resolve_coeffs_2d_pygwy(gint width,
+                                          gint height,
+                                          gint rowstride,
+                                          GwyDoubleArray *data,
+                                          GwyInterpolationType interpolation)
+{
+    g_return_val_if_fail(data->len == height*rowstride, data);
+    g_return_val_if_fail(width <= rowstride, data);
+    gwy_interpolation_resolve_coeffs_2d(width, height, rowstride,
+                                        (gdouble*)data->data,
+                                        interpolation);
+    /* This is the same as freeing data and returning a new array. */
+    return data;
+}
+
+GwyArrayFuncStatus
+gwy_interpolation_get_dval_of_equidists_pygwy(gdouble x,
+                                              GwyDoubleArray *data,
+                                              GwyInterpolationType interpolation,
+                                              gdouble *result)
+{
+    guint suplen = gwy_interpolation_get_support_size(interpolation);
+    gboolean ok = (data->len == suplen || suplen == 0);
+    if (ok) {
+        *result = gwy_interpolation_get_dval_of_equidists(x, (gdouble*)data->data,
+                                                          interpolation);
+    }
+    g_array_free(data, TRUE);
+    return ok;
+}
+
+GwyArrayFuncStatus
+gwy_interpolation_interpolate_1d_pygwy(gdouble x,
+                                       GwyDoubleArray *coeff,
+                                       GwyInterpolationType interpolation,
+                                       gdouble *result)
+{
+    guint suplen = gwy_interpolation_get_support_size(interpolation);
+    gboolean ok = (coeff->len == suplen || suplen == 0);
+    if (ok) {
+        *result = gwy_interpolation_interpolate_1d(x, (gdouble*)coeff->data,
+                                                   interpolation);
+    }
+    g_array_free(coeff, TRUE);
+    return ok;
+}
+
+GwyArrayFuncStatus
+gwy_interpolation_interpolate_2d_pygwy(gdouble x, gdouble y,
+                                       gint rowstride,
+                                       GwyDoubleArray *coeff,
+                                       GwyInterpolationType interpolation,
+                                       gdouble *result)
+{
+    guint suplen = gwy_interpolation_get_support_size(interpolation);
+    gboolean ok = (coeff->len == suplen*rowstride || suplen == 0);
+    if (ok) {
+        *result = gwy_interpolation_interpolate_2d(x, y, rowstride,
+                                                   (gdouble*)coeff->data,
+                                                   interpolation);
+    }
+    g_array_free(coeff, TRUE);
+    return ok;
+}
+
+GwyDoubleArray*
+gwy_interpolation_resample_block_1d_pygwy(GwyDoubleArray *data,
+                                          gint newlength,
+                                          GwyInterpolationType interpolation)
+{
+    GwyDoubleArray *ret = g_array_new(FALSE, FALSE, sizeof(gdouble));
+    g_array_set_size(ret, newlength);
+    gwy_interpolation_resample_block_1d(data->len, (gdouble*)data->data,
+                                        newlength, (gdouble*)ret->data,
+                                        interpolation, FALSE);
+    return ret;
+}
+
+GwyDoubleArray*
+gwy_interpolation_resample_block_2d_pygwy(GwyDoubleArray *data,
+                                          gint width,
+                                          gint height,
+                                          gint rowstride,
+                                          gint newwidth,
+                                          gint newheight,
+                                          gint newrowstride,
+                                          GwyInterpolationType interpolation)
+{
+    GwyDoubleArray *ret = g_array_new(FALSE, TRUE, sizeof(gdouble));
+    g_array_set_size(ret, newrowstride*newheight);
+    g_return_val_if_fail(data->len == height*rowstride, ret);
+    gwy_interpolation_resample_block_2d(width, height, rowstride,
+                                        (gdouble*)data->data,
+                                        newwidth, newheight, newrowstride,
+                                        (gdouble*)ret->data,
+                                        interpolation, FALSE);
+    return ret;
+}
+
+GwyDoubleArray*
+gwy_interpolation_shift_block_1d_pygwy(GwyDoubleArray *data,
+                                       gdouble offset,
+                                       GwyInterpolationType interpolation,
+                                       GwyExteriorType exterior,
+                                       gdouble fill_value)
+{
+    GwyDoubleArray *ret = g_array_new(FALSE, FALSE, sizeof(gdouble));
+    gwy_interpolation_shift_block_1d(data->len, (gdouble*)data->data,
+                                     offset, (gdouble*)ret->data,
+                                     interpolation, exterior, fill_value,
+                                     FALSE);
+    return ret;
+}
+
 /**
  * gwy_selection_get_data_pygwy:
  * @selection: A selection.
@@ -702,6 +885,36 @@ gwy_data_field_circular_area_unextract_pygwy(GwyDataField *data_field,
     return ok;
 }
 
+GwyDoubleArray*
+gwy_data_field_circular_area_extract_with_pos_pygwy(GwyDataField *data_field,
+                                                    gint col, gint row,
+                                                    gdouble radius,
+                                                    GwyIntArrayOutArg xpos,
+                                                    GwyIntArrayOutArg ypos)
+{
+    GwyDoubleArray *array = g_array_new(FALSE, FALSE, sizeof(gdouble));
+    guint size = gwy_data_field_get_circular_area_size(radius);
+    g_array_set_size(array, size);
+    g_array_set_size(xpos, size);
+    g_array_set_size(ypos, size);
+    gwy_data_field_circular_area_extract_with_pos(data_field, col, row, radius,
+                                                  (gdouble*)array->data,
+                                                  (gint*)xpos->data,
+                                                  (gint*)ypos->data);
+    return array;
+}
+
+gboolean
+gwy_data_field_local_maximum_pygwy(GwyDataField *dfield,
+                                   gdouble x, gdouble y,
+                                   gint ax, gint ay,
+                                   gdouble *x_out, gdouble *y_out)
+{
+    *x_out = x;
+    *y_out = y;
+    return gwy_data_field_local_maximum(dfield, x_out, y_out, ax, ay);
+}
+
 GwyArrayFuncStatus
 gwy_data_field_affine_pygwy(GwyDataField *data_field,
                             GwyDataField *dest,
@@ -719,6 +932,90 @@ gwy_data_field_affine_pygwy(GwyDataField *data_field,
     return ok;
 }
 
+GwyArrayFuncStatus
+gwy_data_field_affine_prepare_pygwy(GwyDataField *source,
+                                    GwyDataField *dest,
+                                    GwyDoubleArray *a1a2,
+                                    GwyDoubleArray *a1a2_corr,
+                                    GwyAffineScalingType scaling,
+                                    gboolean prevent_rotation,
+                                    gdouble oversampling,
+                                    GwyDoubleArrayOutArg a1a2_corr_out,
+                                    GwyDoubleArrayOutArg invtrans)
+{
+    gboolean ok = (a1a2->len == 4 && a1a2_corr->len == 4);
+    g_array_set_size(a1a2_corr_out, 4);
+    g_array_set_size(invtrans, 6);
+    gwy_clear((gdouble*)invtrans->data, 6);
+    if (ok) {
+        gwy_assign((gdouble*)a1a2_corr_out->data, (gdouble*)a1a2_corr->data, 4);
+        gwy_data_field_affine_prepare(source, dest,
+                                      (const gdouble*)a1a2->data,
+                                      (gdouble*)a1a2_corr_out->data,
+                                      (gdouble*)invtrans->data,
+                                      scaling, prevent_rotation, oversampling);
+    }
+    else {
+        gwy_clear((gdouble*)a1a2_corr_out->data, 4);
+    }
+    g_array_free(a1a2, TRUE);
+    g_array_free(a1a2_corr, TRUE);
+    return ok;
+}
+
+GwyArrayFuncStatus
+gwy_data_field_measure_lattice_acf_pygwy(GwyDataField *acf2d,
+                                         GwyDoubleArray *a1a2,
+                                         GwyDoubleArrayOutArg a1a2_out,
+                                         gboolean *succeeded)
+{
+    gboolean ok = (a1a2->len == 4);
+    g_array_set_size(a1a2_out, 4);
+    gwy_clear((gdouble*)a1a2_out->data, 4);
+    *succeeded = FALSE;
+    if (ok) {
+        gwy_assign((gdouble*)a1a2_out->data, (gdouble*)a1a2->data, 4);
+        *succeeded = gwy_data_field_measure_lattice_acf(acf2d,
+                                                        (gdouble*)a1a2_out->data);
+    }
+    if (!*succeeded || !ok)
+        gwy_clear((gdouble*)a1a2_out->data, 4);
+    g_array_free(a1a2, TRUE);
+    return ok;
+}
+
+GwyArrayFuncStatus
+gwy_data_field_measure_lattice_psdf_pygwy(GwyDataField *psdf2d,
+                                          GwyDoubleArray *a1a2,
+                                          GwyDoubleArrayOutArg a1a2_out,
+                                          gboolean *succeeded)
+{
+    gboolean ok = (a1a2->len == 4);
+    g_array_set_size(a1a2_out, 4);
+    gwy_clear((gdouble*)a1a2_out->data, 4);
+    *succeeded = FALSE;
+    if (ok) {
+        gwy_assign((gdouble*)a1a2_out->data, (gdouble*)a1a2->data, 4);
+        *succeeded = gwy_data_field_measure_lattice_psdf(psdf2d,
+                                                         (gdouble*)a1a2_out->data);
+    }
+    if (!*succeeded || !ok)
+        gwy_clear((gdouble*)a1a2_out->data, 4);
+    g_array_free(a1a2, TRUE);
+    return ok;
+}
+
+gint
+gwy_data_field_waterpour_pygwy(GwyDataField *data_field,
+                               GwyDataField *result,
+                               GwyIntArrayOutArg grains)
+{
+    guint n = data_field->xres*data_field->yres;
+    g_array_set_size(grains, n);
+    gwy_clear(((gint*)grains->data), n);
+    return gwy_data_field_waterpour(data_field, result, (gint*)grains->data);
+}
+
 void
 gwy_data_field_get_local_maxima_list_pygwy(GwyDataField *dfield,
                                            GwyDoubleArrayOutArg xdata,
@@ -836,6 +1133,37 @@ gwy_container_keys_pygwy(GwyContainer *container)
                             gwy_container_get_n_items(container), TRUE);
 }
 
+GwyConstStringArray*
+gwy_container_keys_by_name_pygwy(GwyContainer *container)
+{
+    const gchar **keys = gwy_container_keys_by_name(container);
+    return create_const_string_array((const gchar*const*)keys,
+                                     gwy_container_get_n_items(container),
+                                     TRUE);
+}
+
+GwyContainer*
+gwy_container_duplicate_by_prefix_pygwy(GwyContainer *container,
+                                        GwyStringArray *keys)
+{
+    GwyContainer *ret;
+    ret = gwy_container_duplicate_by_prefixv(container,
+                                             keys->len,
+                                             (const gchar**)keys->data);
+    free_string_array(keys);
+    return ret;
+}
+
+GwyStringArray*
+gwy_container_serialize_to_text_pygwy(GwyContainer *container)
+{
+    GPtrArray *strs = gwy_container_serialize_to_text(container);
+    GwyStringArray *array = create_string_array((const gchar**)strs->pdata,
+                                                strs->len, FALSE);
+    g_ptr_array_free(strs, TRUE);
+    return array;
+}
+
 static GwyIntArray*
 create_id_array(gint *ids)
 {
@@ -1326,16 +1654,55 @@ gwy_axis_get_major_ticks_pygwy(GwyAxis *axis)
     return create_double_array(ticks, n, FALSE);
 }
 
+gulong
+gwy_undo_qcheckpoint_pygwy(GwyContainer *container, GwyIntArray *keys)
+{
+    gulong id = 0;
+    g_assert(sizeof(GQuark) == sizeof(gint));
+    if (keys->len) {
+        id = gwy_undo_qcheckpointv(container, keys->len, (GQuark*)keys->data);
+    }
+    g_array_free(keys, TRUE);
+    return id;
+}
+
+gulong
+gwy_undo_checkpoint_pygwy(GwyContainer *container, GwyStringArray *keys)
+{
+    gulong id = 0;
+    if (keys->len) {
+        id = gwy_undo_checkpointv(container, keys->len,
+                                  (const gchar**)keys->data);
+    }
+    free_string_array(keys);
+    return id;
+}
+
 gulong
 gwy_app_undo_qcheckpoint_pygwy(GwyContainer *container, GwyIntArray *keys)
 {
-    gulong id;
+    gulong id = 0;
     g_assert(sizeof(GQuark) == sizeof(gint));
-    id = gwy_app_undo_qcheckpointv(container, keys->len, (GQuark*)keys->data);
+    if (keys->len) {
+        id = gwy_app_undo_qcheckpointv(container,
+                                       keys->len, (GQuark*)keys->data);
+    }
     g_array_free(keys, TRUE);
     return id;
 }
 
+gulong
+gwy_app_undo_checkpoint_pygwy(GwyContainer *container, GwyStringArray *keys)
+{
+    gulong id = 0;
+    if (keys->len) {
+        id = gwy_app_undo_checkpointv(container,
+                                      keys->len, (const gchar**)keys->data);
+    }
+    free_string_array(keys);
+    return id;
+}
+
 GObject*
 gwy_inventory_get_item_pygwy(GwyInventory *inventory,
                              const gchar *name)
@@ -1510,6 +1877,97 @@ gwy_peaks_get_quantity_pygwy(GwyPeaks *peaks,
     return array;
 }
 
+GwyIntArray*
+gwy_tip_model_preset_get_params_pygwy(const GwyTipModelPreset *preset)
+{
+    GwyIntArray *array = g_array_new(FALSE, FALSE, sizeof(guint));
+    guint i, n = gwy_tip_model_get_preset_nparams(preset);
+    const GwyTipParamType *paramtypes = gwy_tip_model_get_preset_params(preset);
+    g_array_set_size(array, n);
+    for (i = 0; i < n; i++)
+        g_array_index(array, guint, i) = paramtypes[i];
+    return array;
+}
+
+GwyArrayFuncStatus
+gwy_tip_model_preset_create_pygwy(const GwyTipModelPreset *preset,
+                                  GwyDataField *tip,
+                                  GwyDoubleArray *params)
+{
+    gboolean ok = (params->len == gwy_tip_model_get_preset_nparams(preset));
+    if (ok)
+        gwy_tip_model_preset_create(preset, tip, (const gdouble*)params->data);
+    return ok;
+}
+
+GwyArrayFuncStatus
+gwy_tip_model_preset_create_for_zrange_pygwy(const GwyTipModelPreset *preset,
+                                             GwyDataField *tip,
+                                             gdouble zrange,
+                                             gboolean square,
+                                             GwyDoubleArray *params)
+{
+    gboolean ok = (params->len == gwy_tip_model_get_preset_nparams(preset));
+    if (ok) {
+        gwy_tip_model_preset_create_for_zrange(preset, tip, zrange, square,
+                                               (const gdouble*)params->data);
+    }
+    return ok;
+}
+
+GwySpline*
+gwy_spline_new_from_points_pygwy(GwyDoubleArray *xy)
+{
+    return gwy_spline_new_from_points((GwyXY*)xy->data, xy->len/2);
+}
+
+GwyDoubleArray*
+gwy_spline_get_points_pygwy(GwySpline *spline)
+{
+    GwyDoubleArray *array = g_array_new(FALSE, FALSE, sizeof(gdouble));
+    guint n = gwy_spline_get_npoints(spline);
+    g_array_set_size(array, 2*n);
+    gwy_assign((gdouble*)array->data,
+               (const gdouble*)gwy_spline_get_points(spline),
+               2*n);
+    return array;
+}
+
+GwyDoubleArray*
+gwy_spline_get_tangents_pygwy(GwySpline *spline)
+{
+    GwyDoubleArray *array = g_array_new(FALSE, FALSE, sizeof(gdouble));
+    guint n = gwy_spline_get_npoints(spline);
+    g_array_set_size(array, 2*n);
+    gwy_assign((gdouble*)array->data,
+               (const gdouble*)gwy_spline_get_tangents(spline),
+               2*n);
+    return array;
+}
+
+GwyDoubleArray*
+gwy_spline_sample_naturally_pygwy(GwySpline *spline)
+{
+    guint n;
+    const GwyXY *xy = gwy_spline_sample_naturally(spline, &n);
+    GwyDoubleArray *array = g_array_new(FALSE, FALSE, sizeof(gdouble));
+    g_array_set_size(array, 2*n);
+    gwy_assign((gdouble*)array->data, (const gdouble*)xy, 2*n);
+    return array;
+}
+
+gdouble
+gwy_spline_sample_uniformly_pygwy(GwySpline *spline,
+                                  GwyDoubleArrayOutArg xy,
+                                  GwyDoubleArrayOutArg t,
+                                  guint n)
+{
+    g_array_set_size(xy, 2*n);
+    g_array_set_size(t, 2*n);
+    return gwy_spline_sample_uniformly(spline,
+                                       (GwyXY*)xy->data, (GwyXY*)t->data, n);
+}
+
 GwyDoubleArray*
 gwy_marker_box_get_markers_pygwy(GwyMarkerBox *mbox)
 {
@@ -1526,4 +1984,14 @@ gwy_marker_box_set_markers_pygwy(GwyMarkerBox *mbox,
     g_array_free(markers, TRUE);
 }
 
+void
+gwy_app_sync_data_items_pygwy(GwyContainer *source, GwyContainer *dest,
+                              gint from_id, gint to_id, gboolean delete_too,
+                              GwyIntArray *items)
+{
+    g_assert(sizeof(GwyDataItem) == sizeof(gint));
+    gwy_app_sync_data_itemsv(source, dest, from_id, to_id, delete_too,
+                             (GwyDataItem*)items->data, items->len);
+}
+
 /* vim: set cin et ts=4 sw=4 cino=>1s,e0,n0,f0,{0,}0,^0,\:1s,=0,g1s,h0,t0,+1s,c3,(0,u0 : */
