@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: crop.c 17820 2015-12-11 15:06:32Z yeti-dn $
+ *  @(#) $Id: crop.c 19948 2017-06-22 14:05:41Z yeti-dn $
  *  Copyright (C) 2003-2006 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -96,7 +96,7 @@ static const ToolArgs default_args = {
     TRUE,
 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, crop)
 
 G_DEFINE_TYPE(GwyToolCrop, gwy_tool_crop, GWY_TYPE_PLAIN_TOOL)
 
@@ -203,18 +203,18 @@ gwy_tool_crop_init_dialog(GwyToolCrop *tool)
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(tool->keep_offsets),
                                  tool->args.keep_offsets);
     gtk_table_attach(table, tool->keep_offsets,
-                     0, 1, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
+                     0, 1, row, row+1, GTK_FILL, 0, 0, 0);
     g_signal_connect_swapped(tool->keep_offsets, "toggled",
                              G_CALLBACK(gwy_tool_crop_keep_offsets_toggled),
                              tool);
     row++;
 
     tool->new_channel
-        = gtk_check_button_new_with_mnemonic(_("Create new channel"));
+        = gtk_check_button_new_with_mnemonic(_("Create new image"));
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(tool->new_channel),
                                  tool->args.new_channel);
     gtk_table_attach(table, tool->new_channel,
-                     0, 1, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
+                     0, 1, row, row+1, GTK_FILL, 0, 0, 0);
     g_signal_connect_swapped(tool->new_channel, "toggled",
                              G_CALLBACK(gwy_tool_crop_new_data_toggled),
                              tool);
