@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: distance.c 19044 2016-10-08 19:10:46Z yeti-dn $
+ *  @(#) $Id: distance.c 20111 2017-07-30 14:08:43Z yeti-dn $
  *  Copyright (C) 2003-2008 Nenad Ocelic, David Necas (Yeti), Petr Klapetek.
  *  E-mail: ocelic@biochem.mpg.de, yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -110,7 +110,7 @@ static GwyModuleInfo module_info = {
     &module_register,
     N_("Distance measurement tool, measures distances and angles."),
     "Nenad Ocelic <ocelic@biochem.mpg.de>",
-    "2.13",
+    "2.14",
     "Nenad Ocelic & David Nečas (Yeti) & Petr Klapetek",
     "2004",
 };
@@ -121,7 +121,7 @@ static const ToolArgs default_args = {
     TRUE,
 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, distance)
 
 G_DEFINE_TYPE(GwyToolDistance, gwy_tool_distance, GWY_TYPE_PLAIN_TOOL)
 
@@ -194,7 +194,7 @@ gwy_tool_distance_init(GwyToolDistance *tool)
     gwy_container_gis_boolean_by_name(settings, number_lines_key,
                                       &tool->args.number_lines);
 
-    tool->angle_format = gwy_si_unit_value_format_new(1.0, 1, "deg");
+    tool->angle_format = gwy_si_unit_value_format_new(1.0, 1, _("deg"));
     gwy_plain_tool_connect_selection(plain_tool, tool->layer_type_line,
                                      "line");
 
@@ -623,7 +623,7 @@ gwy_tool_distance_create_report(GwyToolDistance *tool)
     plain_tool = GWY_PLAIN_TOOL(tool);
     text = g_string_new(NULL);
     g_string_append_printf(text,
-                           "n Δx [%s] Δy [%s] φ [%s] R [%s] Δz [%s]\n",
+                           "n\tΔx [%s]\tΔy [%s]\tφ [%s]\tR [%s]\tΔz [%s]\n",
                            plain_tool->coord_format->units,
                            plain_tool->coord_format->units,
                            tool->angle_format->units,
@@ -654,7 +654,7 @@ gwy_tool_distance_create_report(GwyToolDistance *tool)
         val_dz -= gwy_data_field_get_val(plain_tool->data_field, x, y);
         vf_dz = plain_tool->value_format;
 
-        g_string_append_printf(text, "%d %.*f %.*f %.*f %.*f %.*f\n",
+        g_string_append_printf(text, "%d\t%.*f\t%.*f\t%.*f\t%.*f\t%.*f\n",
                                i+1,
                                vf_dx->precision+1, val_dx/vf_dx->magnitude,
                                vf_dy->precision+1, val_dy/vf_dy->magnitude,
