@@ -1,6 +1,6 @@
 /*
- *  @(#) $Id: filter.c 19039 2016-10-08 10:54:58Z yeti-dn $
- *  Copyright (C) 2003-2006 David Necas (Yeti), Petr Klapetek.
+ *  @(#) $Id: filter.c 19948 2017-06-22 14:05:41Z yeti-dn $
+ *  Copyright (C) 2003-2017 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -30,6 +30,7 @@
 #include <libprocess/linestats.h>
 #include <libgwydgets/gwystock.h>
 #include <libgwydgets/gwycombobox.h>
+#include <libgwydgets/gwyadjustbar.h>
 #include <libgwydgets/gwyradiobuttons.h>
 #include <libgwydgets/gwydgetutils.h>
 #include <app/gwyapp.h>
@@ -128,7 +129,7 @@ static GwyModuleInfo module_info = {
     N_("Filter tool, processes selected part of data with a filter "
        "(conservative denoise, mean, median. Kuwahara, minimum, maximum)."),
     "Petr Klapetek <klapetek@gwyddion.net>",
-    "3.12",
+    "3.13",
     "David Nečas (Yeti) & Petr Klapetek",
     "2003",
 };
@@ -145,7 +146,7 @@ static const ToolArgs default_args = {
     5.0,
 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, filter)
 
 G_DEFINE_TYPE(GwyToolFilter, gwy_tool_filter, GWY_TYPE_PLAIN_TOOL)
 
@@ -263,7 +264,7 @@ gwy_tool_filter_init_dialog(GwyToolFilter *tool)
                        FALSE, FALSE, 0);
 
     /* Options */
-    table = GTK_TABLE(gtk_table_new(4, 4, FALSE));
+    table = GTK_TABLE(gtk_table_new(4, 3, FALSE));
     gtk_table_set_col_spacings(table, 6);
     gtk_table_set_row_spacings(table, 2);
     gtk_container_set_border_width(GTK_CONTAINER(table), 4);
@@ -272,8 +273,7 @@ gwy_tool_filter_init_dialog(GwyToolFilter *tool)
     row = 0;
 
     label = gwy_label_new_header(_("Filter"));
-    gtk_table_attach(table, label,
-                     0, 1, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
+    gtk_table_attach(table, label, 0, 2, row, row+1, GTK_FILL, 0, 0, 0);
     row++;
 
     tool->filter_type = gwy_enum_combo_box_new
@@ -281,14 +281,15 @@ gwy_tool_filter_init_dialog(GwyToolFilter *tool)
                                       G_CALLBACK(gwy_tool_filter_type_changed),
                                       tool,
                                       tool->args.filter_type, TRUE);
-    gwy_table_attach_hscale(GTK_WIDGET(table), row, _("_Type:"), NULL,
-                            GTK_OBJECT(tool->filter_type), GWY_HSCALE_WIDGET);
+    gwy_table_attach_adjbar(GTK_WIDGET(table), row, _("_Type:"), NULL,
+                            GTK_OBJECT(tool->filter_type),
+                            GWY_HSCALE_WIDGET_NO_EXPAND);
     row++;
 
     tool->size = gtk_adjustment_new(0.0, 0.0, 1.0, 0.1, 1.0, 0);
     tool->size_spin
-        = gwy_table_attach_hscale(GTK_WIDGET(table), row, _("Si_ze:"), "px",
-                                  tool->size, 0);
+        = gwy_table_attach_adjbar(GTK_WIDGET(table), row, _("Si_ze:"), _("px"),
+                                  tool->size, GWY_HSCALE_SQRT);
     gwy_table_hscale_set_sensitive
                  (tool->size, gwy_tool_filter_is_sized(tool->args.filter_type));
     setup_size_adjustment(tool);
@@ -298,8 +299,7 @@ gwy_tool_filter_init_dialog(GwyToolFilter *tool)
 
     gtk_table_set_row_spacing(table, row-1, 8);
     label = gwy_label_new_header(_("Masking Mode"));
-    gtk_table_attach(table, label,
-                     0, 3, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
+    gtk_table_attach(table, label, 0, 2, row, row+1, GTK_FILL, 0, 0, 0);
     row++;
 
     tool->masking
@@ -307,7 +307,7 @@ gwy_tool_filter_init_dialog(GwyToolFilter *tool)
                                    G_CALLBACK(gwy_tool_filter_masking_changed),
                                    tool,
                                    tool->args.masking);
-    row = gwy_radio_buttons_attach_to_table(tool->masking, table, 3, row);
+    row = gwy_radio_buttons_attach_to_table(tool->masking, table, 2, row);
 
     gwy_plain_tool_add_clear_button(GWY_PLAIN_TOOL(tool));
     gwy_tool_add_hide_button(GWY_TOOL(tool), FALSE);
@@ -457,6 +457,8 @@ static void
 setup_size_adjustment(GwyToolFilter *tool)
 {
     GtkAdjustment *adj = GTK_ADJUSTMENT(tool->size);
+    GtkWidget *adjbar = gwy_table_hscale_get_scale(tool->size);
+
     if (gwy_tool_filter_is_float_sized(tool->args.filter_type)) {
         g_object_set(adj,
                      "lower", 0.01,
@@ -466,6 +468,7 @@ setup_size_adjustment(GwyToolFilter *tool)
                      "value", tool->args.gauss_size,
                      NULL);
         gtk_spin_button_set_digits(GTK_SPIN_BUTTON(tool->size_spin), 2);
+        gwy_adjust_bar_set_snap_to_ticks(GWY_ADJUST_BAR(adjbar), FALSE);
     }
     else {
         g_object_set(adj,
@@ -476,6 +479,7 @@ setup_size_adjustment(GwyToolFilter *tool)
                      "value", (gdouble)tool->args.size,
                      NULL);
         gtk_spin_button_set_digits(GTK_SPIN_BUTTON(tool->size_spin), 0);
+        gwy_adjust_bar_set_snap_to_ticks(GWY_ADJUST_BAR(adjbar), TRUE);
     }
 }
 
