@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: grainmeasure.c 19039 2016-10-08 10:54:58Z yeti-dn $
+ *  @(#) $Id: grainmeasure.c 19948 2017-06-22 14:05:41Z yeti-dn $
  *  Copyright (C) 2007 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
@@ -99,7 +99,7 @@ static GwyModuleInfo module_info = {
 
 static const gchar expanded_key[] = "/module/grainmeasure/expanded";
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, grainmeasure)
 
 G_DEFINE_TYPE(GwyToolGrainMeasure, gwy_tool_grain_measure, GWY_TYPE_PLAIN_TOOL)
 
