@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: grainremover.c 16437 2014-07-24 20:38:55Z yeti-dn $
+ *  @(#) $Id: grainremover.c 19948 2017-06-22 14:05:41Z yeti-dn $
  *  Copyright (C) 2003-2006 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -120,7 +120,7 @@ static const ToolArgs default_args = {
     GRAIN_REMOVE_LAPLACE,
 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, grainremover)
 
 G_DEFINE_TYPE(GwyToolGrainRemover, gwy_tool_grain_remover, GWY_TYPE_PLAIN_TOOL)
 
