@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: level3.c 19039 2016-10-08 10:54:58Z yeti-dn $
+ *  @(#) $Id: level3.c 20103 2017-07-29 04:31:07Z yeti-dn $
  *  Copyright (C) 2003-2006 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -35,6 +35,8 @@
 #define GWY_IS_TOOL_LEVEL3(obj)         (G_TYPE_CHECK_INSTANCE_TYPE((obj), GWY_TYPE_TOOL_LEVEL3))
 #define GWY_TOOL_LEVEL3_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS((obj), GWY_TYPE_TOOL_LEVEL3, GwyToolLevel3Class))
 
+enum { RADIUS_MAX = 32 };
+
 enum {
     COLUMN_I, COLUMN_X, COLUMN_Y, COLUMN_Z, NCOLUMNS
 };
@@ -106,7 +108,7 @@ static GwyModuleInfo module_info = {
     N_("Three-point level tool, levels data by subtracting a plane fitted "
        "through three selected points."),
     "Yeti <yeti@gwyddion.net>",
-    "2.7",
+    "2.8",
     "David Nečas (Yeti) & Petr Klapetek",
     "2003",
 };
@@ -118,7 +120,7 @@ static const ToolArgs default_args = {
     FALSE,
 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, level3)
 
 G_DEFINE_TYPE(GwyToolLevel3, gwy_tool_level3, GWY_TYPE_PLAIN_TOOL)
 
@@ -205,6 +207,7 @@ gwy_tool_level3_init_dialog(GwyToolLevel3 *tool)
     GtkWidget *label, *table;
     GwyNullStore *store;
     guint i;
+    gint row;
 
     dialog = GTK_DIALOG(GWY_TOOL(tool)->dialog);
 
@@ -234,31 +237,35 @@ gwy_tool_level3_init_dialog(GwyToolLevel3 *tool)
     gtk_table_set_col_spacings(GTK_TABLE(table), 6);
     gtk_container_set_border_width(GTK_CONTAINER(table), 4);
     gtk_box_pack_start(GTK_BOX(dialog->vbox), table, TRUE, TRUE, 0);
+    row = 0;
 
-    tool->radius = gtk_adjustment_new(tool->args.radius, 1, 16, 1, 5, 0);
-    gwy_table_attach_spinbutton(table, 1, _("_Averaging radius:"), "px",
-                                tool->radius);
+    tool->radius = gtk_adjustment_new(tool->args.radius, 1, RADIUS_MAX, 1, 5,
+                                      0);
+    gwy_table_attach_adjbar(table, row, _("_Averaging radius:"), _("px"),
+                            tool->radius, GWY_HSCALE_LINEAR | GWY_HSCALE_SNAP);
     g_signal_connect_swapped(tool->radius, "value-changed",
                              G_CALLBACK(gwy_tool_level3_radius_changed), tool);
-    gtk_table_set_row_spacing(GTK_TABLE(table), 1, 8);
+    row++;
 
     tool->instant_apply
             = gtk_check_button_new_with_mnemonic(_("_Instant apply"));
-    gtk_table_attach(GTK_TABLE(table), tool->instant_apply, 0, 3, 2, 3,
-                     GTK_EXPAND | GTK_FILL, 0, 0, 0);
+    gtk_table_attach(GTK_TABLE(table), tool->instant_apply, 0, 2, row, row+1,
+                     GTK_FILL, 0, 0, 0);
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(tool->instant_apply),
                                  tool->args.instant_apply);
     g_signal_connect(tool->instant_apply, "toggled",
                      G_CALLBACK(gwy_tool_level3_instant_apply_changed), tool);
+    row++;
 
     tool->set_zero
             = gtk_check_button_new_with_mnemonic(_("Set plane to _zero"));
-    gtk_table_attach(GTK_TABLE(table), tool->set_zero, 0, 3, 3, 4,
-                     GTK_EXPAND | GTK_FILL, 0, 0, 0);
+    gtk_table_attach(GTK_TABLE(table), tool->set_zero, 0, 2, row, row+1,
+                     GTK_FILL, 0, 0, 0);
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(tool->set_zero),
                                  tool->args.set_zero);
     g_signal_connect(tool->set_zero, "toggled",
                      G_CALLBACK(gwy_tool_level3_set_zero_changed), tool);
+    row++;
 
     gwy_plain_tool_add_clear_button(GWY_PLAIN_TOOL(tool));
     gwy_tool_add_hide_button(GWY_TOOL(tool), FALSE);
