@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: linestats.c 19039 2016-10-08 10:54:58Z yeti-dn $
+ *  @(#) $Id: linestats.c 20102 2017-07-29 04:29:28Z yeti-dn $
  *  Copyright (C) 2003-2016 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -179,7 +179,7 @@ static const GwyEnum sf_types[] =  {
     { N_("Kurtosis"),           GWY_LINE_STAT_KURTOSIS,  },
 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, linestats)
 
 G_DEFINE_TYPE(GwyToolLineStats, gwy_tool_line_stats, GWY_TYPE_PLAIN_TOOL)
 
@@ -332,7 +332,7 @@ gwy_tool_line_stats_init_dialog(GwyToolLineStats *tool)
     /* Output type */
     hbox2 = gtk_hbox_new(FALSE, 8);
     gtk_container_set_border_width(GTK_CONTAINER(hbox2), 4);
-    gtk_box_pack_start(GTK_BOX(vbox), hbox2, FALSE, FALSE, 0);
+    gtk_box_pack_start(GTK_BOX(vbox), hbox2, FALSE, TRUE, 0);
 
     label = gtk_label_new_with_mnemonic(_("_Quantity:"));
     gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
@@ -344,7 +344,7 @@ gwy_tool_line_stats_init_dialog(GwyToolLineStats *tool)
                             tool,
                             tool->args.output_type, TRUE);
     gtk_label_set_mnemonic_widget(GTK_LABEL(label), tool->output_type);
-    gtk_box_pack_start(GTK_BOX(hbox2), tool->output_type, FALSE, FALSE, 0);
+    gtk_box_pack_end(GTK_BOX(hbox2), tool->output_type, FALSE, FALSE, 0);
 
     /* Average */
     hbox2 = gtk_hbox_new(FALSE, 8);
