@@ -1,6 +1,6 @@
 /*
- *  @(#) $Id: maskedit.c 19071 2016-10-14 09:02:41Z yeti-dn $
- *  Copyright (C) 2003-2006 David Necas (Yeti), Petr Klapetek.
+ *  @(#) $Id: maskedit.c 19987 2017-06-26 11:50:55Z yeti-dn $
+ *  Copyright (C) 2003-2017 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -170,7 +170,7 @@ static GwyModuleInfo module_info = {
     N_("Mask editor tool, allows interactive modification of parts "
        "of the mask."),
     "Yeti <yeti@gwyddion.net>",
-    "3.8",
+    "3.11",
     "David Nečas (Yeti) & Petr Klapetek",
     "2004",
 };
@@ -203,7 +203,7 @@ static const ToolArgs default_args = {
     FALSE,
 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, maskedit)
 
 G_DEFINE_TYPE(GwyToolMaskEditor, gwy_tool_mask_editor, GWY_TYPE_PLAIN_TOOL)
 
@@ -322,7 +322,7 @@ gwy_tool_mask_editor_init_dialog(GwyToolMaskEditor *tool)
     const modes[] = {
         {
             MASK_EDIT_SET,
-            GWY_STOCK_MASK,
+            GWY_STOCK_MASK_SET,
             N_("Set mask to selection"),
         },
         {
@@ -382,7 +382,7 @@ gwy_tool_mask_editor_init_dialog(GwyToolMaskEditor *tool)
     };
 
     GtkRadioButton *group;
-    GtkSizeGroup *sizegroup;
+    GtkSizeGroup *sizegroup, *labelsize;
     GtkTooltips *tips;
     GtkDialog *dialog;
     GtkTable *table;
@@ -394,9 +394,10 @@ gwy_tool_mask_editor_init_dialog(GwyToolMaskEditor *tool)
     dialog = GTK_DIALOG(GWY_TOOL(tool)->dialog);
     tips = gwy_app_get_tooltips();
     sizegroup = gtk_size_group_new(GTK_SIZE_GROUP_BOTH);
+    labelsize = gtk_size_group_new(GTK_SIZE_GROUP_HORIZONTAL);
     tool->sensgroup = gwy_sensitivity_group_new();
 
-    table = GTK_TABLE(gtk_table_new(15, 4, FALSE));
+    table = GTK_TABLE(gtk_table_new(15, 3, FALSE));
     gtk_table_set_col_spacings(table, 6);
     gtk_table_set_row_spacings(table, 2);
     gtk_container_set_border_width(GTK_CONTAINER(table), 4);
@@ -413,20 +414,21 @@ gwy_tool_mask_editor_init_dialog(GwyToolMaskEditor *tool)
     button = gtk_radio_button_new_with_mnemonic(NULL, _("_Shapes"));
     tool->style = gtk_radio_button_get_group(GTK_RADIO_BUTTON(button));
     gwy_radio_button_set_value(button, MASK_EDIT_STYLE_SHAPES);
-    gtk_table_attach(table, button, 0, 3, row, row+1, GTK_FILL, 0, 0, 0);
+    gtk_table_attach(table, button, 0, 2, row, row+1, GTK_FILL, 0, 0, 0);
     g_signal_connect_swapped(button, "clicked",
                              G_CALLBACK(gwy_tool_mask_editor_style_changed),
                              tool);
     row++;
 
     /* Mode */
-    label = gtk_label_new(_("Mode:"));
-    gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
-    gtk_table_attach(table, label, 0, 1, row, row+1, GTK_FILL, 0, 0, 0);
-
     hbox = GTK_BOX(gtk_hbox_new(FALSE, 0));
     gtk_table_attach(table, GTK_WIDGET(hbox),
-                     1, 4, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
+                     0, 3, row, row+1, GTK_FILL, 0, 0, 0);
+
+    label = gtk_label_new(_("Mode:"));
+    gtk_size_group_add_widget(labelsize, label);
+    gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
+    gtk_box_pack_start(hbox, label, FALSE, TRUE, 4);
 
     group = NULL;
     for (i = 0; i < G_N_ELEMENTS(modes); i++) {
@@ -449,13 +451,14 @@ gwy_tool_mask_editor_init_dialog(GwyToolMaskEditor *tool)
     row++;
 
     /* Shape */
-    label = gtk_label_new(_("Shape:"));
-    gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
-    gtk_table_attach(table, label, 0, 1, row, row+1, GTK_FILL, 0, 0, 0);
-
     hbox = GTK_BOX(gtk_hbox_new(FALSE, 0));
     gtk_table_attach(table, GTK_WIDGET(hbox),
-                     1, 4, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
+                     0, 3, row, row+1, GTK_FILL, 0, 0, 0);
+
+    label = gtk_label_new(_("Shape:"));
+    gtk_size_group_add_widget(labelsize, label);
+    gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
+    gtk_box_pack_start(hbox, label, FALSE, TRUE, 4);
 
     group = NULL;
     for (i = 0; i < G_N_ELEMENTS(shapes); i++) {
@@ -483,20 +486,21 @@ gwy_tool_mask_editor_init_dialog(GwyToolMaskEditor *tool)
                                                 _("_Drawing Tools"));
     tool->style = gtk_radio_button_get_group(GTK_RADIO_BUTTON(button));
     gwy_radio_button_set_value(button, MASK_EDIT_STYLE_DRAWING);
-    gtk_table_attach(table, button, 0, 3, row, row+1, GTK_FILL, 0, 0, 0);
+    gtk_table_attach(table, button, 0, 2, row, row+1, GTK_FILL, 0, 0, 0);
     g_signal_connect_swapped(button, "clicked",
                              G_CALLBACK(gwy_tool_mask_editor_style_changed),
                              tool);
     row++;
 
     /* Tool */
-    label = gtk_label_new(_("Tool:"));
-    gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
-    gtk_table_attach(table, label, 0, 1, row, row+1, GTK_FILL, 0, 0, 0);
-
     hbox = GTK_BOX(gtk_hbox_new(FALSE, 0));
     gtk_table_attach(table, GTK_WIDGET(hbox),
-                     1, 4, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
+                     0, 3, row, row+1, GTK_FILL, 0, 0, 0);
+
+    label = gtk_label_new(_("Tool:"));
+    gtk_size_group_add_widget(labelsize, label);
+    gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
+    gtk_box_pack_start(hbox, label, FALSE, TRUE, 4);
 
     group = NULL;
     for (i = 0; i < G_N_ELEMENTS(tools); i++) {
@@ -521,8 +525,10 @@ gwy_tool_mask_editor_init_dialog(GwyToolMaskEditor *tool)
     /* Radius */
     tool->radius = gtk_adjustment_new(tool->args.radius, 1.0, 15.0,
                                       1.0, 1.0, 0.0);
-    gwy_table_attach_hscale(GTK_WIDGET(table), row, _("_Radius:"), "px",
-                            tool->radius, 0);
+    gwy_table_attach_adjbar(GTK_WIDGET(table), row, _("_Radius:"), _("px"),
+                            tool->radius, GWY_HSCALE_LINEAR | GWY_HSCALE_SNAP);
+    gtk_size_group_add_widget(labelsize,
+                              gwy_table_hscale_get_label(tool->radius));
     g_signal_connect(tool->radius, "value-changed",
                      G_CALLBACK(gwy_tool_mask_editor_radius_changed), tool);
     row++;
@@ -535,7 +541,7 @@ gwy_tool_mask_editor_init_dialog(GwyToolMaskEditor *tool)
 
     hbox = GTK_BOX(gtk_hbox_new(FALSE, 0));
     gtk_table_attach(table, GTK_WIDGET(hbox),
-                     0, 4, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
+                     0, 3, row, row+1, GTK_FILL, 0, 0, 0);
 
     button = gwy_stock_like_button_new(_("_Invert"), GWY_STOCK_MASK_INVERT);
     gtk_size_group_add_widget(sizegroup, button);
@@ -566,7 +572,7 @@ gwy_tool_mask_editor_init_dialog(GwyToolMaskEditor *tool)
 
     hbox = GTK_BOX(gtk_hbox_new(FALSE, 0));
     gtk_table_attach(table, GTK_WIDGET(hbox),
-                     0, 4, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
+                     0, 3, row, row+1, GTK_FILL, 0, 0, 0);
 
     button = gtk_button_new_with_mnemonic(_("Fill _Voids"));
     gtk_size_group_add_widget(sizegroup, button);
@@ -589,13 +595,13 @@ gwy_tool_mask_editor_init_dialog(GwyToolMaskEditor *tool)
 
     /* Grow/Shrink */
     label = gwy_label_new_header(_("Grow/Shrink"));
-    gtk_table_attach(table, label, 0, 4, row, row+1, GTK_FILL, 0, 0, 0);
+    gtk_table_attach(table, label, 0, 3, row, row+1, GTK_FILL, 0, 0, 0);
     row++;
 
     /* Buttons */
     hbox = GTK_BOX(gtk_hbox_new(FALSE, 0));
     gtk_table_attach(table, GTK_WIDGET(hbox),
-                     0, 4, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
+                     0, 3, row, row+1, GTK_FILL, 0, 0, 0);
 
     button = gwy_stock_like_button_new(_("_Grow"), GWY_STOCK_MASK_GROW);
     gtk_size_group_add_widget(sizegroup, button);
@@ -620,8 +626,8 @@ gwy_tool_mask_editor_init_dialog(GwyToolMaskEditor *tool)
     /* Options */
     tool->gsamount = gtk_adjustment_new(tool->args.gsamount, 1.0, 256.0,
                                         1.0, 10.0, 0.0);
-    gwy_table_attach_hscale(GTK_WIDGET(table), row, _("_Amount:"), "px",
-                            tool->gsamount, 0);
+    gwy_table_attach_adjbar(GTK_WIDGET(table), row, _("_Amount:"), _("px"),
+                            tool->gsamount, GWY_HSCALE_SQRT | GWY_HSCALE_SNAP);
     g_signal_connect(tool->gsamount, "value-changed",
                      G_CALLBACK(gwy_tool_mask_editor_gsamount_changed), tool);
     row++;
@@ -630,10 +636,10 @@ gwy_tool_mask_editor_init_dialog(GwyToolMaskEditor *tool)
                            (gwy_distance_transform_type_get_enum(), -1,
                             G_CALLBACK(gwy_tool_mask_editor_dist_type_changed),
                             tool, tool->args.dist_type, TRUE);
-    gwy_table_attach_hscale(GTK_WIDGET(table), row++,
+    gwy_table_attach_adjbar(GTK_WIDGET(table), row++,
                             _("_Distance type:"), NULL,
                             GTK_OBJECT(tool->dist_type),
-                            GWY_HSCALE_WIDGET);
+                            GWY_HSCALE_WIDGET_NO_EXPAND);
     row++;
 
     tool->from_border
@@ -641,7 +647,7 @@ gwy_tool_mask_editor_init_dialog(GwyToolMaskEditor *tool)
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(tool->from_border),
                                  tool->args.from_border);
     gtk_table_attach(table, tool->from_border,
-                     0, 4, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
+                     0, 3, row, row+1, GTK_FILL, 0, 0, 0);
     g_signal_connect(tool->from_border, "toggled",
                      G_CALLBACK(gwy_tool_mask_editor_from_border_changed),
                      tool);
@@ -653,7 +659,7 @@ gwy_tool_mask_editor_init_dialog(GwyToolMaskEditor *tool)
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(tool->prevent_merge),
                                  tool->args.prevent_merge);
     gtk_table_attach(table, tool->prevent_merge,
-                     0, 4, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
+                     0, 3, row, row+1, GTK_FILL, 0, 0, 0);
     g_signal_connect(tool->prevent_merge, "toggled",
                      G_CALLBACK(gwy_tool_mask_editor_prevent_merge_changed),
                      tool);
@@ -664,6 +670,7 @@ gwy_tool_mask_editor_init_dialog(GwyToolMaskEditor *tool)
     gwy_radio_buttons_set_current(tool->style, style);
 
     g_object_unref(sizegroup);
+    g_object_unref(labelsize);
     g_object_unref(tool->sensgroup);
     gtk_widget_show_all(dialog->vbox);
 }
@@ -1128,7 +1135,8 @@ gwy_tool_mask_editor_selection_finished(GwyPlainTool *plain_tool)
             return;
         }
         gwy_tool_mask_editor_bucket_fill(tool, isel[0], isel[1]);
-        gwy_data_field_data_changed(plain_tool->mask_field);
+        if (plain_tool->mask_field)
+            gwy_data_field_data_changed(plain_tool->mask_field);
         return;
     }
 
@@ -1330,6 +1338,11 @@ gwy_data_field_paint_wide_line(GwyDataField *dfield,
 {
     gint i, q;
 
+    if (!width && !height) {
+        gwy_data_field_circular_area_fill(dfield, col, row, radius, value);
+        return;
+    }
+
     if (ABS(height) >= width) {
         q = width/2;
         if (height > 0) {
@@ -1417,8 +1430,8 @@ gwy_tool_mask_editor_selection_changed(GwyPlainTool *plain_tool,
                 GWY_SWAP(gdouble, xy[0], xy[2]);
                 GWY_SWAP(gdouble, xy[1], xy[3]);
             }
-            xy[2] -= xy[0] - 1;
-            xy[3] -= xy[1] - 1;
+            xy[2] -= xy[0];
+            xy[3] -= xy[1];
             gwy_data_field_paint_wide_line(mfield, xy[0], xy[1], xy[2], xy[3],
                                            r, fillvalue);
         }
