@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: pathlevel.c 19039 2016-10-08 10:54:58Z yeti-dn $
+ *  @(#) $Id: pathlevel.c 19948 2017-06-22 14:05:41Z yeti-dn $
  *  Copyright (C) 2007 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
@@ -110,7 +110,7 @@ static GwyModuleInfo module_info = {
     &module_register,
     N_("Path level tool, performs row leveling along on user-set lines."),
     "Yeti <yeti@gwyddion.net>",
-    "1.8",
+    "1.9",
     "David Nečas (Yeti)",
     "2007",
 };
@@ -119,7 +119,7 @@ static const ToolArgs default_args = {
     1,
 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, pathlevel)
 
 G_DEFINE_TYPE(GwyToolPathLevel, gwy_tool_path_level, GWY_TYPE_PLAIN_TOOL)
 
@@ -243,7 +243,7 @@ gwy_tool_path_level_init_dialog(GwyToolPathLevel *tool)
     gtk_container_add(GTK_CONTAINER(scwin), GTK_WIDGET(tool->treeview));
     gtk_box_pack_start(GTK_BOX(dialog->vbox), scwin, TRUE, TRUE, 0);
 
-    table = GTK_TABLE(gtk_table_new(1, 4, FALSE));
+    table = GTK_TABLE(gtk_table_new(1, 3, FALSE));
     gtk_table_set_col_spacings(table, 6);
     gtk_table_set_row_spacings(table, 2);
     gtk_container_set_border_width(GTK_CONTAINER(table), 4);
@@ -253,8 +253,8 @@ gwy_tool_path_level_init_dialog(GwyToolPathLevel *tool)
 
     tool->thickness = gtk_adjustment_new(tool->args.thickness,
                                          1, MAX_THICKNESS, 1, 10, 0);
-    gwy_table_attach_hscale(GTK_WIDGET(table), row, _("_Thickness:"), "px",
-                            tool->thickness, GWY_HSCALE_SQRT);
+    gwy_table_attach_adjbar(GTK_WIDGET(table), row, _("_Thickness:"), _("px"),
+                            tool->thickness, GWY_HSCALE_SQRT | GWY_HSCALE_SNAP);
     g_signal_connect_swapped(tool->thickness, "value-changed",
                              G_CALLBACK(gwy_tool_path_level_thickness_changed),
                              tool);
