@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: readvalue.c 19044 2016-10-08 19:10:46Z yeti-dn $
+ *  @(#) $Id: readvalue.c 20100 2017-07-29 04:22:16Z yeti-dn $
  *  Copyright (C) 2003-2007,2014 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -30,13 +30,13 @@
 #include <libgwydgets/gwydgetutils.h>
 #include <app/gwyapp.h>
 
-enum { RADIUS_MAX = 32 };
-
 #define GWY_TYPE_TOOL_READ_VALUE            (gwy_tool_read_value_get_type())
 #define GWY_TOOL_READ_VALUE(obj)            (G_TYPE_CHECK_INSTANCE_CAST((obj), GWY_TYPE_TOOL_READ_VALUE, GwyToolReadValue))
 #define GWY_IS_TOOL_READ_VALUE(obj)         (G_TYPE_CHECK_INSTANCE_TYPE((obj), GWY_TYPE_TOOL_READ_VALUE))
 #define GWY_TOOL_READ_VALUE_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS((obj), GWY_TYPE_TOOL_READ_VALUE, GwyToolReadValueClass))
 
+enum { RADIUS_MAX = 32 };
+
 typedef struct _GwyToolReadValue      GwyToolReadValue;
 typedef struct _GwyToolReadValueClass GwyToolReadValueClass;
 
@@ -136,7 +136,7 @@ static GwyModuleInfo module_info = {
     &module_register,
     N_("Pointer tool, reads value under pointer."),
     "Yeti <yeti@gwyddion.net>",
-    "2.12",
+    "2.14",
     "David Nečas (Yeti) & Petr Klapetek",
     "2003",
 };
@@ -145,7 +145,7 @@ static const ToolArgs default_args = {
     1, FALSE,
 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, readvalue)
 
 G_DEFINE_TYPE(GwyToolReadValue, gwy_tool_read_value, GWY_TYPE_PLAIN_TOOL)
 
@@ -219,8 +219,8 @@ gwy_tool_read_value_init(GwyToolReadValue *tool)
     gwy_container_gis_boolean_by_name(settings, show_selection_key,
                                       &tool->args.show_selection);
 
-    tool->pixel_format = gwy_si_unit_value_format_new(1.0, 0, "px");
-    tool->angle_format = gwy_si_unit_value_format_new(1.0, 1, "deg");
+    tool->pixel_format = gwy_si_unit_value_format_new(1.0, 0, _("px"));
+    tool->angle_format = gwy_si_unit_value_format_new(1.0, 1, _("deg"));
     gwy_plain_tool_connect_selection(plain_tool, tool->layer_type_point,
                                      "pointer");
 
@@ -240,21 +240,24 @@ gwy_tool_read_value_init_dialog(GwyToolReadValue *tool)
     dialog = GTK_DIALOG(GWY_TOOL(tool)->dialog);
     tips = gwy_app_get_tooltips();
 
-    table = GTK_TABLE(gtk_table_new(13, 3, FALSE));
+    align = gtk_alignment_new(0.0, 0.0, 1.0, 0.0);
+    gtk_box_pack_start(GTK_BOX(dialog->vbox), align, FALSE, TRUE, 0);
+
+    table = GTK_TABLE(gtk_table_new(12, 3, FALSE));
     gtk_table_set_col_spacings(table, 6);
     gtk_table_set_row_spacings(table, 2);
     gtk_container_set_border_width(GTK_CONTAINER(table), 4);
-    gtk_box_pack_start(GTK_BOX(dialog->vbox), GTK_WIDGET(table),
-                       FALSE, FALSE, 0);
+    gtk_container_add(GTK_CONTAINER(align), GTK_WIDGET(table));
     row = 0;
 
     gtk_table_attach(table, gwy_label_new_header(_("Position")),
-                     0, 3, row, row+1, GTK_FILL, 0, 0, 0);
+                     0, 3, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
     row++;
 
     label = gtk_label_new("X");
     gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
-    gtk_table_attach(table, label, 0, 1, row, row+1, GTK_FILL, 0, 0, 0);
+    gtk_table_attach(table, label, 0, 1, row, row+1,
+                     GTK_EXPAND | GTK_FILL, 0, 0, 0);
 
     tool->xpx = gtk_label_new("123456 px");
     gtk_widget_size_request(tool->xpx, &req);
@@ -270,7 +273,8 @@ gwy_tool_read_value_init_dialog(GwyToolReadValue *tool)
 
     label = gtk_label_new("Y");
     gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
-    gtk_table_attach(table, label, 0, 1, row, row+1, GTK_FILL, 0, 0, 0);
+    gtk_table_attach(table, label, 0, 1, row, row+1,
+                     GTK_EXPAND | GTK_FILL, 0, 0, 0);
 
     tool->ypx = gtk_label_new(NULL);
     gtk_widget_set_size_request(tool->xpx, req.width, -1);
@@ -284,22 +288,21 @@ gwy_tool_read_value_init_dialog(GwyToolReadValue *tool)
     row++;
 
     gtk_table_attach(table, gwy_label_new_header(_("Value")),
-                     0, 3, row, row+1, GTK_FILL, 0, 0, 0);
+                     0, 3, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
     row++;
 
     label = gtk_label_new("Z");
     gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
-    gtk_table_attach(table, label, 0, 1, row, row+1, GTK_FILL, 0, 0, 0);
+    gtk_table_attach(table, label, 0, 1, row, row+1,
+                     GTK_EXPAND | GTK_FILL, 0, 0, 0);
 
     tool->z = gtk_label_new(NULL);
     gtk_misc_set_alignment(GTK_MISC(tool->z), 1.0, 0.5);
-    gtk_table_attach(table, tool->z,
-                     2, 3, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
+    gtk_table_attach(table, tool->z, 2, 3, row, row+1, GTK_FILL, 0, 0, 0);
     row++;
 
     align = gtk_alignment_new(1.0, 0.5, 0.0, 0.0);
-    gtk_table_attach(table, align,
-                     1, 3, row, row+1, GTK_FILL, 0, 0, 0);
+    gtk_table_attach(table, align, 1, 3, row, row+1, GTK_FILL, 0, 0, 0);
 
     tool->set_zero = gtk_button_new_with_mnemonic(_("Set _Zero"));
     gtk_container_add(GTK_CONTAINER(align), tool->set_zero);
@@ -313,55 +316,55 @@ gwy_tool_read_value_init_dialog(GwyToolReadValue *tool)
     row++;
 
     gtk_table_attach(table, gwy_label_new_header(_("Facet")),
-                     0, 3, row, row+1, GTK_FILL, 0, 0, 0);
+                     0, 3, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
     row++;
 
     label = gtk_label_new(_("Inclination θ"));
     gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
-    gtk_table_attach(table, label, 0, 1, row, row+1, GTK_FILL, 0, 0, 0);
+    gtk_table_attach(table, label, 0, 1, row, row+1,
+                     GTK_EXPAND | GTK_FILL, 0, 0, 0);
 
     tool->theta = gtk_label_new(NULL);
     gtk_misc_set_alignment(GTK_MISC(tool->theta), 1.0, 0.5);
-    gtk_table_attach(table, tool->theta,
-                     2, 3, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
+    gtk_table_attach(table, tool->theta, 2, 3, row, row+1, GTK_FILL, 0, 0, 0);
     row++;
 
     label = gtk_label_new(_("Inclination φ"));
     gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
-    gtk_table_attach(table, label, 0, 1, row, row+1, GTK_FILL, 0, 0, 0);
+    gtk_table_attach(table, label, 0, 1, row, row+1,
+                     GTK_EXPAND | GTK_FILL, 0, 0, 0);
 
     tool->phi = gtk_label_new(NULL);
     gtk_misc_set_alignment(GTK_MISC(tool->phi), 1.0, 0.5);
-    gtk_table_attach(table, tool->phi,
-                     2, 3, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
+    gtk_table_attach(table, tool->phi, 2, 3, row, row+1, GTK_FILL, 0, 0, 0);
     gtk_table_set_row_spacing(table, row, 8);
     row++;
 
     gtk_table_attach(table, gwy_label_new_header(_("Curvatures")),
-                     0, 3, row, row+1, GTK_FILL, 0, 0, 0);
+                     0, 3, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
     row++;
 
     label = gtk_label_new(_("Curvature 1"));
     gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
-    gtk_table_attach(table, label, 0, 1, row, row+1, GTK_FILL, 0, 0, 0);
+    gtk_table_attach(table, label, 0, 1, row, row+1,
+                     GTK_EXPAND | GTK_FILL, 0, 0, 0);
 
     tool->curv1 = gtk_label_new(NULL);
     gtk_misc_set_alignment(GTK_MISC(tool->curv1), 1.0, 0.5);
-    gtk_table_attach(table, tool->curv1,
-                     2, 3, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
+    gtk_table_attach(table, tool->curv1, 2, 3, row, row+1, GTK_FILL, 0, 0, 0);
     row++;
 
     label = gtk_label_new(_("Curvature 2"));
     gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
-    gtk_table_attach(table, label, 0, 1, row, row+1, GTK_FILL, 0, 0, 0);
+    gtk_table_attach(table, label, 0, 1, row, row+1,
+                     GTK_EXPAND | GTK_FILL, 0, 0, 0);
 
     tool->curv2 = gtk_label_new(NULL);
     gtk_misc_set_alignment(GTK_MISC(tool->curv2), 1.0, 0.5);
-    gtk_table_attach(table, tool->curv2,
-                     2, 3, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
+    gtk_table_attach(table, tool->curv2, 2, 3, row, row+1, GTK_FILL, 0, 0, 0);
     row++;
 
-    table = GTK_TABLE(gtk_table_new(2, 4, FALSE));
+    table = GTK_TABLE(gtk_table_new(2, 3, FALSE));
     gtk_table_set_col_spacings(table, 6);
     gtk_table_set_row_spacings(table, 2);
     gtk_container_set_border_width(GTK_CONTAINER(table), 4);
@@ -371,8 +374,9 @@ gwy_tool_read_value_init_dialog(GwyToolReadValue *tool)
 
     tool->radius = gtk_adjustment_new(tool->args.radius,
                                       1, RADIUS_MAX, 1, 5, 0);
-    gwy_table_attach_spinbutton(GTK_WIDGET(table), row,
-                                _("_Averaging radius:"), "px", tool->radius);
+    gwy_table_attach_adjbar(GTK_WIDGET(table), row,
+                            _("_Averaging radius:"), _("px"),
+                            tool->radius, GWY_HSCALE_LINEAR | GWY_HSCALE_SNAP);
     g_signal_connect_swapped(tool->radius, "value-changed",
                              G_CALLBACK(gwy_tool_read_value_radius_changed),
                              tool);
@@ -383,7 +387,7 @@ gwy_tool_read_value_init_dialog(GwyToolReadValue *tool)
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(tool->show_selection),
                                  tool->args.show_selection);
     gtk_table_attach(GTK_TABLE(table), tool->show_selection,
-                     0, 3, row, row+1, GTK_FILL, 0, 0, 0);
+                     0, 2, row, row+1, GTK_FILL, 0, 0, 0);
     g_signal_connect(tool->show_selection, "toggled",
                      G_CALLBACK(gwy_tool_read_value_show_selection_changed),
                              tool);
@@ -400,15 +404,14 @@ static void
 gwy_tool_read_value_data_switched(GwyTool *gwytool,
                                   GwyDataView *data_view)
 {
-    GwyPlainTool *plain_tool;
+    GwyPlainTool *plain_tool = GWY_PLAIN_TOOL(gwytool);
+    GwyContainer *container;
     GwyToolReadValue *tool;
     gboolean ignore;
     gchar xukey[24];
     gchar yukey[24];
     gchar zukey[24];
 
-
-    plain_tool = GWY_PLAIN_TOOL(gwytool);
     ignore = (data_view == plain_tool->data_view);
 
     GWY_TOOL_CLASS(gwy_tool_read_value_parent_class)->data_switched(gwytool,
@@ -419,6 +422,7 @@ gwy_tool_read_value_data_switched(GwyTool *gwytool,
 
     tool = GWY_TOOL_READ_VALUE(gwytool);
     if (data_view) {
+        container = plain_tool->container;
         gwy_object_set_or_reset(plain_tool->layer,
                                 tool->layer_type_point,
                                 "draw-marker", tool->args.show_selection,
@@ -429,19 +433,15 @@ gwy_tool_read_value_data_switched(GwyTool *gwytool,
         gwy_selection_set_max_objects(plain_tool->selection, 1);
         gwy_tool_read_value_update_units(tool);
 
-
         g_snprintf(xukey, sizeof(xukey), "/%d/data/cal_xunc", plain_tool->id);
         g_snprintf(yukey, sizeof(yukey), "/%d/data/cal_yunc", plain_tool->id);
         g_snprintf(zukey, sizeof(zukey), "/%d/data/cal_zunc", plain_tool->id);
 
-        if (gwy_container_gis_object_by_name(plain_tool->container, xukey, &(tool->xunc))
-            && gwy_container_gis_object_by_name(plain_tool->container, yukey, &(tool->yunc))
-            && gwy_container_gis_object_by_name(plain_tool->container, zukey, &(tool->zunc)))
-        {
+        tool->has_calibration = FALSE;
+        if (gwy_container_gis_object_by_name(container, xukey, &tool->xunc)
+            && gwy_container_gis_object_by_name(container, yukey, &tool->yunc)
+            && gwy_container_gis_object_by_name(container, zukey, &tool->zunc))
             tool->has_calibration = TRUE;
-        } else {
-            tool->has_calibration = FALSE;
-        }
     }
 }
 
@@ -461,24 +461,23 @@ gwy_tool_read_value_update_units(GwyToolReadValue *tool)
 static void
 gwy_tool_read_value_data_changed(GwyPlainTool *plain_tool)
 {
+    GwyToolReadValue *tool = GWY_TOOL_READ_VALUE(plain_tool);
+    GwyContainer *container = plain_tool->container;
     gchar xukey[24];
     gchar yukey[24];
     gchar zukey[24];
 
+    tool->has_calibration = FALSE;
     g_snprintf(xukey, sizeof(xukey), "/%d/data/cal_xunc", plain_tool->id);
     g_snprintf(yukey, sizeof(yukey), "/%d/data/cal_yunc", plain_tool->id);
     g_snprintf(zukey, sizeof(zukey), "/%d/data/cal_zunc", plain_tool->id);
 
-    if (gwy_container_gis_object_by_name(plain_tool->container, xukey, &(GWY_TOOL_READ_VALUE(plain_tool)->xunc))
-        && gwy_container_gis_object_by_name(plain_tool->container, yukey, &(GWY_TOOL_READ_VALUE(plain_tool)->yunc))
-        && gwy_container_gis_object_by_name(plain_tool->container, zukey, &(GWY_TOOL_READ_VALUE(plain_tool)->zunc)))
-    {
-        GWY_TOOL_READ_VALUE(plain_tool)->has_calibration = TRUE;
-    } else {
-        GWY_TOOL_READ_VALUE(plain_tool)->has_calibration = FALSE;
-    }
+    if (gwy_container_gis_object_by_name(container, xukey, &tool->xunc)
+        && gwy_container_gis_object_by_name(container, yukey, &tool->yunc)
+        && gwy_container_gis_object_by_name(container, zukey, &tool->zunc))
+        tool->has_calibration = TRUE;
 
-    gwy_tool_read_value_update_values(GWY_TOOL_READ_VALUE(plain_tool));
+    gwy_tool_read_value_update_values(tool);
 }
 
 static void
@@ -503,10 +502,11 @@ gwy_tool_read_value_radius_changed(GwyToolReadValue *tool)
 
     tool->args.radius = gwy_adjustment_get_int(tool->radius);
     plain_tool = GWY_PLAIN_TOOL(tool);
-    if (plain_tool->layer)
+    if (plain_tool->layer) {
         g_object_set(plain_tool->layer,
                      "marker-radius", tool->args.radius,
                      NULL);
+    }
     if (plain_tool->selection)
         gwy_tool_read_value_update_values(tool);
 }
