@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: roughness.c 19071 2016-10-14 09:02:41Z yeti-dn $
+ *  @(#) $Id: roughness.c 20256 2017-08-11 17:27:25Z yeti-dn $
  *  Copyright (C) 2006-2008 Martin Hason, David Necas (Yeti), Petr Klapetek.
  *  E-mail: hasonm@physics.muni.cz, yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -186,9 +186,10 @@ struct _GwyToolRoughness {
 
     GtkObject *thickness;
     GtkObject *cutoff;
+    GtkWidget *cutoff_value;
+    GtkWidget *cutoff_units;
     GtkWidget *interpolation;
     GtkWidget *target_graph;
-    GtkWidget *target_hbox;
 
     GtkBox *aux_box;
     GtkWidget *message_label;
@@ -614,7 +615,7 @@ static GwyModuleInfo module_info = {
     &module_register,
     N_("Calculate surface profile parameters."),
     "Martin Hasoň <hasonm@physics.muni.cz>, Yeti <yeti@gwyddion.net>",
-    "1.13",
+    "1.15",
     "Martin Hasoň & David Nečas (Yeti)",
     "2006",
 };
@@ -624,7 +625,7 @@ static const gchar cutoff_key[]        = "/module/roughness/cutoff";
 static const gchar thickness_key[]     = "/module/roughness/thickness";
 static const gchar expanded_key[]      = "/module/roughness/expanded";
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, roughness)
 
 G_DEFINE_TYPE(GwyToolRoughness, gwy_tool_roughness, GWY_TYPE_PLAIN_TOOL)
 
@@ -778,8 +779,8 @@ gwy_tool_roughness_init_dialog(GwyToolRoughness *tool)
 
     GtkDialog *dialog;
     GtkSizeGroup *sizegroup;
-    GtkWidget *dialog_vbox, *hbox, *vbox_left, *vbox_right, *table, *hbox2;
-    GtkWidget *scwin, *treeview, *spin, *label;
+    GtkWidget *dialog_vbox, *hbox, *vbox_left, *vbox_right, *table;
+    GtkWidget *scwin, *treeview, *spin;
     GwyAxis *axis;
     gint row;
 
@@ -824,7 +825,7 @@ gwy_tool_roughness_init_dialog(GwyToolRoughness *tool)
     g_signal_connect_swapped(tool->copy, "clicked",
                              G_CALLBACK(gwy_tool_roughness_copy), tool);
 
-    table = gtk_table_new(5, 4, FALSE);
+    table = gtk_table_new(6, 3, FALSE);
     gtk_table_set_col_spacings(GTK_TABLE(table), 6);
     gtk_table_set_row_spacings(GTK_TABLE(table), 2);
     gtk_container_set_border_width(GTK_CONTAINER(table), 4);
@@ -835,24 +836,38 @@ gwy_tool_roughness_init_dialog(GwyToolRoughness *tool)
         = gwy_enum_combo_box_new(graph_types, G_N_ELEMENTS(graph_types),
                                  G_CALLBACK(gwy_tool_roughness_graph_changed),
                                  tool, tool->graph_type, TRUE);
-    gwy_table_attach_hscale(table, row, _("_Graph:"), NULL,
-                            GTK_OBJECT(tool->graph_out), GWY_HSCALE_WIDGET);
+    gwy_table_attach_adjbar(table, row, _("_Graph:"), NULL,
+                            GTK_OBJECT(tool->graph_out),
+                            GWY_HSCALE_WIDGET_NO_EXPAND);
     row++;
 
     /* cut-off */
     tool->cutoff = gtk_adjustment_new(tool->args.cutoff,
                                       0.0, 0.3, 0.001, 0.1, 0);
-    spin = gwy_table_attach_hscale(table, row, _("C_ut-off:"), NULL,
+    spin = gwy_table_attach_adjbar(table, row, _("C_ut-off:"), NULL,
                                    tool->cutoff, GWY_HSCALE_DEFAULT);
     gtk_spin_button_set_digits(GTK_SPIN_BUTTON(spin), 4);
     g_signal_connect(tool->cutoff, "value-changed",
                      G_CALLBACK(gwy_tool_roughness_cutoff_changed), tool);
     row++;
 
+    tool->cutoff_value = gtk_label_new(NULL);
+    gtk_misc_set_alignment(GTK_MISC(tool->cutoff_value), 1.0, 0.5);
+    gtk_table_attach(GTK_TABLE(table), tool->cutoff_value,
+                     1, 2, row, row+1, GTK_FILL, 0, 0, 0);
+
+    tool->cutoff_units = gtk_label_new(NULL);
+    gtk_misc_set_alignment(GTK_MISC(tool->cutoff_units), 0.0, 0.5);
+    gtk_table_attach(GTK_TABLE(table), tool->cutoff_units,
+                     2, 3, row, row+1, GTK_FILL, 0, 0, 0);
+    row++;
+
+    gtk_table_set_row_spacing(GTK_TABLE(table), row-1, 8);
     tool->thickness = gtk_adjustment_new(tool->args.thickness,
                                          1, 128, 1, 10, 0);
-    gwy_table_attach_hscale(table, row, _("_Thickness:"), "px",
-                            tool->thickness, GWY_HSCALE_DEFAULT);
+    gwy_table_attach_adjbar(table, row, _("_Thickness:"), _("px"),
+                            tool->thickness,
+                            GWY_HSCALE_DEFAULT | GWY_HSCALE_SNAP);
     g_signal_connect(tool->thickness, "value-changed",
                      G_CALLBACK(gwy_tool_roughness_thickness_changed), tool);
     row++;
@@ -861,26 +876,20 @@ gwy_tool_roughness_init_dialog(GwyToolRoughness *tool)
                            (gwy_interpolation_type_get_enum(), -1,
                             G_CALLBACK(gwy_tool_roughness_interpolation_changed),
                             tool, tool->args.interpolation, TRUE);
-    gwy_table_attach_hscale(table, row, _("_Interpolation type:"), NULL,
-                            GTK_OBJECT(tool->interpolation), GWY_HSCALE_WIDGET);
+    gwy_table_attach_adjbar(table, row, _("_Interpolation type:"), NULL,
+                            GTK_OBJECT(tool->interpolation),
+                            GWY_HSCALE_WIDGET_NO_EXPAND);
     row++;
 
-    tool->target_hbox = hbox2 = gtk_hbox_new(FALSE, 6);
-    gtk_table_attach(GTK_TABLE(table), hbox2,
-                     0, 3, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
-
-    label = gtk_label_new_with_mnemonic(_("Target _graph:"));
-    gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
-    gtk_box_pack_start(GTK_BOX(hbox2), label, FALSE, FALSE, 0);
-
     tool->target_graph = gwy_data_chooser_new_graphs();
     gwy_data_chooser_set_none(GWY_DATA_CHOOSER(tool->target_graph),
                               _("New graph"));
     gwy_data_chooser_set_active(GWY_DATA_CHOOSER(tool->target_graph), NULL, -1);
     gwy_data_chooser_set_filter(GWY_DATA_CHOOSER(tool->target_graph),
                                 filter_target_graphs, tool, NULL);
-    gtk_label_set_mnemonic_widget(GTK_LABEL(label), tool->target_graph);
-    gtk_box_pack_end(GTK_BOX(hbox2), tool->target_graph, FALSE, FALSE, 0);
+    gwy_table_attach_adjbar(table, row, _("Target _graph:"), NULL,
+                            GTK_OBJECT(tool->target_graph),
+                            GWY_HSCALE_WIDGET_NO_EXPAND);
     g_signal_connect_swapped(tool->target_graph, "changed",
                              G_CALLBACK(gwy_tool_roughness_target_changed),
                              tool);
@@ -1154,6 +1163,12 @@ gwy_tool_roughness_data_switched(GwyTool *gwytool,
                                 NULL);
         gwy_selection_set_max_objects(plain_tool->selection, 1);
         gwy_tool_roughness_update_units(tool);
+        gtk_label_set_markup(GTK_LABEL(tool->cutoff_units),
+                             plain_tool->coord_format->units);
+    }
+    else {
+        gtk_label_set_markup(GTK_LABEL(tool->cutoff_value), NULL);
+        gtk_label_set_markup(GTK_LABEL(tool->cutoff_units), NULL);
     }
 
     gwy_tool_roughness_update(tool);
@@ -1183,7 +1198,9 @@ gwy_tool_roughness_selection_changed(GwyPlainTool *plain_tool,
 
     if (plain_tool->selection) {
         n = gwy_selection_get_data(plain_tool->selection, NULL);
-        g_return_if_fail(n == 0 || n == 1);
+        /* We can get here before set-max-objects takes effect. */
+        if (!(n == 0 || n == 1))
+            return;
     }
 
     gwy_tool_roughness_update(tool);
@@ -1312,16 +1329,21 @@ gwy_tool_roughness_update(GwyToolRoughness *tool)
     gdouble line[4];
     gint xl1, yl1, xl2, yl2;
     gint n, lineres;
+    gdouble dx;
+    gchar buf[24];
 
     plain_tool = GWY_PLAIN_TOOL(tool);
     if (!plain_tool->selection
         || !(n = gwy_selection_get_data(plain_tool->selection, NULL))) {
         tool->have_data = FALSE;
         gwy_tool_roughness_update_graphs(tool);
-        gtk_tree_model_foreach(GTK_TREE_MODEL(tool->store),
-                               emit_row_changed, NULL);
+        if (tool->store) {
+            gtk_tree_model_foreach(GTK_TREE_MODEL(tool->store),
+                                   emit_row_changed, NULL);
+        }
         gtk_label_set_text(GTK_LABEL(tool->message_label),
                            _("No profile selected."));
+        gtk_label_set_text(GTK_LABEL(tool->cutoff_value), NULL);
         return;
     }
 
@@ -1346,6 +1368,11 @@ gwy_tool_roughness_update(GwyToolRoughness *tool)
                                                 lineres,
                                                 tool->args.thickness,
                                                 tool->args.interpolation);
+    dx = gwy_data_line_get_real(tool->dataline)/gwy_data_line_get_res(tool->dataline);
+    g_snprintf(buf, sizeof(buf), "%.*f",
+               plain_tool->coord_format->precision+1,
+               2*dx/tool->args.cutoff/plain_tool->coord_format->magnitude);
+    gtk_label_set_text(GTK_LABEL(tool->cutoff_value), buf);
 
     gwy_tool_roughness_set_data_from_profile(&tool->profiles,
                                              tool->dataline,
