@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: selectionmanager.c 19039 2016-10-08 10:54:58Z yeti-dn $
+ *  @(#) $Id: selectionmanager.c 19948 2017-06-22 14:05:41Z yeti-dn $
  *  Copyright (C) 2009,2012 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
@@ -149,7 +149,7 @@ static const ToolArgs default_args = {
     FALSE,
 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, selectionmanager)
 
 G_DEFINE_TYPE(GwyToolSelectionManager, gwy_tool_selection_manager, GWY_TYPE_PLAIN_TOOL)
 
