@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: sfunctions.c 19095 2016-10-17 09:26:16Z yeti-dn $
+ *  @(#) $Id: sfunctions.c 20099 2017-07-29 03:58:05Z yeti-dn $
  *  Copyright (C) 2003-2016 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -55,6 +55,8 @@ typedef enum {
     GWY_SF_RPSDF                  = 10,
     GWY_SF_RACF                   = 11,
     GWY_SF_RANGE                  = 12,
+    GWY_SF_ASG                    = 13,
+    GWY_SF_NFUNCTIONS
 } GwySFOutputType;
 
 enum {
@@ -87,6 +89,9 @@ struct _GwyToolSFunctions {
 
     GwyDataLine *line;
 
+    GwyDataField *cached_flipped_field;
+    GwyDataField *cached_fp_mask; /* Always INCLUDE, possibly flipped. */
+
     GtkWidget *graph;
     GwyGraphModel *gmodel;
 
@@ -97,14 +102,12 @@ struct _GwyToolSFunctions {
     GtkObject *resolution;
     GtkWidget *fixres;
     GtkWidget *interpolation;
-    GtkWidget *interpolation_label;
     GtkWidget *update;
     GtkWidget *apply;
     GtkWidget *separate;
     GSList *masking;
     GtkWidget *masking_label;
     GtkWidget *target_graph;
-    GtkWidget *target_hbox;
 
     gboolean has_calibration;
     gboolean has_uline;
@@ -172,8 +175,10 @@ static void     gwy_data_field_area_range                 (GwyDataField *dfield,
                                                            gint lineres);
 static void     update_unc_fields                         (GwyPlainTool *plain_tool);
 static gboolean sfunction_supports_masking                (GwySFOutputType type);
-static gboolean sfunction_has_explicit_resampling         (GwySFOutputType type);
+static gboolean sfunction_has_native_sampling             (GwySFOutputType type);
+static gboolean sfunction_has_interpolation               (GwySFOutputType type);
 static gboolean sfunction_has_direction                   (GwySFOutputType type);
+static gboolean sfunction_is_only_row_wise                (GwySFOutputType type);
 
 static GwyModuleInfo module_info = {
     GWY_MODULE_ABI_VERSION,
@@ -182,7 +187,7 @@ static GwyModuleInfo module_info = {
        "functions (height distribution, correlations, PSDF, Minkowski "
        "functionals) of selected part of data."),
     "Petr Klapetek <klapetek@gwyddion.net>",
-    "2.15",
+    "2.18",
     "David Nečas (Yeti) & Petr Klapetek",
     "2004",
 };
@@ -224,9 +229,10 @@ static const GwyEnum sf_types[] =  {
     { N_("Minkowski boundary"),          GWY_SF_MINKOWSKI_BOUNDARY,     },
     { N_("Minkowski connectivity"),      GWY_SF_MINKOWSKI_CONNECTIVITY, },
     { N_("Range"),                       GWY_SF_RANGE,                  },
+    { N_("Area scale graph"),            GWY_SF_ASG,                    },
 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, sfunctions)
 
 G_DEFINE_TYPE(GwyToolSFunctions, gwy_tool_sfunctions, GWY_TYPE_PLAIN_TOOL)
 
@@ -294,6 +300,8 @@ gwy_tool_sfunctions_finalize(GObject *object)
     GWY_OBJECT_UNREF(tool->xunc);
     GWY_OBJECT_UNREF(tool->yunc);
     GWY_OBJECT_UNREF(tool->zunc);
+    GWY_OBJECT_UNREF(tool->cached_flipped_field);
+    GWY_OBJECT_UNREF(tool->cached_fp_mask);
 
     G_OBJECT_CLASS(gwy_tool_sfunctions_parent_class)->finalize(object);
 }
@@ -319,6 +327,8 @@ gwy_tool_sfunctions_init(GwyToolSFunctions *tool)
                                    &tool->args.masking);
     gwy_container_gis_enum_by_name(settings, output_type_key,
                                    &tool->args.output_type);
+    tool->args.output_type = CLAMP(tool->args.output_type,
+                                   0, GWY_SF_NFUNCTIONS);
     gwy_container_gis_boolean_by_name(settings, options_visible_key,
                                       &tool->args.options_visible);
     gwy_container_gis_boolean_by_name(settings, instant_update_key,
@@ -419,7 +429,7 @@ gwy_tool_sfunctions_init_dialog(GwyToolSFunctions *tool)
                      G_CALLBACK(gwy_tool_sfunctions_options_expanded), tool);
     gtk_box_pack_start(GTK_BOX(vbox), tool->options, FALSE, FALSE, 0);
 
-    table = GTK_TABLE(gtk_table_new(10, 4, FALSE));
+    table = GTK_TABLE(gtk_table_new(10, 3, FALSE));
     gtk_table_set_col_spacings(table, 6);
     gtk_table_set_row_spacings(table, 2);
     gtk_container_set_border_width(GTK_CONTAINER(table), 4);
@@ -429,7 +439,7 @@ gwy_tool_sfunctions_init_dialog(GwyToolSFunctions *tool)
     tool->instant_update
         = gtk_check_button_new_with_mnemonic(_("_Instant updates"));
     gtk_table_attach(table, tool->instant_update,
-                     0, 3, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
+                     0, 2, row, row+1, GTK_FILL, 0, 0, 0);
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(tool->instant_update),
                                  tool->args.instant_update);
     g_signal_connect(tool->instant_update, "toggled",
@@ -440,7 +450,8 @@ gwy_tool_sfunctions_init_dialog(GwyToolSFunctions *tool)
     tool->resolution = gtk_adjustment_new(tool->args.resolution,
                                           MIN_RESOLUTION, MAX_RESOLUTION,
                                           1, 10, 0);
-    gwy_table_attach_hscale(GTK_WIDGET(table), row, _("_Fix res.:"), NULL,
+    gwy_table_attach_adjbar(GTK_WIDGET(table), row,
+                            _("_Fixed resolution:"), NULL,
                             tool->resolution,
                             GWY_HSCALE_CHECK | GWY_HSCALE_SQRT);
     g_signal_connect_swapped(tool->resolution, "value-changed",
@@ -458,43 +469,29 @@ gwy_tool_sfunctions_init_dialog(GwyToolSFunctions *tool)
                         (directions, G_N_ELEMENTS(directions),
                         G_CALLBACK(gwy_tool_sfunctions_direction_changed), tool,
                         tool->args.direction);
-    row = gwy_radio_buttons_attach_to_table(tool->direction, table, 3, row);
+    row = gwy_radio_buttons_attach_to_table(tool->direction, table, 2, row);
     gtk_table_set_row_spacing(table, row-1, 8);
 
-    hbox2 = gtk_hbox_new(FALSE, 4);
-    gtk_table_attach(table, hbox2,
-                     0, 3, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
-
-    label = gtk_label_new_with_mnemonic(_("_Interpolation type:"));
-    gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
-    gtk_box_pack_start(GTK_BOX(hbox2), label, FALSE, FALSE, 0);
-    tool->interpolation_label = label;
-
     tool->interpolation = gwy_enum_combo_box_new
                          (gwy_interpolation_type_get_enum(), -1,
                           G_CALLBACK(gwy_tool_sfunctions_interpolation_changed),
                           tool,
                           tool->args.interpolation, TRUE);
-    gtk_label_set_mnemonic_widget(GTK_LABEL(label), tool->interpolation);
-    gtk_box_pack_end(GTK_BOX(hbox2), tool->interpolation, FALSE, FALSE, 0);
+    gwy_table_attach_adjbar(GTK_WIDGET(table), row,
+                            _("_Interpolation type:"), NULL,
+                            GTK_OBJECT(tool->interpolation),
+                            GWY_HSCALE_WIDGET_NO_EXPAND);
     row++;
 
-    tool->target_hbox = hbox2 = gtk_hbox_new(FALSE, 6);
-    gtk_table_attach(table, hbox2,
-                     0, 3, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
-
-    label = gtk_label_new_with_mnemonic(_("Target _graph:"));
-    gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
-    gtk_box_pack_start(GTK_BOX(hbox2), label, FALSE, FALSE, 0);
-
     tool->target_graph = gwy_data_chooser_new_graphs();
     gwy_data_chooser_set_none(GWY_DATA_CHOOSER(tool->target_graph),
                               _("New graph"));
     gwy_data_chooser_set_active(GWY_DATA_CHOOSER(tool->target_graph), NULL, -1);
     gwy_data_chooser_set_filter(GWY_DATA_CHOOSER(tool->target_graph),
                                 filter_target_graphs, tool, NULL);
-    gtk_label_set_mnemonic_widget(GTK_LABEL(label), tool->target_graph);
-    gtk_box_pack_end(GTK_BOX(hbox2), tool->target_graph, FALSE, FALSE, 0);
+    gwy_table_attach_adjbar(GTK_WIDGET(table), row, _("Target _graph:"), NULL,
+                            GTK_OBJECT(tool->target_graph),
+                            GWY_HSCALE_WIDGET_NO_EXPAND);
     g_signal_connect_swapped(tool->target_graph, "changed",
                              G_CALLBACK(gwy_tool_sfunctions_target_changed),
                              tool);
@@ -507,7 +504,7 @@ gwy_tool_sfunctions_init_dialog(GwyToolSFunctions *tool)
     g_signal_connect(tool->separate, "toggled",
                      G_CALLBACK(gwy_tool_sfunctions_separate_changed), tool);
     gtk_table_attach(table, tool->separate,
-                     0, 3, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
+                     0, 2, row, row+1, GTK_FILL, 0, 0, 0);
 
     row++;
 
@@ -515,7 +512,7 @@ gwy_tool_sfunctions_init_dialog(GwyToolSFunctions *tool)
     gtk_table_set_row_spacing(table, row-1, 8);
     label = tool->masking_label = gwy_label_new_header(_("Masking Mode"));
     gtk_table_attach(table, label,
-                     0, 3, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
+                     0, 2, row, row+1, GTK_FILL, 0, 0, 0);
     row++;
 
     tool->masking
@@ -523,7 +520,7 @@ gwy_tool_sfunctions_init_dialog(GwyToolSFunctions *tool)
                                    G_CALLBACK(gwy_tool_sfunctions_masking_changed),
                                    tool,
                                    tool->args.masking);
-    row = gwy_radio_buttons_attach_to_table(tool->masking, table, 3, row);
+    row = gwy_radio_buttons_attach_to_table(tool->masking, table, 2, row);
 
     tool->gmodel = gwy_graph_model_new();
 
@@ -565,6 +562,9 @@ gwy_tool_sfunctions_data_switched(GwyTool *gwytool,
         return;
 
     tool = GWY_TOOL_SFUNCTIONS(gwytool);
+    GWY_OBJECT_UNREF(tool->cached_flipped_field);
+    GWY_OBJECT_UNREF(tool->cached_fp_mask);
+
     if (data_view) {
         gwy_object_set_or_reset(plain_tool->layer,
                                 tool->layer_type_rect,
@@ -595,9 +595,12 @@ gwy_tool_sfunctions_response(GwyTool *tool,
 static void
 gwy_tool_sfunctions_data_changed(GwyPlainTool *plain_tool)
 {
+    GwyToolSFunctions *tool = GWY_TOOL_SFUNCTIONS(plain_tool);
+
+    GWY_OBJECT_UNREF(tool->cached_flipped_field);
     update_unc_fields(plain_tool);
-    gwy_tool_sfunctions_update_curve(GWY_TOOL_SFUNCTIONS(plain_tool));
-    gwy_tool_sfunctions_update_target_graphs(GWY_TOOL_SFUNCTIONS(plain_tool));
+    gwy_tool_sfunctions_update_curve(tool);
+    gwy_tool_sfunctions_update_target_graphs(tool);
 }
 
 static void
@@ -605,6 +608,7 @@ gwy_tool_sfunctions_mask_changed(GwyPlainTool *plain_tool)
 {
     GwyToolSFunctions *tool = GWY_TOOL_SFUNCTIONS(plain_tool);
 
+    GWY_OBJECT_UNREF(tool->cached_fp_mask);
     if (sfunction_supports_masking(tool->args.output_type))
         gwy_tool_sfunctions_update_curve(tool);
 }
@@ -637,22 +641,23 @@ gwy_tool_sfunctions_selection_changed(GwyPlainTool *plain_tool,
 static void
 gwy_tool_sfunctions_update_sensitivity(GwyToolSFunctions *tool)
 {
+    ToolArgs *args = &tool->args;
     gboolean sensitive;
     GSList *l;
 
-    gtk_widget_set_sensitive(tool->update, !tool->args.instant_update);
-    gwy_table_hscale_set_sensitive(tool->resolution, tool->args.fixres);
+    gtk_widget_set_sensitive(tool->update, !args->instant_update);
+    sensitive = !sfunction_has_native_sampling(args->output_type);
+    gwy_table_hscale_set_sensitive(tool->resolution, sensitive);
 
-    sensitive = (sfunction_has_explicit_resampling(tool->args.output_type)
-                 && tool->args.fixres);
-    gtk_widget_set_sensitive(tool->interpolation, sensitive);
-    gtk_widget_set_sensitive(tool->interpolation_label, sensitive);
+    sensitive = (sfunction_has_interpolation(args->output_type)
+                 && args->fixres);
+    gwy_table_hscale_set_sensitive(GTK_OBJECT(tool->interpolation), sensitive);
 
-    sensitive = sfunction_has_direction(tool->args.output_type);
+    sensitive = sfunction_has_direction(args->output_type);
     for (l = tool->direction; l; l = g_slist_next(l))
         gtk_widget_set_sensitive(GTK_WIDGET(l->data), sensitive);
 
-    sensitive = sfunction_supports_masking(tool->args.output_type);
+    sensitive = sfunction_supports_masking(args->output_type);
     gtk_widget_set_sensitive(tool->masking_label, sensitive);
     for (l = tool->masking; l; l = g_slist_next(l))
         gtk_widget_set_sensitive(GTK_WIDGET(l->data), sensitive);
@@ -662,7 +667,7 @@ static void
 gwy_tool_sfunctions_update_curve(GwyToolSFunctions *tool)
 {
     GwyPlainTool *plain_tool;
-    GwyDataField *dfield, *mask, *tmp_mask = NULL;
+    GwyDataField *dfield, *mask, *mask_to_use = NULL, *field_to_use;
     GwyOrientation dir = tool->args.direction;
     GwyInterpolationType interp = tool->args.interpolation;
     GwyGraphModel *gmodel = tool->gmodel;
@@ -671,6 +676,7 @@ gwy_tool_sfunctions_update_curve(GwyToolSFunctions *tool)
     gint isel[4] = { sizeof("Die, die, GCC!"), 0, 0, 0 };
     gint n, nsel, lineres, w = sizeof("Die, die, GCC!"), h = 0;
     const gchar *title, *xlabel, *ylabel;
+    gboolean xy_is_flipped;
 
     plain_tool = GWY_PLAIN_TOOL(tool);
     dfield = plain_tool->data_field;
@@ -712,24 +718,51 @@ gwy_tool_sfunctions_update_curve(GwyToolSFunctions *tool)
 
     tool->has_uline = FALSE;
     lineres = tool->args.fixres ? tool->args.resolution : -1;
-    if (sfunction_supports_masking(tool->args.output_type) && mask) {
-        if (tool->args.masking == GWY_MASK_EXCLUDE) {
-            tmp_mask = gwy_data_field_duplicate(mask);
-            gwy_data_field_grains_invert(tmp_mask);
+
+    /* Create transformed/inverted mask as necesary and remember it.  Keep
+     * mask_to_use as NULL if we do not want masking.  */
+    if (sfunction_supports_masking(tool->args.output_type)
+        && tool->args.masking != GWY_MASK_IGNORE
+        && mask) {
+        if (!tool->cached_fp_mask) {
+            if (sfunction_is_only_row_wise(tool->args.output_type)
+                && tool->args.direction == GWY_ORIENTATION_VERTICAL) {
+                tool->cached_fp_mask = gwy_data_field_new_alike(mask, FALSE);
+                gwy_data_field_flip_xy(mask, tool->cached_fp_mask, FALSE);
+            }
+            else
+                tool->cached_fp_mask = gwy_data_field_duplicate(mask);
+
+            if (tool->args.masking == GWY_MASK_EXCLUDE)
+                gwy_data_field_grains_invert(tool->cached_fp_mask);
         }
-        else if (tool->args.masking == GWY_MASK_INCLUDE)
-            tmp_mask = g_object_ref(mask);
-        /* Otherwise keep tmp_mask as NULL. */
+        mask_to_use = tool->cached_fp_mask;
+    }
+
+    field_to_use = dfield;
+    xy_is_flipped = FALSE;
+    if (sfunction_is_only_row_wise(tool->args.output_type)
+        && tool->args.direction == GWY_ORIENTATION_VERTICAL) {
+        if (!tool->cached_flipped_field) {
+            tool->cached_flipped_field = gwy_data_field_new_alike(dfield,
+                                                                  FALSE);
+            gwy_data_field_flip_xy(dfield, tool->cached_flipped_field, FALSE);
+        }
+        field_to_use = tool->cached_flipped_field;
+        xy_is_flipped = TRUE;
+        GWY_SWAP(gint, isel[0], isel[1]);
+        GWY_SWAP(gint, w, h);
     }
 
     switch (tool->args.output_type) {
         case GWY_SF_DH:
-        gwy_data_field_area_dh(dfield, tmp_mask, tool->line,
+        gwy_data_field_area_dh(field_to_use, mask_to_use, tool->line,
                                isel[0], isel[1], w, h, lineres);
         xlabel = "z";
         ylabel = "ρ";
         if (tool->has_calibration) {
-            gwy_data_field_area_dh_uncertainty(dfield, tool->zunc, tmp_mask,
+            gwy_data_field_area_dh_uncertainty(field_to_use, tool->zunc,
+                                               mask_to_use,
                                                tool->uline,
                                                isel[0], isel[1], w, h,
                                                lineres);
@@ -738,12 +771,13 @@ gwy_tool_sfunctions_update_curve(GwyToolSFunctions *tool)
         break;
 
         case GWY_SF_CDH:
-        gwy_data_field_area_cdh(dfield, tmp_mask, tool->line,
+        gwy_data_field_area_cdh(field_to_use, mask_to_use, tool->line,
                                 isel[0], isel[1], w, h, lineres);
         xlabel = "z";
         ylabel = "D";
         if (tool->has_calibration) {
-            gwy_data_field_area_cdh_uncertainty(dfield, tool->zunc, tmp_mask,
+            gwy_data_field_area_cdh_uncertainty(field_to_use,
+                                                tool->zunc, mask_to_use,
                                                 tool->uline,
                                                 isel[0], isel[1], w, h,
                                                 lineres);
@@ -752,26 +786,30 @@ gwy_tool_sfunctions_update_curve(GwyToolSFunctions *tool)
         break;
 
         case GWY_SF_DA:
-        gwy_data_field_area_da(dfield, tool->line, isel[0], isel[1], w, h,
-                               dir, lineres);
+        gwy_data_field_area_da_mask(field_to_use, mask_to_use, tool->line,
+                                    isel[0], isel[1], w, h, dir, lineres);
         xlabel = "tan β";
         ylabel = "ρ";
         break;
 
         case GWY_SF_CDA:
-        gwy_data_field_area_cda(dfield, tool->line, isel[0], isel[1], w, h,
-                                dir, lineres);
+        gwy_data_field_area_cda_mask(field_to_use, mask_to_use, tool->line,
+                                     isel[0], isel[1], w, h, dir, lineres);
         xlabel = "tan β";
         ylabel = "D";
         break;
 
         case GWY_SF_ACF:
-        gwy_data_field_area_acf(dfield, tool->line, isel[0], isel[1], w, h,
-                                dir, interp, lineres);
+        g_object_unref(tool->line);
+        tool->line = gwy_data_field_area_row_acf(field_to_use,
+                                                 mask_to_use, GWY_MASK_INCLUDE,
+                                                 isel[0], isel[1], w, h, 1,
+                                                 NULL);
         xlabel = "τ";
         ylabel = "G";
-        if (tool->has_calibration) {
-            gwy_data_field_area_acf_uncertainty(dfield, tool->zunc, tool->uline,
+        if (tool->has_calibration && !xy_is_flipped) {
+            gwy_data_field_area_acf_uncertainty(field_to_use,
+                                                tool->zunc, tool->uline,
                                                 isel[0], isel[1], w, h,
                                                 dir, interp, lineres);
             tool->has_uline = TRUE;
@@ -779,12 +817,16 @@ gwy_tool_sfunctions_update_curve(GwyToolSFunctions *tool)
         break;
 
         case GWY_SF_HHCF:
-        gwy_data_field_area_hhcf(dfield, tool->line, isel[0], isel[1], w, h,
-                                 dir, interp, lineres);
+        g_object_unref(tool->line);
+        tool->line = gwy_data_field_area_row_hhcf(field_to_use,
+                                                  mask_to_use, GWY_MASK_INCLUDE,
+                                                  isel[0], isel[1], w, h, 1,
+                                                  NULL);
         xlabel = "τ";
         ylabel = "H";
-        if (tool->has_calibration) {
-            gwy_data_field_area_hhcf_uncertainty(dfield, tool->zunc, tool->uline,
+        if (tool->has_calibration && !xy_is_flipped) {
+            gwy_data_field_area_hhcf_uncertainty(field_to_use,
+                                                 tool->zunc, tool->uline,
                                                  isel[0], isel[1], w, h,
                                                  dir, interp, lineres);
             tool->has_uline = TRUE;
@@ -792,59 +834,73 @@ gwy_tool_sfunctions_update_curve(GwyToolSFunctions *tool)
         break;
 
         case GWY_SF_PSDF:
-        gwy_data_field_area_psdf(dfield, tool->line, isel[0], isel[1], w, h,
-                                 dir, interp, GWY_WINDOWING_HANN, lineres);
+        g_object_unref(tool->line);
+        tool->line = gwy_data_field_area_row_psdf(field_to_use,
+                                                  mask_to_use, GWY_MASK_INCLUDE,
+                                                  isel[0], isel[1], w, h,
+                                                  GWY_WINDOWING_HANN, 1);
         xlabel = "k";
         ylabel = "W<sub>1</sub>";
         break;
 
         case GWY_SF_MINKOWSKI_VOLUME:
-        gwy_data_field_area_minkowski_volume(dfield, tool->line,
+        gwy_data_field_area_minkowski_volume(field_to_use, tool->line,
                                              isel[0], isel[1], w, h, lineres);
         xlabel = "z";
         ylabel = "V";
         break;
 
         case GWY_SF_MINKOWSKI_BOUNDARY:
-        gwy_data_field_area_minkowski_boundary(dfield, tool->line,
+        gwy_data_field_area_minkowski_boundary(field_to_use, tool->line,
                                                isel[0], isel[1], w, h, lineres);
         xlabel = "z";
         ylabel = "S";
         break;
 
         case GWY_SF_MINKOWSKI_CONNECTIVITY:
-        gwy_data_field_area_minkowski_euler(dfield, tool->line,
+        gwy_data_field_area_minkowski_euler(field_to_use, tool->line,
                                             isel[0], isel[1], w, h, lineres);
         xlabel = "z";
         ylabel = "χ";
         break;
 
         case GWY_SF_RPSDF:
-        gwy_data_field_area_rpsdf(dfield, tool->line, isel[0], isel[1], w, h,
+        gwy_data_field_area_rpsdf(field_to_use, tool->line,
+                                  isel[0], isel[1], w, h,
                                   interp, GWY_WINDOWING_HANN, lineres);
         xlabel = "k";
         ylabel = "W<sub>r</sub>";
         break;
 
         case GWY_SF_RACF:
-        gwy_data_field_area_racf(dfield, tool->line, isel[0], isel[1], w, h,
+        gwy_data_field_area_racf(field_to_use, tool->line,
+                                 isel[0], isel[1], w, h,
                                  lineres);
         xlabel = "τ";
         ylabel = "G<sub>r</sub>";
         break;
 
         case GWY_SF_RANGE:
-        gwy_data_field_area_range(dfield, tool->line, isel[0], isel[1], w, h,
+        gwy_data_field_area_range(field_to_use, tool->line,
+                                  isel[0], isel[1], w, h,
                                   dir, interp, lineres);
         xlabel = "τ";
         ylabel = "R";
         break;
 
+        case GWY_SF_ASG:
+        g_object_unref(tool->line);
+        tool->line = gwy_data_field_area_row_asg(field_to_use,
+                                                 mask_to_use, GWY_MASK_INCLUDE,
+                                                 isel[0], isel[1], w, h, 1);
+        xlabel = "τ";
+        ylabel = "A<sub>excess</sub>";
+        break;
+
         default:
         g_return_if_reached();
         break;
     }
-    GWY_OBJECT_UNREF(tmp_mask);
 
     if (nsel > 0 && n == 0) {
         gcmodel = gwy_graph_curve_model_new();
@@ -942,6 +998,7 @@ gwy_tool_sfunctions_direction_changed(G_GNUC_UNUSED GObject *button,
                                       GwyToolSFunctions *tool)
 {
     tool->args.direction = gwy_radio_buttons_get_current(tool->direction);
+    GWY_OBJECT_UNREF(tool->cached_fp_mask);
     gwy_tool_sfunctions_update_curve(tool);
 }
 
@@ -979,6 +1036,7 @@ gwy_tool_sfunctions_masking_changed(GtkWidget *button,
 
     plain_tool = GWY_PLAIN_TOOL(tool);
     tool->args.masking = gwy_radio_button_get_value(button);
+    GWY_OBJECT_UNREF(tool->cached_fp_mask);
     if (plain_tool->data_field && plain_tool->mask_field)
         gwy_tool_sfunctions_update_curve(tool);
 }
@@ -1172,22 +1230,40 @@ update_unc_fields(GwyPlainTool *plain_tool)
 static gboolean
 sfunction_supports_masking(GwySFOutputType type)
 {
-    return (type == GWY_SF_DH || type == GWY_SF_CDH);
+    return (type == GWY_SF_DH || type == GWY_SF_CDH
+            || type == GWY_SF_DA || type == GWY_SF_CDA
+            || type == GWY_SF_ACF || type == GWY_SF_HHCF || type == GWY_SF_ASG
+            || type == GWY_SF_PSDF);
 }
 
 static gboolean
-sfunction_has_explicit_resampling(GwySFOutputType type)
+sfunction_has_native_sampling(GwySFOutputType type)
 {
-    return (type == GWY_SF_ACF || type == GWY_SF_HHCF
-            || type == GWY_SF_PSDF || type == GWY_SF_RPSDF
+    return (type == GWY_SF_ACF || type == GWY_SF_HHCF || type == GWY_SF_ASG
+            || type == GWY_SF_PSDF
             || type == GWY_SF_RANGE);
 }
 
+static gboolean
+sfunction_has_interpolation(GwySFOutputType type)
+{
+    /* RACF has no interpolation argument and all the other related functions
+     * have native sampling so we do not want interpolation. */
+    return (type == GWY_SF_RPSDF);
+}
+
 static gboolean
 sfunction_has_direction(GwySFOutputType type)
 {
     return (type == GWY_SF_DA || type == GWY_SF_CDA
-            || type == GWY_SF_ACF || type == GWY_SF_HHCF
+            || type == GWY_SF_ACF || type == GWY_SF_HHCF || type == GWY_SF_ASG
+            || type == GWY_SF_PSDF);
+}
+
+static gboolean
+sfunction_is_only_row_wise(GwySFOutputType type)
+{
+    return (type == GWY_SF_ACF || type == GWY_SF_HHCF || type == GWY_SF_ASG
             || type == GWY_SF_PSDF);
 }
 
