@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: spectro.c 19039 2016-10-08 10:54:58Z yeti-dn $
+ *  @(#) $Id: spectro.c 20071 2017-07-12 07:49:00Z yeti-dn $
  *  Copyright (C) 2003-2014 Owain Davies, David Necas (Yeti), Petr Klapetek.
  *  E-mail: owain.davies@blueyonder.co.uk, yeti@gwyddion.net,
  *          klapetek@gwyddion.net.
@@ -71,6 +71,7 @@ struct _GwyToolSpectro {
     GtkTreeModel *model;
 
     GwyDataLine *line;
+    GwyDataLine *weights;
     GtkWidget *graph;
     GwyGraphModel *gmodel;
     GwySpectra *spectra;
@@ -119,8 +120,10 @@ static void     gwy_tool_spectro_show_curve          (GwyToolSpectro *tool,
                                                       gint i);
 static void     gwy_tool_spectro_gather_curve        (GwyToolSpectro *tool,
                                                       gint i);
-static void     gwy_tool_spectro_show_averaged       (GwyToolSpectro *tool,
-                                                      guint nsel);
+static void     accumulate_lines                     (GwyDataLine *accum,
+                                                      GwyDataLine *dline,
+                                                      GwyDataLine *weights);
+static void     gwy_tool_spectro_show_averaged       (GwyToolSpectro *tool);
 static void     gwy_tool_spectro_update_header       (GwyToolSpectro *tool,
                                                       guint col,
                                                       GString *str,
@@ -150,7 +153,7 @@ static GwyModuleInfo module_info = {
     &module_register,
     N_("Point Spectrum, extracts point spectra to a graph."),
     "Owain Davies <owain.davies@blueyonder.co.uk>",
-    "0.10",
+    "0.11",
     "Owain Davies, David Nečas (Yeti) & Petr Klapetek",
     "2006",
 };
@@ -166,7 +169,7 @@ static const ToolArgs default_args = {
     GWY_APP_DATA_ID_NONE,
 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, spectro)
 
 G_DEFINE_TYPE(GwyToolSpectro, gwy_tool_spectro, GWY_TYPE_PLAIN_TOOL)
 
@@ -650,7 +653,7 @@ gwy_tool_spectro_tree_sel_changed(GtkTreeSelection *selection,
     }
 
     if (tool->args.average && nsel)
-        gwy_tool_spectro_show_averaged(tool, nsel);
+        gwy_tool_spectro_show_averaged(tool);
 }
 
 static void
@@ -739,33 +742,73 @@ gwy_tool_spectro_gather_curve(GwyToolSpectro *tool,
 {
     GwyPlainTool *plain_tool;
     GwyDataLine *spectrum;
-    gint i, n;
 
     plain_tool = GWY_PLAIN_TOOL(tool);
     g_return_if_fail(plain_tool->selection);
 
     spectrum = gwy_spectra_get_spectrum(tool->spectra, id);
-    if (!tool->line)
+    if (!tool->line) {
+        /* Use the first selected line as the template. */
         tool->line = gwy_data_line_duplicate(spectrum);
+        tool->weights = gwy_data_line_new_alike(spectrum, TRUE);
+        gwy_data_line_fill(tool->weights, 1.0);
+    }
     else {
-        gdouble *sdata, *data;
-
+        /* Accumulate the others. */
         g_return_if_fail(tool->line);
-        n = gwy_data_line_get_res(tool->line);
-        g_return_if_fail(gwy_data_line_get_res(spectrum) == n);
-        sdata = gwy_data_line_get_data(spectrum);
-        data = gwy_data_line_get_data(tool->line);
-        for (i = 0; i < n; i++)
-            data[i] += sdata[i];
+        g_return_if_fail(tool->weights);
+        accumulate_lines(tool->line, spectrum, tool->weights);
     }
 }
 
 static void
-gwy_tool_spectro_show_averaged(GwyToolSpectro *tool,
-                               guint nsel)
+accumulate_lines(GwyDataLine *accum, GwyDataLine *dline, GwyDataLine *weights)
+{
+    gint i, n, n1;
+    gdouble *adata, *data, *wdata;
+    gdouble real, off, real1, off1;
+
+    n = gwy_data_line_get_res(accum);
+    n1 = gwy_data_line_get_res(dline);
+    data = gwy_data_line_get_data(dline);
+    adata = gwy_data_line_get_data(accum);
+    real = gwy_data_line_get_real(accum);
+    real1 = gwy_data_line_get_real(dline);
+    off = gwy_data_line_get_offset(accum);
+    off1 = gwy_data_line_get_offset(dline);
+
+    if (n1 == n
+        && fabs(real1 - real) <= 1e-9*(fabs(real1) + fabs(real))
+        && fabs(off1 - off) <= 1e-9*(fabs(off1) + fabs(off))) {
+        for (i = 0; i < n1; i++)
+            adata[i] += data[i];
+        gwy_data_line_add(weights, 1.0);
+        return;
+    }
+
+    if (off1 >= real + off || off >= real1 + off1)
+        return;
+
+    /* This is not very good but better than a CRTICIAL message we used to
+     * do here... */
+    wdata = gwy_data_line_get_data(weights);
+    for (i = 0; i < n; i++) {
+        gdouble x = (i + 0.5)*real/n + off;
+        gint j = floor((x - off1)/real1*n1);
+        if (j >= 0 && j+1 < n1) {
+            adata[i] += data[j];
+            wdata[i] += 1.0;
+        }
+    }
+}
+
+static void
+gwy_tool_spectro_show_averaged(GwyToolSpectro *tool)
 {
     GwyGraphCurveModel *gcmodel;
     const GwyRGBA *rgba;
+    gdouble *adata, *wdata;
+    gint i, n;
 
     gcmodel = gwy_graph_curve_model_new();
     rgba = gwy_graph_get_preset_color(0);
@@ -774,13 +817,18 @@ gwy_tool_spectro_show_averaged(GwyToolSpectro *tool,
                  "description", gwy_spectra_get_title(tool->spectra),
                  "color", rgba,
                  NULL);
-    gwy_data_line_multiply(tool->line, 1.0/nsel);
+    n = gwy_data_line_get_res(tool->line);
+    adata = gwy_data_line_get_data(tool->line);
+    wdata = gwy_data_line_get_data(tool->weights);
+    for (i = 0; i < n; i++)
+        adata[i] /= wdata[i];
     gwy_graph_curve_model_set_data_from_dataline(gcmodel, tool->line, 0, 0);
     gwy_graph_model_add_curve(tool->gmodel, gcmodel);
     g_object_unref(gcmodel);
 
     gwy_graph_model_set_units_from_data_line(tool->gmodel, tool->line);
     GWY_OBJECT_UNREF(tool->line);
+    GWY_OBJECT_UNREF(tool->weights);
 }
 
 static void
@@ -872,10 +920,7 @@ gwy_tool_spectro_render_color(G_GNUC_UNUSED GtkCellLayout *layout,
             if (GPOINTER_TO_UINT(g_object_get_data(G_OBJECT(gcmodel),
                                                    "sid")) == idx) {
                 g_object_get(gcmodel, "color", &rgba, NULL);
-                pixel = 0xff
-                    | ((guint32)(guchar)floor(255.99999*rgba->b) << 8)
-                    | ((guint32)(guchar)floor(255.99999*rgba->g) << 16)
-                    | ((guint32)(guchar)floor(255.99999*rgba->r) << 24);
+                pixel = 0xff | gwy_rgba_to_pixbuf_pixel(rgba);
                 gwy_rgba_free(rgba);
                 break;
             }
