@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: spotremove.c 19039 2016-10-08 10:54:58Z yeti-dn $
+ *  @(#) $Id: spotremove.c 19948 2017-06-22 14:05:41Z yeti-dn $
  *  Copyright (C) 2003-2006 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -176,7 +176,7 @@ static const InterpolateFunc method_functions[] = {
     &fractal_average,
 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, spotremove)
 
 G_DEFINE_TYPE(GwyToolSpotRemover, gwy_tool_spot_remover, GWY_TYPE_PLAIN_TOOL)
 
