@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: stats.c 19041 2016-10-08 13:12:34Z yeti-dn $
+ *  @(#) $Id: stats.c 20111 2017-07-30 14:08:43Z yeti-dn $
  *  Copyright (C) 2003-2016 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -236,7 +236,7 @@ static const ToolArgs default_args = {
     GWY_MASK_IGNORE,
 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, stats)
 
 G_DEFINE_TYPE(GwyToolStats, gwy_tool_stats, GWY_TYPE_PLAIN_TOOL)
 
@@ -305,7 +305,7 @@ gwy_tool_stats_init(GwyToolStats *tool)
         return;
 
     plain_tool->lazy_updates = TRUE;
-    plain_tool->unit_style = GWY_SI_UNIT_FORMAT_MARKUP;
+    plain_tool->unit_style = GWY_SI_UNIT_FORMAT_VFMARKUP;
 
     settings = gwy_app_settings_get();
     tool->args = default_args;
@@ -316,7 +316,7 @@ gwy_tool_stats_init(GwyToolStats *tool)
     tool->args.masking = gwy_enum_sanitize_value(tool->args.masking,
                                                  GWY_TYPE_MASKING_TYPE);
 
-    tool->angle_format = gwy_si_unit_value_format_new(1.0, 1, "deg");
+    tool->angle_format = gwy_si_unit_value_format_new(1.0, 1, _("deg"));
     gwy_plain_tool_connect_selection(plain_tool, tool->layer_type_rect,
                                      "rectangle");
 
@@ -387,8 +387,7 @@ gwy_tool_stats_init_dialog(GwyToolStats *tool)
     row = 0;
 
     label = gwy_label_new_header(_("Masking Mode"));
-    gtk_table_attach(table, label,
-                     0, 3, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
+    gtk_table_attach(table, label, 0, 3, row, row+1, GTK_FILL, 0, 0, 0);
     row++;
 
     tool->masking
@@ -400,14 +399,13 @@ gwy_tool_stats_init_dialog(GwyToolStats *tool)
     gtk_table_set_row_spacing(table, row-1, 8);
 
     label = gwy_label_new_header(_("Options"));
-    gtk_table_attach(table, label,
-                     0, 3, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
+    gtk_table_attach(table, label, 0, 3, row, row+1, GTK_FILL, 0, 0, 0);
     row++;
 
     tool->instant_update
         = gtk_check_button_new_with_mnemonic(_("_Instant updates"));
     gtk_table_attach(table, tool->instant_update,
-                     0, 3, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
+                     0, 3, row, row+1, GTK_FILL, 0, 0, 0);
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(tool->instant_update),
                                  tool->args.instant_update);
     g_signal_connect(tool->instant_update, "toggled",
@@ -423,21 +421,20 @@ gwy_tool_stats_init_dialog(GwyToolStats *tool)
     row = 0;
 
     gtk_table_attach(table, gwy_label_new_header(_("Parameters")),
-                     0, 2, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
+                     0, 2, row, row+1, GTK_FILL, 0, 0, 0);
     row++;
 
     for (i = 0; i < G_N_ELEMENTS(values); i++) {
         label = gtk_label_new(_(values[i].name));
         gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
-        gtk_table_attach(table, label,
-                         0, 1, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
+        gtk_table_attach(table, label, 0, 1, row, row+1, GTK_FILL, 0, 0, 0);
 
         plabel = (GtkWidget**)G_STRUCT_MEMBER_P(tool, values[i].offset);
         *plabel = gtk_label_new(NULL);
         gtk_misc_set_alignment(GTK_MISC(*plabel), 1.0, 0.5);
         gtk_label_set_selectable(GTK_LABEL(*plabel), TRUE);
-        gtk_table_attach(table, *plabel,
-                         1, 2, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
+        gtk_table_attach(table, *plabel, 1, 2, row, row+1,
+                         GTK_EXPAND | GTK_FILL, 0, 0, 0);
 
         row++;
     }
@@ -513,7 +510,6 @@ gwy_tool_stats_data_switched(GwyTool *gwytool,
 
     gtk_widget_set_sensitive(tool->copy, data_view != NULL);
     gtk_widget_set_sensitive(tool->save, data_view != NULL);
-
 }
 
 static void
