@@ -1,6 +1,6 @@
 /*
  *  @(#) $Id: volcal.c 14954 2013-04-23 15:43:19Z klapetek $
- *  Copyright (C) 2003 David Necas (Yeti), Petr Klapetek.
+ *  Copyright (C) 2013 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -174,12 +174,12 @@ static GwyModuleInfo module_info = {
     &module_register,
     N_("Recalibrate volume data dimensions or value range."),
     "Petr Klapetek <klapetek@gwyddion.net>",
-    "1.1",
+    "1.2",
     "David Nečas (Yeti) & Petr Klapetek",
     "2013",
 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, volume_calibrate)
 
 static gboolean
 module_register(void)
@@ -361,7 +361,7 @@ volcal_dialog(VolcalArgs *args,
               GwyBrick *brick)
 {
     enum { RESPONSE_RESET = 1};
-    GtkWidget *dialog, *spin, *table, *label;
+    GtkWidget *dialog, *spin, *table;
     GwySIUnit *unit;
     VolcalControls controls;
     gint row, response;
@@ -371,7 +371,8 @@ volcal_dialog(VolcalArgs *args,
                                          GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
                                          NULL);
 
-    controls.ok = gtk_dialog_add_button(GTK_DIALOG(dialog), GTK_STOCK_OK, GTK_RESPONSE_OK);
+    controls.ok = gtk_dialog_add_button(GTK_DIALOG(dialog),
+                                        GTK_STOCK_OK, GTK_RESPONSE_OK);
     gtk_dialog_set_default_response(GTK_DIALOG(dialog), GTK_RESPONSE_OK);
     gwy_help_add_to_volume_dialog(GTK_DIALOG(dialog), GWY_HELP_DEFAULT);
 
@@ -386,22 +387,16 @@ volcal_dialog(VolcalArgs *args,
     row = 0;
 
     /***** New Real Dimensions *****/
-    label = gwy_label_new_header(_("New Real Dimensions"));
-    gtk_table_attach(GTK_TABLE(table), label,
-                     0, 3, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
+    gtk_table_attach(GTK_TABLE(table),
+                     gwy_label_new_header(_("New Real Dimensions")),
+                     0, 2, row, row+1, GTK_FILL, 0, 0, 0);
     row++;
 
-    label = gtk_label_new_with_mnemonic(_("_X range:"));
-    gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
-    gtk_table_attach(GTK_TABLE(table), label,
-                     0, 1, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
-
     controls.xreal = gtk_adjustment_new(args->xreal/pow10(args->xexponent),
                                         0.01, 10000, 1, 10, 0);
-    spin = gtk_spin_button_new(GTK_ADJUSTMENT(controls.xreal), 1, 2);
-    gtk_spin_button_set_numeric(GTK_SPIN_BUTTON(spin), TRUE);
-    gtk_table_attach(GTK_TABLE(table), spin,
-                     1, 2, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
+    spin = gwy_table_attach_adjbar(table, row, _("_X range:"), NULL,
+                                   controls.xreal, GWY_HSCALE_LOG);
+    gtk_spin_button_set_digits(GTK_SPIN_BUTTON(spin), 3);
 
     unit = gwy_brick_get_si_unit_x(brick);
     controls.xexponent
@@ -409,202 +404,147 @@ volcal_dialog(VolcalArgs *args,
                                         &controls, -15, 6, unit,
                                         args->xexponent);
     gtk_table_attach(GTK_TABLE(table), controls.xexponent, 2, 3, row, row+1,
-                     GTK_EXPAND | GTK_FILL | GTK_SHRINK, 0, 0, 0);
+                     GTK_FILL | GTK_SHRINK, 0, 0, 0);
 
     controls.xunits = gtk_button_new_with_label(gwy_sgettext("verb|Change"));
     g_object_set_data(G_OBJECT(controls.xunits), "id", (gpointer)"x");
     gtk_table_attach(GTK_TABLE(table), controls.xunits,
-                     3, 4, row, row+1,
-                     GTK_EXPAND | GTK_FILL | GTK_SHRINK, 0, 0, 0);
+                     3, 4, row, row+1, GTK_FILL | GTK_SHRINK, 0, 0, 0);
     row++;
 
-    label = gtk_label_new_with_mnemonic(_("_Y range:"));
-    gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
-    gtk_table_attach(GTK_TABLE(table), label,
-                     0, 1, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
-
     controls.yreal = gtk_adjustment_new(args->yreal/pow10(args->yexponent),
                                         0.01, 10000, 1, 10, 0);
-    spin = gtk_spin_button_new(GTK_ADJUSTMENT(controls.yreal), 1, 2);
-    gtk_spin_button_set_numeric(GTK_SPIN_BUTTON(spin), TRUE);
-    gtk_table_attach(GTK_TABLE(table), spin,
-                     1, 2, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
+    spin = gwy_table_attach_adjbar(table, row, _("_Y range:"), NULL,
+                                   controls.yreal, GWY_HSCALE_LOG);
+    gtk_spin_button_set_digits(GTK_SPIN_BUTTON(spin), 3);
 
     unit = gwy_brick_get_si_unit_y(brick);
     controls.yexponent
         = gwy_combo_box_metric_unit_new(G_CALLBACK(yexponent_changed_cb),
                                         &controls, -15, 6, unit,
                                         args->yexponent);
-    gtk_table_attach(GTK_TABLE(table), controls.yexponent, 2, 3, row, row+1,
-                     GTK_EXPAND | GTK_FILL | GTK_SHRINK, 0, 0, 0);
+    gtk_table_attach(GTK_TABLE(table), controls.yexponent,
+                     2, 3, row, row+1, GTK_FILL | GTK_SHRINK, 0, 0, 0);
 
     controls.yunits = gtk_button_new_with_label(gwy_sgettext("verb|Change"));
     g_object_set_data(G_OBJECT(controls.yunits), "id", (gpointer)"y");
     gtk_table_attach(GTK_TABLE(table), controls.yunits,
-                     3, 4, row, row+1,
-                     GTK_EXPAND | GTK_FILL | GTK_SHRINK, 0, 0, 0);
+                     3, 4, row, row+1, GTK_FILL | GTK_SHRINK, 0, 0, 0);
     row++;
 
-    label = gtk_label_new_with_mnemonic(_("_Z range:"));
-    gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
-    gtk_table_attach(GTK_TABLE(table), label,
-                     0, 1, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
-
     controls.zreal = gtk_adjustment_new(args->zreal/pow10(args->zexponent),
                                         0.01, 10000, 1, 10, 0);
-    spin = gtk_spin_button_new(GTK_ADJUSTMENT(controls.zreal), 1, 2);
-    gtk_spin_button_set_numeric(GTK_SPIN_BUTTON(spin), TRUE);
-    gtk_table_attach(GTK_TABLE(table), spin,
-                     1, 2, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
+    spin = gwy_table_attach_adjbar(table, row, _("_Z range:"), NULL,
+                                   controls.zreal, GWY_HSCALE_LOG);
+    gtk_spin_button_set_digits(GTK_SPIN_BUTTON(spin), 3);
 
     unit = gwy_brick_get_si_unit_z(brick);
     controls.zexponent
         = gwy_combo_box_metric_unit_new(G_CALLBACK(zexponent_changed_cb),
                                         &controls, -15, 6, unit,
                                         args->zexponent);
-    gtk_table_attach(GTK_TABLE(table), controls.zexponent, 2, 3, row, row+1,
-                     GTK_EXPAND | GTK_FILL | GTK_SHRINK, 0, 0, 0);
+    gtk_table_attach(GTK_TABLE(table), controls.zexponent,
+                     2, 3, row, row+1, GTK_FILL | GTK_SHRINK, 0, 0, 0);
 
     controls.zunits = gtk_button_new_with_label(gwy_sgettext("verb|Change"));
     g_object_set_data(G_OBJECT(controls.zunits), "id", (gpointer)"z");
     gtk_table_attach(GTK_TABLE(table), controls.zunits,
-                     3, 4, row, row+1,
-                     GTK_EXPAND | GTK_FILL | GTK_SHRINK, 0, 0, 0);
+                     3, 4, row, row+1, GTK_FILL | GTK_SHRINK, 0, 0, 0);
     row++;
 
 
     /***** Lateral Offsets *****/
 
-    label = gtk_label_new_with_mnemonic(_("_X offset:"));
-    gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
-    gtk_table_attach(GTK_TABLE(table), label,
-                     0, 1, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
-
     controls.x0 = gtk_adjustment_new(args->x0/pow10(args->xexponent),
                                      -10000, 10000, 1, 10, 0);
-    spin = gtk_spin_button_new(GTK_ADJUSTMENT(controls.x0), 1, 2);
-    gtk_spin_button_set_numeric(GTK_SPIN_BUTTON(spin), TRUE);
-    gtk_table_attach(GTK_TABLE(table), spin,
-                     1, 2, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
+    spin = gwy_table_attach_adjbar(table, row, _("_X offset:"), NULL,
+                                   controls.x0, GWY_HSCALE_SQRT);
+    gtk_spin_button_set_digits(GTK_SPIN_BUTTON(spin), 2);
     row++;
 
-    label = gtk_label_new_with_mnemonic(_("_Y offset:"));
-    gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
-    gtk_table_attach(GTK_TABLE(table), label,
-                     0, 1, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
-
-    controls.y0 = gtk_adjustment_new(args->y0/pow10(args->yexponent),
+    controls.y0 = gtk_adjustment_new(args->y0/pow10(args->xexponent),
                                      -10000, 10000, 1, 10, 0);
-    spin = gtk_spin_button_new(GTK_ADJUSTMENT(controls.y0), 1, 2);
-    gtk_spin_button_set_numeric(GTK_SPIN_BUTTON(spin), TRUE);
-    gtk_table_attach(GTK_TABLE(table), spin,
-                     1, 2, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
-    gtk_table_set_row_spacing(GTK_TABLE(table), row, 8);
+    spin = gwy_table_attach_adjbar(table, row, _("_Y offset:"), NULL,
+                                   controls.y0, GWY_HSCALE_SQRT);
+    gtk_spin_button_set_digits(GTK_SPIN_BUTTON(spin), 2);
     row++;
 
-    label = gtk_label_new_with_mnemonic(_("_Z offset:"));
-    gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
-    gtk_table_attach(GTK_TABLE(table), label,
-                     0, 1, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
-
-    controls.z0 = gtk_adjustment_new(args->z0/pow10(args->zexponent),
+    controls.z0 = gtk_adjustment_new(args->z0/pow10(args->xexponent),
                                      -10000, 10000, 1, 10, 0);
-    spin = gtk_spin_button_new(GTK_ADJUSTMENT(controls.z0), 1, 2);
-    gtk_spin_button_set_numeric(GTK_SPIN_BUTTON(spin), TRUE);
-    gtk_table_attach(GTK_TABLE(table), spin,
-                     1, 2, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
-    gtk_table_set_row_spacing(GTK_TABLE(table), row, 8);
+    spin = gwy_table_attach_adjbar(table, row, _("_Z offset:"), NULL,
+                                   controls.z0, GWY_HSCALE_SQRT);
+    gtk_spin_button_set_digits(GTK_SPIN_BUTTON(spin), 2);
     row++;
 
-
     /***** Value Range *****/
-    label = gwy_label_new_header(_("Value Range"));
-    gtk_table_attach(GTK_TABLE(table), label,
-                     0, 3, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
+    gtk_table_attach(GTK_TABLE(table), gwy_label_new_header(_("Value Range")),
+                     0, 2, row, row+1, GTK_FILL, 0, 0, 0);
     row++;
 
-    label = gtk_label_new_with_mnemonic(_("_Value range:"));
-    gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
-    gtk_table_attach(GTK_TABLE(table), label,
-                     0, 1, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
-
     controls.wreal = gtk_adjustment_new(args->wreal/pow10(args->wexponent),
                                         -10000, 10000, 1, 10, 0);
-    spin = gtk_spin_button_new(GTK_ADJUSTMENT(controls.wreal), 1, 2);
-    gtk_spin_button_set_numeric(GTK_SPIN_BUTTON(spin), TRUE);
-    gtk_table_attach(GTK_TABLE(table), spin,
-                     1, 2, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
+    spin = gwy_table_attach_adjbar(table, row, _("_Value range:"), NULL,
+                                   controls.wreal, GWY_HSCALE_SQRT);
+    gtk_spin_button_set_digits(GTK_SPIN_BUTTON(spin), 2);
 
     unit = gwy_brick_get_si_unit_w(brick);
     controls.wexponent
         = gwy_combo_box_metric_unit_new(G_CALLBACK(wexponent_changed_cb),
                                         &controls, -15, 6, unit,
                                         args->wexponent);
-    gtk_table_attach(GTK_TABLE(table), controls.wexponent, 2, 3, row, row+1,
-                     GTK_EXPAND | GTK_FILL | GTK_SHRINK, 0, 0, 0);
+    gtk_table_attach(GTK_TABLE(table), controls.wexponent,
+                     2, 3, row, row+1, GTK_FILL | GTK_SHRINK, 0, 0, 0);
 
     controls.wunits = gtk_button_new_with_label(gwy_sgettext("verb|Change"));
     g_object_set_data(G_OBJECT(controls.wunits), "id", (gpointer)"w");
     gtk_table_attach(GTK_TABLE(table), controls.wunits,
-                     3, 4, row, row+1,
-                     GTK_EXPAND | GTK_FILL | GTK_SHRINK, 0, 0, 0);
+                     3, 4, row, row+1, GTK_FILL | GTK_SHRINK, 0, 0, 0);
     row++;
 
     /***** Value Shift *****/
 
-    label = gtk_label_new_with_mnemonic(_("Value shi_ft:"));
-    gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
-    gtk_table_attach(GTK_TABLE(table), label,
-                     0, 1, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
-
     controls.wshift = gtk_adjustment_new(args->wshift/pow10(args->wexponent),
                                          -10000, 10000, 1, 10, 0);
-    spin = gtk_spin_button_new(GTK_ADJUSTMENT(controls.wshift), 1, 2);
-    gtk_spin_button_set_numeric(GTK_SPIN_BUTTON(spin), TRUE);
-    gtk_table_attach(GTK_TABLE(table), spin,
-                     1, 2, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
-    gtk_table_set_row_spacing(GTK_TABLE(table), row, 8);
+    spin = gwy_table_attach_adjbar(table, row, _("Value shi_ft:"), NULL,
+                                   controls.wshift, GWY_HSCALE_SQRT);
+    gtk_spin_button_set_digits(GTK_SPIN_BUTTON(spin), 2);
     row++;
 
     /***** Calibration Coefficients *****/
-    label = gwy_label_new_header(_("Calibration Coefficients"));
-    gtk_table_attach(GTK_TABLE(table), label,
-                     0, 3, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
+    gtk_table_attach(GTK_TABLE(table),
+                     gwy_label_new_header(_("Calibration Coefficients")),
+                     0, 2, row, row+1, GTK_FILL, 0, 0, 0);
     row++;
 
     controls.xratio = gtk_adjustment_new(args->xratio, 0.001, 1000, 0.1, 1, 0);
-    spin = gwy_table_attach_spinbutton(table, row,
-                                       _("_X calibration factor:"), "",
-                                       controls.xratio);
-    controls.xpower10 = gwy_table_get_child_widget(table, row, 2);
+    spin = gwy_table_attach_adjbar(table, row, _("_X calibration factor:"), " ",
+                                   controls.xratio, GWY_HSCALE_LOG);
     gtk_spin_button_set_digits(GTK_SPIN_BUTTON(spin), 3);
+    controls.xpower10 = gwy_table_hscale_get_units(controls.xratio);
     row++;
 
     controls.yratio = gtk_adjustment_new(args->yratio, 0.001, 1000, 0.1, 1, 0);
-    spin = gwy_table_attach_spinbutton(table, row,
-                                       _("_Y calibration factor:"), "",
-                                       controls.yratio);
-    controls.ypower10 = gwy_table_get_child_widget(table, row, 2);
+    spin = gwy_table_attach_adjbar(table, row, _("_Y calibration factor:"), " ",
+                                   controls.yratio, GWY_HSCALE_LOG);
     gtk_spin_button_set_digits(GTK_SPIN_BUTTON(spin), 3);
+    controls.ypower10 = gwy_table_hscale_get_units(controls.xratio);
     row++;
 
     controls.zratio = gtk_adjustment_new(args->zratio, -1000, 1000, 0.1, 1, 0);
-    spin = gwy_table_attach_spinbutton(table, row,
-                                       _("_Z calibration factor:"), "",
-                                       controls.zratio);
-    controls.zpower10 = gwy_table_get_child_widget(table, row, 2);
+    spin = gwy_table_attach_adjbar(table, row, _("_Z calibration factor:"), " ",
+                                   controls.zratio, GWY_HSCALE_LOG);
     gtk_spin_button_set_digits(GTK_SPIN_BUTTON(spin), 3);
+    controls.zpower10 = gwy_table_hscale_get_units(controls.zratio);
     row++;
 
     controls.wratio = gtk_adjustment_new(args->wratio, -1000, 1000, 0.1, 1, 0);
-    spin = gwy_table_attach_spinbutton(table, row,
-                                       _("_Value calibration factor:"), "",
-                                       controls.wratio);
-    controls.wpower10 = gwy_table_get_child_widget(table, row, 2);
+    spin = gwy_table_attach_adjbar(table, row,
+                                   _("_Value calibration factor:"), " ",
+                                   controls.wratio, GWY_HSCALE_SQRT);
     gtk_spin_button_set_digits(GTK_SPIN_BUTTON(spin), 3);
+    controls.wpower10 = gwy_table_hscale_get_units(controls.zratio);
     row++;
 
-
     g_signal_connect(controls.xreal, "value-changed",
                      G_CALLBACK(xreal_changed_cb), &controls);
     g_signal_connect(controls.yreal, "value-changed",
