@@ -1,6 +1,6 @@
 /*
- *  @(#) $Id: volume_extract.c 18729 2016-07-19 15:26:29Z yeti-dn $
- *  Copyright (C) 2003 David Necas (Yeti), Petr Klapetek.
+ *  @(#) $Id: volume_extract.c 20007 2017-07-02 20:42:02Z yeti-dn $
+ *  Copyright (C) 2013 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -136,70 +136,63 @@ typedef struct {
     cairo_surface_t *image;
 } ExtractControls;
 
-static gboolean module_register                    (void);
-static void     extract                            (GwyContainer *data,
-                                                    GwyRunType run);
-static void     extract_dialog                     (ExtractArgs *args,
-                                                    GwyContainer *data,
-                                                    GwyBrick *brick,
-                                                    gint id);
-
-static void     extract_dialog_update_controls  (ExtractControls *controls,
-                                                    ExtractArgs *args);
-static void     extract_dialog_update_values    (ExtractControls *controls,
-                                                    ExtractArgs *args);
-static void     extract_load_data               (ExtractControls *controls,
-                                                    ExtractArgs *args);
-static void     extract_invalidate                   (ExtractControls *controls);
-static void     update_change_cb                   (ExtractControls *controls);
-static void     gupdate_change_cb                   (ExtractControls *controls);
-
-static void     preview                            (ExtractControls *controls,
-                                                    ExtractArgs *args);
-static void     extract_load_args               (GwyContainer *container,
-                                                    ExtractArgs *args);
-static void     extract_save_args               (GwyContainer *container,
-                                                    ExtractArgs *args);
-static void     type_changed_cb                   (GtkWidget *combo,
-                                                   ExtractControls *controls);
-static void     gtype_changed_cb                   (GtkWidget *combo,
-                                                   ExtractControls *controls);
-static void     page_switched                      (ExtractControls *controls,
-                                                    GtkNotebookPage *page,
-                                                    gint pagenum);
-static void     graph_selection_finished_cb        (GwySelection *selection,
-                                                    ExtractControls *controls);
-static void     p3d_build                           (ExtractControls *controls,
-                                                     ExtractArgs *args);
-static void     p3d_prepare_wdata                   (ExtractControls *controls,
-                                                     ExtractArgs *args);
-static void     extract_zscale_cb                (ExtractControls *controls);
-static void     extract_opacity_cb                (ExtractControls *controls);
-static void     extract_threshold_cb                (ExtractControls *controls);
-//static gboolean p3d_on_draw_event                  (GtkWidget *widget,
-//                                                   cairo_t *cr,
-//                                                   ExtractControls *controls);
-static gboolean p3d_on_draw_event                  (GtkWidget *widget,
-                                                    GdkEventExpose *event,
-                                                    ExtractControls *controls);
-static gboolean p3d_clicked                        (GtkWidget *widget,
-                                                   GdkEventButton *event,
-                                                   ExtractControls *controls);
-static gboolean p3d_released                        (GtkWidget *widget,
-                                                   GdkEventButton *event,
-                                                   ExtractControls *controls);
-static gboolean p3d_moved                         (GtkWidget *widget,
-                                                   GdkEventMotion *event,
-                                                   ExtractControls *controls);
-static void p3d_xview_cb                          (ExtractControls *controls);
-static void p3d_yview_cb                          (ExtractControls *controls);
-static void p3d_zview_cb                          (ExtractControls *controls);
-static void perspective_change_cb                 (ExtractControls *controls);
-static void render_change_cb                 (ExtractControls *controls);
-
-static void p3d_set_axes                          (ExtractControls *controls);
-static void p3d_add_wireframe                     (ExtractControls *controls);
-
+static gboolean module_register               (void);
+static void     extract                       (GwyContainer *data,
+                                               GwyRunType run);
+static void     extract_dialog                (ExtractArgs *args,
+                                               GwyContainer *data,
+                                               GwyBrick *brick,
+                                               gint id);
+static void     extract_dialog_update_controls(ExtractControls *controls,
+                                               ExtractArgs *args);
+static void     extract_dialog_update_values  (ExtractControls *controls,
+                                               ExtractArgs *args);
+static void     extract_load_data             (ExtractControls *controls,
+                                               ExtractArgs *args);
+static void     extract_invalidate            (ExtractControls *controls);
+static void     update_change_cb              (ExtractControls *controls);
+static void     gupdate_change_cb             (ExtractControls *controls);
+static void     preview                       (ExtractControls *controls,
+                                               ExtractArgs *args);
+static void     extract_load_args             (GwyContainer *container,
+                                               ExtractArgs *args);
+static void     extract_save_args             (GwyContainer *container,
+                                               ExtractArgs *args);
+static void     type_changed_cb               (GtkWidget *combo,
+                                               ExtractControls *controls);
+static void     gtype_changed_cb              (GtkWidget *combo,
+                                               ExtractControls *controls);
+static void     page_switched                 (ExtractControls *controls,
+                                               GtkNotebookPage *page,
+                                               gint pagenum);
+static void     graph_selection_finished_cb   (GwySelection *selection,
+                                               ExtractControls *controls);
+static void     p3d_build                     (ExtractControls *controls,
+                                               ExtractArgs *args);
+static void     p3d_prepare_wdata             (ExtractControls *controls,
+                                               ExtractArgs *args);
+static void     extract_zscale_cb             (ExtractControls *controls);
+static void     extract_opacity_cb            (ExtractControls *controls);
+static void     extract_threshold_cb          (ExtractControls *controls);
+static gboolean p3d_expose                    (GtkWidget *widget,
+                                               GdkEventExpose *event,
+                                               ExtractControls *controls);
+static gboolean p3d_clicked                   (GtkWidget *widget,
+                                               GdkEventButton *event,
+                                               ExtractControls *controls);
+static gboolean p3d_released                  (GtkWidget *widget,
+                                               GdkEventButton *event,
+                                               ExtractControls *controls);
+static gboolean p3d_moved                     (GtkWidget *widget,
+                                               GdkEventMotion *event,
+                                               ExtractControls *controls);
+static void     p3d_xview_cb                  (ExtractControls *controls);
+static void     p3d_yview_cb                  (ExtractControls *controls);
+static void     p3d_zview_cb                  (ExtractControls *controls);
+static void     perspective_change_cb         (ExtractControls *controls);
+static void     render_change_cb              (ExtractControls *controls);
+static void     p3d_set_axes                  (ExtractControls *controls);
+static void     p3d_add_wireframe             (ExtractControls *controls);
 
 static const ExtractArgs extract_defaults = {
     CUT_DIRX,
@@ -227,14 +220,14 @@ static GwyModuleInfo module_info = {
     "2013",
 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, volume_extract)
 
 static gboolean
 module_register(void)
 {
     gwy_volume_func_register("extract",
                              (GwyVolumeFunc)&extract,
-                             N_("/Show and _extract..."),
+                             N_("/Show and _Extract..."),
                              NULL,
                              EXTRACT_RUN_MODES,
                              GWY_MENU_FLAG_VOLUME,
@@ -280,7 +273,7 @@ extract_dialog(ExtractArgs *args,
         { N_("Z direction"), GRAPH_DIRZ, },
     };
 
-    GtkWidget *dialog, *table, *hbox, *label, *notebook, *button;
+    GtkWidget *dialog, *table, *hbox, *notebook, *button, *hbox2;
     GwyDataField *dfield;
     GwyDataLine *dline, *calibration;
     ExtractControls controls;
@@ -346,7 +339,7 @@ extract_dialog(ExtractArgs *args,
     g_signal_connect_swapped(notebook, "switch-page",
                                  G_CALLBACK(page_switched), &controls);
 
-    /////////////////////////////  projections page ///////////////////////////////////////
+    /***** Projections *****/
 
     hbox = gtk_hbox_new(FALSE, 2);
     gtk_notebook_append_page(GTK_NOTEBOOK(notebook),
@@ -379,45 +372,39 @@ extract_dialog(ExtractArgs *args,
 
     gtk_box_pack_start(GTK_BOX(hbox), controls.view, FALSE, FALSE, 4);
 
-    table = gtk_table_new(11, 4, FALSE);
+    table = gtk_table_new(7, 3, FALSE);
     gtk_table_set_row_spacings(GTK_TABLE(table), 2);
     gtk_table_set_col_spacings(GTK_TABLE(table), 6);
     gtk_container_set_border_width(GTK_CONTAINER(table), 4);
     gtk_box_pack_start(GTK_BOX(hbox), table, TRUE, TRUE, 4);
     row = 0;
-    controls.xpos = gtk_adjustment_new(args->xpos,
-                                            0.0, 100, 1, 10, 0);
-    gwy_table_attach_hscale(table, row++, _("X position"), "%",
-                            controls.xpos, 0);
+
+    controls.xpos = gtk_adjustment_new(args->xpos, 0.0, 100, 1, 10, 0);
+    gwy_table_attach_adjbar(table, row++, _("X position"), "%",
+                            controls.xpos, GWY_HSCALE_LINEAR);
     g_signal_connect_swapped(controls.xpos, "value-changed",
                              G_CALLBACK(extract_invalidate), &controls);
 
-    controls.ypos = gtk_adjustment_new(args->ypos,
-                                            0.0, 100, 1, 10, 0);
-    gwy_table_attach_hscale(table, row++, _("Y position"), "%",
-                            controls.ypos, 0);
+    controls.ypos = gtk_adjustment_new(args->ypos, 0.0, 100, 1, 10, 0);
+    gwy_table_attach_adjbar(table, row++, _("Y position"), "%",
+                            controls.ypos, GWY_HSCALE_LINEAR);
     g_signal_connect_swapped(controls.ypos, "value-changed",
                              G_CALLBACK(extract_invalidate), &controls);
 
-    controls.zpos = gtk_adjustment_new(args->zpos,
-                                            0.0, 100, 1, 10, 0);
-    gwy_table_attach_hscale(table, row++, _("Z position"), "%",
-                            controls.zpos, 0);
+    controls.zpos = gtk_adjustment_new(args->zpos, 0.0, 100, 1, 10, 0);
+    gwy_table_attach_adjbar(table, row++, _("Z position"), "%",
+                            controls.zpos, GWY_HSCALE_LINEAR);
     g_signal_connect_swapped(controls.zpos, "value-changed",
                              G_CALLBACK(extract_invalidate), &controls);
 
-    label = gtk_label_new(_("Shown cut direction:"));
-    gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
-    gtk_table_attach(GTK_TABLE(table), label,
-                     0, 4, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
-    row++;
-
-    controls.type
-        = gwy_enum_combo_box_new(types, G_N_ELEMENTS(types),
-                                 G_CALLBACK(type_changed_cb), &controls,
-                                 args->type, TRUE);
-    gwy_table_attach_hscale(table, row, _("Show mode:"), NULL,
-                            GTK_OBJECT(controls.type), GWY_HSCALE_WIDGET);
+    gtk_table_set_row_spacing(GTK_TABLE(table), row-1, 8);
+    controls.type = gwy_enum_combo_box_new(types, G_N_ELEMENTS(types),
+                                           G_CALLBACK(type_changed_cb),
+                                           &controls,
+                                           args->type, TRUE);
+    gwy_table_attach_adjbar(table, row, _("Shown cut direction:"), NULL,
+                            GTK_OBJECT(controls.type),
+                            GWY_HSCALE_WIDGET_NO_EXPAND);
     type_changed_cb(controls.type, &controls);
     row++;
 
@@ -425,32 +412,34 @@ extract_dialog(ExtractArgs *args,
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(controls.update),
                                  args->update);
     gtk_table_attach(GTK_TABLE(table), controls.update,
-                     0, 3, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
+                     0, 2, row, row+1, GTK_FILL, 0, 0, 0);
     g_signal_connect_swapped(controls.update, "toggled",
                              G_CALLBACK(update_change_cb), &controls);
     row++;
 
+    gtk_table_set_row_spacing(GTK_TABLE(table), row-1, 8);
     controls.info = gtk_label_new(_("No data loaded"));
     gtk_misc_set_alignment(GTK_MISC(controls.info), 0.0, 0.5);
     gtk_table_attach(GTK_TABLE(table), controls.info,
-                     0, 4, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
+                     0, 2, row, row+1, GTK_FILL, 0, 0, 0);
     row++;
 
-    /////////////////////////////  graphs page ///////////////////////////////////////
+    /***** Graphs page *****/
 
     hbox = gtk_hbox_new(FALSE, 2);
-    gtk_notebook_append_page(GTK_NOTEBOOK(notebook),
-                               hbox,
-                               gtk_label_new(_("Graphs")));
+    gtk_notebook_append_page(GTK_NOTEBOOK(notebook), hbox,
+                             gtk_label_new(_("Graphs")));
 
     dfield = gwy_data_field_new(PREVIEW_SIZE, PREVIEW_SIZE,
                                 PREVIEW_SIZE, PREVIEW_SIZE,
                                 TRUE);
     gwy_container_set_object_by_name(controls.mydata, "/1/data", dfield);
 
-    if (data) gwy_app_sync_data_items(data, controls.mydata, id, 1, FALSE,
-                            GWY_DATA_ITEM_PALETTE,
-                            0);
+    if (data) {
+        gwy_app_sync_data_items(data, controls.mydata, id, 1, FALSE,
+                                GWY_DATA_ITEM_PALETTE,
+                                0);
+    }
 
     controls.gview = gwy_data_view_new(controls.mydata);
     layer = gwy_layer_basic_new();
@@ -473,12 +462,13 @@ extract_dialog(ExtractArgs *args,
 
 
     gtk_box_pack_start(GTK_BOX(hbox), controls.gview, FALSE, FALSE, 4);
-    table = gtk_table_new(11, 4, FALSE);
+    table = gtk_table_new(3, 4, FALSE);
     gtk_table_set_row_spacings(GTK_TABLE(table), 2);
     gtk_table_set_col_spacings(GTK_TABLE(table), 6);
     gtk_container_set_border_width(GTK_CONTAINER(table), 4);
     gtk_box_pack_start(GTK_BOX(hbox), table, TRUE, TRUE, 4);
     row = 0;
+
     controls.gmodel = gwy_graph_model_new();
     controls.graph = gwy_graph_new(controls.gmodel);
     gwy_graph_enable_user_input(GWY_GRAPH(controls.graph), FALSE);
@@ -487,18 +477,14 @@ extract_dialog(ExtractArgs *args,
                      0, 4, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
     row++;
 
-    label = gtk_label_new(_("Graph cut direction:"));
-    gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
-    gtk_table_attach(GTK_TABLE(table), label,
-                     0, 4, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
-    row++;
-
+    gtk_table_set_row_spacing(GTK_TABLE(table), row-1, 8);
     controls.gtype
         = gwy_enum_combo_box_new(gtypes, G_N_ELEMENTS(gtypes),
                                  G_CALLBACK(gtype_changed_cb), &controls,
                                  args->gtype, TRUE);
-    gwy_table_attach_hscale(table, row, _("Show mode:"), NULL,
-                            GTK_OBJECT(controls.gtype), GWY_HSCALE_WIDGET);
+    gwy_table_attach_adjbar(table, row, _("Graph cut direction:"), NULL,
+                            GTK_OBJECT(controls.gtype),
+                            GWY_HSCALE_WIDGET_NO_EXPAND);
     gtype_changed_cb(controls.gtype, &controls);
     row++;
 
@@ -506,29 +492,32 @@ extract_dialog(ExtractArgs *args,
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(controls.gupdate),
                                  args->update);
     gtk_table_attach(GTK_TABLE(table), controls.gupdate,
-                     0, 3, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
+                     0, 2, row, row+1, GTK_FILL, 0, 0, 0);
     g_signal_connect_swapped(controls.gupdate, "toggled",
                              G_CALLBACK(gupdate_change_cb), &controls);
     row++;
 
+    gtk_table_set_row_spacing(GTK_TABLE(table), row-1, 8);
     controls.ginfo = gtk_label_new(_("No data loaded"));
     gtk_misc_set_alignment(GTK_MISC(controls.ginfo), 0.0, 0.5);
     gtk_table_attach(GTK_TABLE(table), controls.ginfo,
-                     0, 4, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
+                     0, 2, row, row+1, GTK_FILL, 0, 0, 0);
     row++;
 
-    /////////////////////////////  3D page ///////////////////////////////////////
+    /***** 3D *****/
 
     hbox = gtk_hbox_new(FALSE, 2);
-    gtk_notebook_append_page(GTK_NOTEBOOK(notebook),
-                               hbox,
-                               gtk_label_new(_("3D view")));
+    gtk_notebook_append_page(GTK_NOTEBOOK(notebook), hbox,
+                             gtk_label_new(_("3D view")));
 
     controls.drawarea = gtk_drawing_area_new();
-    gtk_widget_add_events(controls.drawarea, GDK_BUTTON_PRESS_MASK | GDK_BUTTON_RELEASE_MASK | GDK_POINTER_MOTION_MASK);
+    gtk_widget_add_events(controls.drawarea,
+                          GDK_BUTTON_PRESS_MASK
+                          | GDK_BUTTON_RELEASE_MASK
+                          | GDK_POINTER_MOTION_MASK);
 
-    g_signal_connect(GTK_DRAWING_AREA(controls.drawarea), "expose-event", //should be "draw" for newer Gtk+
-                     G_CALLBACK(p3d_on_draw_event), &controls);
+    g_signal_connect(GTK_DRAWING_AREA(controls.drawarea), "expose-event",
+                     G_CALLBACK(p3d_expose), &controls);
     g_signal_connect(controls.drawarea, "button-press-event",
                      G_CALLBACK(p3d_clicked), &controls);
     g_signal_connect(controls.drawarea, "button-release-event",
@@ -539,77 +528,74 @@ extract_dialog(ExtractArgs *args,
     gtk_box_pack_start(GTK_BOX(hbox), controls.drawarea, FALSE, FALSE, 4);
     gtk_widget_set_size_request(controls.drawarea, PREVIEW_SIZE, PREVIEW_SIZE);
 
-    table = gtk_table_new(11, 4, FALSE);
+    table = gtk_table_new(7, 4, FALSE);
     gtk_table_set_row_spacings(GTK_TABLE(table), 2);
     gtk_table_set_col_spacings(GTK_TABLE(table), 6);
     gtk_container_set_border_width(GTK_CONTAINER(table), 4);
     gtk_box_pack_start(GTK_BOX(hbox), table, TRUE, TRUE, 4);
     row = 0;
-    controls.size = gtk_adjustment_new(args->size,
-                                            1, 100, 1, 10, 0);
-    gwy_table_attach_hscale(table, row++, _("Zoom"), "%",
-                            controls.size, 0);
+    controls.size = gtk_adjustment_new(args->size, 1, 100, 1, 10, 0);
+    gwy_table_attach_adjbar(table, row++, _("Zoom"), "%",
+                            controls.size, GWY_HSCALE_SQRT);
     g_signal_connect_swapped(controls.size, "value-changed",
                              G_CALLBACK(extract_invalidate), &controls);
     row++;
 
-    controls.threshold = gtk_adjustment_new(args->threshold,
-                                            1, 100, 1, 10, 0);
-    gwy_table_attach_hscale(table, row++, _("Wireframe threshold"), "%",
-                            controls.threshold, 0);
+    controls.threshold = gtk_adjustment_new(args->threshold, 1, 100, 1, 10, 0);
+    gwy_table_attach_adjbar(table, row++, _("Wireframe threshold"), "%",
+                            controls.threshold, GWY_HSCALE_LINEAR);
     g_signal_connect_swapped(controls.threshold, "value-changed",
                              G_CALLBACK(extract_threshold_cb), &controls);
     row++;
 
-    controls.zscale = gtk_adjustment_new(args->zscale,
-                                            1, 100, 1, 10, 0);
-    gwy_table_attach_hscale(table, row++, _("Z scale"), "%",
-                            controls.zscale, 0);
+    controls.zscale = gtk_adjustment_new(args->zscale, 1, 100, 1, 10, 0);
+    gwy_table_attach_adjbar(table, row++, _("Z scale"), "%",
+                            controls.zscale, GWY_HSCALE_SQRT);
     g_signal_connect_swapped(controls.zscale, "value-changed",
                              G_CALLBACK(extract_zscale_cb), &controls);
     row++;
 
-    controls.opacity = gtk_adjustment_new(args->opacity,
-                                            1, 100, 1, 10, 0);
-    gwy_table_attach_hscale(table, row++, _("Opacity scale"), "%",
-                            controls.opacity, 0);
+    controls.opacity = gtk_adjustment_new(args->opacity, 1, 100, 1, 10, 0);
+    gwy_table_attach_adjbar(table, row++, _("Opacity scale"), "%",
+                            controls.opacity, GWY_HSCALE_LINEAR);
     g_signal_connect_swapped(controls.opacity, "value-changed",
                              G_CALLBACK(extract_opacity_cb), &controls);
     row++;
 
-    controls.perspective = gtk_check_button_new_with_mnemonic(_("apply perspective"));
+    controls.perspective = gtk_check_button_new_with_label(_("Apply perspective"));
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(controls.perspective),
                                  args->perspective);
     gtk_table_attach(GTK_TABLE(table), controls.perspective,
-                     0, 3, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
+                     0, 2, row, row+1, GTK_FILL, 0, 0, 0);
     g_signal_connect_swapped(controls.perspective, "toggled",
                              G_CALLBACK(perspective_change_cb), &controls);
     row++;
 
-    controls.render = gtk_check_button_new_with_mnemonic(_("instant 3D render"));
+    controls.render = gtk_check_button_new_with_label(_("Instant 3D render"));
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(controls.render),
                                  args->render);
     gtk_table_attach(GTK_TABLE(table), controls.render,
-                     0, 3, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
+                     0, 2, row, row+1, GTK_FILL, 0, 0, 0);
     g_signal_connect_swapped(controls.render, "toggled",
                              G_CALLBACK(render_change_cb), &controls);
     row++;
 
+    hbox2 = gtk_hbox_new(TRUE, 2);
+    gtk_table_attach(GTK_TABLE(table), hbox2,
+                     0, 1, row, row+1, GTK_FILL, 0, 0, 0);
+
     button = gtk_button_new_with_mnemonic(_("X view"));
-    gtk_table_attach(GTK_TABLE(table), button,
-                     0, 1, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
+    gtk_box_pack_start(GTK_BOX(hbox2), button, TRUE, TRUE, 0);
     g_signal_connect_swapped(button, "clicked",
                              G_CALLBACK(p3d_xview_cb), &controls);
 
     button = gtk_button_new_with_mnemonic(_("Y view"));
-    gtk_table_attach(GTK_TABLE(table), button,
-                     1, 2, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
+    gtk_box_pack_start(GTK_BOX(hbox2), button, TRUE, TRUE, 0);
     g_signal_connect_swapped(button, "clicked",
                              G_CALLBACK(p3d_yview_cb), &controls);
 
     button = gtk_button_new_with_mnemonic(_("Z view"));
-    gtk_table_attach(GTK_TABLE(table), button,
-                     2, 3, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
+    gtk_box_pack_start(GTK_BOX(hbox2), button, TRUE, TRUE, 0);
     g_signal_connect_swapped(button, "clicked",
                              G_CALLBACK(p3d_zview_cb), &controls);
 
@@ -1460,9 +1446,9 @@ raysum(ExtractControls *controls, gdouble pos[3], gdouble dir[3], gdouble min, g
 }
 
 static gboolean
-//p3d_on_draw_event(GtkWidget *widget, cairo_t *cr,
-//              ExtractControls *controls)
-p3d_on_draw_event(GtkWidget *widget, G_GNUC_UNUSED GdkEventExpose *event, ExtractControls *controls)
+p3d_expose(GtkWidget *widget,
+           G_GNUC_UNUSED GdkEventExpose *event,
+           ExtractControls *controls)
 {
     cairo_t *ci, *cr = gdk_cairo_create(GDK_WINDOW(widget->window));
     gdouble sx, sy;
@@ -1942,41 +1928,32 @@ p3d_prepare_wdata(ExtractControls *controls, ExtractArgs *args)
 }
 
 static gboolean
-gothere(gdouble *data, gdouble *vdata, gint xres, gint yres, gint col, gint row, gint dir, gdouble threshold)
+gothere(gdouble *data, gdouble *vdata, gint xres, gint yres, gint col, gint row, gdouble threshold)
 {
-    if (vdata[col+xres*row] == 1) return FALSE;
-    if (row < 1 || row>=(yres-1)) return FALSE;
-    if (col < 1 || col>=(xres-1)) return FALSE;
+    guint k = row + yres*col;
 
-    if (dir == 0) /*y const*/ {
-    if ((data[row + yres*col]>threshold) &&
-                                     ((data[row-1 + yres*col]<threshold) || (data[row + yres*(col-1)]<threshold)
-                                      || (data[row+1 + yres*col]<threshold) || (data[row + yres*(col+1)]<threshold)
-                                      || (data[row+1 + yres*(col+1)]<threshold) || (data[row-1 + yres*(col-1)]<threshold)
-                                      || (data[row+1 + yres*(col-1)]<threshold) || (data[row-1 + yres*(col+1)]<threshold))) return TRUE;
+    if (vdata[k] == 1)
+        return FALSE;
+    if (row < 1 || row >= yres-1)
+        return FALSE;
+    if (col < 1 || col >= xres-1)
+        return FALSE;
 
-    } else if (dir == 1) /*y const;  HUH? shouldn't this be x const or something?*/ {
-        if (data[col + xres*row]>threshold &&
-                                     (data[col-1 + xres*row]<threshold || data[col + xres*(row-1)]<threshold
-                                      || data[col+1 + xres*row]<threshold || data[col + xres*(row+1)]<threshold
-                                      || data[col+1 + xres*(row+1)]<threshold || data[col-1 + xres*(row-1)]<threshold
-                                      || data[col+1 + xres*(row-1)]<threshold || data[col-1 + xres*(row+1)]<threshold)) return TRUE;
-    } else {
-        if (data[col + xres*row]>threshold &&
-                                     (data[col-1 + xres*row]<threshold || data[col + xres*(row-1)]<threshold
-                                      || data[col+1 + xres*row]<threshold || data[col + xres*(row+1)]<threshold
-                                      || data[col+1 + xres*(row+1)]<threshold || data[col-1 + xres*(row-1)]<threshold
-                                      || data[col+1 + xres*(row-1)]<threshold || data[col-1 + xres*(row+1)]<threshold)) return TRUE;
-     }
+    if ((data[k] > threshold) &&
+        ((data[k-1] < threshold) || (data[k-yres] < threshold)
+         || (data[k+1] < threshold) || (data[k+yres] < threshold)
+         || (data[k+yres+1] < threshold) || (data[k-yres-1] < threshold)
+         || (data[k-yres+1] < threshold) || (data[k+yres-1] < threshold)))
+        return TRUE;
 
-    vdata[col+xres*row] = 1;
+    vdata[k] = 1;
     return FALSE;
-
 }
 
 static void
 visitme(ExtractControls *controls, gint *actual_nps, gdouble *data, gdouble *vdata, gint xres, gint yres, gint zres, gint col, gint row, gint dir, gint tval, gboolean *move, gdouble threshold)
 {
+    gint first_res, second_res;
     /*detect ad add a segment of necessary*/
     //printf("pos %d %d ", col, row);
 
@@ -1993,11 +1970,13 @@ visitme(ExtractControls *controls, gint *actual_nps, gdouble *data, gdouble *vda
         controls->px[controls->nps] = 2*controls->bwidth*(gdouble)tval/(gdouble)xres - controls->bwidth;
         controls->py[controls->nps] = 2*controls->bheight*(gdouble)col/(gdouble)yres - controls->bheight;
         controls->pz[controls->nps] = 2*controls->bdepth*(gdouble)row/(gdouble)zres - controls->bdepth;
-    } else if (dir==1) /*y const*/ {
+    }
+    else if (dir == 1) /*y const*/ {
         controls->px[controls->nps] = 2*controls->bwidth*(gdouble)col/(gdouble)xres - controls->bwidth;
         controls->py[controls->nps] = 2*controls->bheight*(gdouble)tval/(gdouble)yres - controls->bheight;
         controls->pz[controls->nps] = 2*controls->bdepth*(gdouble)row/(gdouble)zres - controls->bdepth;
-    } else {
+    }
+    else {
         controls->px[controls->nps] = 2*controls->bwidth*(gdouble)col/(gdouble)xres - controls->bwidth;
         controls->py[controls->nps] = 2*controls->bheight*(gdouble)row/(gdouble)yres - controls->bheight;
         controls->pz[controls->nps] = 2*controls->bdepth*(gdouble)tval/(gdouble)zres - controls->bdepth;
@@ -2011,24 +1990,36 @@ visitme(ExtractControls *controls, gint *actual_nps, gdouble *data, gdouble *vda
     controls->nps += 1;
     vdata[col+xres*row] = 1;
 
-    /*go to neighbor positions*/
-    if (gothere(data, vdata, xres, yres, col+1, row, dir, threshold))
-        visitme(controls, actual_nps,data, vdata, xres, yres, zres, col+1, row, dir, tval, move, threshold);
-    else if (gothere(data, vdata, xres, yres, col-1, row, dir, threshold))
-             visitme(controls, actual_nps, data, vdata, xres, yres, zres, col-1, row, dir, tval, move, threshold);
-    else if (gothere(data, vdata, xres, yres, col, row+1, dir, threshold))
-             visitme(controls, actual_nps, data, vdata, xres, yres, zres, col, row+1, dir, tval, move, threshold);
-    else if (gothere(data, vdata, xres, yres, col, row-1, dir, threshold))
-             visitme(controls, actual_nps, data, vdata, xres, yres, zres, col, row-1, dir, tval, move, threshold);
-    else if (gothere(data, vdata, xres, yres, col+1, row+1, dir, threshold))
-             visitme(controls, actual_nps, data, vdata, xres, yres, zres, col+1, row+1, dir, tval, move, threshold);
-    else if (gothere(data, vdata, xres, yres, col-1, row-1, dir, threshold))
-             visitme(controls, actual_nps, data, vdata, xres, yres, zres, col-1, row-1, dir, tval, move, threshold);
-    else if (gothere(data, vdata, xres, yres, col+1, row-1, dir, threshold))
-             visitme(controls, actual_nps, data, vdata, xres, yres, zres, col+1, row-1, dir, tval, move, threshold);
-    else if (gothere(data, vdata, xres, yres, col-1, row+1, dir, threshold))
-             visitme(controls, actual_nps, data, vdata, xres, yres, zres, col-1, row+1, dir, tval, move, threshold);
+    if (dir == 0) {
+        first_res = yres;
+        second_res = zres;
+    }
+    else if (dir == 1) {
+        first_res = xres;
+        second_res = zres;
+    }
+    else {
+        first_res = xres;
+        second_res = yres;
+    }
 
+    /*go to neighbor positions*/
+    if (gothere(data, vdata, first_res, second_res, col+1, row, threshold))
+        visitme(controls, actual_nps,data, vdata, xres, yres, zres, col+1, row, dir, tval, move, threshold);
+    else if (gothere(data, vdata, first_res, second_res, col-1, row, threshold))
+        visitme(controls, actual_nps, data, vdata, xres, yres, zres, col-1, row, dir, tval, move, threshold);
+    else if (gothere(data, vdata, first_res, second_res, col, row+1, threshold))
+        visitme(controls, actual_nps, data, vdata, xres, yres, zres, col, row+1, dir, tval, move, threshold);
+    else if (gothere(data, vdata, first_res, second_res, col, row-1, threshold))
+        visitme(controls, actual_nps, data, vdata, xres, yres, zres, col, row-1, dir, tval, move, threshold);
+    else if (gothere(data, vdata, first_res, second_res, col+1, row+1, threshold))
+        visitme(controls, actual_nps, data, vdata, xres, yres, zres, col+1, row+1, dir, tval, move, threshold);
+    else if (gothere(data, vdata, first_res, second_res, col-1, row-1, threshold))
+        visitme(controls, actual_nps, data, vdata, xres, yres, zres, col-1, row-1, dir, tval, move, threshold);
+    else if (gothere(data, vdata, first_res, second_res, col+1, row-1, threshold))
+        visitme(controls, actual_nps, data, vdata, xres, yres, zres, col+1, row-1, dir, tval, move, threshold);
+    else if (gothere(data, vdata, first_res, second_res, col-1, row+1, threshold))
+        visitme(controls, actual_nps, data, vdata, xres, yres, zres, col-1, row+1, dir, tval, move, threshold);
 }
 
 static void
@@ -2055,8 +2046,8 @@ p3d_add_wireframe(ExtractControls *controls)
     threshold = gwy_brick_get_min(controls->brick)
         + (gwy_brick_get_max(controls->brick) - gwy_brick_get_min(controls->brick))/100.0*controls->args->threshold;
 
-    for (i=0; i<xres; i+=spacing) // why use 40 as a magic number - choose xres / 15 or something like that?
-    {
+    for (i = 0; i < xres; i += spacing) { // why use 40 as a magic number - choose xres / 15 or something like that?
+        /* Extract yz plane. */
         gwy_brick_extract_plane(controls->brick, cut, i, 0, 0, -1, yres, zres, FALSE);
         data = gwy_data_field_get_data(cut);
         gwy_data_field_clear(visited);
@@ -2064,12 +2055,10 @@ p3d_add_wireframe(ExtractControls *controls)
         gwy_data_field_threshold(cut, threshold, 0, 1);
         move = 1;
         /*here comes the algorithm*/
-        for (col=1; col<zres-1; col++)
-        {
-        for (row=1; row<yres-1; row++)
-            {
+        for (col=1; col < zres-1; col++) {
+            for (row=1; row < yres-1; row++) {
                 move = 1;
-        if (gothere(data, vdata, zres, yres, col, row, 0, threshold)) {
+                if (gothere(data, vdata, yres, zres, col, row, threshold)) {
                     visitme(controls, &actual_nps, data, vdata, xres, yres, zres, col, row, 0, i, &move, threshold);
                 }
             }
@@ -2078,8 +2067,8 @@ p3d_add_wireframe(ExtractControls *controls)
 
     gwy_data_field_resample(visited, xres, zres, GWY_INTERPOLATION_NONE);
 
-    for (i=0; i<yres; i+=spacing)
-    {
+    for (i = 0; i < yres; i += spacing) {
+        /* Extract xz plane. */
         gwy_brick_extract_plane(controls->brick, cut, 0, i, 0, xres, -1, zres, FALSE);
         data = gwy_data_field_get_data(cut);
 
@@ -2091,21 +2080,19 @@ p3d_add_wireframe(ExtractControls *controls)
         move = 1;
 
         /*here comes the algorithm*/
-        for (col=1; col<xres; col++)
-        {
-            for (row=1; row<zres; row++)
-            {
-                    move = 1;
-                    if (gothere(data, vdata, xres, yres, col, row, 1, threshold))
-                        visitme(controls, &actual_nps, data, vdata, xres, yres, zres, col, row, 1, i, &move, threshold);
+        for (col = 1; col < xres; col++) {
+            for (row = 1; row < zres; row++) {
+                move = 1;
+                if (gothere(data, vdata, xres, zres, col, row, threshold))
+                    visitme(controls, &actual_nps, data, vdata, xres, yres, zres, col, row, 1, i, &move, threshold);
             }
         }
     }
 
     gwy_data_field_resample(visited, xres, yres, GWY_INTERPOLATION_NONE);
 
-    for (i=0; i<zres; i+=spacing)
-    {
+    for (i = 0; i < zres; i += spacing) {
+        /* Extract xy plane. */
         gwy_brick_extract_plane(controls->brick, cut, 0, 0, i, xres, yres, -1, FALSE);
         data = gwy_data_field_get_data(cut);
 
@@ -2117,26 +2104,20 @@ p3d_add_wireframe(ExtractControls *controls)
         move = 1;
 
         /*here comes the algorithm*/
-        for (col=1; col<xres; col++)
-        {
-            for (row=1; row<yres; row++)
-            {
-                    move = 1;
-                    if (gothere(data, vdata, xres, yres, col, row, 2, threshold))
-                        visitme(controls, &actual_nps, data, vdata, xres, yres, zres, col, row, 2, i, &move, threshold);
+        for (col = 1; col < xres; col++) {
+            for (row = 1; row < yres; row++) {
+                move = 1;
+                if (gothere(data, vdata, xres, yres, col, row, threshold))
+                    visitme(controls, &actual_nps, data, vdata, xres, yres, zres, col, row, 2, i, &move, threshold);
             }
         }
     }
 //    printf("we have %d segments at the end\nRunning simplification:\n", controls->nps);
-    controls->nps = simplify(controls->px, controls->py, controls->pz, controls->ps, controls->nps);
-
-    if (controls->wpx) g_free(controls->wpx);
-    if (controls->wpy) g_free(controls->wpy);
-    if (controls->wpz) g_free(controls->wpz);
-
-    controls->wpx = g_new(gdouble, controls->nps);
-    controls->wpy = g_new(gdouble, controls->nps);
-    controls->wpz = g_new(gdouble, controls->nps);
+    controls->nps = simplify(controls->px, controls->py, controls->pz,
+                             controls->ps, controls->nps);
+    controls->wpx = g_renew(gdouble, controls->wpx, controls->nps);
+    controls->wpy = g_renew(gdouble, controls->wpy, controls->nps);
+    controls->wpz = g_renew(gdouble, controls->wpz, controls->nps);
 
 //    printf("we have %d segments after simplification\n", controls->nps);
 }
