@@ -198,19 +198,19 @@ static GwyModuleInfo module_info = {
     &module_register,
     N_("Evaluate volume force-distance data"),
     "Petr Klapetek <klapetek@gwyddion.net>",
-    "1.0",
+    "1.1",
     "David Nečas (Yeti) & Petr Klapetek",
     "2013",
 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, volume_fdfit)
 
 static gboolean
 module_register(void)
 {
     gwy_volume_func_register("volume_fdfit",
                             (GwyVolumeFunc)&volfit,
-                            N_("/_Evaluate FD data..."),
+                            N_("/_Evaluate FD Data..."),
                             GWY_STOCK_VOLUME_FD,
                             VOLFIT_RUN_MODES,
                             GWY_MENU_FLAG_VOLUME,
@@ -264,7 +264,7 @@ volfit(GwyContainer *data, GwyRunType run)
 static void
 volfit_dialog(VolfitArgs *args)
 {
-    GtkWidget *label, *dialog, *hbox, *hbox2, *table, *align, *expander, *scroll, *spin;
+    GtkWidget *label, *dialog, *hbox, *hbox2, *table, *align, *expander, *scroll;
     GtkTable *table2;
     GwyGraphArea *area;
     GwySelection *selection;
@@ -365,54 +365,30 @@ volfit_dialog(VolfitArgs *args)
     row = 0;
 
     /* Curve to volfit selected by xpos, ypos*/
-    label = gtk_label_new_with_mnemonic(_("Curve _X position:"));
-    gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
-    gtk_table_attach(GTK_TABLE(table), label,
-                     0, 1, row, row+1, GTK_FILL, 0, 0, 0);
-
     controls.xpos = gtk_adjustment_new(args->xpos,
-                                        0, gwy_brick_get_xres(args->brick)-1, 1, 10, 0);
-    spin = gtk_spin_button_new(GTK_ADJUSTMENT(controls.xpos), 1, 2);
-    gtk_spin_button_set_numeric(GTK_SPIN_BUTTON(spin), TRUE);
-    gtk_spin_button_set_digits(GTK_SPIN_BUTTON(spin), 0);
-    gtk_table_attach(GTK_TABLE(table), spin,
-                     1, 2, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
+                                       0, gwy_brick_get_xres(args->brick)-1,
+                                       1, 10, 0);
+    gwy_table_attach_adjbar(table, row, _("Curve _X position:"), NULL,
+                            controls.xpos, GWY_HSCALE_LINEAR | GWY_HSCALE_SNAP);
     g_signal_connect(controls.xpos, "value-changed",
                      G_CALLBACK(xpos_changed_cb), &controls);
-
-
-
     row++;
-    label = gtk_label_new_with_mnemonic(_("Curve _Y position:"));
-    gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
-    gtk_table_attach(GTK_TABLE(table), label,
-                     0, 1, row, row+1, GTK_FILL, 0, 0, 0);
 
     controls.ypos = gtk_adjustment_new(args->ypos,
-                                       0, gwy_brick_get_yres(args->brick)-1, 1, 10, 0);
-    spin = gtk_spin_button_new(GTK_ADJUSTMENT(controls.ypos), 1, 2);
-    gtk_spin_button_set_numeric(GTK_SPIN_BUTTON(spin), TRUE);
-    gtk_spin_button_set_digits(GTK_SPIN_BUTTON(spin), 0);
-    gtk_table_attach(GTK_TABLE(table), spin,
-                     1, 2, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
+                                       0, gwy_brick_get_yres(args->brick)-1,
+                                       1, 10, 0);
+    gwy_table_attach_adjbar(table, row, _("Curve _Y position:"), NULL,
+                            controls.ypos, GWY_HSCALE_LINEAR | GWY_HSCALE_SNAP);
     g_signal_connect(controls.ypos, "value-changed",
                      G_CALLBACK(ypos_changed_cb), &controls);
-
     row++;
 
-
     /* Fitted function */
-    label = gtk_label_new_with_mnemonic(_("F_unction:"));
-    gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
-    gtk_table_attach(GTK_TABLE(table), label,
-                     0, 1, row, row+1, GTK_FILL, 0, 0, 0);
-
     controls.function = function_selector_new(G_CALLBACK(function_changed),
                                               &controls, args->function_type);
-    gtk_label_set_mnemonic_widget(GTK_LABEL(label), controls.function);
-
-    gtk_table_attach(GTK_TABLE(table), controls.function,
-                     1, 2, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
+    gwy_table_attach_adjbar(table, row, _("F_unction:"), NULL,
+                            GTK_OBJECT(controls.function),
+                            GWY_HSCALE_WIDGET_NO_EXPAND);
     row++;
 
     controls.formula = gtk_label_new("f(x) =");
@@ -466,7 +442,7 @@ volfit_dialog(VolfitArgs *args)
     controls.chisq = gtk_label_new(NULL);
     gtk_misc_set_alignment(GTK_MISC(controls.chisq), 0.0, 0.5);
     gtk_table_attach(GTK_TABLE(table), controls.chisq,
-                     1, 2, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
+                     1, 2, row, row+1, GTK_FILL, 0, 0, 0);
 
     gtk_table_set_row_spacing(GTK_TABLE(table), row, 8);
     row++;
