@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: volume_kmeans.c 19058 2016-10-12 15:08:10Z dn2010 $
+ *  @(#) $Id: volume_kmeans.c 20088 2017-07-25 20:44:20Z dn2010 $
  *  Copyright (C) 2003 David Necas (Yeti), Petr Klapetek,
  *  Daniil Bratashov, Evgeniy Ryabov.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net, dn2010@gmail.com.
@@ -60,24 +60,25 @@ typedef struct {
     GtkObject *outliers_threshold;
 } KMeansControls;
 
-static gboolean  module_register     (void);
-static void      volume_kmeans       (GwyContainer *data,
-                                      GwyRunType run);
-static void      kmeans_dialog       (GwyContainer *data,
-                                      KMeansArgs *args);
-static void  remove_outliers_toggled (KMeansControls *controls);
-static void      kmeans_dialog_update(KMeansControls *controls,
-                                      KMeansArgs *args);
-static void      kmeans_values_update(KMeansControls *controls,
-                                      KMeansArgs *args);
-static GwyBrick* normalize_brick     (GwyBrick *brick,
-                                      GwyDataField *intfield);
-static void      volume_kmeans_do    (GwyContainer *data,
-                                      KMeansArgs *args);
-static void      kmeans_load_args    (GwyContainer *container,
-                                      KMeansArgs *args);
-static void      kmeans_save_args    (GwyContainer *container,
-                                      KMeansArgs *args);
+static gboolean  module_register        (void);
+static void      volume_kmeans          (GwyContainer *data,
+                                         GwyRunType run);
+static void      kmeans_dialog          (GwyContainer *data,
+                                         KMeansArgs *args);
+static void      remove_outliers_toggled(KMeansControls *controls,
+                                         GtkToggleButton *toggle);
+static void      kmeans_dialog_update   (KMeansControls *controls,
+                                         KMeansArgs *args);
+static void      kmeans_values_update   (KMeansControls *controls,
+                                         KMeansArgs *args);
+static GwyBrick* normalize_brick        (GwyBrick *brick,
+                                         GwyDataField *intfield);
+static void      volume_kmeans_do       (GwyContainer *data,
+                                         KMeansArgs *args);
+static void      kmeans_load_args       (GwyContainer *container,
+                                         KMeansArgs *args);
+static void      kmeans_save_args       (GwyContainer *container,
+                                         KMeansArgs *args);
 
 static const KMeansArgs kmeans_defaults = {
     10,
@@ -93,19 +94,19 @@ static GwyModuleInfo module_info = {
     &module_register,
     N_("Calculates K-means clustering on volume data."),
     "Daniil Bratashov <dn2010@gmail.com> & Evgeniy Ryabov <k1u2r3ka@mail.ru>",
-    "1.4",
+    "1.5",
     "David Nečas (Yeti) & Petr Klapetek & Daniil Bratashov & Evgeniy Ryabov",
     "2014",
 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, volume_kmeans)
 
 static gboolean
 module_register(void)
 {
     gwy_volume_func_register("kmeans",
                               (GwyVolumeFunc)&volume_kmeans,
-                              N_("/_K-means clustering..."),
+                              N_("/_K-Means Clustering..."),
                               GWY_STOCK_VOLUME_KMEANS,
                               KMEANS_RUN_MODES,
                               GWY_MENU_FLAG_VOLUME,
@@ -158,7 +159,7 @@ kmeans_dialog(GwyContainer *data, KMeansArgs *args)
     gtk_dialog_set_default_response(GTK_DIALOG(dialog), GTK_RESPONSE_OK);
     gwy_help_add_to_volume_dialog(GTK_DIALOG(dialog), GWY_HELP_DEFAULT);
 
-    table = gtk_table_new(6, 4, FALSE);
+    table = gtk_table_new(6, 3, FALSE);
     gtk_table_set_row_spacings(GTK_TABLE(table), 2);
     gtk_table_set_col_spacings(GTK_TABLE(table), 6);
     gtk_container_set_border_width(GTK_CONTAINER(table), 4);
@@ -166,50 +167,42 @@ kmeans_dialog(GwyContainer *data, KMeansArgs *args)
                        TRUE, TRUE, 4);
 
     controls.k = gtk_adjustment_new(args->k, 2, 100, 1, 10, 0);
-    gwy_table_attach_hscale(table, row,
-                            _("_Number of clusters:"), NULL,
-                            controls.k, GWY_HSCALE_SQRT);
+    gwy_table_attach_adjbar(table, row, _("_Number of clusters:"), NULL,
+                            controls.k, GWY_HSCALE_SQRT | GWY_HSCALE_SNAP);
     row++;
 
     controls.epsilon = gtk_adjustment_new(-log10(args->epsilon),
                                           1.0, 20.0, 0.01, 1.0, 0);
-    gwy_table_attach_hscale(table, row,
+    gwy_table_attach_adjbar(table, row,
                             _("Convergence _precision digits:"), NULL,
-                            controls.epsilon, GWY_HSCALE_DEFAULT);
+                            controls.epsilon, GWY_HSCALE_LINEAR);
     row++;
 
     controls.max_iterations = gtk_adjustment_new(args->max_iterations,
                                                  1, 10000, 1, 1, 0);
-    gwy_table_attach_hscale(table, row,
-                            _("_Max. iterations:"), NULL,
+    gwy_table_attach_adjbar(table, row, _("_Max. iterations:"), NULL,
                             controls.max_iterations, GWY_HSCALE_LOG);
     row++;
 
-    controls.normalize
-                  = gtk_check_button_new_with_mnemonic(_("_Normalize"));
-    gtk_table_attach_defaults(GTK_TABLE(table), controls.normalize,
-                              0, 3, row, row+1);
+    controls.normalize = gtk_check_button_new_with_mnemonic(_("_Normalize"));
+    gtk_table_attach(GTK_TABLE(table), controls.normalize,
+                     0, 2, row, row+1, GTK_FILL, 0, 0, 0);
     row++;
 
     controls.remove_outliers
         = gtk_check_button_new_with_mnemonic(_("_Remove outliers"));
-    gtk_table_attach_defaults(GTK_TABLE(table),
-                              controls.remove_outliers,
-                              0, 3, row, row+1);
+    gtk_table_attach(GTK_TABLE(table), controls.remove_outliers,
+                     0, 2, row, row+1, GTK_FILL, 0, 0, 0);
     g_signal_connect_swapped(controls.remove_outliers, "toggled",
-                             G_CALLBACK(remove_outliers_toggled),
-                             &controls);
+                             G_CALLBACK(remove_outliers_toggled), &controls);
     row++;
 
-    controls.outliers_threshold
-                          = gtk_adjustment_new(args->outliers_threshold,
-                                               1.0, 10.0, 0.1, 1, 0);
-    gwy_table_attach_hscale(table, row,
-                            _("Outliers _threshold:"), NULL,
-                            controls.outliers_threshold,
-                            GWY_HSCALE_DEFAULT);
+    controls.outliers_threshold = gtk_adjustment_new(args->outliers_threshold,
+                                                     1.0, 10.0, 0.1, 1, 0);
+    gwy_table_attach_adjbar(table, row, _("Outliers _threshold:"), NULL,
+                            controls.outliers_threshold, GWY_HSCALE_LINEAR);
     gwy_table_hscale_set_sensitive(controls.outliers_threshold,
-                                   gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(controls.remove_outliers)));
+                                   args->remove_outliers);
     row++;
 
     kmeans_dialog_update(&controls, args);
@@ -245,10 +238,11 @@ kmeans_dialog(GwyContainer *data, KMeansArgs *args)
     volume_kmeans_do(data, args);
 }
 
-static void remove_outliers_toggled (KMeansControls *controls)
+static void
+remove_outliers_toggled(KMeansControls *controls, GtkToggleButton *toggle)
 {
     gwy_table_hscale_set_sensitive(controls->outliers_threshold,
-                                   gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(controls->remove_outliers)));
+                                   gtk_toggle_button_get_active(toggle));
 }
 
 /* XXX: Duplicate with volume_kmedians.c */
@@ -702,6 +696,9 @@ volume_kmeans_do(GwyContainer *container, KMeansArgs *args)
                      g_strdup_printf(_("K-means center %d"), c + 1),
                      "color", rgba,
                      NULL);
+        if (!gwy_graph_curve_model_is_ordered(gcmodel)) {
+            gwy_graph_curve_model_enforce_order(gcmodel);
+        }
         gwy_graph_model_add_curve(gmodel, gcmodel);
         g_object_unref(gcmodel);
     }
