@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: volume_kmedians.c 18886 2016-08-26 08:26:22Z yeti-dn $
+ *  @(#) $Id: volume_kmedians.c 20088 2017-07-25 20:44:20Z dn2010 $
  *  Copyright (C) 2003 David Necas (Yeti), Petr Klapetek,
  *  Daniil Bratashov, Evgeniy Ryabov.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net,
@@ -87,19 +87,19 @@ static GwyModuleInfo module_info = {
     &module_register,
     N_("Calculates K-medians clustering on volume data."),
     "Daniil Bratashov <dn2010@gmail.com> & Evgeniy Ryabov <k1u2r3ka@mail.ru>",
-    "1.1",
+    "1.2",
     "David Nečas (Yeti) & Petr Klapetek & Daniil Bratashov & Evgeniy Ryabov",
     "2014",
 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, volume_kmedians)
 
 static gboolean
 module_register(void)
 {
     gwy_volume_func_register("kmedians",
                              (GwyVolumeFunc)&volume_kmedians,
-                             N_("/_K-medians clustering..."),
+                             N_("/_K-Medians Clustering..."),
                              GWY_STOCK_VOLUME_KMEDIANS,
                              KMEDIANS_RUN_MODES,
                              GWY_MENU_FLAG_VOLUME,
@@ -152,7 +152,7 @@ kmedians_dialog(GwyContainer *data, KMediansArgs *args)
     gtk_dialog_set_default_response(GTK_DIALOG(dialog), GTK_RESPONSE_OK);
     gwy_help_add_to_volume_dialog(GTK_DIALOG(dialog), GWY_HELP_DEFAULT);
 
-    table = gtk_table_new(4, 4, FALSE);
+    table = gtk_table_new(4, 3, FALSE);
     gtk_table_set_row_spacings(GTK_TABLE(table), 2);
     gtk_table_set_col_spacings(GTK_TABLE(table), 6);
     gtk_container_set_border_width(GTK_CONTAINER(table), 4);
@@ -160,29 +160,27 @@ kmedians_dialog(GwyContainer *data, KMediansArgs *args)
                        TRUE, TRUE, 4);
 
     controls.k = gtk_adjustment_new(args->k, 2, 100, 1, 10, 0);
-    gwy_table_attach_hscale(table, row,
-                            _("_Number of clusters:"), NULL,
+    gwy_table_attach_adjbar(table, row, _("_Number of clusters:"), NULL,
                             controls.k, GWY_HSCALE_SQRT);
     row++;
 
     controls.epsilon = gtk_adjustment_new(-log10(args->epsilon),
                                           1.0, 20.0, 0.01, 1.0, 0);
-    gwy_table_attach_hscale(table, row,
+    gwy_table_attach_adjbar(table, row,
                             _("Convergence _precision digits:"), NULL,
-                            controls.epsilon, GWY_HSCALE_DEFAULT);
+                            controls.epsilon, GWY_HSCALE_LINEAR);
     row++;
 
     controls.max_iterations = gtk_adjustment_new(args->max_iterations,
                                                  1, 10000, 1, 1, 0);
-    gwy_table_attach_hscale(table, row,
-                            _("_Max. iterations:"), NULL,
+    gwy_table_attach_adjbar(table, row, _("_Max. iterations:"), NULL,
                             controls.max_iterations, GWY_HSCALE_LOG);
     row++;
 
     controls.normalize
         = gtk_check_button_new_with_mnemonic(_("_Normalize"));
-    gtk_table_attach_defaults(GTK_TABLE(table), controls.normalize,
-                              0, 3, row, row+1);
+    gtk_table_attach(GTK_TABLE(table), controls.normalize,
+                     0, 2, row, row+1, GTK_FILL, 0, 0, 0);
 
     kmedians_dialog_update(&controls, args);
     gtk_widget_show_all(dialog);
@@ -546,6 +544,9 @@ volume_kmedians_do(GwyContainer *container, KMediansArgs *args)
                      g_strdup_printf(_("K-medians center %d"), c + 1),
                      "color", rgba,
                      NULL);
+        if (!gwy_graph_curve_model_is_ordered(gcmodel)) {
+            gwy_graph_curve_model_enforce_order(gcmodel);
+        }
         gwy_graph_model_add_curve(gmodel, gcmodel);
         g_object_unref(gcmodel);
     }
