@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: volume_linestat.c 17511 2015-10-05 21:09:24Z yeti-dn $
+ *  @(#) $Id: volume_linestat.c 20173 2017-08-07 04:58:08Z dn2010 $
  *  Copyright (C) 2015 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
@@ -143,6 +143,8 @@ static const GwyEnum quantities[] =  {
     { N_("Median"),             GWY_LINE_STAT_MEDIAN,    },
     { N_("Minimum"),            GWY_LINE_STAT_MINIMUM,   },
     { N_("Maximum"),            GWY_LINE_STAT_MAXIMUM,   },
+    { N_("Min. position"),      GWY_LINE_STAT_MINPOS,    },
+    { N_("Max. position"),      GWY_LINE_STAT_MAXPOS,    },
     { N_("Range"),              GWY_LINE_STAT_RANGE,     },
     { N_("Slope"),              GWY_LINE_STAT_SLOPE,     },
     { N_("tan β<sub>0</sub>"),  GWY_LINE_STAT_TAN_BETA0, },
@@ -170,12 +172,12 @@ static GwyModuleInfo module_info = {
     &module_register,
     N_("Summarizes profiles of volume data to a channel."),
     "Yeti <yeti@gwyddion.net>",
-    "1.0",
+    "1.2",
     "David Nečas (Yeti)",
     "2015",
 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, volume_linestat)
 
 static gboolean
 module_register(void)
@@ -215,7 +217,7 @@ line_stat(GwyContainer *data, GwyRunType run)
             != gwy_data_line_get_res(args.calibration)))
         args.calibration = NULL;
 
-    wunit = gwy_brick_get_si_unit_z(brick);
+    wunit = gwy_brick_get_si_unit_w(brick);
     if (args.calibration)
         zunit = gwy_data_line_get_si_unit_y(args.calibration);
     else
@@ -255,6 +257,7 @@ line_stat_dialog(LineStatArgs *args, GwyContainer *data, gint id)
     GwyDataField *dfield;
     GwyGraphCurveModel *gcmodel;
     GwyGraphModel *gmodel;
+    GwySIUnit *siunitz;
     gint response, row;
     GwyPixmapLayer *layer;
     GwyVectorLayer *vlayer = NULL;
@@ -263,23 +266,25 @@ line_stat_dialog(LineStatArgs *args, GwyContainer *data, gint id)
     const guchar *gradient;
     gchar key[40];
     gdouble xy[2];
+    gdouble zmax;
     guint nquantities;
 
     controls.args = args;
 
     brick = args->brick;
     if (args->calibration) {
-        controls.zvf
-            = gwy_data_line_get_value_format_y(args->calibration,
-                                               GWY_SI_UNIT_FORMAT_VFMARKUP,
-                                               NULL);
+        siunitz = gwy_data_line_get_si_unit_y(args->calibration);
+        zmax = gwy_data_line_get_max(args->calibration);
     }
     else {
-        controls.zvf
-            = gwy_brick_get_value_format_z(brick,
-                                           GWY_SI_UNIT_FORMAT_VFMARKUP,
-                                           NULL);
+        siunitz = gwy_brick_get_si_unit_z(brick);
+        zmax = gwy_brick_get_zreal(brick);
     }
+    controls.zvf = gwy_si_unit_get_format_with_digits(siunitz,
+                                                      GWY_SI_UNIT_FORMAT_VFMARKUP,
+                                                      zmax,
+                                                      5, /* 5 digits */
+                                                      NULL);
 
     dialog = gtk_dialog_new_with_buttons(_("Summarize Volume Profiles"),
                                          NULL, 0, NULL);
@@ -710,6 +715,8 @@ extract_summary_image(const LineStatArgs *args, GwyDataField *dfield)
         { GWY_LINE_STAT_MEDIAN,    gwy_data_line_get_median,    },
         { GWY_LINE_STAT_MINIMUM,   gwy_data_line_get_min,       },
         { GWY_LINE_STAT_MAXIMUM,   gwy_data_line_get_max,       },
+        { GWY_LINE_STAT_MINPOS,    gwy_data_line_min_pos_i,     },
+        { GWY_LINE_STAT_MAXPOS,    gwy_data_line_max_pos_i,     },
         { GWY_LINE_STAT_RANGE,     get_data_line_range,         },
         { GWY_LINE_STAT_LENGTH,    gwy_data_line_get_length,    },
         { GWY_LINE_STAT_TAN_BETA0, gwy_data_line_get_tan_beta0, },
@@ -726,12 +733,13 @@ extract_summary_image(const LineStatArgs *args, GwyDataField *dfield)
     GwyLineStatQuantity quantity = args->quantity;
     GwyBrick *brick = args->brick;
     GwySIUnit *imgunit, *zunit, *wunit;
-    gint xres = brick->xres, yres = brick->yres;
+    gint xres = brick->xres, yres = brick->yres, zres = brick->zres;
     gint zfrom = args->zfrom, zto = args->zto;
     LineStatIter iter;
     LineStatFunc lsfunc = NULL;
-    gint i;
+    gint i, j;
     guint k;
+    gdouble *data, val, zreal, zoffset;
 
     if (zfrom == -1 && zto == -1) {
         zfrom = 0;
@@ -765,25 +773,49 @@ extract_summary_image(const LineStatArgs *args, GwyDataField *dfield)
     }
     line_stat_iter_free(&iter);
 
+    if ((quantity == GWY_LINE_STAT_MINPOS)
+        || (quantity == GWY_LINE_STAT_MAXPOS)) {
+        gwy_data_field_add(dfield, zfrom);
+        if (args->calibration) {
+            data = gwy_data_field_get_data(dfield);
+            for (i = 0; i < xres * yres; i++) {
+                j = *(data);
+                val = gwy_data_line_get_val(args->calibration, j);
+                *(data++) = val;
+            }
+            gwy_data_field_data_changed(dfield);
+        }
+        else {
+            zreal = gwy_brick_get_zreal(args->brick);
+            zoffset = gwy_brick_get_zoffset(args->brick);
+            gwy_data_field_multiply(dfield, zreal/zres);
+            gwy_data_field_add(dfield, zoffset);
+        }
+    }
+
     imgunit = gwy_data_field_get_si_unit_z(dfield);
-    wunit = gwy_brick_get_si_unit_z(brick);
+    wunit = gwy_brick_get_si_unit_w(brick);
     if (args->calibration)
         zunit = gwy_data_line_get_si_unit_y(args->calibration);
     else
         zunit = gwy_brick_get_si_unit_z(brick);
 
-    if (quantity == GWY_LINE_STAT_TAN_BETA0
-        || quantity == GWY_LINE_STAT_SLOPE)
+    if ((quantity == GWY_LINE_STAT_MINPOS)
+        || (quantity == GWY_LINE_STAT_MAXPOS)) {
+        gwy_serializable_clone(G_OBJECT(zunit),
+                               G_OBJECT(gwy_data_field_get_si_unit_z(dfield)));
+    }
+    else if ((quantity == GWY_LINE_STAT_TAN_BETA0)
+             || (quantity == GWY_LINE_STAT_SLOPE))
         gwy_si_unit_divide(wunit, zunit, imgunit);
-    else if (quantity == GWY_LINE_STAT_SKEW
-             || quantity == GWY_LINE_STAT_KURTOSIS)
+    else if ((quantity == GWY_LINE_STAT_SKEW)
+             || (quantity == GWY_LINE_STAT_KURTOSIS))
         gwy_si_unit_set_from_string(imgunit, NULL);
     else if (quantity == GWY_LINE_STAT_VARIATION)
         gwy_si_unit_multiply(wunit, zunit, imgunit);
 
     gwy_data_field_invalidate(dfield);
     gwy_data_field_data_changed(dfield);
-
 }
 
 static void
