@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: volume_slice.c 18886 2016-08-26 08:26:22Z yeti-dn $
+ *  @(#) $Id: volume_slice.c 19948 2017-06-22 14:05:41Z yeti-dn $
  *  Copyright (C) 2015-2016 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
@@ -25,6 +25,7 @@
 #include <libgwyddion/gwymacros.h>
 #include <libgwyddion/gwymath.h>
 #include <libprocess/brick.h>
+#include <libprocess/gwyprocess.h>
 #include <libgwydgets/gwydataview.h>
 #include <libgwydgets/gwylayer-basic.h>
 #include <libgwydgets/gwyradiobuttons.h>
@@ -170,7 +171,6 @@ static void     extract_graph_curve    (const SliceArgs *args,
                                         gboolean use_calibration);
 static void     extract_gmodel         (const SliceArgs *args,
                                         GwyGraphModel *gmodel);
-static void     flip_xy                (GwyDataField *dfield);
 static void     slice_sanitize_args    (SliceArgs *args);
 static void     slice_load_args        (GwyContainer *container,
                                         SliceArgs *args);
@@ -195,12 +195,12 @@ static GwyModuleInfo module_info = {
     &module_register,
     N_("Extracts image planes and line graphs from volume data."),
     "Yeti <yeti@gwyddion.net>",
-    "2.2",
+    "2.3",
     "David Nečas (Yeti)",
     "2015",
 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, volume_slice)
 
 static gboolean
 module_register(void)
@@ -275,6 +275,8 @@ slice_dialog(SliceArgs *args, GwyContainer *data, gint id)
     GwyDataLine *calibration;
     GwyGraphCurveModel *gcmodel;
     GwyGraphModel *gmodel;
+    GwySIUnit *siunitz;
+    gdouble zmax;
     gint response, row;
     GwyPixmapLayer *layer;
     GwyVectorLayer *vlayer = NULL;
@@ -441,7 +443,10 @@ slice_dialog(SliceArgs *args, GwyContainer *data, gint id)
 
     controls.xpos = gtk_adjustment_new(args->currpos.x, 0.0, brick->xres-1.0,
                                        1.0, 10.0, 0);
-    gwy_table_attach_spinbutton(table, row, _("_X:"), "px", controls.xpos);
+    gwy_table_attach_adjbar(table, row, _("_X:"), _("px"),
+                            controls.xpos, GWY_HSCALE_LINEAR | GWY_HSCALE_SNAP);
+    gtk_widget_set_size_request(gwy_table_hscale_get_scale(controls.xpos),
+                                96, -1);
     g_signal_connect_swapped(controls.xpos, "value-changed",
                              G_CALLBACK(xpos_changed), &controls);
 
@@ -461,7 +466,10 @@ slice_dialog(SliceArgs *args, GwyContainer *data, gint id)
 
     controls.ypos = gtk_adjustment_new(args->currpos.y, 0.0, brick->yres-1.0,
                                        1.0, 10.0, 0);
-    gwy_table_attach_spinbutton(table, row, _("_Y:"), "px", controls.ypos);
+    gwy_table_attach_adjbar(table, row, _("_Y:"), _("px"),
+                            controls.ypos, GWY_HSCALE_LINEAR | GWY_HSCALE_SNAP);
+    gtk_widget_set_size_request(gwy_table_hscale_get_scale(controls.xpos),
+                                96, -1);
     g_signal_connect_swapped(controls.ypos, "value-changed",
                              G_CALLBACK(ypos_changed), &controls);
 
@@ -481,7 +489,10 @@ slice_dialog(SliceArgs *args, GwyContainer *data, gint id)
 
     controls.zpos = gtk_adjustment_new(args->currpos.z, 0.0, brick->zres-1.0,
                                        1.0, 10.0, 0);
-    gwy_table_attach_spinbutton(table, row, _("_Z:"), "px", controls.zpos);
+    gwy_table_attach_adjbar(table, row, _("_Z:"), _("px"),
+                            controls.zpos, GWY_HSCALE_LINEAR | GWY_HSCALE_SNAP);
+    gtk_widget_set_size_request(gwy_table_hscale_get_scale(controls.xpos),
+                                96, -1);
     g_signal_connect_swapped(controls.zpos, "value-changed",
                              G_CALLBACK(zpos_changed), &controls);
 
@@ -490,15 +501,18 @@ slice_dialog(SliceArgs *args, GwyContainer *data, gint id)
     gtk_table_attach(GTK_TABLE(table), controls.zposreal,
                      3, 4, row, row+1, GTK_FILL, 0, 0, 0);
     if ((calibration = gwy_brick_get_zcalibration(brick))) {
-        controls.zvf = gwy_data_line_get_value_format_y(calibration,
-                                                        GWY_SI_UNIT_FORMAT_VFMARKUP,
-                                                        NULL);
+        siunitz = gwy_data_line_get_si_unit_y(calibration);
+        zmax = gwy_data_line_get_max(calibration);
     }
     else {
-        controls.zvf = gwy_brick_get_value_format_z(brick,
-                                                    GWY_SI_UNIT_FORMAT_VFMARKUP,
-                                                    NULL);
+        siunitz = gwy_brick_get_si_unit_z(brick);
+        zmax = gwy_brick_get_zreal(brick);
     }
+    controls.zvf = gwy_si_unit_get_format_with_digits(siunitz,
+                                                      GWY_SI_UNIT_FORMAT_VFMARKUP,
+                                                      zmax,
+                                                      5, /* 5 digits */
+                                                      NULL);
     label = gtk_label_new(controls.zvf->units);
     gtk_label_set_use_markup(GTK_LABEL(label), TRUE);
     gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
@@ -518,6 +532,7 @@ slice_dialog(SliceArgs *args, GwyContainer *data, gint id)
     update_position(&controls, &pos);
     controls.in_update = FALSE;
     multiselect_changed(&controls, GTK_TOGGLE_BUTTON(controls.multiselect));
+    update_target_graphs(&controls);
 
     gtk_widget_show_all(dialog);
     do {
@@ -730,7 +745,7 @@ plane_selection_changed(SliceControls *controls,
     if (base_plane == PLANE_YZ || base_plane == PLANE_ZY)
         pos.x = CLAMP(gwy_brick_rtoi(brick, r - brick->xoff), 0, brick->xres-1);
     else if (base_plane == PLANE_YX || base_plane == PLANE_XY)
-        pos.z = CLAMP(gwy_brick_rtok(brick, r - brick->zoff), 0, brick->zres-1);
+        pos.z = CLAMP(gwy_brick_rtok_cal(brick, r), 0, brick->zres-1);
     else if (base_plane == PLANE_XZ || base_plane == PLANE_ZX)
         pos.y = CLAMP(gwy_brick_rtoj(brick, r - brick->yoff), 0, brick->yres-1);
     else {
@@ -924,14 +939,14 @@ update_position(SliceControls *controls,
         xy[1] = gwy_brick_jtor(brick, pos->y);
         if (base_plane != PLANE_XY)
             GWY_SWAP(gdouble, xy[0], xy[1]);
-        z = gwy_brick_ktor(brick, pos->z) + brick->zoff;
+        z = gwy_brick_ktor_cal(brick, pos->z);
         point_changed = (pos->x != args->currpos.x
                          || pos->y != args->currpos.y);
         plane_changed = (pos->z != args->currpos.z);
     }
     else if (base_plane == PLANE_XZ || base_plane == PLANE_ZX) {
         xy[0] = gwy_brick_itor(brick, pos->x);
-        xy[1] = gwy_brick_ktor(brick, pos->z);
+        xy[1] = gwy_brick_ktor_cal(brick, pos->z);
         if (base_plane != PLANE_XZ)
             GWY_SWAP(gdouble, xy[0], xy[1]);
         z = gwy_brick_jtor(brick, pos->y) + brick->yoff;
@@ -941,7 +956,7 @@ update_position(SliceControls *controls,
     }
     else if (base_plane == PLANE_YZ || base_plane == PLANE_ZY) {
         xy[0] = gwy_brick_jtor(brick, pos->y);
-        xy[1] = gwy_brick_ktor(brick, pos->z);
+        xy[1] = gwy_brick_ktor_cal(brick, pos->z);
         if (base_plane != PLANE_YZ)
             GWY_SWAP(gdouble, xy[0], xy[1]);
         z = gwy_brick_itor(brick, pos->x) + brick->xoff;
@@ -973,7 +988,7 @@ update_position(SliceControls *controls,
         extract_gmodel(args, gmodel);
 
         gcmodel = gwy_graph_model_get_curve(gmodel, 0);
-        extract_graph_curve(args, gcmodel, controls->current_object, FALSE);
+        extract_graph_curve(args, gcmodel, controls->current_object, TRUE);
     }
 
     if (plane_changed) {
@@ -1033,7 +1048,6 @@ update_labels(SliceControls *controls)
 {
     SliceArgs *args = controls->args;
     GwyBrick *brick = args->brick;
-    GwyDataLine *calibration;
     gdouble x, y, z;
     gchar buf[64];
 
@@ -1047,9 +1061,7 @@ update_labels(SliceControls *controls)
                controls->xvf->precision, y/controls->yvf->magnitude);
     gtk_label_set_markup(GTK_LABEL(controls->yposreal), buf);
 
-    z = gwy_brick_ktor(brick, args->currpos.z);
-    if ((calibration = gwy_brick_get_zcalibration(brick)))
-        z = gwy_data_line_get_val(calibration, args->currpos.z);
+    z = gwy_brick_ktor_cal(brick, args->currpos.z);
     g_snprintf(buf, sizeof(buf), "%.*f",
                controls->zvf->precision, z/controls->zvf->magnitude);
     gtk_label_set_markup(GTK_LABEL(controls->zposreal), buf);
@@ -1141,14 +1153,13 @@ extract_one_image(SliceArgs *args, GwyContainer *data, gint id, gint idx)
 
     if (base_plane == PLANE_XY || base_plane == PLANE_YX) {
         i = pos->z;
+        r = gwy_brick_ktor_cal(brick, i);
         if ((calibration = gwy_brick_get_zcalibration(brick))) {
-            r = gwy_data_line_get_val(calibration, i);
             vf = gwy_data_line_get_value_format_y(calibration,
                                                   GWY_SI_UNIT_FORMAT_VFMARKUP,
                                                   NULL);
         }
         else {
-            r = gwy_brick_ktor(brick, i);
             vf = gwy_brick_get_value_format_z(brick,
                                               GWY_SI_UNIT_FORMAT_VFMARKUP,
                                               NULL);
@@ -1217,8 +1228,11 @@ extract_image_plane(const SliceArgs *args, GwyDataField *dfield)
                                 FALSE);
     }
 
-    if (do_flip)
-        flip_xy(dfield);
+    if (do_flip) {
+        GwyDataField *tmp = gwy_data_field_duplicate(dfield);
+        gwy_data_field_flip_xy(tmp, dfield, FALSE);
+        g_object_unref(tmp);
+    }
 }
 
 static void
@@ -1291,6 +1305,10 @@ extract_graph_curve(const SliceArgs *args,
     else
         gwy_graph_curve_model_set_data_from_dataline(gcmodel, line, 0, 0);
 
+    if (!gwy_graph_curve_model_is_ordered(gcmodel)) {
+        gwy_graph_curve_model_enforce_order(gcmodel);
+    }
+
     g_object_unref(line);
 }
 
@@ -1331,7 +1349,7 @@ extract_gmodel(const SliceArgs *args, GwyGraphModel *gmodel)
     calibration = gwy_brick_get_zcalibration(brick);
     if (base_plane == PLANE_XY || base_plane == PLANE_YX) {
         if (calibration)
-            xunit = gwy_data_line_get_si_unit_x(calibration);
+            xunit = gwy_data_line_get_si_unit_y(calibration);
         else
             xunit = gwy_brick_get_si_unit_z(brick);
     }
@@ -1353,30 +1371,6 @@ extract_gmodel(const SliceArgs *args, GwyGraphModel *gmodel)
     g_object_unref(yunit);
 }
 
-static void
-flip_xy(GwyDataField *dfield)
-{
-    GwyDataField *tmp;
-    gint xres, yres, i, j;
-    gdouble *dd;
-    const gdouble *sd;
-
-    xres = gwy_data_field_get_xres(dfield);
-    yres = gwy_data_field_get_yres(dfield);
-    tmp = gwy_data_field_duplicate(dfield);
-    gwy_data_field_resample(dfield, yres, xres, GWY_INTERPOLATION_NONE);
-    sd = gwy_data_field_get_data_const(tmp);
-    dd = gwy_data_field_get_data(dfield);
-    for (i = 0; i < xres; i++) {
-        for (j = 0; j < yres; j++) {
-            dd[i*yres + j] = sd[j*xres + i];
-        }
-    }
-    gwy_data_field_set_xreal(dfield, gwy_data_field_get_yreal(tmp));
-    gwy_data_field_set_yreal(dfield, gwy_data_field_get_xreal(tmp));
-    g_object_unref(tmp);
-}
-
 static const gchar base_plane_key[]  = "/module/volume_slice/base_plane";
 static const gchar multiselect_key[] = "/module/volume_slice/multiselect";
 static const gchar output_type_key[] = "/module/volume_slice/output_type";
