@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: volume_zcal.c 18626 2016-04-22 10:15:13Z yeti-dn $
+ *  @(#) $Id: volume_zcal.c 19948 2017-06-22 14:05:41Z yeti-dn $
  *  Copyright (C) 2015 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
@@ -108,7 +108,7 @@ static GwyModuleInfo module_info = {
     "2015",
 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, volume_zcal)
 
 static gboolean
 module_register(void)
