@@ -84,7 +84,7 @@ typedef struct {
     gdouble zdrift_b;
     gdouble zdrift_c;
     gint zdrift_average;
-  
+
     gboolean fit_xdrift;
     gboolean fit_ydrift;
     gboolean fit_zdrift;
@@ -95,8 +95,8 @@ typedef struct {
 
     gdouble threshold_time;
     gdouble threshold_length;
-    gdouble neighbors;   
-    gint iterations; 
+    gdouble neighbors;
+    gint iterations;
 
     /* Interface only. */
     gdouble xmin;
@@ -225,9 +225,9 @@ static void          threshold_changed      (XYZDriftControls *controls,
                                              GtkAdjustment *adj);
 static void          iterations_changed     (XYZDriftControls *controls,
                                              GtkAdjustment *adj);
-static void          zdrift_type_changed    (GtkWidget *combo, 
+static void          zdrift_type_changed    (GtkWidget *combo,
                                              XYZDriftControls *controls);
-static void          graph_changed          (GtkWidget *combo, 
+static void          graph_changed          (GtkWidget *combo,
                                              XYZDriftControls *controls);
 static void          reset_ranges           (XYZDriftControls *controls);
 static void          preview                (XYZDriftControls *controls);
@@ -244,12 +244,12 @@ static void          xyzdrift_load_args       (GwyContainer *container,
 static void          xyzdrift_save_args       (GwyContainer *container,
                                              XYZDriftArgs *args);
 
-static void          correct_drift          (GwyXYZ *points, 
-                                             gint npoints, 
-                                             gdouble *xdrift, 
-                                             gdouble *ydrift, 
+static void          correct_drift          (GwyXYZ *points,
+                                             gint npoints,
+                                             gdouble *xdrift,
+                                             gdouble *ydrift,
                                              gdouble *zdrift,
-                                             GwyXYZ *corpoints, 
+                                             GwyXYZ *corpoints,
                                              gboolean correctz);
 
 static const XYZDriftArgs xyzdrift_defaults = {
@@ -271,7 +271,7 @@ static GwyModuleInfo module_info = {
     "2016",
 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, xyz_drift)
 
 static gboolean
 module_register(void)
@@ -343,7 +343,7 @@ xyzdrift(GwyContainer *data, GwyRunType run)
        siunit = gwy_surface_get_si_unit_z(timesurface);
 
        if (gwy_si_unit_equal(siunit, siunits)
-           || gwy_strequal(title, "Timestamp")) {
+           || g_ascii_strcasecmp(title, "Timestamp") == 0) {
           rdata.timesurface = gwy_container_get_object(data, key);
           rdata.timepoints = rdata.timesurface->data;
           rdata.ntimepoints = rdata.timesurface->n;
@@ -364,7 +364,7 @@ xyzdrift(GwyContainer *data, GwyRunType run)
        gtk_widget_destroy (dialog);
        return;
     }
-    
+
 
     initialize_ranges(&rdata, &args);
 
@@ -396,7 +396,7 @@ xyzdrift(GwyContainer *data, GwyRunType run)
                      NULL);
 
         gcmodel = gwy_graph_curve_model_new();
-        gwy_graph_curve_model_set_data(gcmodel, rdata.time, rdata.xdrift, 
+        gwy_graph_curve_model_set_data(gcmodel, rdata.time, rdata.xdrift,
                                        rdata.npoints);
 
         g_object_set(gcmodel, "description", _("x-axis drift"), NULL);
@@ -415,7 +415,7 @@ xyzdrift(GwyContainer *data, GwyRunType run)
                      NULL);
 
         gcmodel = gwy_graph_curve_model_new();
-        gwy_graph_curve_model_set_data(gcmodel, rdata.time, rdata.ydrift, 
+        gwy_graph_curve_model_set_data(gcmodel, rdata.time, rdata.ydrift,
                                        rdata.npoints);
 
         g_object_set(gcmodel, "description", _("y-axis drift"), NULL);
@@ -434,7 +434,7 @@ xyzdrift(GwyContainer *data, GwyRunType run)
                      NULL);
 
         gcmodel = gwy_graph_curve_model_new();
-        gwy_graph_curve_model_set_data(gcmodel, rdata.time, rdata.zdrift, 
+        gwy_graph_curve_model_set_data(gcmodel, rdata.time, rdata.zdrift,
                                        rdata.npoints);
 
         g_object_set(gcmodel, "description", _("z-axis drift"), NULL);
@@ -735,7 +735,7 @@ construct_resolutions(XYZDriftControls *controls,
     gtk_label_set_mnemonic_widget(GTK_LABEL(label), spin);
     gtk_table_attach(table, spin, 1, 2, row, row+1,
                      GTK_EXPAND | GTK_FILL, 0, 0, 0);
-    label = gtk_label_new("px");
+    label = gtk_label_new(_("px"));
     gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
     gtk_table_attach(table, label, 2, 3, row, row+1,
                      GTK_EXPAND | GTK_FILL, 0, 0, 0);
@@ -750,7 +750,7 @@ construct_resolutions(XYZDriftControls *controls,
     gtk_label_set_mnemonic_widget(GTK_LABEL(label), spin);
     gtk_table_attach(table, spin, 1, 2, row, row+1,
                      GTK_EXPAND | GTK_FILL, 0, 0, 0);
-    label = gtk_label_new("px");
+    label = gtk_label_new(_("px"));
     gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
     gtk_table_attach(table, label, 2, 3, row, row+1,
                      GTK_EXPAND | GTK_FILL, 0, 0, 0);
@@ -834,7 +834,7 @@ construct_options(XYZDriftControls *controls,
     GwySurface *surface = controls->rdata->surface;
     GwySIValueFormat *vf;
 
- 
+
     GtkWidget *label, *spin, *button;
     static const GwyEnum zdrifts[] = {
         { N_("2nd order polynom"),  GWY_XYZDRIFT_ZMETHOD_POLYNOM,  },
@@ -1107,7 +1107,7 @@ construct_options(XYZDriftControls *controls,
                      G_CALLBACK(x_to_inits_cb), controls);
 
 
- 
+
     row++;
 
     label = gtk_label_new(_("Y drift:"));
@@ -1142,7 +1142,7 @@ construct_options(XYZDriftControls *controls,
                      G_CALLBACK(z_to_inits_cb), controls);
 
    gwy_si_unit_value_format_free(vf);
- 
+
 
     return row;
 }
@@ -1322,7 +1322,7 @@ zdrift_changed(XYZDriftControls *controls,
     //args->zdrift_average = gtk_adjustment_get_value(GTK_ADJUSTMENT(controls->zdrift_average));
 }
 
-static void          
+static void
 zdrift_type_changed(G_GNUC_UNUSED GtkWidget *combo, XYZDriftControls *controls)
 {
 
@@ -1380,7 +1380,7 @@ find_next_pos(double px, G_GNUC_UNUSED double ppx, double pv, double ppv, double
 
 
 
-static void          
+static void
 graph_changed(G_GNUC_UNUSED GtkWidget *combo, XYZDriftControls *controls)
 {
     GwyGraphCurveModel *gcmodel;
@@ -1528,7 +1528,7 @@ get_bining(GwyXYZ *points, gint npoints, gint ***bin, gint **nbin, gdouble xreal
 }
 
 static gint
-find_closest_point_bining(GwyXYZ *points, gdouble *time, gdouble tt, gdouble pt, gint index, gint ***bin, gint **nbin, 
+find_closest_point_bining(GwyXYZ *points, gdouble *time, gdouble tt, gdouble pt, gint index, gint ***bin, gint **nbin,
                           gdouble xreal, gdouble yreal, gdouble xoffset, gdouble yoffset)
 {
     gint bi, bj, i, j, k, bindex;
@@ -1552,16 +1552,16 @@ find_closest_point_bining(GwyXYZ *points, gdouble *time, gdouble tt, gdouble pt,
 
                      sdist = (points[index].x - points[bindex].x)*(points[index].x - points[bindex].x) +
                          (points[index].y - points[bindex].y)*(points[index].y - points[bindex].y);
-                      
+
     //                 printf("%d %d   %g %g    %g %g   %g\n", index, bindex, points[index].x, points[index].y, points[bindex].x, points[bindex].y, sdist);
- 
+
                      if (sdist<spt) {
                         if (sdist<mindist) {
                            mindist = sdist;
                             closest = bindex;
                         }
                      }
-                  }  
+                  }
             }
         }
     }
@@ -1570,7 +1570,7 @@ find_closest_point_bining(GwyXYZ *points, gdouble *time, gdouble tt, gdouble pt,
 }
 
 
-static gint 
+static gint
 find_neighbors(gint *nbfrom, gint *nbto, GwyXYZ *points, gdouble *time, gint npoints, gdouble timethreshold, gdouble posthreshold,
                gdouble xreal, gdouble yreal, gdouble xoffset, gdouble yoffset, gdouble neighbors, gdouble fraction)
 {
@@ -1629,7 +1629,7 @@ fit_func_to_curve(gdouble *xdata, gdouble *ydata, gint ndata, const gchar *name,
     guint i, n;
 
 
-   /* 
+   /*
     FILE *fw = fopen("fitdata.txt", "w");
     for (i=0; i<ndata; i++) {
         fprintf(fw, "%g %g\n", xdata[i], ydata[i]);
@@ -1744,7 +1744,7 @@ check_nbs_errors(GtkWidget *window, gint nnbs)
                                   GTK_BUTTONS_CLOSE,
                                   _("No neighbors found"));
         gtk_dialog_run (GTK_DIALOG (dialog));
-        gtk_widget_destroy (dialog); 
+        gtk_widget_destroy (dialog);
         return FALSE;
     }
 
@@ -1753,7 +1753,6 @@ check_nbs_errors(GtkWidget *window, gint nnbs)
     }
 
     return TRUE;
-
 }
 
 static gboolean
@@ -1768,13 +1767,13 @@ get_zdrift(XYZDriftControls *controls, GwyXYZ *points, GwyXYZ *corpoints, gint n
     gboolean fixed[3];
     gboolean ok=0;
 
-    gdouble timethreshold = controls->args->threshold_time; 
-    gdouble posthreshold = controls->args->threshold_length; 
+    gdouble timethreshold = controls->args->threshold_time;
+    gdouble posthreshold = controls->args->threshold_length;
 
     //FILE *fw = fopen("driftdata.txt", "w");
 
     //set drift arrays
-    set_drift(controls, npoints, time, xdrift, ydrift, zdrift, 
+    set_drift(controls, npoints, time, xdrift, ydrift, zdrift,
                     bx, cx, by, cy, *bz, *cz);
 
     //correct xy data (corpoints) for drift, don't correct z as this will be fitted
@@ -1783,24 +1782,24 @@ get_zdrift(XYZDriftControls *controls, GwyXYZ *points, GwyXYZ *corpoints, gint n
 
     //find neigbors for error evaluation
     nnbs = find_neighbors(nbfrom, nbto, corpoints, time, npoints, timethreshold, posthreshold,
-                          controls->args->xmax - controls->args->xmin, controls->args->ymax - controls->args->ymin, controls->args->xmin, controls->args->ymin, 
+                          controls->args->xmax - controls->args->xmin, controls->args->ymax - controls->args->ymin, controls->args->xmin, controls->args->ymin,
                           controls->args->neighbors, controls->fraction);
 
     if (!check_nbs_errors(controls->dialog, nnbs)) return FALSE;
-    
+
     dtime = g_new(gdouble, nnbs);
     drift = g_new(gdouble, nnbs);
 
     for (i=0; i<nnbs; i++) {
         dtime[i] = (time[nbfrom[i]]+time[nbto[i]])/2;
         drift[i] = (corpoints[nbto[i]].z - corpoints[nbfrom[i]].z)/(time[nbto[i]] - time[nbfrom[i]]);
-    }    
+    }
 
     if (controls->args->zdrift_type==GWY_XYZDRIFT_ZMETHOD_POLYNOM) {
         params[0] = *bz;
         params[1] = 2*(*cz);
         fixed[0] = 0;
-        fixed[1] = 0; 
+        fixed[1] = 0;
 
         ok = fit_func_to_curve(dtime, drift, nnbs, _("Polynomial (order 1)"), params, errors, fixed);
 
@@ -1813,7 +1812,7 @@ get_zdrift(XYZDriftControls *controls, GwyXYZ *points, GwyXYZ *corpoints, gint n
         params[1] = (*bz)/(*cz);
         params[2] = *cz;
         fixed[0] = 1;
-        fixed[1] = 0; 
+        fixed[1] = 0;
         fixed[2] = 0;
 
         ok = fit_func_to_curve(dtime, drift, nnbs, _("Exponential"), params, errors, fixed);
@@ -1824,7 +1823,7 @@ get_zdrift(XYZDriftControls *controls, GwyXYZ *points, GwyXYZ *corpoints, gint n
     }
 
     /*
-    printf("Fitting completed with %d: %g %g\n", ok, *bz, *cz);  
+    printf("Fitting completed with %d: %g %g\n", ok, *bz, *cz);
 
 
     for (i=0; i<nnbs; i++) {
@@ -1841,19 +1840,20 @@ get_zdrift(XYZDriftControls *controls, GwyXYZ *points, GwyXYZ *corpoints, gint n
 
     return ok;
 }
+
 static gdouble
 get_xydrift_error(XYZDriftControls *controls, GwyXYZ *points, GwyXYZ *corpoints, gint npoints, gdouble *time, gdouble *xdrift, gdouble *ydrift, gdouble *zdrift,
                   gdouble bx, gdouble cx, gdouble by, gdouble cy, gdouble bz, gdouble cz, gint *nbfrom, gint *nbto)
 {
     gint nnbs;
-    gdouble timethreshold = controls->args->threshold_time; 
-    gdouble posthreshold = controls->args->threshold_length; 
+    gdouble timethreshold = controls->args->threshold_time;
+    gdouble posthreshold = controls->args->threshold_length;
 
     if (!gwy_app_wait_set_fraction(controls->fraction)) return -1;
 
 
     //set drift arrays
-    set_drift(controls, npoints, time, xdrift, ydrift, zdrift, 
+    set_drift(controls, npoints, time, xdrift, ydrift, zdrift,
                      bx, cx, by, cy, bz, cz);
 
     //correct xyz data (corpoints) for drift
@@ -1862,7 +1862,7 @@ get_xydrift_error(XYZDriftControls *controls, GwyXYZ *points, GwyXYZ *corpoints,
 
     //find neigbors for error evaluation
     nnbs = find_neighbors(nbfrom, nbto, corpoints, time, npoints, timethreshold, posthreshold,
-                          controls->args->xmax - controls->args->xmin, controls->args->ymax - controls->args->ymin, controls->args->xmin, controls->args->ymin, 
+                          controls->args->xmax - controls->args->xmin, controls->args->ymax - controls->args->ymin, controls->args->xmin, controls->args->ymin,
                           controls->args->neighbors, controls->fraction);
 
     //printf("%d neighbors for parameter; %g %g\n", nnbs, timethreshold, posthreshold);
@@ -1906,13 +1906,13 @@ estimate_drift(XYZDriftControls *controls, GwyXYZ *points, GwyXYZ *corpoints, gi
     cdiff = controls->cdiff;
 
 //    bdiff = 1e-12; //gesi, poly
-//    cdiff = 1e-15;   
+//    cdiff = 1e-15;
 //    bdiff = 1e-8;  //gesi, exp
 //    cdiff = 500;
- 
+
 
 //    bdiff = 1e-8; //gen, poly
-//    cdiff = 1e-12;    
+//    cdiff = 1e-12;
 //    bdiff = 1e-5; //gen, exp
 //    cdiff = 100;
 
@@ -1938,7 +1938,7 @@ estimate_drift(XYZDriftControls *controls, GwyXYZ *points, GwyXYZ *corpoints, gi
            }
 
 
-           if (controls->args->fit_xdrift) 
+           if (controls->args->fit_xdrift)
            {
                //iterate through bx
                pbx = bx;
@@ -1948,8 +1948,8 @@ estimate_drift(XYZDriftControls *controls, GwyXYZ *points, GwyXYZ *corpoints, gi
                vpbx = get_xydrift_error(controls, points, corpoints, npoints, time, xdrift, ydrift, zdrift,
                       bx, cx, by, cy, bz, cz, nbfrom, nbto);
 
-               if (vpbx==-1) break; 
- 
+               if (vpbx==-1) break;
+
                diff = bdiff;
                mindiff = diff/100;
                bx = pbx+diff;
@@ -1979,12 +1979,12 @@ estimate_drift(XYZDriftControls *controls, GwyXYZ *points, GwyXYZ *corpoints, gi
 
                   intit++;
                } while (!done && intit<100);
-  
+
                sofar += 1;
                controls->fraction = sofar/total;
                if (!gwy_app_wait_set_fraction(controls->fraction)) break;
            }
-           if (controls->args->fit_xdrift) 
+           if (controls->args->fit_xdrift)
            {
                //iterate through cx
                pcx = cx;
@@ -1993,7 +1993,7 @@ estimate_drift(XYZDriftControls *controls, GwyXYZ *points, GwyXYZ *corpoints, gi
                vpcx = get_xydrift_error(controls, points, corpoints, npoints, time, xdrift, ydrift, zdrift,
                       bx, cx, by, cy, bz, cz, nbfrom, nbto);
 
-               if (vpcx==-1) break; 
+               if (vpcx==-1) break;
 
                diff = cdiff;
                mindiff = diff/100;
@@ -2025,12 +2025,12 @@ estimate_drift(XYZDriftControls *controls, GwyXYZ *points, GwyXYZ *corpoints, gi
                   intit++;
                } while (!done && intit<100);
                sofar += 1;
-              
+
                controls->fraction = sofar/total;
                if (!gwy_app_wait_set_fraction(controls->fraction)) break;
            }
 
-           if (controls->args->fit_ydrift) 
+           if (controls->args->fit_ydrift)
            {
                //iterate through by
                pby = by;
@@ -2040,7 +2040,7 @@ estimate_drift(XYZDriftControls *controls, GwyXYZ *points, GwyXYZ *corpoints, gi
                       bx, cx, by, cy, bz, cz, nbfrom, nbto);
 
                if (vpby==-1) break;
- 
+
                diff = bdiff;
                mindiff = bdiff/100;
                by = pby+diff;
@@ -2071,11 +2071,11 @@ estimate_drift(XYZDriftControls *controls, GwyXYZ *points, GwyXYZ *corpoints, gi
                   intit++;
                } while (!done && intit<100);
                sofar += 1;
-              
+
                controls->fraction = sofar/total;
                if (!gwy_app_wait_set_fraction(controls->fraction)) break;
            }
-           if (controls->args->fit_ydrift) 
+           if (controls->args->fit_ydrift)
            {
                //iterate through cy
                pcy = cy;
@@ -2083,7 +2083,7 @@ estimate_drift(XYZDriftControls *controls, GwyXYZ *points, GwyXYZ *corpoints, gi
 
                vpcy = get_xydrift_error(controls, points, corpoints, npoints, time, xdrift, ydrift, zdrift,
                       bx, cx, by, cy, bz, cz, nbfrom, nbto);
- 
+
                if (vpcy==-1) break;
 
                diff = cdiff;
@@ -2116,7 +2116,7 @@ estimate_drift(XYZDriftControls *controls, GwyXYZ *points, GwyXYZ *corpoints, gi
                   intit++;
                } while (!done && intit<100);
                sofar += 1;
-              
+
 
                controls->fraction = sofar/total;
                if (!gwy_app_wait_set_fraction(controls->fraction)) break;
@@ -2135,8 +2135,8 @@ estimate_drift(XYZDriftControls *controls, GwyXYZ *points, GwyXYZ *corpoints, gi
     rdata->zdrift_b_result = bz;
     rdata->zdrift_c_result = cz;
 
-    
-    /*printf("Resulting drifts: x %g %g    y %g %g    z %g %g\n", 
+
+    /*printf("Resulting drifts: x %g %g    y %g %g    z %g %g\n",
                               rdata->xdrift_b_result, rdata->xdrift_c_result,
                               rdata->ydrift_b_result, rdata->ydrift_c_result,
                               rdata->zdrift_b_result, rdata->zdrift_c_result
@@ -2146,8 +2146,6 @@ estimate_drift(XYZDriftControls *controls, GwyXYZ *points, GwyXYZ *corpoints, gi
 
     free(nbfrom);
     free(nbto);
-
-
 }
 
 
@@ -2159,7 +2157,7 @@ guess(XYZDriftControls *controls)
     XYZDriftData *rdata = controls->rdata;
 
     timespan = rdata->timepoints[rdata->npoints-1].z - rdata->timepoints[0].z;
-    xspan = args->xmax - args->xmin; 
+    xspan = args->xmax - args->xmin;
 
     controls->in_update = 1;
 
@@ -2175,7 +2173,7 @@ guess(XYZDriftControls *controls)
     controls->in_update = 0;
 
 }
- 
+
 
 static void
 preview(XYZDriftControls *controls)
@@ -2204,25 +2202,25 @@ preview(XYZDriftControls *controls)
     init_drift(controls, rdata->timepoints, rdata->npoints, rdata->time);
 
     /*estimate the drift using some fitting routine, returning filled xdrift, ydrift and zdrift arrays*/
-    if (args->fit_xdrift || args->fit_ydrift || args->fit_zdrift) 
+    if (args->fit_xdrift || args->fit_ydrift || args->fit_zdrift)
         estimate_drift(controls, rdata->points, rdata->corpoints, rdata->npoints, rdata->time,
                        rdata->xdrift, rdata->ydrift, rdata->zdrift);
 
     /*correct data for drift, creating corpoints from points*/
-    set_drift(controls, rdata->npoints, rdata->time, rdata->xdrift, rdata->ydrift, rdata->zdrift, 
-                    rdata->xdrift_b_result, rdata->xdrift_c_result, 
-                    rdata->ydrift_b_result, rdata->ydrift_c_result, 
+    set_drift(controls, rdata->npoints, rdata->time, rdata->xdrift, rdata->ydrift, rdata->zdrift,
+                    rdata->xdrift_b_result, rdata->xdrift_c_result,
+                    rdata->ydrift_b_result, rdata->ydrift_c_result,
                     rdata->zdrift_b_result, rdata->zdrift_c_result);
 
     correct_drift(rdata->points, rdata->npoints, rdata->xdrift, rdata->ydrift, rdata->zdrift,
                   rdata->corpoints, TRUE);
 
     g_snprintf(buffer, sizeof(buffer), "b = %g,  c = %g", rdata->xdrift_b_result, rdata->xdrift_c_result);
-    gtk_label_set_text(GTK_LABEL(controls->result_x), buffer); 
+    gtk_label_set_text(GTK_LABEL(controls->result_x), buffer);
     g_snprintf(buffer, sizeof(buffer), "b = %g,  c = %g", rdata->ydrift_b_result, rdata->ydrift_c_result);
-    gtk_label_set_text(GTK_LABEL(controls->result_y), buffer); 
+    gtk_label_set_text(GTK_LABEL(controls->result_y), buffer);
     g_snprintf(buffer, sizeof(buffer), "b = %g,  c = %g", rdata->zdrift_b_result, rdata->zdrift_c_result);
-    gtk_label_set_text(GTK_LABEL(controls->result_z), buffer); 
+    gtk_label_set_text(GTK_LABEL(controls->result_z), buffer);
 
 
     /*render preview*/
@@ -2249,9 +2247,6 @@ preview(XYZDriftControls *controls)
 
     gwy_container_set_object_by_name(controls->mydata, "/0/data", dfield);
     g_object_unref(dfield);
-
- 
-
 }
 
 
@@ -2343,26 +2338,25 @@ initialize_ranges(const XYZDriftData *rdata,
 }
 
 
-
-static const gchar xres_key[]          = "/module/xyz_drift/xres";
-static const gchar yres_key[]          = "/module/xyz_drift/yres";
-static const gchar xdrift_b_key[]          = "/module/xyz_drift/xdrift_b";
-static const gchar xdrift_c_key[]          = "/module/xyz_drift/xdrift_c";
-static const gchar ydrift_b_key[]          = "/module/xyz_drift/ydrift_b";
-static const gchar ydrift_c_key[]          = "/module/xyz_drift/ydrift_c";
-static const gchar zdrift_b_key[]          = "/module/xyz_drift/zdrift_b";
-static const gchar zdrift_c_key[]          = "/module/xyz_drift/zdrift_c";
-static const gchar fit_xdrift_key[]          = "/module/xyz_drift/fit_xdrift";
-static const gchar fit_ydrift_key[]          = "/module/xyz_drift/fit_ydrift";
-static const gchar fit_zdrift_key[]          = "/module/xyz_drift/fit_zdrift";
-static const gchar graph_type_key[]          = "/module/xyz_drift/graph_type";
-static const gchar threshold_time_key[]          = "/module/xyz_drift/threshold_time";
-static const gchar threshold_length_key[]          = "/module/xyz_drift/threshold_length";
-static const gchar neighbors_key[]          = "/module/xyz_drift/neighbors";
-static const gchar iterations_key[]          = "/module/xyz_drift/iterations";
-static const gchar xdrift_type_key[]          = "/module/xyz_drift/xdrift_type_key";
-static const gchar ydrift_type_key[]          = "/module/xyz_drift/ydrift_type_key";
-static const gchar zdrift_type_key[]          = "/module/xyz_drift/zdrift_type_key";
+static const gchar xres_key[]             = "/module/xyz_drift/xres";
+static const gchar yres_key[]             = "/module/xyz_drift/yres";
+static const gchar xdrift_b_key[]         = "/module/xyz_drift/xdrift_b";
+static const gchar xdrift_c_key[]         = "/module/xyz_drift/xdrift_c";
+static const gchar ydrift_b_key[]         = "/module/xyz_drift/ydrift_b";
+static const gchar ydrift_c_key[]         = "/module/xyz_drift/ydrift_c";
+static const gchar zdrift_b_key[]         = "/module/xyz_drift/zdrift_b";
+static const gchar zdrift_c_key[]         = "/module/xyz_drift/zdrift_c";
+static const gchar fit_xdrift_key[]       = "/module/xyz_drift/fit_xdrift";
+static const gchar fit_ydrift_key[]       = "/module/xyz_drift/fit_ydrift";
+static const gchar fit_zdrift_key[]       = "/module/xyz_drift/fit_zdrift";
+static const gchar graph_type_key[]       = "/module/xyz_drift/graph_type";
+static const gchar threshold_time_key[]   = "/module/xyz_drift/threshold_time";
+static const gchar threshold_length_key[] = "/module/xyz_drift/threshold_length";
+static const gchar neighbors_key[]        = "/module/xyz_drift/neighbors";
+static const gchar iterations_key[]       = "/module/xyz_drift/iterations";
+static const gchar xdrift_type_key[]      = "/module/xyz_drift/xdrift_type_key";
+static const gchar ydrift_type_key[]      = "/module/xyz_drift/ydrift_type_key";
+static const gchar zdrift_type_key[]      = "/module/xyz_drift/zdrift_type_key";
 
 static void
 xyzdrift_sanitize_args(XYZDriftArgs *args)
@@ -2376,7 +2370,7 @@ xyzdrift_sanitize_args(XYZDriftArgs *args)
     args->ydrift_type = MIN(args->ydrift_type, GWY_XYZDRIFT_METHOD_EXPONENTIAL);
     args->zdrift_type = MIN(args->zdrift_type, GWY_XYZDRIFT_ZMETHOD_AVERAGE);
     args->graph_type = MIN(args->graph_type, GWY_XYZDRIFT_GRAPH_Z);
- 
+
     args->xres = CLAMP(args->xres, 2, 16384);
     args->yres = CLAMP(args->yres, 2, 16384);
 
@@ -2440,8 +2434,6 @@ xyzdrift_save_args(GwyContainer *container,
 
 }
 
-
-
            /* //automatic estimation of start difference, skip for now
 
            vbx = get_xydrift_error(controls, points, corpoints, npoints, time, xdrift, ydrift, zdrift,
@@ -2461,8 +2453,6 @@ xyzdrift_save_args(GwyContainer *container,
            printf("diff found: %g\n", mindiff);
 
            */
- 
-
 
 
 /* vim: set cin et ts=4 sw=4 cino=>1s,e0,n0,f0,{0,}0,^0,\:1s,=0,g1s,h0,t0,+1s,c3,(0,u0 : */
