@@ -1,5 +1,5 @@
 /*
- *  $Id: xyz_level.c 19013 2016-09-29 07:56:27Z yeti-dn $
+ *  $Id: xyz_level.c 19948 2017-06-22 14:05:41Z yeti-dn $
  *  Copyright (C) 2016 David Necas (Yeti).
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -97,7 +97,7 @@ static GwyModuleInfo module_info = {
     "2016",
 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, xyz_level)
 
 static gboolean
 module_register(void)
