@@ -1,5 +1,5 @@
 /*
- *  $Id: xyz_raster.c 18606 2016-04-14 12:41:22Z yeti-dn $
+ *  $Id: xyz_raster.c 19948 2017-06-22 14:05:41Z yeti-dn $
  *  Copyright (C) 2016 David Necas (Yeti).
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -114,75 +114,72 @@ typedef struct {
     guint size;
 } WorkQueue;
 
-static gboolean      module_register        (void);
-static void          xyzras                 (GwyContainer *data,
-                                             GwyRunType run);
-static gboolean      xyzras_dialog          (XYZRasArgs *arg,
-                                             XYZRasData *rdata,
-                                             GwyContainer *data,
-                                             gint id);
-static void          add_dfield_to_data     (GwyDataField *dfield,
-                                             GwyContainer *data,
-                                             gint id);
-static gint          construct_resolutions  (XYZRasControls *controls,
-                                             GtkTable *table,
-                                             gint row);
-static gint          construct_physical_dims(XYZRasControls *controls,
-                                             GtkTable *table,
-                                             gint row);
-static gint          construct_options      (XYZRasControls *controls,
-                                             GtkTable *table,
-                                             gint row);
-static void          make_pixels_square     (XYZRasControls *controls);
-static void          xres_changed           (XYZRasControls *controls,
-                                             GtkAdjustment *adj);
-static void          yres_changed           (XYZRasControls *controls,
-                                             GtkAdjustment *adj);
-static void          xmin_changed           (XYZRasControls *controls,
-                                             GtkEntry *entry);
-static void          xmax_changed           (XYZRasControls *controls,
-                                             GtkEntry *entry);
-static void          ymin_changed           (XYZRasControls *controls,
-                                             GtkEntry *entry);
-static void          ymax_changed           (XYZRasControls *controls,
-                                             GtkEntry *entry);
-static void          interpolation_changed  (XYZRasControls *controls,
-                                             GtkComboBox *combo);
-static void          exterior_changed       (XYZRasControls *controls,
-                                             GtkComboBox *combo);
-static void          reset_ranges           (XYZRasControls *controls);
-static void          update_selection       (XYZRasControls *controls);
-static void          selection_changed      (XYZRasControls *controls,
-                                             gint hint,
-                                             GwySelection *selection);
-static void          clear_selection        (XYZRasControls *controls);
-static void          preview                (XYZRasControls *controls);
-static void          triangulation_info     (XYZRasControls *controls);
-static void          render_regular_directly(XYZRasControls *controls);
-static GwyDataField* xyzras_do              (XYZRasData *rdata,
-                                             const XYZRasArgs *args,
-                                             GtkWindow *dialog,
-                                             gchar **error);
-static gboolean      interpolate_field      (guint npoints,
-                                             const GwyXYZ *points,
-                                             GwyDataField *dfield,
-                                             GwySetFractionFunc set_fraction,
-                                             GwySetMessageFunc set_message);
-static gboolean      extend_borders         (XYZRasData *rdata,
-                                             const XYZRasArgs *args,
-                                             gboolean check_for_changes,
-                                             gdouble epsrel);
-static void          xyzras_free            (XYZRasData *rdata);
-static void          initialize_ranges      (const XYZRasData *rdata,
-                                             XYZRasArgs *args);
-static void          invalidate_raster      (XYZRasData *rdata);
-static void          analyse_points         (XYZRasData *rdata,
-                                             double epsrel);
-static GwyDataField* check_regular_grid     (GwySurface *surface);
-static void          xyzras_load_args       (GwyContainer *container,
-                                             XYZRasArgs *args);
-static void          xyzras_save_args       (GwyContainer *container,
-                                             XYZRasArgs *args);
+static gboolean      module_register          (void);
+static void          xyzras                   (GwyContainer *data,
+                                               GwyRunType run);
+static gboolean      xyzras_dialog            (XYZRasArgs *arg,
+                                               XYZRasData *rdata,
+                                               GwyContainer *data,
+                                               gint id);
+static void          add_dfield_to_data       (GwyDataField *dfield,
+                                               GwyContainer *data,
+                                               gint id);
+static gint          construct_physical_dims  (XYZRasControls *controls,
+                                               GtkTable *table,
+                                               gint row);
+static gint          construct_options        (XYZRasControls *controls,
+                                               GtkTable *table,
+                                               gint row);
+static void          make_pixels_square       (XYZRasControls *controls);
+static void          xres_changed             (XYZRasControls *controls,
+                                               GtkAdjustment *adj);
+static void          yres_changed             (XYZRasControls *controls,
+                                               GtkAdjustment *adj);
+static void          xmin_changed             (XYZRasControls *controls,
+                                               GtkEntry *entry);
+static void          xmax_changed             (XYZRasControls *controls,
+                                               GtkEntry *entry);
+static void          ymin_changed             (XYZRasControls *controls,
+                                               GtkEntry *entry);
+static void          ymax_changed             (XYZRasControls *controls,
+                                               GtkEntry *entry);
+static void          interpolation_changed    (XYZRasControls *controls,
+                                               GtkComboBox *combo);
+static void          exterior_changed         (XYZRasControls *controls,
+                                               GtkComboBox *combo);
+static void          reset_ranges             (XYZRasControls *controls);
+static void          update_selection         (XYZRasControls *controls);
+static void          selection_changed        (XYZRasControls *controls,
+                                               gint hint,
+                                               GwySelection *selection);
+static void          clear_selection          (XYZRasControls *controls);
+static void          preview                  (XYZRasControls *controls);
+static void          triangulation_info       (XYZRasControls *controls);
+static void          render_regular_directly  (XYZRasControls *controls);
+static GwyDataField* xyzras_do                (XYZRasData *rdata,
+                                               const XYZRasArgs *args,
+                                               GtkWindow *dialog,
+                                               gchar **error);
+static gboolean      interpolate_field        (guint npoints,
+                                               const GwyXYZ *points,
+                                               GwyDataField *dfield,
+                                               GwySetFractionFunc set_fraction,
+                                               GwySetMessageFunc set_message);
+static gboolean      extend_borders           (XYZRasData *rdata,
+                                               const XYZRasArgs *args,
+                                               gboolean check_for_changes,
+                                               gdouble epsrel);
+static void          xyzras_free              (XYZRasData *rdata);
+static void          initialize_ranges        (const XYZRasData *rdata,
+                                               XYZRasArgs *args);
+static void          invalidate_raster        (XYZRasData *rdata);
+static void          analyse_points           (XYZRasData *rdata,
+                                               double epsrel);
+static GwyDataField* check_regular_grid       (GwySurface *surface);
+static void          xyzras_load_args         (GwyContainer *container,
+                                               XYZRasArgs *args);
+static void          xyzras_save_args         (GwyContainer *container,
+                                               XYZRasArgs *args);
 
 static const XYZRasArgs xyzras_defaults = {
     GWY_INTERPOLATION_LINEAR, GWY_EXTERIOR_MIRROR_EXTEND,
@@ -196,12 +193,12 @@ static GwyModuleInfo module_info = {
     &module_register,
     N_("Rasterizes XYZ data to images."),
     "Yeti <yeti@gwyddion.net>",
-    "1.0",
+    "1.1",
     "David Nečas (Yeti)",
     "2016",
 };
 
-GWY_MODULE_QUERY(module_info)
+GWY_MODULE_QUERY2(module_info, xyz_raster)
 
 static gboolean
 module_register(void)
@@ -318,7 +315,7 @@ xyzras_dialog(XYZRasArgs *args,
               GwyContainer *data,
               gint id)
 {
-    GtkWidget *dialog, *vbox, *align, *label, *hbox, *button;
+    GtkWidget *dialog, *vbox, *label, *hbox, *button;
     GwyPixmapLayer *player;
     GwyVectorLayer *vlayer;
     GwyDataField *dfield;
@@ -367,35 +364,52 @@ xyzras_dialog(XYZRasArgs *args,
     gtk_box_pack_start(GTK_BOX(GTK_DIALOG(dialog)->vbox), hbox, TRUE, TRUE, 0);
 
     /* Left column */
-    align = gtk_alignment_new(0.0, 0.0, 0.0, 0.0);
-    gtk_box_pack_start(GTK_BOX(hbox), align, FALSE, FALSE, 0);
+    vbox = gtk_vbox_new(FALSE, 8);
+    gtk_box_pack_start(GTK_BOX(hbox), vbox, FALSE, FALSE, 0);
 
-    table = GTK_TABLE(gtk_table_new(10, 5, FALSE));
+    table = GTK_TABLE(gtk_table_new(4, 5, FALSE));
     gtk_table_set_row_spacings(table, 2);
     gtk_table_set_col_spacings(table, 6);
-    gtk_container_add(GTK_CONTAINER(align), GTK_WIDGET(table));
+    gtk_box_pack_start(GTK_BOX(vbox), GTK_WIDGET(table), FALSE, FALSE, 0);
     row = 0;
 
-    row = construct_resolutions(&controls, table, row);
+    gtk_table_attach(table, gwy_label_new_header(_("Resolution")),
+                     0, 4, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
+    row++;
+
+    controls.xres = gtk_adjustment_new(args->xres, 2, 16384, 1, 100, 0);
+    gwy_table_attach_adjbar(GTK_WIDGET(table), row,
+                            _("_Horizontal size:"), _("px"),
+                            controls.xres, GWY_HSCALE_LOG | GWY_HSCALE_SNAP);
+    row++;
+
+    controls.yres = gtk_adjustment_new(args->yres, 2, 16384, 1, 100, 0);
+    gwy_table_attach_adjbar(GTK_WIDGET(table), row,
+                            _("_Vertical size:"), _("px"),
+                            controls.yres, GWY_HSCALE_LOG | GWY_HSCALE_SNAP);
+    row++;
 
     button = gtk_button_new_with_mnemonic(_("Make Pixels S_quare"));
-    gtk_table_attach(table, button, 1, 4, row, row+1,
-                     GTK_FILL, 0, 0, 0);
+    gtk_table_attach(table, button, 0, 2, row, row+1, GTK_FILL, 0, 0, 0);
     g_signal_connect_swapped(button, "clicked",
                              G_CALLBACK(make_pixels_square), &controls);
-    gtk_table_set_row_spacing(table, row, 8);
     row++;
 
+    table = GTK_TABLE(gtk_table_new(7, 5, FALSE));
+    gtk_table_set_row_spacings(table, 2);
+    gtk_table_set_col_spacings(table, 6);
+    gtk_box_pack_start(GTK_BOX(vbox), GTK_WIDGET(table), FALSE, FALSE, 0);
+    row = 0;
+
     row = construct_physical_dims(&controls, table, row);
 
     button = gtk_button_new_with_mnemonic(_("Reset Ran_ges"));
-    gtk_table_attach(table, button, 1, 4, row, row+1,
-                     GTK_FILL, 0, 0, 0);
+    gtk_table_attach(table, button, 0, 4, row, row+1, GTK_FILL, 0, 0, 0);
     g_signal_connect_swapped(button, "clicked",
                              G_CALLBACK(reset_ranges), &controls);
-    gtk_table_set_row_spacing(table, row, 8);
     row++;
 
+    gtk_table_set_row_spacing(table, row-1, 8);
     row = construct_options(&controls, table, row);
 
     /* Right column */
@@ -506,51 +520,6 @@ xyzras_dialog(XYZRasArgs *args,
     return TRUE;
 }
 
-static gint
-construct_resolutions(XYZRasControls *controls,
-                      GtkTable *table,
-                      gint row)
-{
-    XYZRasArgs *args = controls->args;
-    GtkWidget *spin, *label;
-
-    gtk_table_attach(table, gwy_label_new_header(_("Resolution")),
-                     0, 4, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
-    row++;
-
-    label = gtk_label_new_with_mnemonic(_("_Horizontal size:"));
-    gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
-    gtk_table_attach(table, label, 0, 1, row, row+1,
-                     GTK_EXPAND | GTK_FILL, 0, 0, 0);
-    controls->xres = gtk_adjustment_new(args->xres, 2, 16384, 1, 100, 0);
-    spin = gtk_spin_button_new(GTK_ADJUSTMENT(controls->xres), 0, 0);
-    gtk_label_set_mnemonic_widget(GTK_LABEL(label), spin);
-    gtk_table_attach(table, spin, 1, 2, row, row+1,
-                     GTK_EXPAND | GTK_FILL, 0, 0, 0);
-    label = gtk_label_new("px");
-    gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
-    gtk_table_attach(table, label, 2, 3, row, row+1,
-                     GTK_EXPAND | GTK_FILL, 0, 0, 0);
-    row++;
-
-    label = gtk_label_new_with_mnemonic(_("_Vertical size:"));
-    gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
-    gtk_table_attach(table, label, 0, 1, row, row+1,
-                     GTK_EXPAND | GTK_FILL, 0, 0, 0);
-    controls->yres = gtk_adjustment_new(args->yres, 2, 16384, 1, 100, 0);
-    spin = gtk_spin_button_new(GTK_ADJUSTMENT(controls->yres), 0, 0);
-    gtk_label_set_mnemonic_widget(GTK_LABEL(label), spin);
-    gtk_table_attach(table, spin, 1, 2, row, row+1,
-                     GTK_EXPAND | GTK_FILL, 0, 0, 0);
-    label = gtk_label_new("px");
-    gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
-    gtk_table_attach(table, label, 2, 3, row, row+1,
-                     GTK_EXPAND | GTK_FILL, 0, 0, 0);
-    row++;
-
-    return row;
-}
-
 static gint
 construct_physical_dims(XYZRasControls *controls,
                         GtkTable *table,
@@ -1050,13 +1019,18 @@ xyzras_do(XYZRasData *rdata,
             gwy_debug("must triangulate");
             if (!triangulation)
                 rdata->triangulation = triangulation = gwy_triangulation_new();
+            /* This can fail for two different reasons:
+             * 1) numerical failure
+             * 2) cancellation
+             * In the second case we do not want another attempt at the
+             * triangulation and should stop immediately. */
             ok = gwy_triangulation_triangulate_iterative(triangulation,
                                                          points->len,
                                                          points->data,
                                                          sizeof(GwyXYZ),
                                                          set_fraction,
                                                          set_message);
-            if (!ok) {
+            if (!ok && !gwy_app_wait_was_canceled()) {
                 /* Try again with a small jitter.  The jitter is small
                  * compared to pixel size, not typical point distance, so
                  * it should be insubstantial in the raster image. */
@@ -1638,91 +1612,26 @@ analyse_points(XYZRasData *rdata,
 static GwyDataField*
 check_regular_grid(GwySurface *surface)
 {
-    gdouble ymaxstep, xmin, xmax, ymin, ymax, dx, dy;
+    GwyXY xymin, dxy;
     guint n, xres, yres, k;
     GwyDataField *dfield;
-    gdouble *yvalues, *data;
-    gboolean *encountered;
-    gboolean ok = TRUE;
+    gdouble *data;
+    guint *map;
 
     n = surface->n;
-    if (n < 4)
+    if (!(map = gwy_check_regular_2d_grid((const gdouble*)surface->data, 3, n,
+                                          -1.0, &xres, &yres, &xymin, &dxy)))
         return NULL;
 
-    /* Do not create Nx1 or 1xN fields. */
-    gwy_surface_get_xrange(surface, &xmin, &xmax);
-    gwy_surface_get_yrange(surface, &ymin, &ymax);
-    if (xmin == xmax || ymin == ymax)
-        return NULL;
-
-    yvalues = g_new(gdouble, n);
-    for (k = 0; k < n; k++)
-        yvalues[k] = surface->data[k].y;
-    gwy_math_sort(n, yvalues);
-
-    ymaxstep = 0.0;
-    for (k = 1; k < n; k++) {
-        if (yvalues[k] - yvalues[k-1] > ymaxstep)
-            ymaxstep = yvalues[k] - yvalues[k-1];
-    }
-    gwy_debug("ymaxstep %g", ymaxstep);
-    yres = (gint)ceil((ymax - ymin)/ymaxstep) + 1;
-    gwy_debug("estimated yres %d", yres);
-    g_free(yvalues);
-
-    if (n % yres != 0)
-        return NULL;
-
-    xres = n/yres;
-    gwy_debug("yres %d", xres);
-    dx = (xmax - xmin)/(xres - 1);
-    dy = (ymax - ymin)/(yres - 1);
-    xmin -= 0.5*dx;
-    xmax += 0.5*dx;
-    ymin -= 0.5*dy;
-    ymax += 0.5*dy;
-
-    dfield = gwy_data_field_new(xres, yres, xmax - xmin, ymax - ymin, FALSE);
+    dfield = gwy_data_field_new(xres, yres, xres*dxy.x, yres*dxy.y, FALSE);
     data = gwy_data_field_get_data(dfield);
-    encountered = g_new0(gboolean, n);
-    for (k = 0; k < n; k++) {
-        gdouble y = (surface->data[k].y - ymin)/dy;
-        gdouble x = (surface->data[k].x - xmin)/dx;
-        gint i = (gint)floor(y);
-        gint j = (gint)floor(x);
+    for (k = 0; k < n; k++)
+        data[k] = surface->data[map[k]].z;
+    g_free(map);
 
-        if (fabs(x - j - 0.5) > 0.01) {
-            gwy_debug("point (%d,%d) too far in x %g", j, i, x - j - 0.5);
-            ok = FALSE;
-            break;
-        }
-        if (fabs(y - i - 0.5) > 0.01) {
-            gwy_debug("point (%d,%d) too far in y %g", j, i, y - i - 0.5);
-            ok = FALSE;
-            break;
-        }
-        if (encountered[i*xres + j]) {
-            gwy_debug("point (%d,%d) encountered twice", j, i);
-            ok = FALSE;
-            break;
-        }
-
-        encountered[i*xres + j] = TRUE;
-        data[i*xres + j] = surface->data[k].z;
-    }
-
-    g_free(encountered);
-    if (!ok) {
-        g_object_unref(dfield);
-        return NULL;
-    }
-
-    gwy_data_field_set_xoffset(dfield, xmin);
-    gwy_data_field_set_yoffset(dfield, ymin);
-    gwy_serializable_clone(G_OBJECT(gwy_surface_get_si_unit_xy(surface)),
-                           G_OBJECT(gwy_data_field_get_si_unit_xy(dfield)));
-    gwy_serializable_clone(G_OBJECT(gwy_surface_get_si_unit_z(surface)),
-                           G_OBJECT(gwy_data_field_get_si_unit_z(dfield)));
+    gwy_data_field_set_xoffset(dfield, xymin.x);
+    gwy_data_field_set_yoffset(dfield, xymin.y);
+    gwy_surface_copy_units_to_data_field(surface, dfield);
     return dfield;
 }
 
